---
hide:
  - toc
---

# Security Overview

<link href="https://truecharts.org/_static/trivy.css" type="text/css" rel="stylesheet" />

## Helm-Chart

##### Scan Results

#### Chart Object: cloud9/templates/common.yaml
    

      
| Type         |    Misconfiguration ID   |   Check  |  Severity |                   Explaination                   | Links  |
|:----------------|:------------------:|:-----------:|:------------------:|-----------------------------------------|-----------------------------------------|
| Kubernetes Security Check         |    KSV003   |   Default capabilities not dropped  |  LOW | <details><summary>Expand...</summary> The container should drop all default capabilities and add only those that are needed for its execution. <br> <hr> <br> Container &#39;RELEASE-NAME-cloud9&#39; of Deployment &#39;RELEASE-NAME-cloud9&#39; should add &#39;ALL&#39; to &#39;securityContext.capabilities.drop&#39; </details>| <details><summary>Expand...</summary><a href="https://kubesec.io/basics/containers-securitycontext-capabilities-drop-index-all/">https://kubesec.io/basics/containers-securitycontext-capabilities-drop-index-all/</a><br><a href="https://avd.aquasec.com/appshield/ksv003">https://avd.aquasec.com/appshield/ksv003</a><br></details>  |
| Kubernetes Security Check         |    KSV012   |   Runs as root user  |  MEDIUM | <details><summary>Expand...</summary> &#39;runAsNonRoot&#39; forces the running image to run as a non-root user to ensure least privileges. <br> <hr> <br> Container &#39;RELEASE-NAME-cloud9&#39; of Deployment &#39;RELEASE-NAME-cloud9&#39; should set &#39;securityContext.runAsNonRoot&#39; to true </details>| <details><summary>Expand...</summary><a href="https://kubernetes.io/docs/concepts/security/pod-security-standards/#restricted">https://kubernetes.io/docs/concepts/security/pod-security-standards/#restricted</a><br><a href="https://avd.aquasec.com/appshield/ksv012">https://avd.aquasec.com/appshield/ksv012</a><br></details>  |
| Kubernetes Security Check         |    KSV012   |   Runs as root user  |  MEDIUM | <details><summary>Expand...</summary> &#39;runAsNonRoot&#39; forces the running image to run as a non-root user to ensure least privileges. <br> <hr> <br> Container &#39;autopermissions&#39; of Deployment &#39;RELEASE-NAME-cloud9&#39; should set &#39;securityContext.runAsNonRoot&#39; to true </details>| <details><summary>Expand...</summary><a href="https://kubernetes.io/docs/concepts/security/pod-security-standards/#restricted">https://kubernetes.io/docs/concepts/security/pod-security-standards/#restricted</a><br><a href="https://avd.aquasec.com/appshield/ksv012">https://avd.aquasec.com/appshield/ksv012</a><br></details>  |
| Kubernetes Security Check         |    KSV014   |   Root file system is not read-only  |  LOW | <details><summary>Expand...</summary> An immutable root file system prevents applications from writing to their local disk. This can limit intrusions, as attackers will not be able to tamper with the file system or write foreign executables to disk. <br> <hr> <br> Container &#39;RELEASE-NAME-cloud9&#39; of Deployment &#39;RELEASE-NAME-cloud9&#39; should set &#39;securityContext.readOnlyRootFilesystem&#39; to true </details>| <details><summary>Expand...</summary><a href="https://kubesec.io/basics/containers-securitycontext-readonlyrootfilesystem-true/">https://kubesec.io/basics/containers-securitycontext-readonlyrootfilesystem-true/</a><br><a href="https://avd.aquasec.com/appshield/ksv014">https://avd.aquasec.com/appshield/ksv014</a><br></details>  |
| Kubernetes Security Check         |    KSV014   |   Root file system is not read-only  |  LOW | <details><summary>Expand...</summary> An immutable root file system prevents applications from writing to their local disk. This can limit intrusions, as attackers will not be able to tamper with the file system or write foreign executables to disk. <br> <hr> <br> Container &#39;autopermissions&#39; of Deployment &#39;RELEASE-NAME-cloud9&#39; should set &#39;securityContext.readOnlyRootFilesystem&#39; to true </details>| <details><summary>Expand...</summary><a href="https://kubesec.io/basics/containers-securitycontext-readonlyrootfilesystem-true/">https://kubesec.io/basics/containers-securitycontext-readonlyrootfilesystem-true/</a><br><a href="https://avd.aquasec.com/appshield/ksv014">https://avd.aquasec.com/appshield/ksv014</a><br></details>  |
| Kubernetes Security Check         |    KSV020   |   Runs with low user ID  |  MEDIUM | <details><summary>Expand...</summary> Force the container to run with user ID &gt; 10000 to avoid conflicts with the host’s user table. <br> <hr> <br> Container &#39;RELEASE-NAME-cloud9&#39; of Deployment &#39;RELEASE-NAME-cloud9&#39; should set &#39;securityContext.runAsUser&#39; &gt; 10000 </details>| <details><summary>Expand...</summary><a href="https://kubesec.io/basics/containers-securitycontext-runasuser/">https://kubesec.io/basics/containers-securitycontext-runasuser/</a><br><a href="https://avd.aquasec.com/appshield/ksv020">https://avd.aquasec.com/appshield/ksv020</a><br></details>  |
| Kubernetes Security Check         |    KSV020   |   Runs with low user ID  |  MEDIUM | <details><summary>Expand...</summary> Force the container to run with user ID &gt; 10000 to avoid conflicts with the host’s user table. <br> <hr> <br> Container &#39;autopermissions&#39; of Deployment &#39;RELEASE-NAME-cloud9&#39; should set &#39;securityContext.runAsUser&#39; &gt; 10000 </details>| <details><summary>Expand...</summary><a href="https://kubesec.io/basics/containers-securitycontext-runasuser/">https://kubesec.io/basics/containers-securitycontext-runasuser/</a><br><a href="https://avd.aquasec.com/appshield/ksv020">https://avd.aquasec.com/appshield/ksv020</a><br></details>  |
| Kubernetes Security Check         |    KSV021   |   Runs with low group ID  |  MEDIUM | <details><summary>Expand...</summary> Force the container to run with group ID &gt; 10000 to avoid conflicts with the host’s user table. <br> <hr> <br> Container &#39;RELEASE-NAME-cloud9&#39; of Deployment &#39;RELEASE-NAME-cloud9&#39; should set &#39;securityContext.runAsGroup&#39; &gt; 10000 </details>| <details><summary>Expand...</summary><a href="https://kubesec.io/basics/containers-securitycontext-runasuser/">https://kubesec.io/basics/containers-securitycontext-runasuser/</a><br><a href="https://avd.aquasec.com/appshield/ksv021">https://avd.aquasec.com/appshield/ksv021</a><br></details>  |
| Kubernetes Security Check         |    KSV021   |   Runs with low group ID  |  MEDIUM | <details><summary>Expand...</summary> Force the container to run with group ID &gt; 10000 to avoid conflicts with the host’s user table. <br> <hr> <br> Container &#39;autopermissions&#39; of Deployment &#39;RELEASE-NAME-cloud9&#39; should set &#39;securityContext.runAsGroup&#39; &gt; 10000 </details>| <details><summary>Expand...</summary><a href="https://kubesec.io/basics/containers-securitycontext-runasuser/">https://kubesec.io/basics/containers-securitycontext-runasuser/</a><br><a href="https://avd.aquasec.com/appshield/ksv021">https://avd.aquasec.com/appshield/ksv021</a><br></details>  |
| Kubernetes Security Check         |    KSV029   |   A root primary or supplementary GID set  |  LOW | <details><summary>Expand...</summary> Containers should be forbidden from running with a root primary or supplementary GID. <br> <hr> <br> Deployment &#39;RELEASE-NAME-cloud9&#39; should set &#39;spec.securityContext.runAsGroup&#39;, &#39;spec.securityContext.supplementalGroups[*]&#39; and &#39;spec.securityContext.fsGroup&#39; to integer greater than 0 </details>| <details><summary>Expand...</summary><a href="https://kubernetes.io/docs/concepts/security/pod-security-standards/#restricted">https://kubernetes.io/docs/concepts/security/pod-security-standards/#restricted</a><br><a href="https://avd.aquasec.com/appshield/ksv029">https://avd.aquasec.com/appshield/ksv029</a><br></details>  |

## Containers

##### Detected Containers

          tccr.io/truecharts/alpine:v3.14.2@sha256:4095394abbae907e94b1f2fd2e2de6c4f201a5b9704573243ca8eb16db8cdb7c
          tccr.io/truecharts/cloud9:version-1.29.2@sha256:4891fa151fe52c43719f0346124f29c81ed47be16cdc34554b8896b0cb80cb73

##### Scan Results


#### Container: tccr.io/truecharts/alpine:v3.14.2@sha256:4095394abbae907e94b1f2fd2e2de6c4f201a5b9704573243ca8eb16db8cdb7c (alpine 3.14.2)
    

**alpine**

      
| Package         |    Vulnerability   |   Severity  |  Installed Version | Fixed Version |                   Links                   |
|:----------------|:------------------:|:-----------:|:------------------:|:-------------:|-----------------------------------------|
| busybox         |    CVE-2021-42378   |   HIGH  |  1.33.1-r3 | 1.33.1-r6 | <details><summary>Expand...</summary><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2021-42378">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2021-42378</a><br><a href="https://jfrog.com/blog/unboxing-busybox-14-new-vulnerabilities-uncovered-by-claroty-and-jfrog/">https://jfrog.com/blog/unboxing-busybox-14-new-vulnerabilities-uncovered-by-claroty-and-jfrog/</a><br><a href="https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/6T2TURBYYJGBMQTTN2DSOAIQGP7WCPGV/">https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/6T2TURBYYJGBMQTTN2DSOAIQGP7WCPGV/</a><br><a href="https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/UQXGOGWBIYWOIVXJVRKHZR34UMEHQBXS/">https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/UQXGOGWBIYWOIVXJVRKHZR34UMEHQBXS/</a><br><a href="https://ubuntu.com/security/notices/USN-5179-1">https://ubuntu.com/security/notices/USN-5179-1</a><br></details>  |
| busybox         |    CVE-2021-42379   |   HIGH  |  1.33.1-r3 | 1.33.1-r6 | <details><summary>Expand...</summary><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2021-42379">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2021-42379</a><br><a href="https://jfrog.com/blog/unboxing-busybox-14-new-vulnerabilities-uncovered-by-claroty-and-jfrog/">https://jfrog.com/blog/unboxing-busybox-14-new-vulnerabilities-uncovered-by-claroty-and-jfrog/</a><br><a href="https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/6T2TURBYYJGBMQTTN2DSOAIQGP7WCPGV/">https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/6T2TURBYYJGBMQTTN2DSOAIQGP7WCPGV/</a><br><a href="https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/UQXGOGWBIYWOIVXJVRKHZR34UMEHQBXS/">https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/UQXGOGWBIYWOIVXJVRKHZR34UMEHQBXS/</a><br><a href="https://ubuntu.com/security/notices/USN-5179-1">https://ubuntu.com/security/notices/USN-5179-1</a><br></details>  |
| busybox         |    CVE-2021-42380   |   HIGH  |  1.33.1-r3 | 1.33.1-r6 | <details><summary>Expand...</summary><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2021-42380">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2021-42380</a><br><a href="https://jfrog.com/blog/unboxing-busybox-14-new-vulnerabilities-uncovered-by-claroty-and-jfrog/">https://jfrog.com/blog/unboxing-busybox-14-new-vulnerabilities-uncovered-by-claroty-and-jfrog/</a><br><a href="https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/6T2TURBYYJGBMQTTN2DSOAIQGP7WCPGV/">https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/6T2TURBYYJGBMQTTN2DSOAIQGP7WCPGV/</a><br><a href="https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/UQXGOGWBIYWOIVXJVRKHZR34UMEHQBXS/">https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/UQXGOGWBIYWOIVXJVRKHZR34UMEHQBXS/</a><br><a href="https://ubuntu.com/security/notices/USN-5179-1">https://ubuntu.com/security/notices/USN-5179-1</a><br></details>  |
| busybox         |    CVE-2021-42381   |   HIGH  |  1.33.1-r3 | 1.33.1-r6 | <details><summary>Expand...</summary><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2021-42381">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2021-42381</a><br><a href="https://jfrog.com/blog/unboxing-busybox-14-new-vulnerabilities-uncovered-by-claroty-and-jfrog/">https://jfrog.com/blog/unboxing-busybox-14-new-vulnerabilities-uncovered-by-claroty-and-jfrog/</a><br><a href="https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/6T2TURBYYJGBMQTTN2DSOAIQGP7WCPGV/">https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/6T2TURBYYJGBMQTTN2DSOAIQGP7WCPGV/</a><br><a href="https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/UQXGOGWBIYWOIVXJVRKHZR34UMEHQBXS/">https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/UQXGOGWBIYWOIVXJVRKHZR34UMEHQBXS/</a><br><a href="https://ubuntu.com/security/notices/USN-5179-1">https://ubuntu.com/security/notices/USN-5179-1</a><br></details>  |
| busybox         |    CVE-2021-42382   |   HIGH  |  1.33.1-r3 | 1.33.1-r6 | <details><summary>Expand...</summary><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2021-42382">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2021-42382</a><br><a href="https://jfrog.com/blog/unboxing-busybox-14-new-vulnerabilities-uncovered-by-claroty-and-jfrog/">https://jfrog.com/blog/unboxing-busybox-14-new-vulnerabilities-uncovered-by-claroty-and-jfrog/</a><br><a href="https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/6T2TURBYYJGBMQTTN2DSOAIQGP7WCPGV/">https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/6T2TURBYYJGBMQTTN2DSOAIQGP7WCPGV/</a><br><a href="https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/UQXGOGWBIYWOIVXJVRKHZR34UMEHQBXS/">https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/UQXGOGWBIYWOIVXJVRKHZR34UMEHQBXS/</a><br><a href="https://ubuntu.com/security/notices/USN-5179-1">https://ubuntu.com/security/notices/USN-5179-1</a><br></details>  |
| busybox         |    CVE-2021-42383   |   HIGH  |  1.33.1-r3 | 1.33.1-r6 | <details><summary>Expand...</summary><a href="https://jfrog.com/blog/unboxing-busybox-14-new-vulnerabilities-uncovered-by-claroty-and-jfrog/">https://jfrog.com/blog/unboxing-busybox-14-new-vulnerabilities-uncovered-by-claroty-and-jfrog/</a><br><a href="https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/6T2TURBYYJGBMQTTN2DSOAIQGP7WCPGV/">https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/6T2TURBYYJGBMQTTN2DSOAIQGP7WCPGV/</a><br><a href="https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/UQXGOGWBIYWOIVXJVRKHZR34UMEHQBXS/">https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/UQXGOGWBIYWOIVXJVRKHZR34UMEHQBXS/</a><br></details>  |
| busybox         |    CVE-2021-42384   |   HIGH  |  1.33.1-r3 | 1.33.1-r6 | <details><summary>Expand...</summary><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2021-42384">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2021-42384</a><br><a href="https://jfrog.com/blog/unboxing-busybox-14-new-vulnerabilities-uncovered-by-claroty-and-jfrog/">https://jfrog.com/blog/unboxing-busybox-14-new-vulnerabilities-uncovered-by-claroty-and-jfrog/</a><br><a href="https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/6T2TURBYYJGBMQTTN2DSOAIQGP7WCPGV/">https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/6T2TURBYYJGBMQTTN2DSOAIQGP7WCPGV/</a><br><a href="https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/UQXGOGWBIYWOIVXJVRKHZR34UMEHQBXS/">https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/UQXGOGWBIYWOIVXJVRKHZR34UMEHQBXS/</a><br><a href="https://ubuntu.com/security/notices/USN-5179-1">https://ubuntu.com/security/notices/USN-5179-1</a><br></details>  |
| busybox         |    CVE-2021-42385   |   HIGH  |  1.33.1-r3 | 1.33.1-r6 | <details><summary>Expand...</summary><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2021-42385">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2021-42385</a><br><a href="https://jfrog.com/blog/unboxing-busybox-14-new-vulnerabilities-uncovered-by-claroty-and-jfrog/">https://jfrog.com/blog/unboxing-busybox-14-new-vulnerabilities-uncovered-by-claroty-and-jfrog/</a><br><a href="https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/6T2TURBYYJGBMQTTN2DSOAIQGP7WCPGV/">https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/6T2TURBYYJGBMQTTN2DSOAIQGP7WCPGV/</a><br><a href="https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/UQXGOGWBIYWOIVXJVRKHZR34UMEHQBXS/">https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/UQXGOGWBIYWOIVXJVRKHZR34UMEHQBXS/</a><br><a href="https://ubuntu.com/security/notices/USN-5179-1">https://ubuntu.com/security/notices/USN-5179-1</a><br></details>  |
| busybox         |    CVE-2021-42386   |   HIGH  |  1.33.1-r3 | 1.33.1-r6 | <details><summary>Expand...</summary><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2021-42386">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2021-42386</a><br><a href="https://jfrog.com/blog/unboxing-busybox-14-new-vulnerabilities-uncovered-by-claroty-and-jfrog/">https://jfrog.com/blog/unboxing-busybox-14-new-vulnerabilities-uncovered-by-claroty-and-jfrog/</a><br><a href="https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/6T2TURBYYJGBMQTTN2DSOAIQGP7WCPGV/">https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/6T2TURBYYJGBMQTTN2DSOAIQGP7WCPGV/</a><br><a href="https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/UQXGOGWBIYWOIVXJVRKHZR34UMEHQBXS/">https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/UQXGOGWBIYWOIVXJVRKHZR34UMEHQBXS/</a><br><a href="https://ubuntu.com/security/notices/USN-5179-1">https://ubuntu.com/security/notices/USN-5179-1</a><br></details>  |
| busybox         |    CVE-2021-42374   |   MEDIUM  |  1.33.1-r3 | 1.33.1-r4 | <details><summary>Expand...</summary><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2021-42374">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2021-42374</a><br><a href="https://jfrog.com/blog/unboxing-busybox-14-new-vulnerabilities-uncovered-by-claroty-and-jfrog/">https://jfrog.com/blog/unboxing-busybox-14-new-vulnerabilities-uncovered-by-claroty-and-jfrog/</a><br><a href="https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/6T2TURBYYJGBMQTTN2DSOAIQGP7WCPGV/">https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/6T2TURBYYJGBMQTTN2DSOAIQGP7WCPGV/</a><br><a href="https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/UQXGOGWBIYWOIVXJVRKHZR34UMEHQBXS/">https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/UQXGOGWBIYWOIVXJVRKHZR34UMEHQBXS/</a><br><a href="https://ubuntu.com/security/notices/USN-5179-1">https://ubuntu.com/security/notices/USN-5179-1</a><br></details>  |
| busybox         |    CVE-2021-42375   |   MEDIUM  |  1.33.1-r3 | 1.33.1-r5 | <details><summary>Expand...</summary><a href="https://jfrog.com/blog/unboxing-busybox-14-new-vulnerabilities-uncovered-by-claroty-and-jfrog/">https://jfrog.com/blog/unboxing-busybox-14-new-vulnerabilities-uncovered-by-claroty-and-jfrog/</a><br><a href="https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/6T2TURBYYJGBMQTTN2DSOAIQGP7WCPGV/">https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/6T2TURBYYJGBMQTTN2DSOAIQGP7WCPGV/</a><br><a href="https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/UQXGOGWBIYWOIVXJVRKHZR34UMEHQBXS/">https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/UQXGOGWBIYWOIVXJVRKHZR34UMEHQBXS/</a><br></details>  |
| ssl_client         |    CVE-2021-42378   |   HIGH  |  1.33.1-r3 | 1.33.1-r6 | <details><summary>Expand...</summary><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2021-42378">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2021-42378</a><br><a href="https://jfrog.com/blog/unboxing-busybox-14-new-vulnerabilities-uncovered-by-claroty-and-jfrog/">https://jfrog.com/blog/unboxing-busybox-14-new-vulnerabilities-uncovered-by-claroty-and-jfrog/</a><br><a href="https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/6T2TURBYYJGBMQTTN2DSOAIQGP7WCPGV/">https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/6T2TURBYYJGBMQTTN2DSOAIQGP7WCPGV/</a><br><a href="https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/UQXGOGWBIYWOIVXJVRKHZR34UMEHQBXS/">https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/UQXGOGWBIYWOIVXJVRKHZR34UMEHQBXS/</a><br><a href="https://ubuntu.com/security/notices/USN-5179-1">https://ubuntu.com/security/notices/USN-5179-1</a><br></details>  |
| ssl_client         |    CVE-2021-42379   |   HIGH  |  1.33.1-r3 | 1.33.1-r6 | <details><summary>Expand...</summary><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2021-42379">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2021-42379</a><br><a href="https://jfrog.com/blog/unboxing-busybox-14-new-vulnerabilities-uncovered-by-claroty-and-jfrog/">https://jfrog.com/blog/unboxing-busybox-14-new-vulnerabilities-uncovered-by-claroty-and-jfrog/</a><br><a href="https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/6T2TURBYYJGBMQTTN2DSOAIQGP7WCPGV/">https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/6T2TURBYYJGBMQTTN2DSOAIQGP7WCPGV/</a><br><a href="https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/UQXGOGWBIYWOIVXJVRKHZR34UMEHQBXS/">https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/UQXGOGWBIYWOIVXJVRKHZR34UMEHQBXS/</a><br><a href="https://ubuntu.com/security/notices/USN-5179-1">https://ubuntu.com/security/notices/USN-5179-1</a><br></details>  |
| ssl_client         |    CVE-2021-42380   |   HIGH  |  1.33.1-r3 | 1.33.1-r6 | <details><summary>Expand...</summary><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2021-42380">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2021-42380</a><br><a href="https://jfrog.com/blog/unboxing-busybox-14-new-vulnerabilities-uncovered-by-claroty-and-jfrog/">https://jfrog.com/blog/unboxing-busybox-14-new-vulnerabilities-uncovered-by-claroty-and-jfrog/</a><br><a href="https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/6T2TURBYYJGBMQTTN2DSOAIQGP7WCPGV/">https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/6T2TURBYYJGBMQTTN2DSOAIQGP7WCPGV/</a><br><a href="https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/UQXGOGWBIYWOIVXJVRKHZR34UMEHQBXS/">https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/UQXGOGWBIYWOIVXJVRKHZR34UMEHQBXS/</a><br><a href="https://ubuntu.com/security/notices/USN-5179-1">https://ubuntu.com/security/notices/USN-5179-1</a><br></details>  |
| ssl_client         |    CVE-2021-42381   |   HIGH  |  1.33.1-r3 | 1.33.1-r6 | <details><summary>Expand...</summary><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2021-42381">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2021-42381</a><br><a href="https://jfrog.com/blog/unboxing-busybox-14-new-vulnerabilities-uncovered-by-claroty-and-jfrog/">https://jfrog.com/blog/unboxing-busybox-14-new-vulnerabilities-uncovered-by-claroty-and-jfrog/</a><br><a href="https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/6T2TURBYYJGBMQTTN2DSOAIQGP7WCPGV/">https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/6T2TURBYYJGBMQTTN2DSOAIQGP7WCPGV/</a><br><a href="https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/UQXGOGWBIYWOIVXJVRKHZR34UMEHQBXS/">https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/UQXGOGWBIYWOIVXJVRKHZR34UMEHQBXS/</a><br><a href="https://ubuntu.com/security/notices/USN-5179-1">https://ubuntu.com/security/notices/USN-5179-1</a><br></details>  |
| ssl_client         |    CVE-2021-42382   |   HIGH  |  1.33.1-r3 | 1.33.1-r6 | <details><summary>Expand...</summary><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2021-42382">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2021-42382</a><br><a href="https://jfrog.com/blog/unboxing-busybox-14-new-vulnerabilities-uncovered-by-claroty-and-jfrog/">https://jfrog.com/blog/unboxing-busybox-14-new-vulnerabilities-uncovered-by-claroty-and-jfrog/</a><br><a href="https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/6T2TURBYYJGBMQTTN2DSOAIQGP7WCPGV/">https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/6T2TURBYYJGBMQTTN2DSOAIQGP7WCPGV/</a><br><a href="https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/UQXGOGWBIYWOIVXJVRKHZR34UMEHQBXS/">https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/UQXGOGWBIYWOIVXJVRKHZR34UMEHQBXS/</a><br><a href="https://ubuntu.com/security/notices/USN-5179-1">https://ubuntu.com/security/notices/USN-5179-1</a><br></details>  |
| ssl_client         |    CVE-2021-42383   |   HIGH  |  1.33.1-r3 | 1.33.1-r6 | <details><summary>Expand...</summary><a href="https://jfrog.com/blog/unboxing-busybox-14-new-vulnerabilities-uncovered-by-claroty-and-jfrog/">https://jfrog.com/blog/unboxing-busybox-14-new-vulnerabilities-uncovered-by-claroty-and-jfrog/</a><br><a href="https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/6T2TURBYYJGBMQTTN2DSOAIQGP7WCPGV/">https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/6T2TURBYYJGBMQTTN2DSOAIQGP7WCPGV/</a><br><a href="https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/UQXGOGWBIYWOIVXJVRKHZR34UMEHQBXS/">https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/UQXGOGWBIYWOIVXJVRKHZR34UMEHQBXS/</a><br></details>  |
| ssl_client         |    CVE-2021-42384   |   HIGH  |  1.33.1-r3 | 1.33.1-r6 | <details><summary>Expand...</summary><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2021-42384">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2021-42384</a><br><a href="https://jfrog.com/blog/unboxing-busybox-14-new-vulnerabilities-uncovered-by-claroty-and-jfrog/">https://jfrog.com/blog/unboxing-busybox-14-new-vulnerabilities-uncovered-by-claroty-and-jfrog/</a><br><a href="https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/6T2TURBYYJGBMQTTN2DSOAIQGP7WCPGV/">https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/6T2TURBYYJGBMQTTN2DSOAIQGP7WCPGV/</a><br><a href="https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/UQXGOGWBIYWOIVXJVRKHZR34UMEHQBXS/">https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/UQXGOGWBIYWOIVXJVRKHZR34UMEHQBXS/</a><br><a href="https://ubuntu.com/security/notices/USN-5179-1">https://ubuntu.com/security/notices/USN-5179-1</a><br></details>  |
| ssl_client         |    CVE-2021-42385   |   HIGH  |  1.33.1-r3 | 1.33.1-r6 | <details><summary>Expand...</summary><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2021-42385">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2021-42385</a><br><a href="https://jfrog.com/blog/unboxing-busybox-14-new-vulnerabilities-uncovered-by-claroty-and-jfrog/">https://jfrog.com/blog/unboxing-busybox-14-new-vulnerabilities-uncovered-by-claroty-and-jfrog/</a><br><a href="https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/6T2TURBYYJGBMQTTN2DSOAIQGP7WCPGV/">https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/6T2TURBYYJGBMQTTN2DSOAIQGP7WCPGV/</a><br><a href="https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/UQXGOGWBIYWOIVXJVRKHZR34UMEHQBXS/">https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/UQXGOGWBIYWOIVXJVRKHZR34UMEHQBXS/</a><br><a href="https://ubuntu.com/security/notices/USN-5179-1">https://ubuntu.com/security/notices/USN-5179-1</a><br></details>  |
| ssl_client         |    CVE-2021-42386   |   HIGH  |  1.33.1-r3 | 1.33.1-r6 | <details><summary>Expand...</summary><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2021-42386">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2021-42386</a><br><a href="https://jfrog.com/blog/unboxing-busybox-14-new-vulnerabilities-uncovered-by-claroty-and-jfrog/">https://jfrog.com/blog/unboxing-busybox-14-new-vulnerabilities-uncovered-by-claroty-and-jfrog/</a><br><a href="https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/6T2TURBYYJGBMQTTN2DSOAIQGP7WCPGV/">https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/6T2TURBYYJGBMQTTN2DSOAIQGP7WCPGV/</a><br><a href="https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/UQXGOGWBIYWOIVXJVRKHZR34UMEHQBXS/">https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/UQXGOGWBIYWOIVXJVRKHZR34UMEHQBXS/</a><br><a href="https://ubuntu.com/security/notices/USN-5179-1">https://ubuntu.com/security/notices/USN-5179-1</a><br></details>  |
| ssl_client         |    CVE-2021-42374   |   MEDIUM  |  1.33.1-r3 | 1.33.1-r4 | <details><summary>Expand...</summary><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2021-42374">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2021-42374</a><br><a href="https://jfrog.com/blog/unboxing-busybox-14-new-vulnerabilities-uncovered-by-claroty-and-jfrog/">https://jfrog.com/blog/unboxing-busybox-14-new-vulnerabilities-uncovered-by-claroty-and-jfrog/</a><br><a href="https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/6T2TURBYYJGBMQTTN2DSOAIQGP7WCPGV/">https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/6T2TURBYYJGBMQTTN2DSOAIQGP7WCPGV/</a><br><a href="https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/UQXGOGWBIYWOIVXJVRKHZR34UMEHQBXS/">https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/UQXGOGWBIYWOIVXJVRKHZR34UMEHQBXS/</a><br><a href="https://ubuntu.com/security/notices/USN-5179-1">https://ubuntu.com/security/notices/USN-5179-1</a><br></details>  |
| ssl_client         |    CVE-2021-42375   |   MEDIUM  |  1.33.1-r3 | 1.33.1-r5 | <details><summary>Expand...</summary><a href="https://jfrog.com/blog/unboxing-busybox-14-new-vulnerabilities-uncovered-by-claroty-and-jfrog/">https://jfrog.com/blog/unboxing-busybox-14-new-vulnerabilities-uncovered-by-claroty-and-jfrog/</a><br><a href="https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/6T2TURBYYJGBMQTTN2DSOAIQGP7WCPGV/">https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/6T2TURBYYJGBMQTTN2DSOAIQGP7WCPGV/</a><br><a href="https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/UQXGOGWBIYWOIVXJVRKHZR34UMEHQBXS/">https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/UQXGOGWBIYWOIVXJVRKHZR34UMEHQBXS/</a><br></details>  |


#### Container: tccr.io/truecharts/cloud9:version-1.29.2@sha256:4891fa151fe52c43719f0346124f29c81ed47be16cdc34554b8896b0cb80cb73 (ubuntu 18.04)
    

**ubuntu**

      
| Package         |    Vulnerability   |   Severity  |  Installed Version | Fixed Version |                   Links                   |
|:----------------|:------------------:|:-----------:|:------------------:|:-------------:|-----------------------------------------|
| bash         |    CVE-2019-18276   |   LOW  |  4.4.18-2ubuntu1.2 |  | <details><summary>Expand...</summary><a href="http://packetstormsecurity.com/files/155498/Bash-5.0-Patch-11-Privilege-Escalation.html">http://packetstormsecurity.com/files/155498/Bash-5.0-Patch-11-Privilege-Escalation.html</a><br><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2019-18276">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2019-18276</a><br><a href="https://github.com/bminor/bash/commit/951bdaad7a18cc0dc1036bba86b18b90874d39ff">https://github.com/bminor/bash/commit/951bdaad7a18cc0dc1036bba86b18b90874d39ff</a><br><a href="https://linux.oracle.com/cve/CVE-2019-18276.html">https://linux.oracle.com/cve/CVE-2019-18276.html</a><br><a href="https://linux.oracle.com/errata/ELSA-2021-1679.html">https://linux.oracle.com/errata/ELSA-2021-1679.html</a><br><a href="https://lists.apache.org/thread.html/rf9fa47ab66495c78bb4120b0754dd9531ca2ff0430f6685ac9b07772@%3Cdev.mina.apache.org%3E">https://lists.apache.org/thread.html/rf9fa47ab66495c78bb4120b0754dd9531ca2ff0430f6685ac9b07772@%3Cdev.mina.apache.org%3E</a><br><a href="https://security.gentoo.org/glsa/202105-34">https://security.gentoo.org/glsa/202105-34</a><br><a href="https://security.netapp.com/advisory/ntap-20200430-0003/">https://security.netapp.com/advisory/ntap-20200430-0003/</a><br><a href="https://www.youtube.com/watch?v=-wGtxJ8opa8">https://www.youtube.com/watch?v=-wGtxJ8opa8</a><br></details>  |
| coreutils         |    CVE-2016-2781   |   LOW  |  8.28-1ubuntu1 |  | <details><summary>Expand...</summary><a href="http://seclists.org/oss-sec/2016/q1/452">http://seclists.org/oss-sec/2016/q1/452</a><br><a href="http://www.openwall.com/lists/oss-security/2016/02/28/2">http://www.openwall.com/lists/oss-security/2016/02/28/2</a><br><a href="http://www.openwall.com/lists/oss-security/2016/02/28/3">http://www.openwall.com/lists/oss-security/2016/02/28/3</a><br><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2016-2781">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2016-2781</a><br><a href="https://lists.apache.org/thread.html/rf9fa47ab66495c78bb4120b0754dd9531ca2ff0430f6685ac9b07772@%3Cdev.mina.apache.org%3E">https://lists.apache.org/thread.html/rf9fa47ab66495c78bb4120b0754dd9531ca2ff0430f6685ac9b07772@%3Cdev.mina.apache.org%3E</a><br><a href="https://lore.kernel.org/patchwork/patch/793178/">https://lore.kernel.org/patchwork/patch/793178/</a><br></details>  |
| dirmngr         |    CVE-2019-13050   |   LOW  |  2.2.4-1ubuntu1.4 |  | <details><summary>Expand...</summary><a href="http://lists.opensuse.org/opensuse-security-announce/2019-08/msg00039.html">http://lists.opensuse.org/opensuse-security-announce/2019-08/msg00039.html</a><br><a href="https://access.redhat.com/articles/4264021">https://access.redhat.com/articles/4264021</a><br><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2019-13050">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2019-13050</a><br><a href="https://gist.github.com/rjhansen/67ab921ffb4084c865b3618d6955275f">https://gist.github.com/rjhansen/67ab921ffb4084c865b3618d6955275f</a><br><a href="https://linux.oracle.com/cve/CVE-2019-13050.html">https://linux.oracle.com/cve/CVE-2019-13050.html</a><br><a href="https://linux.oracle.com/errata/ELSA-2020-4490.html">https://linux.oracle.com/errata/ELSA-2020-4490.html</a><br><a href="https://lists.apache.org/thread.html/r58af02e294bd07f487e2c64ffc0a29b837db5600e33b6e698b9d696b@%3Cissues.bookkeeper.apache.org%3E">https://lists.apache.org/thread.html/r58af02e294bd07f487e2c64ffc0a29b837db5600e33b6e698b9d696b@%3Cissues.bookkeeper.apache.org%3E</a><br><a href="https://lists.apache.org/thread.html/rf4c02775860db415b4955778a131c2795223f61cb8c6a450893651e4@%3Cissues.bookkeeper.apache.org%3E">https://lists.apache.org/thread.html/rf4c02775860db415b4955778a131c2795223f61cb8c6a450893651e4@%3Cissues.bookkeeper.apache.org%3E</a><br><a href="https://lists.apache.org/thread.html/rf9fa47ab66495c78bb4120b0754dd9531ca2ff0430f6685ac9b07772@%3Cdev.mina.apache.org%3E">https://lists.apache.org/thread.html/rf9fa47ab66495c78bb4120b0754dd9531ca2ff0430f6685ac9b07772@%3Cdev.mina.apache.org%3E</a><br><a href="https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/AUK2YRO6QIH64WP2LRA5D4LACTXQPPU4/">https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/AUK2YRO6QIH64WP2LRA5D4LACTXQPPU4/</a><br><a href="https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/CP4ON34YEXEZDZOXXWV43KVGGO6WZLJ5/">https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/CP4ON34YEXEZDZOXXWV43KVGGO6WZLJ5/</a><br><a href="https://lists.gnupg.org/pipermail/gnupg-announce/2019q3/000439.html">https://lists.gnupg.org/pipermail/gnupg-announce/2019q3/000439.html</a><br><a href="https://support.f5.com/csp/article/K08654551">https://support.f5.com/csp/article/K08654551</a><br><a href="https://support.f5.com/csp/article/K08654551?utm_source=f5support&amp;amp;utm_medium=RSS">https://support.f5.com/csp/article/K08654551?utm_source=f5support&amp;amp;utm_medium=RSS</a><br><a href="https://twitter.com/lambdafu/status/1147162583969009664">https://twitter.com/lambdafu/status/1147162583969009664</a><br></details>  |
| gcc-8-base         |    CVE-2020-13844   |   MEDIUM  |  8.4.0-1ubuntu1~18.04 |  | <details><summary>Expand...</summary><a href="http://lists.llvm.org/pipermail/llvm-dev/2020-June/142109.html">http://lists.llvm.org/pipermail/llvm-dev/2020-June/142109.html</a><br><a href="http://lists.opensuse.org/opensuse-security-announce/2020-10/msg00039.html">http://lists.opensuse.org/opensuse-security-announce/2020-10/msg00039.html</a><br><a href="http://lists.opensuse.org/opensuse-security-announce/2020-10/msg00040.html">http://lists.opensuse.org/opensuse-security-announce/2020-10/msg00040.html</a><br><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2020-13844">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2020-13844</a><br><a href="https://developer.arm.com/support/arm-security-updates/speculative-processor-vulnerability">https://developer.arm.com/support/arm-security-updates/speculative-processor-vulnerability</a><br><a href="https://developer.arm.com/support/arm-security-updates/speculative-processor-vulnerability/downloads/straight-line-speculation">https://developer.arm.com/support/arm-security-updates/speculative-processor-vulnerability/downloads/straight-line-speculation</a><br><a href="https://developer.arm.com/support/arm-security-updates/speculative-processor-vulnerability/frequently-asked-questions">https://developer.arm.com/support/arm-security-updates/speculative-processor-vulnerability/frequently-asked-questions</a><br><a href="https://gcc.gnu.org/pipermail/gcc-patches/2020-June/547520.html">https://gcc.gnu.org/pipermail/gcc-patches/2020-June/547520.html</a><br><a href="https://git.kernel.org/pub/scm/linux/kernel/git/torvalds/linux.git/commit/?id=679db70801da9fda91d26caf13bf5b5ccc74e8e8">https://git.kernel.org/pub/scm/linux/kernel/git/torvalds/linux.git/commit/?id=679db70801da9fda91d26caf13bf5b5ccc74e8e8</a><br></details>  |
| git         |    CVE-2018-1000021   |   LOW  |  1:2.17.1-1ubuntu0.9 |  | <details><summary>Expand...</summary><a href="http://www.batterystapl.es/2018/01/security-implications-of-ansi-escape.html">http://www.batterystapl.es/2018/01/security-implications-of-ansi-escape.html</a><br><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2018-1000021">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2018-1000021</a><br></details>  |
| git-man         |    CVE-2018-1000021   |   LOW  |  1:2.17.1-1ubuntu0.9 |  | <details><summary>Expand...</summary><a href="http://www.batterystapl.es/2018/01/security-implications-of-ansi-escape.html">http://www.batterystapl.es/2018/01/security-implications-of-ansi-escape.html</a><br><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2018-1000021">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2018-1000021</a><br></details>  |
| gnupg         |    CVE-2019-13050   |   LOW  |  2.2.4-1ubuntu1.4 |  | <details><summary>Expand...</summary><a href="http://lists.opensuse.org/opensuse-security-announce/2019-08/msg00039.html">http://lists.opensuse.org/opensuse-security-announce/2019-08/msg00039.html</a><br><a href="https://access.redhat.com/articles/4264021">https://access.redhat.com/articles/4264021</a><br><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2019-13050">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2019-13050</a><br><a href="https://gist.github.com/rjhansen/67ab921ffb4084c865b3618d6955275f">https://gist.github.com/rjhansen/67ab921ffb4084c865b3618d6955275f</a><br><a href="https://linux.oracle.com/cve/CVE-2019-13050.html">https://linux.oracle.com/cve/CVE-2019-13050.html</a><br><a href="https://linux.oracle.com/errata/ELSA-2020-4490.html">https://linux.oracle.com/errata/ELSA-2020-4490.html</a><br><a href="https://lists.apache.org/thread.html/r58af02e294bd07f487e2c64ffc0a29b837db5600e33b6e698b9d696b@%3Cissues.bookkeeper.apache.org%3E">https://lists.apache.org/thread.html/r58af02e294bd07f487e2c64ffc0a29b837db5600e33b6e698b9d696b@%3Cissues.bookkeeper.apache.org%3E</a><br><a href="https://lists.apache.org/thread.html/rf4c02775860db415b4955778a131c2795223f61cb8c6a450893651e4@%3Cissues.bookkeeper.apache.org%3E">https://lists.apache.org/thread.html/rf4c02775860db415b4955778a131c2795223f61cb8c6a450893651e4@%3Cissues.bookkeeper.apache.org%3E</a><br><a href="https://lists.apache.org/thread.html/rf9fa47ab66495c78bb4120b0754dd9531ca2ff0430f6685ac9b07772@%3Cdev.mina.apache.org%3E">https://lists.apache.org/thread.html/rf9fa47ab66495c78bb4120b0754dd9531ca2ff0430f6685ac9b07772@%3Cdev.mina.apache.org%3E</a><br><a href="https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/AUK2YRO6QIH64WP2LRA5D4LACTXQPPU4/">https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/AUK2YRO6QIH64WP2LRA5D4LACTXQPPU4/</a><br><a href="https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/CP4ON34YEXEZDZOXXWV43KVGGO6WZLJ5/">https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/CP4ON34YEXEZDZOXXWV43KVGGO6WZLJ5/</a><br><a href="https://lists.gnupg.org/pipermail/gnupg-announce/2019q3/000439.html">https://lists.gnupg.org/pipermail/gnupg-announce/2019q3/000439.html</a><br><a href="https://support.f5.com/csp/article/K08654551">https://support.f5.com/csp/article/K08654551</a><br><a href="https://support.f5.com/csp/article/K08654551?utm_source=f5support&amp;amp;utm_medium=RSS">https://support.f5.com/csp/article/K08654551?utm_source=f5support&amp;amp;utm_medium=RSS</a><br><a href="https://twitter.com/lambdafu/status/1147162583969009664">https://twitter.com/lambdafu/status/1147162583969009664</a><br></details>  |
| gnupg-l10n         |    CVE-2019-13050   |   LOW  |  2.2.4-1ubuntu1.4 |  | <details><summary>Expand...</summary><a href="http://lists.opensuse.org/opensuse-security-announce/2019-08/msg00039.html">http://lists.opensuse.org/opensuse-security-announce/2019-08/msg00039.html</a><br><a href="https://access.redhat.com/articles/4264021">https://access.redhat.com/articles/4264021</a><br><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2019-13050">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2019-13050</a><br><a href="https://gist.github.com/rjhansen/67ab921ffb4084c865b3618d6955275f">https://gist.github.com/rjhansen/67ab921ffb4084c865b3618d6955275f</a><br><a href="https://linux.oracle.com/cve/CVE-2019-13050.html">https://linux.oracle.com/cve/CVE-2019-13050.html</a><br><a href="https://linux.oracle.com/errata/ELSA-2020-4490.html">https://linux.oracle.com/errata/ELSA-2020-4490.html</a><br><a href="https://lists.apache.org/thread.html/r58af02e294bd07f487e2c64ffc0a29b837db5600e33b6e698b9d696b@%3Cissues.bookkeeper.apache.org%3E">https://lists.apache.org/thread.html/r58af02e294bd07f487e2c64ffc0a29b837db5600e33b6e698b9d696b@%3Cissues.bookkeeper.apache.org%3E</a><br><a href="https://lists.apache.org/thread.html/rf4c02775860db415b4955778a131c2795223f61cb8c6a450893651e4@%3Cissues.bookkeeper.apache.org%3E">https://lists.apache.org/thread.html/rf4c02775860db415b4955778a131c2795223f61cb8c6a450893651e4@%3Cissues.bookkeeper.apache.org%3E</a><br><a href="https://lists.apache.org/thread.html/rf9fa47ab66495c78bb4120b0754dd9531ca2ff0430f6685ac9b07772@%3Cdev.mina.apache.org%3E">https://lists.apache.org/thread.html/rf9fa47ab66495c78bb4120b0754dd9531ca2ff0430f6685ac9b07772@%3Cdev.mina.apache.org%3E</a><br><a href="https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/AUK2YRO6QIH64WP2LRA5D4LACTXQPPU4/">https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/AUK2YRO6QIH64WP2LRA5D4LACTXQPPU4/</a><br><a href="https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/CP4ON34YEXEZDZOXXWV43KVGGO6WZLJ5/">https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/CP4ON34YEXEZDZOXXWV43KVGGO6WZLJ5/</a><br><a href="https://lists.gnupg.org/pipermail/gnupg-announce/2019q3/000439.html">https://lists.gnupg.org/pipermail/gnupg-announce/2019q3/000439.html</a><br><a href="https://support.f5.com/csp/article/K08654551">https://support.f5.com/csp/article/K08654551</a><br><a href="https://support.f5.com/csp/article/K08654551?utm_source=f5support&amp;amp;utm_medium=RSS">https://support.f5.com/csp/article/K08654551?utm_source=f5support&amp;amp;utm_medium=RSS</a><br><a href="https://twitter.com/lambdafu/status/1147162583969009664">https://twitter.com/lambdafu/status/1147162583969009664</a><br></details>  |
| gnupg-utils         |    CVE-2019-13050   |   LOW  |  2.2.4-1ubuntu1.4 |  | <details><summary>Expand...</summary><a href="http://lists.opensuse.org/opensuse-security-announce/2019-08/msg00039.html">http://lists.opensuse.org/opensuse-security-announce/2019-08/msg00039.html</a><br><a href="https://access.redhat.com/articles/4264021">https://access.redhat.com/articles/4264021</a><br><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2019-13050">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2019-13050</a><br><a href="https://gist.github.com/rjhansen/67ab921ffb4084c865b3618d6955275f">https://gist.github.com/rjhansen/67ab921ffb4084c865b3618d6955275f</a><br><a href="https://linux.oracle.com/cve/CVE-2019-13050.html">https://linux.oracle.com/cve/CVE-2019-13050.html</a><br><a href="https://linux.oracle.com/errata/ELSA-2020-4490.html">https://linux.oracle.com/errata/ELSA-2020-4490.html</a><br><a href="https://lists.apache.org/thread.html/r58af02e294bd07f487e2c64ffc0a29b837db5600e33b6e698b9d696b@%3Cissues.bookkeeper.apache.org%3E">https://lists.apache.org/thread.html/r58af02e294bd07f487e2c64ffc0a29b837db5600e33b6e698b9d696b@%3Cissues.bookkeeper.apache.org%3E</a><br><a href="https://lists.apache.org/thread.html/rf4c02775860db415b4955778a131c2795223f61cb8c6a450893651e4@%3Cissues.bookkeeper.apache.org%3E">https://lists.apache.org/thread.html/rf4c02775860db415b4955778a131c2795223f61cb8c6a450893651e4@%3Cissues.bookkeeper.apache.org%3E</a><br><a href="https://lists.apache.org/thread.html/rf9fa47ab66495c78bb4120b0754dd9531ca2ff0430f6685ac9b07772@%3Cdev.mina.apache.org%3E">https://lists.apache.org/thread.html/rf9fa47ab66495c78bb4120b0754dd9531ca2ff0430f6685ac9b07772@%3Cdev.mina.apache.org%3E</a><br><a href="https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/AUK2YRO6QIH64WP2LRA5D4LACTXQPPU4/">https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/AUK2YRO6QIH64WP2LRA5D4LACTXQPPU4/</a><br><a href="https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/CP4ON34YEXEZDZOXXWV43KVGGO6WZLJ5/">https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/CP4ON34YEXEZDZOXXWV43KVGGO6WZLJ5/</a><br><a href="https://lists.gnupg.org/pipermail/gnupg-announce/2019q3/000439.html">https://lists.gnupg.org/pipermail/gnupg-announce/2019q3/000439.html</a><br><a href="https://support.f5.com/csp/article/K08654551">https://support.f5.com/csp/article/K08654551</a><br><a href="https://support.f5.com/csp/article/K08654551?utm_source=f5support&amp;amp;utm_medium=RSS">https://support.f5.com/csp/article/K08654551?utm_source=f5support&amp;amp;utm_medium=RSS</a><br><a href="https://twitter.com/lambdafu/status/1147162583969009664">https://twitter.com/lambdafu/status/1147162583969009664</a><br></details>  |
| gpg         |    CVE-2019-13050   |   LOW  |  2.2.4-1ubuntu1.4 |  | <details><summary>Expand...</summary><a href="http://lists.opensuse.org/opensuse-security-announce/2019-08/msg00039.html">http://lists.opensuse.org/opensuse-security-announce/2019-08/msg00039.html</a><br><a href="https://access.redhat.com/articles/4264021">https://access.redhat.com/articles/4264021</a><br><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2019-13050">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2019-13050</a><br><a href="https://gist.github.com/rjhansen/67ab921ffb4084c865b3618d6955275f">https://gist.github.com/rjhansen/67ab921ffb4084c865b3618d6955275f</a><br><a href="https://linux.oracle.com/cve/CVE-2019-13050.html">https://linux.oracle.com/cve/CVE-2019-13050.html</a><br><a href="https://linux.oracle.com/errata/ELSA-2020-4490.html">https://linux.oracle.com/errata/ELSA-2020-4490.html</a><br><a href="https://lists.apache.org/thread.html/r58af02e294bd07f487e2c64ffc0a29b837db5600e33b6e698b9d696b@%3Cissues.bookkeeper.apache.org%3E">https://lists.apache.org/thread.html/r58af02e294bd07f487e2c64ffc0a29b837db5600e33b6e698b9d696b@%3Cissues.bookkeeper.apache.org%3E</a><br><a href="https://lists.apache.org/thread.html/rf4c02775860db415b4955778a131c2795223f61cb8c6a450893651e4@%3Cissues.bookkeeper.apache.org%3E">https://lists.apache.org/thread.html/rf4c02775860db415b4955778a131c2795223f61cb8c6a450893651e4@%3Cissues.bookkeeper.apache.org%3E</a><br><a href="https://lists.apache.org/thread.html/rf9fa47ab66495c78bb4120b0754dd9531ca2ff0430f6685ac9b07772@%3Cdev.mina.apache.org%3E">https://lists.apache.org/thread.html/rf9fa47ab66495c78bb4120b0754dd9531ca2ff0430f6685ac9b07772@%3Cdev.mina.apache.org%3E</a><br><a href="https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/AUK2YRO6QIH64WP2LRA5D4LACTXQPPU4/">https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/AUK2YRO6QIH64WP2LRA5D4LACTXQPPU4/</a><br><a href="https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/CP4ON34YEXEZDZOXXWV43KVGGO6WZLJ5/">https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/CP4ON34YEXEZDZOXXWV43KVGGO6WZLJ5/</a><br><a href="https://lists.gnupg.org/pipermail/gnupg-announce/2019q3/000439.html">https://lists.gnupg.org/pipermail/gnupg-announce/2019q3/000439.html</a><br><a href="https://support.f5.com/csp/article/K08654551">https://support.f5.com/csp/article/K08654551</a><br><a href="https://support.f5.com/csp/article/K08654551?utm_source=f5support&amp;amp;utm_medium=RSS">https://support.f5.com/csp/article/K08654551?utm_source=f5support&amp;amp;utm_medium=RSS</a><br><a href="https://twitter.com/lambdafu/status/1147162583969009664">https://twitter.com/lambdafu/status/1147162583969009664</a><br></details>  |
| gpg-agent         |    CVE-2019-13050   |   LOW  |  2.2.4-1ubuntu1.4 |  | <details><summary>Expand...</summary><a href="http://lists.opensuse.org/opensuse-security-announce/2019-08/msg00039.html">http://lists.opensuse.org/opensuse-security-announce/2019-08/msg00039.html</a><br><a href="https://access.redhat.com/articles/4264021">https://access.redhat.com/articles/4264021</a><br><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2019-13050">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2019-13050</a><br><a href="https://gist.github.com/rjhansen/67ab921ffb4084c865b3618d6955275f">https://gist.github.com/rjhansen/67ab921ffb4084c865b3618d6955275f</a><br><a href="https://linux.oracle.com/cve/CVE-2019-13050.html">https://linux.oracle.com/cve/CVE-2019-13050.html</a><br><a href="https://linux.oracle.com/errata/ELSA-2020-4490.html">https://linux.oracle.com/errata/ELSA-2020-4490.html</a><br><a href="https://lists.apache.org/thread.html/r58af02e294bd07f487e2c64ffc0a29b837db5600e33b6e698b9d696b@%3Cissues.bookkeeper.apache.org%3E">https://lists.apache.org/thread.html/r58af02e294bd07f487e2c64ffc0a29b837db5600e33b6e698b9d696b@%3Cissues.bookkeeper.apache.org%3E</a><br><a href="https://lists.apache.org/thread.html/rf4c02775860db415b4955778a131c2795223f61cb8c6a450893651e4@%3Cissues.bookkeeper.apache.org%3E">https://lists.apache.org/thread.html/rf4c02775860db415b4955778a131c2795223f61cb8c6a450893651e4@%3Cissues.bookkeeper.apache.org%3E</a><br><a href="https://lists.apache.org/thread.html/rf9fa47ab66495c78bb4120b0754dd9531ca2ff0430f6685ac9b07772@%3Cdev.mina.apache.org%3E">https://lists.apache.org/thread.html/rf9fa47ab66495c78bb4120b0754dd9531ca2ff0430f6685ac9b07772@%3Cdev.mina.apache.org%3E</a><br><a href="https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/AUK2YRO6QIH64WP2LRA5D4LACTXQPPU4/">https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/AUK2YRO6QIH64WP2LRA5D4LACTXQPPU4/</a><br><a href="https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/CP4ON34YEXEZDZOXXWV43KVGGO6WZLJ5/">https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/CP4ON34YEXEZDZOXXWV43KVGGO6WZLJ5/</a><br><a href="https://lists.gnupg.org/pipermail/gnupg-announce/2019q3/000439.html">https://lists.gnupg.org/pipermail/gnupg-announce/2019q3/000439.html</a><br><a href="https://support.f5.com/csp/article/K08654551">https://support.f5.com/csp/article/K08654551</a><br><a href="https://support.f5.com/csp/article/K08654551?utm_source=f5support&amp;amp;utm_medium=RSS">https://support.f5.com/csp/article/K08654551?utm_source=f5support&amp;amp;utm_medium=RSS</a><br><a href="https://twitter.com/lambdafu/status/1147162583969009664">https://twitter.com/lambdafu/status/1147162583969009664</a><br></details>  |
| gpg-wks-client         |    CVE-2019-13050   |   LOW  |  2.2.4-1ubuntu1.4 |  | <details><summary>Expand...</summary><a href="http://lists.opensuse.org/opensuse-security-announce/2019-08/msg00039.html">http://lists.opensuse.org/opensuse-security-announce/2019-08/msg00039.html</a><br><a href="https://access.redhat.com/articles/4264021">https://access.redhat.com/articles/4264021</a><br><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2019-13050">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2019-13050</a><br><a href="https://gist.github.com/rjhansen/67ab921ffb4084c865b3618d6955275f">https://gist.github.com/rjhansen/67ab921ffb4084c865b3618d6955275f</a><br><a href="https://linux.oracle.com/cve/CVE-2019-13050.html">https://linux.oracle.com/cve/CVE-2019-13050.html</a><br><a href="https://linux.oracle.com/errata/ELSA-2020-4490.html">https://linux.oracle.com/errata/ELSA-2020-4490.html</a><br><a href="https://lists.apache.org/thread.html/r58af02e294bd07f487e2c64ffc0a29b837db5600e33b6e698b9d696b@%3Cissues.bookkeeper.apache.org%3E">https://lists.apache.org/thread.html/r58af02e294bd07f487e2c64ffc0a29b837db5600e33b6e698b9d696b@%3Cissues.bookkeeper.apache.org%3E</a><br><a href="https://lists.apache.org/thread.html/rf4c02775860db415b4955778a131c2795223f61cb8c6a450893651e4@%3Cissues.bookkeeper.apache.org%3E">https://lists.apache.org/thread.html/rf4c02775860db415b4955778a131c2795223f61cb8c6a450893651e4@%3Cissues.bookkeeper.apache.org%3E</a><br><a href="https://lists.apache.org/thread.html/rf9fa47ab66495c78bb4120b0754dd9531ca2ff0430f6685ac9b07772@%3Cdev.mina.apache.org%3E">https://lists.apache.org/thread.html/rf9fa47ab66495c78bb4120b0754dd9531ca2ff0430f6685ac9b07772@%3Cdev.mina.apache.org%3E</a><br><a href="https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/AUK2YRO6QIH64WP2LRA5D4LACTXQPPU4/">https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/AUK2YRO6QIH64WP2LRA5D4LACTXQPPU4/</a><br><a href="https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/CP4ON34YEXEZDZOXXWV43KVGGO6WZLJ5/">https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/CP4ON34YEXEZDZOXXWV43KVGGO6WZLJ5/</a><br><a href="https://lists.gnupg.org/pipermail/gnupg-announce/2019q3/000439.html">https://lists.gnupg.org/pipermail/gnupg-announce/2019q3/000439.html</a><br><a href="https://support.f5.com/csp/article/K08654551">https://support.f5.com/csp/article/K08654551</a><br><a href="https://support.f5.com/csp/article/K08654551?utm_source=f5support&amp;amp;utm_medium=RSS">https://support.f5.com/csp/article/K08654551?utm_source=f5support&amp;amp;utm_medium=RSS</a><br><a href="https://twitter.com/lambdafu/status/1147162583969009664">https://twitter.com/lambdafu/status/1147162583969009664</a><br></details>  |
| gpg-wks-server         |    CVE-2019-13050   |   LOW  |  2.2.4-1ubuntu1.4 |  | <details><summary>Expand...</summary><a href="http://lists.opensuse.org/opensuse-security-announce/2019-08/msg00039.html">http://lists.opensuse.org/opensuse-security-announce/2019-08/msg00039.html</a><br><a href="https://access.redhat.com/articles/4264021">https://access.redhat.com/articles/4264021</a><br><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2019-13050">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2019-13050</a><br><a href="https://gist.github.com/rjhansen/67ab921ffb4084c865b3618d6955275f">https://gist.github.com/rjhansen/67ab921ffb4084c865b3618d6955275f</a><br><a href="https://linux.oracle.com/cve/CVE-2019-13050.html">https://linux.oracle.com/cve/CVE-2019-13050.html</a><br><a href="https://linux.oracle.com/errata/ELSA-2020-4490.html">https://linux.oracle.com/errata/ELSA-2020-4490.html</a><br><a href="https://lists.apache.org/thread.html/r58af02e294bd07f487e2c64ffc0a29b837db5600e33b6e698b9d696b@%3Cissues.bookkeeper.apache.org%3E">https://lists.apache.org/thread.html/r58af02e294bd07f487e2c64ffc0a29b837db5600e33b6e698b9d696b@%3Cissues.bookkeeper.apache.org%3E</a><br><a href="https://lists.apache.org/thread.html/rf4c02775860db415b4955778a131c2795223f61cb8c6a450893651e4@%3Cissues.bookkeeper.apache.org%3E">https://lists.apache.org/thread.html/rf4c02775860db415b4955778a131c2795223f61cb8c6a450893651e4@%3Cissues.bookkeeper.apache.org%3E</a><br><a href="https://lists.apache.org/thread.html/rf9fa47ab66495c78bb4120b0754dd9531ca2ff0430f6685ac9b07772@%3Cdev.mina.apache.org%3E">https://lists.apache.org/thread.html/rf9fa47ab66495c78bb4120b0754dd9531ca2ff0430f6685ac9b07772@%3Cdev.mina.apache.org%3E</a><br><a href="https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/AUK2YRO6QIH64WP2LRA5D4LACTXQPPU4/">https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/AUK2YRO6QIH64WP2LRA5D4LACTXQPPU4/</a><br><a href="https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/CP4ON34YEXEZDZOXXWV43KVGGO6WZLJ5/">https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/CP4ON34YEXEZDZOXXWV43KVGGO6WZLJ5/</a><br><a href="https://lists.gnupg.org/pipermail/gnupg-announce/2019q3/000439.html">https://lists.gnupg.org/pipermail/gnupg-announce/2019q3/000439.html</a><br><a href="https://support.f5.com/csp/article/K08654551">https://support.f5.com/csp/article/K08654551</a><br><a href="https://support.f5.com/csp/article/K08654551?utm_source=f5support&amp;amp;utm_medium=RSS">https://support.f5.com/csp/article/K08654551?utm_source=f5support&amp;amp;utm_medium=RSS</a><br><a href="https://twitter.com/lambdafu/status/1147162583969009664">https://twitter.com/lambdafu/status/1147162583969009664</a><br></details>  |
| gpgconf         |    CVE-2019-13050   |   LOW  |  2.2.4-1ubuntu1.4 |  | <details><summary>Expand...</summary><a href="http://lists.opensuse.org/opensuse-security-announce/2019-08/msg00039.html">http://lists.opensuse.org/opensuse-security-announce/2019-08/msg00039.html</a><br><a href="https://access.redhat.com/articles/4264021">https://access.redhat.com/articles/4264021</a><br><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2019-13050">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2019-13050</a><br><a href="https://gist.github.com/rjhansen/67ab921ffb4084c865b3618d6955275f">https://gist.github.com/rjhansen/67ab921ffb4084c865b3618d6955275f</a><br><a href="https://linux.oracle.com/cve/CVE-2019-13050.html">https://linux.oracle.com/cve/CVE-2019-13050.html</a><br><a href="https://linux.oracle.com/errata/ELSA-2020-4490.html">https://linux.oracle.com/errata/ELSA-2020-4490.html</a><br><a href="https://lists.apache.org/thread.html/r58af02e294bd07f487e2c64ffc0a29b837db5600e33b6e698b9d696b@%3Cissues.bookkeeper.apache.org%3E">https://lists.apache.org/thread.html/r58af02e294bd07f487e2c64ffc0a29b837db5600e33b6e698b9d696b@%3Cissues.bookkeeper.apache.org%3E</a><br><a href="https://lists.apache.org/thread.html/rf4c02775860db415b4955778a131c2795223f61cb8c6a450893651e4@%3Cissues.bookkeeper.apache.org%3E">https://lists.apache.org/thread.html/rf4c02775860db415b4955778a131c2795223f61cb8c6a450893651e4@%3Cissues.bookkeeper.apache.org%3E</a><br><a href="https://lists.apache.org/thread.html/rf9fa47ab66495c78bb4120b0754dd9531ca2ff0430f6685ac9b07772@%3Cdev.mina.apache.org%3E">https://lists.apache.org/thread.html/rf9fa47ab66495c78bb4120b0754dd9531ca2ff0430f6685ac9b07772@%3Cdev.mina.apache.org%3E</a><br><a href="https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/AUK2YRO6QIH64WP2LRA5D4LACTXQPPU4/">https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/AUK2YRO6QIH64WP2LRA5D4LACTXQPPU4/</a><br><a href="https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/CP4ON34YEXEZDZOXXWV43KVGGO6WZLJ5/">https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/CP4ON34YEXEZDZOXXWV43KVGGO6WZLJ5/</a><br><a href="https://lists.gnupg.org/pipermail/gnupg-announce/2019q3/000439.html">https://lists.gnupg.org/pipermail/gnupg-announce/2019q3/000439.html</a><br><a href="https://support.f5.com/csp/article/K08654551">https://support.f5.com/csp/article/K08654551</a><br><a href="https://support.f5.com/csp/article/K08654551?utm_source=f5support&amp;amp;utm_medium=RSS">https://support.f5.com/csp/article/K08654551?utm_source=f5support&amp;amp;utm_medium=RSS</a><br><a href="https://twitter.com/lambdafu/status/1147162583969009664">https://twitter.com/lambdafu/status/1147162583969009664</a><br></details>  |
| gpgsm         |    CVE-2019-13050   |   LOW  |  2.2.4-1ubuntu1.4 |  | <details><summary>Expand...</summary><a href="http://lists.opensuse.org/opensuse-security-announce/2019-08/msg00039.html">http://lists.opensuse.org/opensuse-security-announce/2019-08/msg00039.html</a><br><a href="https://access.redhat.com/articles/4264021">https://access.redhat.com/articles/4264021</a><br><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2019-13050">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2019-13050</a><br><a href="https://gist.github.com/rjhansen/67ab921ffb4084c865b3618d6955275f">https://gist.github.com/rjhansen/67ab921ffb4084c865b3618d6955275f</a><br><a href="https://linux.oracle.com/cve/CVE-2019-13050.html">https://linux.oracle.com/cve/CVE-2019-13050.html</a><br><a href="https://linux.oracle.com/errata/ELSA-2020-4490.html">https://linux.oracle.com/errata/ELSA-2020-4490.html</a><br><a href="https://lists.apache.org/thread.html/r58af02e294bd07f487e2c64ffc0a29b837db5600e33b6e698b9d696b@%3Cissues.bookkeeper.apache.org%3E">https://lists.apache.org/thread.html/r58af02e294bd07f487e2c64ffc0a29b837db5600e33b6e698b9d696b@%3Cissues.bookkeeper.apache.org%3E</a><br><a href="https://lists.apache.org/thread.html/rf4c02775860db415b4955778a131c2795223f61cb8c6a450893651e4@%3Cissues.bookkeeper.apache.org%3E">https://lists.apache.org/thread.html/rf4c02775860db415b4955778a131c2795223f61cb8c6a450893651e4@%3Cissues.bookkeeper.apache.org%3E</a><br><a href="https://lists.apache.org/thread.html/rf9fa47ab66495c78bb4120b0754dd9531ca2ff0430f6685ac9b07772@%3Cdev.mina.apache.org%3E">https://lists.apache.org/thread.html/rf9fa47ab66495c78bb4120b0754dd9531ca2ff0430f6685ac9b07772@%3Cdev.mina.apache.org%3E</a><br><a href="https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/AUK2YRO6QIH64WP2LRA5D4LACTXQPPU4/">https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/AUK2YRO6QIH64WP2LRA5D4LACTXQPPU4/</a><br><a href="https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/CP4ON34YEXEZDZOXXWV43KVGGO6WZLJ5/">https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/CP4ON34YEXEZDZOXXWV43KVGGO6WZLJ5/</a><br><a href="https://lists.gnupg.org/pipermail/gnupg-announce/2019q3/000439.html">https://lists.gnupg.org/pipermail/gnupg-announce/2019q3/000439.html</a><br><a href="https://support.f5.com/csp/article/K08654551">https://support.f5.com/csp/article/K08654551</a><br><a href="https://support.f5.com/csp/article/K08654551?utm_source=f5support&amp;amp;utm_medium=RSS">https://support.f5.com/csp/article/K08654551?utm_source=f5support&amp;amp;utm_medium=RSS</a><br><a href="https://twitter.com/lambdafu/status/1147162583969009664">https://twitter.com/lambdafu/status/1147162583969009664</a><br></details>  |
| gpgv         |    CVE-2019-13050   |   LOW  |  2.2.4-1ubuntu1.4 |  | <details><summary>Expand...</summary><a href="http://lists.opensuse.org/opensuse-security-announce/2019-08/msg00039.html">http://lists.opensuse.org/opensuse-security-announce/2019-08/msg00039.html</a><br><a href="https://access.redhat.com/articles/4264021">https://access.redhat.com/articles/4264021</a><br><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2019-13050">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2019-13050</a><br><a href="https://gist.github.com/rjhansen/67ab921ffb4084c865b3618d6955275f">https://gist.github.com/rjhansen/67ab921ffb4084c865b3618d6955275f</a><br><a href="https://linux.oracle.com/cve/CVE-2019-13050.html">https://linux.oracle.com/cve/CVE-2019-13050.html</a><br><a href="https://linux.oracle.com/errata/ELSA-2020-4490.html">https://linux.oracle.com/errata/ELSA-2020-4490.html</a><br><a href="https://lists.apache.org/thread.html/r58af02e294bd07f487e2c64ffc0a29b837db5600e33b6e698b9d696b@%3Cissues.bookkeeper.apache.org%3E">https://lists.apache.org/thread.html/r58af02e294bd07f487e2c64ffc0a29b837db5600e33b6e698b9d696b@%3Cissues.bookkeeper.apache.org%3E</a><br><a href="https://lists.apache.org/thread.html/rf4c02775860db415b4955778a131c2795223f61cb8c6a450893651e4@%3Cissues.bookkeeper.apache.org%3E">https://lists.apache.org/thread.html/rf4c02775860db415b4955778a131c2795223f61cb8c6a450893651e4@%3Cissues.bookkeeper.apache.org%3E</a><br><a href="https://lists.apache.org/thread.html/rf9fa47ab66495c78bb4120b0754dd9531ca2ff0430f6685ac9b07772@%3Cdev.mina.apache.org%3E">https://lists.apache.org/thread.html/rf9fa47ab66495c78bb4120b0754dd9531ca2ff0430f6685ac9b07772@%3Cdev.mina.apache.org%3E</a><br><a href="https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/AUK2YRO6QIH64WP2LRA5D4LACTXQPPU4/">https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/AUK2YRO6QIH64WP2LRA5D4LACTXQPPU4/</a><br><a href="https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/CP4ON34YEXEZDZOXXWV43KVGGO6WZLJ5/">https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/CP4ON34YEXEZDZOXXWV43KVGGO6WZLJ5/</a><br><a href="https://lists.gnupg.org/pipermail/gnupg-announce/2019q3/000439.html">https://lists.gnupg.org/pipermail/gnupg-announce/2019q3/000439.html</a><br><a href="https://support.f5.com/csp/article/K08654551">https://support.f5.com/csp/article/K08654551</a><br><a href="https://support.f5.com/csp/article/K08654551?utm_source=f5support&amp;amp;utm_medium=RSS">https://support.f5.com/csp/article/K08654551?utm_source=f5support&amp;amp;utm_medium=RSS</a><br><a href="https://twitter.com/lambdafu/status/1147162583969009664">https://twitter.com/lambdafu/status/1147162583969009664</a><br></details>  |
| krb5-locales         |    CVE-2018-20217   |   MEDIUM  |  1.16-2ubuntu0.2 |  | <details><summary>Expand...</summary><a href="http://krbdev.mit.edu/rt/Ticket/Display.html?id=8763">http://krbdev.mit.edu/rt/Ticket/Display.html?id=8763</a><br><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2018-20217">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2018-20217</a><br><a href="https://github.com/krb5/krb5/commit/5e6d1796106df8ba6bc1973ee0917c170d929086">https://github.com/krb5/krb5/commit/5e6d1796106df8ba6bc1973ee0917c170d929086</a><br><a href="https://lists.debian.org/debian-lts-announce/2019/01/msg00020.html">https://lists.debian.org/debian-lts-announce/2019/01/msg00020.html</a><br><a href="https://lists.debian.org/debian-lts-announce/2021/09/msg00019.html">https://lists.debian.org/debian-lts-announce/2021/09/msg00019.html</a><br><a href="https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/2KNHELH4YHNT6H2ESJWX2UIDXLBNGB2O/">https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/2KNHELH4YHNT6H2ESJWX2UIDXLBNGB2O/</a><br><a href="https://security.netapp.com/advisory/ntap-20190416-0006/">https://security.netapp.com/advisory/ntap-20190416-0006/</a><br></details>  |
| krb5-locales         |    CVE-2021-36222   |   MEDIUM  |  1.16-2ubuntu0.2 |  | <details><summary>Expand...</summary><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2021-36222">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2021-36222</a><br><a href="https://github.com/krb5/krb5/commit/fc98f520caefff2e5ee9a0026fdf5109944b3562">https://github.com/krb5/krb5/commit/fc98f520caefff2e5ee9a0026fdf5109944b3562</a><br><a href="https://github.com/krb5/krb5/releases">https://github.com/krb5/krb5/releases</a><br><a href="https://linux.oracle.com/cve/CVE-2021-36222.html">https://linux.oracle.com/cve/CVE-2021-36222.html</a><br><a href="https://linux.oracle.com/errata/ELSA-2021-3576.html">https://linux.oracle.com/errata/ELSA-2021-3576.html</a><br><a href="https://security.netapp.com/advisory/ntap-20211022-0003/">https://security.netapp.com/advisory/ntap-20211022-0003/</a><br><a href="https://security.netapp.com/advisory/ntap-20211104-0007/">https://security.netapp.com/advisory/ntap-20211104-0007/</a><br><a href="https://web.mit.edu/kerberos/advisories/">https://web.mit.edu/kerberos/advisories/</a><br><a href="https://www.debian.org/security/2021/dsa-4944">https://www.debian.org/security/2021/dsa-4944</a><br><a href="https://www.oracle.com/security-alerts/cpuoct2021.html">https://www.oracle.com/security-alerts/cpuoct2021.html</a><br></details>  |
| krb5-locales         |    CVE-2018-5709   |   LOW  |  1.16-2ubuntu0.2 |  | <details><summary>Expand...</summary><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2018-5709">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2018-5709</a><br><a href="https://github.com/poojamnit/Kerberos-V5-1.16-Vulnerabilities/tree/master/Integer%20Overflow">https://github.com/poojamnit/Kerberos-V5-1.16-Vulnerabilities/tree/master/Integer%20Overflow</a><br><a href="https://lists.apache.org/thread.html/rf9fa47ab66495c78bb4120b0754dd9531ca2ff0430f6685ac9b07772@%3Cdev.mina.apache.org%3E">https://lists.apache.org/thread.html/rf9fa47ab66495c78bb4120b0754dd9531ca2ff0430f6685ac9b07772@%3Cdev.mina.apache.org%3E</a><br></details>  |
| krb5-locales         |    CVE-2018-5710   |   LOW  |  1.16-2ubuntu0.2 |  | <details><summary>Expand...</summary><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2018-5710">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2018-5710</a><br><a href="https://github.com/poojamnit/Kerberos-V5-1.16-Vulnerabilities/tree/master/Denial%20Of%20Service(DoS)">https://github.com/poojamnit/Kerberos-V5-1.16-Vulnerabilities/tree/master/Denial%20Of%20Service(DoS)</a><br></details>  |
| libasn1-8-heimdal         |    CVE-2019-12098   |   LOW  |  7.5.0+dfsg-1 |  | <details><summary>Expand...</summary><a href="http://lists.opensuse.org/opensuse-security-announce/2019-07/msg00002.html">http://lists.opensuse.org/opensuse-security-announce/2019-07/msg00002.html</a><br><a href="http://lists.opensuse.org/opensuse-security-announce/2019-07/msg00003.html">http://lists.opensuse.org/opensuse-security-announce/2019-07/msg00003.html</a><br><a href="http://lists.opensuse.org/opensuse-security-announce/2019-08/msg00026.html">http://lists.opensuse.org/opensuse-security-announce/2019-08/msg00026.html</a><br><a href="http://www.h5l.org/pipermail/heimdal-announce/2019-May/000009.html">http://www.h5l.org/pipermail/heimdal-announce/2019-May/000009.html</a><br><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2019-12098">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2019-12098</a><br><a href="https://github.com/heimdal/heimdal/commit/2f7f3d9960aa6ea21358bdf3687cee5149aa35cf">https://github.com/heimdal/heimdal/commit/2f7f3d9960aa6ea21358bdf3687cee5149aa35cf</a><br><a href="https://github.com/heimdal/heimdal/compare/3e58559...bbafe72">https://github.com/heimdal/heimdal/compare/3e58559...bbafe72</a><br><a href="https://github.com/heimdal/heimdal/releases/tag/heimdal-7.6.0">https://github.com/heimdal/heimdal/releases/tag/heimdal-7.6.0</a><br><a href="https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/GIXEDVVMPD6ZAJSMI2EZ7FNEIVNWE5PD/">https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/GIXEDVVMPD6ZAJSMI2EZ7FNEIVNWE5PD/</a><br><a href="https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/SLXXIF4LOQEAEDAF4UGP2AO6WDNTDFUB/">https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/SLXXIF4LOQEAEDAF4UGP2AO6WDNTDFUB/</a><br><a href="https://seclists.org/bugtraq/2019/Jun/1">https://seclists.org/bugtraq/2019/Jun/1</a><br><a href="https://www.debian.org/security/2019/dsa-4455">https://www.debian.org/security/2019/dsa-4455</a><br></details>  |
| libasn1-8-heimdal         |    CVE-2021-3671   |   LOW  |  7.5.0+dfsg-1 |  | <details><summary>Expand...</summary><a href="https://bugzilla.redhat.com/show_bug.cgi?id=2013080,">https://bugzilla.redhat.com/show_bug.cgi?id=2013080,</a><br><a href="https://bugzilla.samba.org/show_bug.cgi?id=14770,">https://bugzilla.samba.org/show_bug.cgi?id=14770,</a><br><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2021-3671">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2021-3671</a><br><a href="https://github.com/heimdal/heimdal/commit/04171147948d0a3636bc6374181926f0fb2ec83a">https://github.com/heimdal/heimdal/commit/04171147948d0a3636bc6374181926f0fb2ec83a</a><br><a href="https://ubuntu.com/security/notices/USN-5142-1">https://ubuntu.com/security/notices/USN-5142-1</a><br><a href="https://ubuntu.com/security/notices/USN-5174-1">https://ubuntu.com/security/notices/USN-5174-1</a><br></details>  |
| libc-bin         |    CVE-2021-35942   |   MEDIUM  |  2.27-3ubuntu1.4 |  | <details><summary>Expand...</summary><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2021-35942">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2021-35942</a><br><a href="https://linux.oracle.com/cve/CVE-2021-35942.html">https://linux.oracle.com/cve/CVE-2021-35942.html</a><br><a href="https://linux.oracle.com/errata/ELSA-2021-9560.html">https://linux.oracle.com/errata/ELSA-2021-9560.html</a><br><a href="https://security.netapp.com/advisory/ntap-20210827-0005/">https://security.netapp.com/advisory/ntap-20210827-0005/</a><br><a href="https://sourceware.org/bugzilla/show_bug.cgi?id=28011">https://sourceware.org/bugzilla/show_bug.cgi?id=28011</a><br><a href="https://sourceware.org/git/?p=glibc.git;a=commit;h=5adda61f62b77384718b4c0d8336ade8f2b4b35c">https://sourceware.org/git/?p=glibc.git;a=commit;h=5adda61f62b77384718b4c0d8336ade8f2b4b35c</a><br><a href="https://sourceware.org/git/?p=glibc.git;a=commitdiff;h=5adda61f62b77384718b4c0d8336ade8f2b4b35c">https://sourceware.org/git/?p=glibc.git;a=commitdiff;h=5adda61f62b77384718b4c0d8336ade8f2b4b35c</a><br><a href="https://sourceware.org/glibc/wiki/Security%20Exceptions">https://sourceware.org/glibc/wiki/Security%20Exceptions</a><br></details>  |
| libc-bin         |    CVE-2021-38604   |   MEDIUM  |  2.27-3ubuntu1.4 |  | <details><summary>Expand...</summary><a href="https://blog.tuxcare.com/cve/tuxcare-team-identifies-cve-2021-38604-a-new-vulnerability-in-glibc">https://blog.tuxcare.com/cve/tuxcare-team-identifies-cve-2021-38604-a-new-vulnerability-in-glibc</a><br><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2021-38604">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2021-38604</a><br><a href="https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/GYEXYM37RCJWJ6B5KQUYQI4NZBDDYSXP/">https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/GYEXYM37RCJWJ6B5KQUYQI4NZBDDYSXP/</a><br><a href="https://security.netapp.com/advisory/ntap-20210909-0005/">https://security.netapp.com/advisory/ntap-20210909-0005/</a><br><a href="https://sourceware.org/bugzilla/show_bug.cgi?id=28213">https://sourceware.org/bugzilla/show_bug.cgi?id=28213</a><br><a href="https://sourceware.org/git/?p=glibc.git;a=commit;h=4cc79c217744743077bf7a0ec5e0a4318f1e6641">https://sourceware.org/git/?p=glibc.git;a=commit;h=4cc79c217744743077bf7a0ec5e0a4318f1e6641</a><br><a href="https://sourceware.org/git/?p=glibc.git;a=commit;h=b805aebd42364fe696e417808a700fdb9800c9e8">https://sourceware.org/git/?p=glibc.git;a=commit;h=b805aebd42364fe696e417808a700fdb9800c9e8</a><br></details>  |
| libc-bin         |    CVE-2009-5155   |   LOW  |  2.27-3ubuntu1.4 |  | <details><summary>Expand...</summary><a href="http://git.savannah.gnu.org/cgit/gnulib.git/commit/?id=5513b40999149090987a0341c018d05d3eea1272">http://git.savannah.gnu.org/cgit/gnulib.git/commit/?id=5513b40999149090987a0341c018d05d3eea1272</a><br><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2009-5155">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2009-5155</a><br><a href="https://debbugs.gnu.org/cgi/bugreport.cgi?bug=22793">https://debbugs.gnu.org/cgi/bugreport.cgi?bug=22793</a><br><a href="https://debbugs.gnu.org/cgi/bugreport.cgi?bug=32806">https://debbugs.gnu.org/cgi/bugreport.cgi?bug=32806</a><br><a href="https://debbugs.gnu.org/cgi/bugreport.cgi?bug=34238">https://debbugs.gnu.org/cgi/bugreport.cgi?bug=34238</a><br><a href="https://lists.apache.org/thread.html/r58af02e294bd07f487e2c64ffc0a29b837db5600e33b6e698b9d696b@%3Cissues.bookkeeper.apache.org%3E">https://lists.apache.org/thread.html/r58af02e294bd07f487e2c64ffc0a29b837db5600e33b6e698b9d696b@%3Cissues.bookkeeper.apache.org%3E</a><br><a href="https://lists.apache.org/thread.html/rf4c02775860db415b4955778a131c2795223f61cb8c6a450893651e4@%3Cissues.bookkeeper.apache.org%3E">https://lists.apache.org/thread.html/rf4c02775860db415b4955778a131c2795223f61cb8c6a450893651e4@%3Cissues.bookkeeper.apache.org%3E</a><br><a href="https://security.netapp.com/advisory/ntap-20190315-0002/">https://security.netapp.com/advisory/ntap-20190315-0002/</a><br><a href="https://sourceware.org/bugzilla/show_bug.cgi?id=11053">https://sourceware.org/bugzilla/show_bug.cgi?id=11053</a><br><a href="https://sourceware.org/bugzilla/show_bug.cgi?id=18986">https://sourceware.org/bugzilla/show_bug.cgi?id=18986</a><br><a href="https://sourceware.org/git/gitweb.cgi?p=glibc.git;h=eb04c21373e2a2885f3d52ff192b0499afe3c672">https://sourceware.org/git/gitweb.cgi?p=glibc.git;h=eb04c21373e2a2885f3d52ff192b0499afe3c672</a><br><a href="https://support.f5.com/csp/article/K64119434">https://support.f5.com/csp/article/K64119434</a><br><a href="https://support.f5.com/csp/article/K64119434?utm_source=f5support&amp;amp;utm_medium=RSS">https://support.f5.com/csp/article/K64119434?utm_source=f5support&amp;amp;utm_medium=RSS</a><br><a href="https://ubuntu.com/security/notices/USN-4954-1">https://ubuntu.com/security/notices/USN-4954-1</a><br></details>  |
| libc-bin         |    CVE-2015-8985   |   LOW  |  2.27-3ubuntu1.4 |  | <details><summary>Expand...</summary><a href="http://www.openwall.com/lists/oss-security/2017/02/14/9">http://www.openwall.com/lists/oss-security/2017/02/14/9</a><br><a href="http://www.securityfocus.com/bid/76916">http://www.securityfocus.com/bid/76916</a><br><a href="https://bugs.debian.org/cgi-bin/bugreport.cgi?bug=779392">https://bugs.debian.org/cgi-bin/bugreport.cgi?bug=779392</a><br><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2015-8985">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2015-8985</a><br><a href="https://security.gentoo.org/glsa/201908-06">https://security.gentoo.org/glsa/201908-06</a><br></details>  |
| libc-bin         |    CVE-2016-10228   |   LOW  |  2.27-3ubuntu1.4 |  | <details><summary>Expand...</summary><a href="http://openwall.com/lists/oss-security/2017/03/01/10">http://openwall.com/lists/oss-security/2017/03/01/10</a><br><a href="http://www.securityfocus.com/bid/96525">http://www.securityfocus.com/bid/96525</a><br><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2016-10228">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2016-10228</a><br><a href="https://linux.oracle.com/cve/CVE-2016-10228.html">https://linux.oracle.com/cve/CVE-2016-10228.html</a><br><a href="https://linux.oracle.com/errata/ELSA-2021-9344.html">https://linux.oracle.com/errata/ELSA-2021-9344.html</a><br><a href="https://lists.apache.org/thread.html/rf9fa47ab66495c78bb4120b0754dd9531ca2ff0430f6685ac9b07772@%3Cdev.mina.apache.org%3E">https://lists.apache.org/thread.html/rf9fa47ab66495c78bb4120b0754dd9531ca2ff0430f6685ac9b07772@%3Cdev.mina.apache.org%3E</a><br><a href="https://security.gentoo.org/glsa/202101-20">https://security.gentoo.org/glsa/202101-20</a><br><a href="https://sourceware.org/bugzilla/show_bug.cgi?id=19519">https://sourceware.org/bugzilla/show_bug.cgi?id=19519</a><br><a href="https://sourceware.org/bugzilla/show_bug.cgi?id=19519#c21">https://sourceware.org/bugzilla/show_bug.cgi?id=19519#c21</a><br><a href="https://sourceware.org/bugzilla/show_bug.cgi?id=26224">https://sourceware.org/bugzilla/show_bug.cgi?id=26224</a><br></details>  |
| libc-bin         |    CVE-2016-10739   |   LOW  |  2.27-3ubuntu1.4 |  | <details><summary>Expand...</summary><a href="http://lists.opensuse.org/opensuse-security-announce/2019-04/msg00082.html">http://lists.opensuse.org/opensuse-security-announce/2019-04/msg00082.html</a><br><a href="http://www.securityfocus.com/bid/106672">http://www.securityfocus.com/bid/106672</a><br><a href="https://access.redhat.com/errata/RHSA-2019:2118">https://access.redhat.com/errata/RHSA-2019:2118</a><br><a href="https://access.redhat.com/errata/RHSA-2019:3513">https://access.redhat.com/errata/RHSA-2019:3513</a><br><a href="https://bugzilla.redhat.com/show_bug.cgi?id=1347549">https://bugzilla.redhat.com/show_bug.cgi?id=1347549</a><br><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2016-10739">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2016-10739</a><br><a href="https://linux.oracle.com/cve/CVE-2016-10739.html">https://linux.oracle.com/cve/CVE-2016-10739.html</a><br><a href="https://linux.oracle.com/errata/ELSA-2019-3513.html">https://linux.oracle.com/errata/ELSA-2019-3513.html</a><br><a href="https://sourceware.org/bugzilla/show_bug.cgi?id=20018">https://sourceware.org/bugzilla/show_bug.cgi?id=20018</a><br></details>  |
| libc-bin         |    CVE-2019-25013   |   LOW  |  2.27-3ubuntu1.4 |  | <details><summary>Expand...</summary><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2019-25013">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2019-25013</a><br><a href="https://linux.oracle.com/cve/CVE-2019-25013.html">https://linux.oracle.com/cve/CVE-2019-25013.html</a><br><a href="https://linux.oracle.com/errata/ELSA-2021-9344.html">https://linux.oracle.com/errata/ELSA-2021-9344.html</a><br><a href="https://lists.apache.org/thread.html/r32d767ac804e9b8aad4355bb85960a6a1385eab7afff549a5e98660f@%3Cjira.kafka.apache.org%3E">https://lists.apache.org/thread.html/r32d767ac804e9b8aad4355bb85960a6a1385eab7afff549a5e98660f@%3Cjira.kafka.apache.org%3E</a><br><a href="https://lists.apache.org/thread.html/r448bb851cc8e6e3f93f3c28c70032b37062625d81214744474ac49e7@%3Cdev.kafka.apache.org%3E">https://lists.apache.org/thread.html/r448bb851cc8e6e3f93f3c28c70032b37062625d81214744474ac49e7@%3Cdev.kafka.apache.org%3E</a><br><a href="https://lists.apache.org/thread.html/r4806a391091e082bdea17266452ca656ebc176e51bb3932733b3a0a2@%3Cjira.kafka.apache.org%3E">https://lists.apache.org/thread.html/r4806a391091e082bdea17266452ca656ebc176e51bb3932733b3a0a2@%3Cjira.kafka.apache.org%3E</a><br><a href="https://lists.apache.org/thread.html/r499e4f96d0b5109ef083f2feccd33c51650c1b7d7068aa3bd47efca9@%3Cjira.kafka.apache.org%3E">https://lists.apache.org/thread.html/r499e4f96d0b5109ef083f2feccd33c51650c1b7d7068aa3bd47efca9@%3Cjira.kafka.apache.org%3E</a><br><a href="https://lists.apache.org/thread.html/r5af4430421bb6f9973294691a7904bbd260937e9eef96b20556f43ff@%3Cjira.kafka.apache.org%3E">https://lists.apache.org/thread.html/r5af4430421bb6f9973294691a7904bbd260937e9eef96b20556f43ff@%3Cjira.kafka.apache.org%3E</a><br><a href="https://lists.apache.org/thread.html/r750eee18542bc02bd8350861c424ee60a9b9b225568fa09436a37ece@%3Cissues.zookeeper.apache.org%3E">https://lists.apache.org/thread.html/r750eee18542bc02bd8350861c424ee60a9b9b225568fa09436a37ece@%3Cissues.zookeeper.apache.org%3E</a><br><a href="https://lists.apache.org/thread.html/r7a2e94adfe0a2f0a1d42e4927e8c32ecac97d37db9cb68095fe9ddbc@%3Cdev.zookeeper.apache.org%3E">https://lists.apache.org/thread.html/r7a2e94adfe0a2f0a1d42e4927e8c32ecac97d37db9cb68095fe9ddbc@%3Cdev.zookeeper.apache.org%3E</a><br><a href="https://lists.apache.org/thread.html/rd2354f9ccce41e494fbadcbc5ad87218de6ec0fff8a7b54c8462226c@%3Cissues.zookeeper.apache.org%3E">https://lists.apache.org/thread.html/rd2354f9ccce41e494fbadcbc5ad87218de6ec0fff8a7b54c8462226c@%3Cissues.zookeeper.apache.org%3E</a><br><a href="https://lists.apache.org/thread.html/rf9fa47ab66495c78bb4120b0754dd9531ca2ff0430f6685ac9b07772@%3Cdev.mina.apache.org%3E">https://lists.apache.org/thread.html/rf9fa47ab66495c78bb4120b0754dd9531ca2ff0430f6685ac9b07772@%3Cdev.mina.apache.org%3E</a><br><a href="https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/4Y6TX47P47KABSFOL26FLDNVCWXDKDEZ/">https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/4Y6TX47P47KABSFOL26FLDNVCWXDKDEZ/</a><br><a href="https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/TVCUNLQ3HXGS4VPUQKWTJGRAW2KTFGXS/">https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/TVCUNLQ3HXGS4VPUQKWTJGRAW2KTFGXS/</a><br><a href="https://security.netapp.com/advisory/ntap-20210205-0004/">https://security.netapp.com/advisory/ntap-20210205-0004/</a><br><a href="https://sourceware.org/bugzilla/show_bug.cgi?id=24973">https://sourceware.org/bugzilla/show_bug.cgi?id=24973</a><br><a href="https://sourceware.org/git/?p=glibc.git;a=commit;h=ee7a3144c9922808181009b7b3e50e852fb4999b">https://sourceware.org/git/?p=glibc.git;a=commit;h=ee7a3144c9922808181009b7b3e50e852fb4999b</a><br></details>  |
| libc-bin         |    CVE-2020-27618   |   LOW  |  2.27-3ubuntu1.4 |  | <details><summary>Expand...</summary><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2020-27618">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2020-27618</a><br><a href="https://linux.oracle.com/cve/CVE-2020-27618.html">https://linux.oracle.com/cve/CVE-2020-27618.html</a><br><a href="https://linux.oracle.com/errata/ELSA-2021-9344.html">https://linux.oracle.com/errata/ELSA-2021-9344.html</a><br><a href="https://security.netapp.com/advisory/ntap-20210401-0006/">https://security.netapp.com/advisory/ntap-20210401-0006/</a><br><a href="https://sourceware.org/bugzilla/show_bug.cgi?id=19519#c21">https://sourceware.org/bugzilla/show_bug.cgi?id=19519#c21</a><br><a href="https://sourceware.org/bugzilla/show_bug.cgi?id=26224">https://sourceware.org/bugzilla/show_bug.cgi?id=26224</a><br></details>  |
| libc-bin         |    CVE-2020-6096   |   LOW  |  2.27-3ubuntu1.4 |  | <details><summary>Expand...</summary><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2020-6096">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2020-6096</a><br><a href="https://lists.apache.org/thread.html/rf9fa47ab66495c78bb4120b0754dd9531ca2ff0430f6685ac9b07772@%3Cdev.mina.apache.org%3E">https://lists.apache.org/thread.html/rf9fa47ab66495c78bb4120b0754dd9531ca2ff0430f6685ac9b07772@%3Cdev.mina.apache.org%3E</a><br><a href="https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/SPYXTDOOB4PQGTYAMZAZNJIB3FF6YQXI/">https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/SPYXTDOOB4PQGTYAMZAZNJIB3FF6YQXI/</a><br><a href="https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/URXOIA2LDUKHQXK4BE55BQBRI6ZZG3Y6/">https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/URXOIA2LDUKHQXK4BE55BQBRI6ZZG3Y6/</a><br><a href="https://security.gentoo.org/glsa/202101-20">https://security.gentoo.org/glsa/202101-20</a><br><a href="https://sourceware.org/bugzilla/attachment.cgi?id=12334">https://sourceware.org/bugzilla/attachment.cgi?id=12334</a><br><a href="https://sourceware.org/bugzilla/show_bug.cgi?id=25620">https://sourceware.org/bugzilla/show_bug.cgi?id=25620</a><br><a href="https://talosintelligence.com/vulnerability_reports/TALOS-2020-1019">https://talosintelligence.com/vulnerability_reports/TALOS-2020-1019</a><br><a href="https://ubuntu.com/security/notices/USN-4954-1">https://ubuntu.com/security/notices/USN-4954-1</a><br><a href="https://www.talosintelligence.com/vulnerability_reports/TALOS-2020-1019">https://www.talosintelligence.com/vulnerability_reports/TALOS-2020-1019</a><br></details>  |
| libc-bin         |    CVE-2021-3326   |   LOW  |  2.27-3ubuntu1.4 |  | <details><summary>Expand...</summary><a href="http://www.openwall.com/lists/oss-security/2021/01/28/2">http://www.openwall.com/lists/oss-security/2021/01/28/2</a><br><a href="https://bugs.chromium.org/p/project-zero/issues/detail?id=2146">https://bugs.chromium.org/p/project-zero/issues/detail?id=2146</a><br><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2021-3326">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2021-3326</a><br><a href="https://linux.oracle.com/cve/CVE-2021-3326.html">https://linux.oracle.com/cve/CVE-2021-3326.html</a><br><a href="https://linux.oracle.com/errata/ELSA-2021-9344.html">https://linux.oracle.com/errata/ELSA-2021-9344.html</a><br><a href="https://security.netapp.com/advisory/ntap-20210304-0007/">https://security.netapp.com/advisory/ntap-20210304-0007/</a><br><a href="https://sourceware.org/bugzilla/show_bug.cgi?id=27256">https://sourceware.org/bugzilla/show_bug.cgi?id=27256</a><br><a href="https://sourceware.org/git/?p=glibc.git;a=commit;h=7d88c6142c6efc160c0ee5e4f85cde382c072888">https://sourceware.org/git/?p=glibc.git;a=commit;h=7d88c6142c6efc160c0ee5e4f85cde382c072888</a><br><a href="https://sourceware.org/pipermail/libc-alpha/2021-January/122058.html">https://sourceware.org/pipermail/libc-alpha/2021-January/122058.html</a><br></details>  |
| libc-bin         |    CVE-2021-33574   |   LOW  |  2.27-3ubuntu1.4 |  | <details><summary>Expand...</summary><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2021-33574">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2021-33574</a><br><a href="https://linux.oracle.com/cve/CVE-2021-33574.html">https://linux.oracle.com/cve/CVE-2021-33574.html</a><br><a href="https://linux.oracle.com/errata/ELSA-2021-9560.html">https://linux.oracle.com/errata/ELSA-2021-9560.html</a><br><a href="https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/RBUUWUGXVILQXVWEOU7N42ICHPJNAEUP/">https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/RBUUWUGXVILQXVWEOU7N42ICHPJNAEUP/</a><br><a href="https://security.gentoo.org/glsa/202107-07">https://security.gentoo.org/glsa/202107-07</a><br><a href="https://security.netapp.com/advisory/ntap-20210629-0005/">https://security.netapp.com/advisory/ntap-20210629-0005/</a><br><a href="https://sourceware.org/bugzilla/show_bug.cgi?id=27896">https://sourceware.org/bugzilla/show_bug.cgi?id=27896</a><br><a href="https://sourceware.org/bugzilla/show_bug.cgi?id=27896#c1">https://sourceware.org/bugzilla/show_bug.cgi?id=27896#c1</a><br></details>  |
| libc6         |    CVE-2021-35942   |   MEDIUM  |  2.27-3ubuntu1.4 |  | <details><summary>Expand...</summary><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2021-35942">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2021-35942</a><br><a href="https://linux.oracle.com/cve/CVE-2021-35942.html">https://linux.oracle.com/cve/CVE-2021-35942.html</a><br><a href="https://linux.oracle.com/errata/ELSA-2021-9560.html">https://linux.oracle.com/errata/ELSA-2021-9560.html</a><br><a href="https://security.netapp.com/advisory/ntap-20210827-0005/">https://security.netapp.com/advisory/ntap-20210827-0005/</a><br><a href="https://sourceware.org/bugzilla/show_bug.cgi?id=28011">https://sourceware.org/bugzilla/show_bug.cgi?id=28011</a><br><a href="https://sourceware.org/git/?p=glibc.git;a=commit;h=5adda61f62b77384718b4c0d8336ade8f2b4b35c">https://sourceware.org/git/?p=glibc.git;a=commit;h=5adda61f62b77384718b4c0d8336ade8f2b4b35c</a><br><a href="https://sourceware.org/git/?p=glibc.git;a=commitdiff;h=5adda61f62b77384718b4c0d8336ade8f2b4b35c">https://sourceware.org/git/?p=glibc.git;a=commitdiff;h=5adda61f62b77384718b4c0d8336ade8f2b4b35c</a><br><a href="https://sourceware.org/glibc/wiki/Security%20Exceptions">https://sourceware.org/glibc/wiki/Security%20Exceptions</a><br></details>  |
| libc6         |    CVE-2021-38604   |   MEDIUM  |  2.27-3ubuntu1.4 |  | <details><summary>Expand...</summary><a href="https://blog.tuxcare.com/cve/tuxcare-team-identifies-cve-2021-38604-a-new-vulnerability-in-glibc">https://blog.tuxcare.com/cve/tuxcare-team-identifies-cve-2021-38604-a-new-vulnerability-in-glibc</a><br><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2021-38604">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2021-38604</a><br><a href="https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/GYEXYM37RCJWJ6B5KQUYQI4NZBDDYSXP/">https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/GYEXYM37RCJWJ6B5KQUYQI4NZBDDYSXP/</a><br><a href="https://security.netapp.com/advisory/ntap-20210909-0005/">https://security.netapp.com/advisory/ntap-20210909-0005/</a><br><a href="https://sourceware.org/bugzilla/show_bug.cgi?id=28213">https://sourceware.org/bugzilla/show_bug.cgi?id=28213</a><br><a href="https://sourceware.org/git/?p=glibc.git;a=commit;h=4cc79c217744743077bf7a0ec5e0a4318f1e6641">https://sourceware.org/git/?p=glibc.git;a=commit;h=4cc79c217744743077bf7a0ec5e0a4318f1e6641</a><br><a href="https://sourceware.org/git/?p=glibc.git;a=commit;h=b805aebd42364fe696e417808a700fdb9800c9e8">https://sourceware.org/git/?p=glibc.git;a=commit;h=b805aebd42364fe696e417808a700fdb9800c9e8</a><br></details>  |
| libc6         |    CVE-2009-5155   |   LOW  |  2.27-3ubuntu1.4 |  | <details><summary>Expand...</summary><a href="http://git.savannah.gnu.org/cgit/gnulib.git/commit/?id=5513b40999149090987a0341c018d05d3eea1272">http://git.savannah.gnu.org/cgit/gnulib.git/commit/?id=5513b40999149090987a0341c018d05d3eea1272</a><br><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2009-5155">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2009-5155</a><br><a href="https://debbugs.gnu.org/cgi/bugreport.cgi?bug=22793">https://debbugs.gnu.org/cgi/bugreport.cgi?bug=22793</a><br><a href="https://debbugs.gnu.org/cgi/bugreport.cgi?bug=32806">https://debbugs.gnu.org/cgi/bugreport.cgi?bug=32806</a><br><a href="https://debbugs.gnu.org/cgi/bugreport.cgi?bug=34238">https://debbugs.gnu.org/cgi/bugreport.cgi?bug=34238</a><br><a href="https://lists.apache.org/thread.html/r58af02e294bd07f487e2c64ffc0a29b837db5600e33b6e698b9d696b@%3Cissues.bookkeeper.apache.org%3E">https://lists.apache.org/thread.html/r58af02e294bd07f487e2c64ffc0a29b837db5600e33b6e698b9d696b@%3Cissues.bookkeeper.apache.org%3E</a><br><a href="https://lists.apache.org/thread.html/rf4c02775860db415b4955778a131c2795223f61cb8c6a450893651e4@%3Cissues.bookkeeper.apache.org%3E">https://lists.apache.org/thread.html/rf4c02775860db415b4955778a131c2795223f61cb8c6a450893651e4@%3Cissues.bookkeeper.apache.org%3E</a><br><a href="https://security.netapp.com/advisory/ntap-20190315-0002/">https://security.netapp.com/advisory/ntap-20190315-0002/</a><br><a href="https://sourceware.org/bugzilla/show_bug.cgi?id=11053">https://sourceware.org/bugzilla/show_bug.cgi?id=11053</a><br><a href="https://sourceware.org/bugzilla/show_bug.cgi?id=18986">https://sourceware.org/bugzilla/show_bug.cgi?id=18986</a><br><a href="https://sourceware.org/git/gitweb.cgi?p=glibc.git;h=eb04c21373e2a2885f3d52ff192b0499afe3c672">https://sourceware.org/git/gitweb.cgi?p=glibc.git;h=eb04c21373e2a2885f3d52ff192b0499afe3c672</a><br><a href="https://support.f5.com/csp/article/K64119434">https://support.f5.com/csp/article/K64119434</a><br><a href="https://support.f5.com/csp/article/K64119434?utm_source=f5support&amp;amp;utm_medium=RSS">https://support.f5.com/csp/article/K64119434?utm_source=f5support&amp;amp;utm_medium=RSS</a><br><a href="https://ubuntu.com/security/notices/USN-4954-1">https://ubuntu.com/security/notices/USN-4954-1</a><br></details>  |
| libc6         |    CVE-2015-8985   |   LOW  |  2.27-3ubuntu1.4 |  | <details><summary>Expand...</summary><a href="http://www.openwall.com/lists/oss-security/2017/02/14/9">http://www.openwall.com/lists/oss-security/2017/02/14/9</a><br><a href="http://www.securityfocus.com/bid/76916">http://www.securityfocus.com/bid/76916</a><br><a href="https://bugs.debian.org/cgi-bin/bugreport.cgi?bug=779392">https://bugs.debian.org/cgi-bin/bugreport.cgi?bug=779392</a><br><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2015-8985">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2015-8985</a><br><a href="https://security.gentoo.org/glsa/201908-06">https://security.gentoo.org/glsa/201908-06</a><br></details>  |
| libc6         |    CVE-2016-10228   |   LOW  |  2.27-3ubuntu1.4 |  | <details><summary>Expand...</summary><a href="http://openwall.com/lists/oss-security/2017/03/01/10">http://openwall.com/lists/oss-security/2017/03/01/10</a><br><a href="http://www.securityfocus.com/bid/96525">http://www.securityfocus.com/bid/96525</a><br><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2016-10228">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2016-10228</a><br><a href="https://linux.oracle.com/cve/CVE-2016-10228.html">https://linux.oracle.com/cve/CVE-2016-10228.html</a><br><a href="https://linux.oracle.com/errata/ELSA-2021-9344.html">https://linux.oracle.com/errata/ELSA-2021-9344.html</a><br><a href="https://lists.apache.org/thread.html/rf9fa47ab66495c78bb4120b0754dd9531ca2ff0430f6685ac9b07772@%3Cdev.mina.apache.org%3E">https://lists.apache.org/thread.html/rf9fa47ab66495c78bb4120b0754dd9531ca2ff0430f6685ac9b07772@%3Cdev.mina.apache.org%3E</a><br><a href="https://security.gentoo.org/glsa/202101-20">https://security.gentoo.org/glsa/202101-20</a><br><a href="https://sourceware.org/bugzilla/show_bug.cgi?id=19519">https://sourceware.org/bugzilla/show_bug.cgi?id=19519</a><br><a href="https://sourceware.org/bugzilla/show_bug.cgi?id=19519#c21">https://sourceware.org/bugzilla/show_bug.cgi?id=19519#c21</a><br><a href="https://sourceware.org/bugzilla/show_bug.cgi?id=26224">https://sourceware.org/bugzilla/show_bug.cgi?id=26224</a><br></details>  |
| libc6         |    CVE-2016-10739   |   LOW  |  2.27-3ubuntu1.4 |  | <details><summary>Expand...</summary><a href="http://lists.opensuse.org/opensuse-security-announce/2019-04/msg00082.html">http://lists.opensuse.org/opensuse-security-announce/2019-04/msg00082.html</a><br><a href="http://www.securityfocus.com/bid/106672">http://www.securityfocus.com/bid/106672</a><br><a href="https://access.redhat.com/errata/RHSA-2019:2118">https://access.redhat.com/errata/RHSA-2019:2118</a><br><a href="https://access.redhat.com/errata/RHSA-2019:3513">https://access.redhat.com/errata/RHSA-2019:3513</a><br><a href="https://bugzilla.redhat.com/show_bug.cgi?id=1347549">https://bugzilla.redhat.com/show_bug.cgi?id=1347549</a><br><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2016-10739">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2016-10739</a><br><a href="https://linux.oracle.com/cve/CVE-2016-10739.html">https://linux.oracle.com/cve/CVE-2016-10739.html</a><br><a href="https://linux.oracle.com/errata/ELSA-2019-3513.html">https://linux.oracle.com/errata/ELSA-2019-3513.html</a><br><a href="https://sourceware.org/bugzilla/show_bug.cgi?id=20018">https://sourceware.org/bugzilla/show_bug.cgi?id=20018</a><br></details>  |
| libc6         |    CVE-2019-25013   |   LOW  |  2.27-3ubuntu1.4 |  | <details><summary>Expand...</summary><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2019-25013">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2019-25013</a><br><a href="https://linux.oracle.com/cve/CVE-2019-25013.html">https://linux.oracle.com/cve/CVE-2019-25013.html</a><br><a href="https://linux.oracle.com/errata/ELSA-2021-9344.html">https://linux.oracle.com/errata/ELSA-2021-9344.html</a><br><a href="https://lists.apache.org/thread.html/r32d767ac804e9b8aad4355bb85960a6a1385eab7afff549a5e98660f@%3Cjira.kafka.apache.org%3E">https://lists.apache.org/thread.html/r32d767ac804e9b8aad4355bb85960a6a1385eab7afff549a5e98660f@%3Cjira.kafka.apache.org%3E</a><br><a href="https://lists.apache.org/thread.html/r448bb851cc8e6e3f93f3c28c70032b37062625d81214744474ac49e7@%3Cdev.kafka.apache.org%3E">https://lists.apache.org/thread.html/r448bb851cc8e6e3f93f3c28c70032b37062625d81214744474ac49e7@%3Cdev.kafka.apache.org%3E</a><br><a href="https://lists.apache.org/thread.html/r4806a391091e082bdea17266452ca656ebc176e51bb3932733b3a0a2@%3Cjira.kafka.apache.org%3E">https://lists.apache.org/thread.html/r4806a391091e082bdea17266452ca656ebc176e51bb3932733b3a0a2@%3Cjira.kafka.apache.org%3E</a><br><a href="https://lists.apache.org/thread.html/r499e4f96d0b5109ef083f2feccd33c51650c1b7d7068aa3bd47efca9@%3Cjira.kafka.apache.org%3E">https://lists.apache.org/thread.html/r499e4f96d0b5109ef083f2feccd33c51650c1b7d7068aa3bd47efca9@%3Cjira.kafka.apache.org%3E</a><br><a href="https://lists.apache.org/thread.html/r5af4430421bb6f9973294691a7904bbd260937e9eef96b20556f43ff@%3Cjira.kafka.apache.org%3E">https://lists.apache.org/thread.html/r5af4430421bb6f9973294691a7904bbd260937e9eef96b20556f43ff@%3Cjira.kafka.apache.org%3E</a><br><a href="https://lists.apache.org/thread.html/r750eee18542bc02bd8350861c424ee60a9b9b225568fa09436a37ece@%3Cissues.zookeeper.apache.org%3E">https://lists.apache.org/thread.html/r750eee18542bc02bd8350861c424ee60a9b9b225568fa09436a37ece@%3Cissues.zookeeper.apache.org%3E</a><br><a href="https://lists.apache.org/thread.html/r7a2e94adfe0a2f0a1d42e4927e8c32ecac97d37db9cb68095fe9ddbc@%3Cdev.zookeeper.apache.org%3E">https://lists.apache.org/thread.html/r7a2e94adfe0a2f0a1d42e4927e8c32ecac97d37db9cb68095fe9ddbc@%3Cdev.zookeeper.apache.org%3E</a><br><a href="https://lists.apache.org/thread.html/rd2354f9ccce41e494fbadcbc5ad87218de6ec0fff8a7b54c8462226c@%3Cissues.zookeeper.apache.org%3E">https://lists.apache.org/thread.html/rd2354f9ccce41e494fbadcbc5ad87218de6ec0fff8a7b54c8462226c@%3Cissues.zookeeper.apache.org%3E</a><br><a href="https://lists.apache.org/thread.html/rf9fa47ab66495c78bb4120b0754dd9531ca2ff0430f6685ac9b07772@%3Cdev.mina.apache.org%3E">https://lists.apache.org/thread.html/rf9fa47ab66495c78bb4120b0754dd9531ca2ff0430f6685ac9b07772@%3Cdev.mina.apache.org%3E</a><br><a href="https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/4Y6TX47P47KABSFOL26FLDNVCWXDKDEZ/">https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/4Y6TX47P47KABSFOL26FLDNVCWXDKDEZ/</a><br><a href="https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/TVCUNLQ3HXGS4VPUQKWTJGRAW2KTFGXS/">https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/TVCUNLQ3HXGS4VPUQKWTJGRAW2KTFGXS/</a><br><a href="https://security.netapp.com/advisory/ntap-20210205-0004/">https://security.netapp.com/advisory/ntap-20210205-0004/</a><br><a href="https://sourceware.org/bugzilla/show_bug.cgi?id=24973">https://sourceware.org/bugzilla/show_bug.cgi?id=24973</a><br><a href="https://sourceware.org/git/?p=glibc.git;a=commit;h=ee7a3144c9922808181009b7b3e50e852fb4999b">https://sourceware.org/git/?p=glibc.git;a=commit;h=ee7a3144c9922808181009b7b3e50e852fb4999b</a><br></details>  |
| libc6         |    CVE-2020-27618   |   LOW  |  2.27-3ubuntu1.4 |  | <details><summary>Expand...</summary><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2020-27618">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2020-27618</a><br><a href="https://linux.oracle.com/cve/CVE-2020-27618.html">https://linux.oracle.com/cve/CVE-2020-27618.html</a><br><a href="https://linux.oracle.com/errata/ELSA-2021-9344.html">https://linux.oracle.com/errata/ELSA-2021-9344.html</a><br><a href="https://security.netapp.com/advisory/ntap-20210401-0006/">https://security.netapp.com/advisory/ntap-20210401-0006/</a><br><a href="https://sourceware.org/bugzilla/show_bug.cgi?id=19519#c21">https://sourceware.org/bugzilla/show_bug.cgi?id=19519#c21</a><br><a href="https://sourceware.org/bugzilla/show_bug.cgi?id=26224">https://sourceware.org/bugzilla/show_bug.cgi?id=26224</a><br></details>  |
| libc6         |    CVE-2020-6096   |   LOW  |  2.27-3ubuntu1.4 |  | <details><summary>Expand...</summary><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2020-6096">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2020-6096</a><br><a href="https://lists.apache.org/thread.html/rf9fa47ab66495c78bb4120b0754dd9531ca2ff0430f6685ac9b07772@%3Cdev.mina.apache.org%3E">https://lists.apache.org/thread.html/rf9fa47ab66495c78bb4120b0754dd9531ca2ff0430f6685ac9b07772@%3Cdev.mina.apache.org%3E</a><br><a href="https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/SPYXTDOOB4PQGTYAMZAZNJIB3FF6YQXI/">https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/SPYXTDOOB4PQGTYAMZAZNJIB3FF6YQXI/</a><br><a href="https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/URXOIA2LDUKHQXK4BE55BQBRI6ZZG3Y6/">https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/URXOIA2LDUKHQXK4BE55BQBRI6ZZG3Y6/</a><br><a href="https://security.gentoo.org/glsa/202101-20">https://security.gentoo.org/glsa/202101-20</a><br><a href="https://sourceware.org/bugzilla/attachment.cgi?id=12334">https://sourceware.org/bugzilla/attachment.cgi?id=12334</a><br><a href="https://sourceware.org/bugzilla/show_bug.cgi?id=25620">https://sourceware.org/bugzilla/show_bug.cgi?id=25620</a><br><a href="https://talosintelligence.com/vulnerability_reports/TALOS-2020-1019">https://talosintelligence.com/vulnerability_reports/TALOS-2020-1019</a><br><a href="https://ubuntu.com/security/notices/USN-4954-1">https://ubuntu.com/security/notices/USN-4954-1</a><br><a href="https://www.talosintelligence.com/vulnerability_reports/TALOS-2020-1019">https://www.talosintelligence.com/vulnerability_reports/TALOS-2020-1019</a><br></details>  |
| libc6         |    CVE-2021-3326   |   LOW  |  2.27-3ubuntu1.4 |  | <details><summary>Expand...</summary><a href="http://www.openwall.com/lists/oss-security/2021/01/28/2">http://www.openwall.com/lists/oss-security/2021/01/28/2</a><br><a href="https://bugs.chromium.org/p/project-zero/issues/detail?id=2146">https://bugs.chromium.org/p/project-zero/issues/detail?id=2146</a><br><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2021-3326">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2021-3326</a><br><a href="https://linux.oracle.com/cve/CVE-2021-3326.html">https://linux.oracle.com/cve/CVE-2021-3326.html</a><br><a href="https://linux.oracle.com/errata/ELSA-2021-9344.html">https://linux.oracle.com/errata/ELSA-2021-9344.html</a><br><a href="https://security.netapp.com/advisory/ntap-20210304-0007/">https://security.netapp.com/advisory/ntap-20210304-0007/</a><br><a href="https://sourceware.org/bugzilla/show_bug.cgi?id=27256">https://sourceware.org/bugzilla/show_bug.cgi?id=27256</a><br><a href="https://sourceware.org/git/?p=glibc.git;a=commit;h=7d88c6142c6efc160c0ee5e4f85cde382c072888">https://sourceware.org/git/?p=glibc.git;a=commit;h=7d88c6142c6efc160c0ee5e4f85cde382c072888</a><br><a href="https://sourceware.org/pipermail/libc-alpha/2021-January/122058.html">https://sourceware.org/pipermail/libc-alpha/2021-January/122058.html</a><br></details>  |
| libc6         |    CVE-2021-33574   |   LOW  |  2.27-3ubuntu1.4 |  | <details><summary>Expand...</summary><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2021-33574">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2021-33574</a><br><a href="https://linux.oracle.com/cve/CVE-2021-33574.html">https://linux.oracle.com/cve/CVE-2021-33574.html</a><br><a href="https://linux.oracle.com/errata/ELSA-2021-9560.html">https://linux.oracle.com/errata/ELSA-2021-9560.html</a><br><a href="https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/RBUUWUGXVILQXVWEOU7N42ICHPJNAEUP/">https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/RBUUWUGXVILQXVWEOU7N42ICHPJNAEUP/</a><br><a href="https://security.gentoo.org/glsa/202107-07">https://security.gentoo.org/glsa/202107-07</a><br><a href="https://security.netapp.com/advisory/ntap-20210629-0005/">https://security.netapp.com/advisory/ntap-20210629-0005/</a><br><a href="https://sourceware.org/bugzilla/show_bug.cgi?id=27896">https://sourceware.org/bugzilla/show_bug.cgi?id=27896</a><br><a href="https://sourceware.org/bugzilla/show_bug.cgi?id=27896#c1">https://sourceware.org/bugzilla/show_bug.cgi?id=27896#c1</a><br></details>  |
| libgcc1         |    CVE-2020-13844   |   MEDIUM  |  8.4.0-1ubuntu1~18.04 |  | <details><summary>Expand...</summary><a href="http://lists.llvm.org/pipermail/llvm-dev/2020-June/142109.html">http://lists.llvm.org/pipermail/llvm-dev/2020-June/142109.html</a><br><a href="http://lists.opensuse.org/opensuse-security-announce/2020-10/msg00039.html">http://lists.opensuse.org/opensuse-security-announce/2020-10/msg00039.html</a><br><a href="http://lists.opensuse.org/opensuse-security-announce/2020-10/msg00040.html">http://lists.opensuse.org/opensuse-security-announce/2020-10/msg00040.html</a><br><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2020-13844">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2020-13844</a><br><a href="https://developer.arm.com/support/arm-security-updates/speculative-processor-vulnerability">https://developer.arm.com/support/arm-security-updates/speculative-processor-vulnerability</a><br><a href="https://developer.arm.com/support/arm-security-updates/speculative-processor-vulnerability/downloads/straight-line-speculation">https://developer.arm.com/support/arm-security-updates/speculative-processor-vulnerability/downloads/straight-line-speculation</a><br><a href="https://developer.arm.com/support/arm-security-updates/speculative-processor-vulnerability/frequently-asked-questions">https://developer.arm.com/support/arm-security-updates/speculative-processor-vulnerability/frequently-asked-questions</a><br><a href="https://gcc.gnu.org/pipermail/gcc-patches/2020-June/547520.html">https://gcc.gnu.org/pipermail/gcc-patches/2020-June/547520.html</a><br><a href="https://git.kernel.org/pub/scm/linux/kernel/git/torvalds/linux.git/commit/?id=679db70801da9fda91d26caf13bf5b5ccc74e8e8">https://git.kernel.org/pub/scm/linux/kernel/git/torvalds/linux.git/commit/?id=679db70801da9fda91d26caf13bf5b5ccc74e8e8</a><br></details>  |
| libgnutls30         |    CVE-2018-16868   |   LOW  |  3.5.18-1ubuntu1.5 |  | <details><summary>Expand...</summary><a href="http://cat.eyalro.net/">http://cat.eyalro.net/</a><br><a href="http://lists.opensuse.org/opensuse-security-announce/2019-05/msg00017.html">http://lists.opensuse.org/opensuse-security-announce/2019-05/msg00017.html</a><br><a href="http://lists.opensuse.org/opensuse-security-announce/2019-05/msg00068.html">http://lists.opensuse.org/opensuse-security-announce/2019-05/msg00068.html</a><br><a href="http://www.securityfocus.com/bid/106080">http://www.securityfocus.com/bid/106080</a><br><a href="https://bugzilla.redhat.com/show_bug.cgi?id=CVE-2018-16868">https://bugzilla.redhat.com/show_bug.cgi?id=CVE-2018-16868</a><br><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2018-16868">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2018-16868</a><br></details>  |
| libgssapi-krb5-2         |    CVE-2018-20217   |   MEDIUM  |  1.16-2ubuntu0.2 |  | <details><summary>Expand...</summary><a href="http://krbdev.mit.edu/rt/Ticket/Display.html?id=8763">http://krbdev.mit.edu/rt/Ticket/Display.html?id=8763</a><br><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2018-20217">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2018-20217</a><br><a href="https://github.com/krb5/krb5/commit/5e6d1796106df8ba6bc1973ee0917c170d929086">https://github.com/krb5/krb5/commit/5e6d1796106df8ba6bc1973ee0917c170d929086</a><br><a href="https://lists.debian.org/debian-lts-announce/2019/01/msg00020.html">https://lists.debian.org/debian-lts-announce/2019/01/msg00020.html</a><br><a href="https://lists.debian.org/debian-lts-announce/2021/09/msg00019.html">https://lists.debian.org/debian-lts-announce/2021/09/msg00019.html</a><br><a href="https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/2KNHELH4YHNT6H2ESJWX2UIDXLBNGB2O/">https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/2KNHELH4YHNT6H2ESJWX2UIDXLBNGB2O/</a><br><a href="https://security.netapp.com/advisory/ntap-20190416-0006/">https://security.netapp.com/advisory/ntap-20190416-0006/</a><br></details>  |
| libgssapi-krb5-2         |    CVE-2021-36222   |   MEDIUM  |  1.16-2ubuntu0.2 |  | <details><summary>Expand...</summary><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2021-36222">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2021-36222</a><br><a href="https://github.com/krb5/krb5/commit/fc98f520caefff2e5ee9a0026fdf5109944b3562">https://github.com/krb5/krb5/commit/fc98f520caefff2e5ee9a0026fdf5109944b3562</a><br><a href="https://github.com/krb5/krb5/releases">https://github.com/krb5/krb5/releases</a><br><a href="https://linux.oracle.com/cve/CVE-2021-36222.html">https://linux.oracle.com/cve/CVE-2021-36222.html</a><br><a href="https://linux.oracle.com/errata/ELSA-2021-3576.html">https://linux.oracle.com/errata/ELSA-2021-3576.html</a><br><a href="https://security.netapp.com/advisory/ntap-20211022-0003/">https://security.netapp.com/advisory/ntap-20211022-0003/</a><br><a href="https://security.netapp.com/advisory/ntap-20211104-0007/">https://security.netapp.com/advisory/ntap-20211104-0007/</a><br><a href="https://web.mit.edu/kerberos/advisories/">https://web.mit.edu/kerberos/advisories/</a><br><a href="https://www.debian.org/security/2021/dsa-4944">https://www.debian.org/security/2021/dsa-4944</a><br><a href="https://www.oracle.com/security-alerts/cpuoct2021.html">https://www.oracle.com/security-alerts/cpuoct2021.html</a><br></details>  |
| libgssapi-krb5-2         |    CVE-2018-5709   |   LOW  |  1.16-2ubuntu0.2 |  | <details><summary>Expand...</summary><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2018-5709">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2018-5709</a><br><a href="https://github.com/poojamnit/Kerberos-V5-1.16-Vulnerabilities/tree/master/Integer%20Overflow">https://github.com/poojamnit/Kerberos-V5-1.16-Vulnerabilities/tree/master/Integer%20Overflow</a><br><a href="https://lists.apache.org/thread.html/rf9fa47ab66495c78bb4120b0754dd9531ca2ff0430f6685ac9b07772@%3Cdev.mina.apache.org%3E">https://lists.apache.org/thread.html/rf9fa47ab66495c78bb4120b0754dd9531ca2ff0430f6685ac9b07772@%3Cdev.mina.apache.org%3E</a><br></details>  |
| libgssapi-krb5-2         |    CVE-2018-5710   |   LOW  |  1.16-2ubuntu0.2 |  | <details><summary>Expand...</summary><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2018-5710">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2018-5710</a><br><a href="https://github.com/poojamnit/Kerberos-V5-1.16-Vulnerabilities/tree/master/Denial%20Of%20Service(DoS)">https://github.com/poojamnit/Kerberos-V5-1.16-Vulnerabilities/tree/master/Denial%20Of%20Service(DoS)</a><br></details>  |
| libgssapi3-heimdal         |    CVE-2019-12098   |   LOW  |  7.5.0+dfsg-1 |  | <details><summary>Expand...</summary><a href="http://lists.opensuse.org/opensuse-security-announce/2019-07/msg00002.html">http://lists.opensuse.org/opensuse-security-announce/2019-07/msg00002.html</a><br><a href="http://lists.opensuse.org/opensuse-security-announce/2019-07/msg00003.html">http://lists.opensuse.org/opensuse-security-announce/2019-07/msg00003.html</a><br><a href="http://lists.opensuse.org/opensuse-security-announce/2019-08/msg00026.html">http://lists.opensuse.org/opensuse-security-announce/2019-08/msg00026.html</a><br><a href="http://www.h5l.org/pipermail/heimdal-announce/2019-May/000009.html">http://www.h5l.org/pipermail/heimdal-announce/2019-May/000009.html</a><br><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2019-12098">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2019-12098</a><br><a href="https://github.com/heimdal/heimdal/commit/2f7f3d9960aa6ea21358bdf3687cee5149aa35cf">https://github.com/heimdal/heimdal/commit/2f7f3d9960aa6ea21358bdf3687cee5149aa35cf</a><br><a href="https://github.com/heimdal/heimdal/compare/3e58559...bbafe72">https://github.com/heimdal/heimdal/compare/3e58559...bbafe72</a><br><a href="https://github.com/heimdal/heimdal/releases/tag/heimdal-7.6.0">https://github.com/heimdal/heimdal/releases/tag/heimdal-7.6.0</a><br><a href="https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/GIXEDVVMPD6ZAJSMI2EZ7FNEIVNWE5PD/">https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/GIXEDVVMPD6ZAJSMI2EZ7FNEIVNWE5PD/</a><br><a href="https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/SLXXIF4LOQEAEDAF4UGP2AO6WDNTDFUB/">https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/SLXXIF4LOQEAEDAF4UGP2AO6WDNTDFUB/</a><br><a href="https://seclists.org/bugtraq/2019/Jun/1">https://seclists.org/bugtraq/2019/Jun/1</a><br><a href="https://www.debian.org/security/2019/dsa-4455">https://www.debian.org/security/2019/dsa-4455</a><br></details>  |
| libgssapi3-heimdal         |    CVE-2021-3671   |   LOW  |  7.5.0+dfsg-1 |  | <details><summary>Expand...</summary><a href="https://bugzilla.redhat.com/show_bug.cgi?id=2013080,">https://bugzilla.redhat.com/show_bug.cgi?id=2013080,</a><br><a href="https://bugzilla.samba.org/show_bug.cgi?id=14770,">https://bugzilla.samba.org/show_bug.cgi?id=14770,</a><br><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2021-3671">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2021-3671</a><br><a href="https://github.com/heimdal/heimdal/commit/04171147948d0a3636bc6374181926f0fb2ec83a">https://github.com/heimdal/heimdal/commit/04171147948d0a3636bc6374181926f0fb2ec83a</a><br><a href="https://ubuntu.com/security/notices/USN-5142-1">https://ubuntu.com/security/notices/USN-5142-1</a><br><a href="https://ubuntu.com/security/notices/USN-5174-1">https://ubuntu.com/security/notices/USN-5174-1</a><br></details>  |
| libhcrypto4-heimdal         |    CVE-2019-12098   |   LOW  |  7.5.0+dfsg-1 |  | <details><summary>Expand...</summary><a href="http://lists.opensuse.org/opensuse-security-announce/2019-07/msg00002.html">http://lists.opensuse.org/opensuse-security-announce/2019-07/msg00002.html</a><br><a href="http://lists.opensuse.org/opensuse-security-announce/2019-07/msg00003.html">http://lists.opensuse.org/opensuse-security-announce/2019-07/msg00003.html</a><br><a href="http://lists.opensuse.org/opensuse-security-announce/2019-08/msg00026.html">http://lists.opensuse.org/opensuse-security-announce/2019-08/msg00026.html</a><br><a href="http://www.h5l.org/pipermail/heimdal-announce/2019-May/000009.html">http://www.h5l.org/pipermail/heimdal-announce/2019-May/000009.html</a><br><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2019-12098">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2019-12098</a><br><a href="https://github.com/heimdal/heimdal/commit/2f7f3d9960aa6ea21358bdf3687cee5149aa35cf">https://github.com/heimdal/heimdal/commit/2f7f3d9960aa6ea21358bdf3687cee5149aa35cf</a><br><a href="https://github.com/heimdal/heimdal/compare/3e58559...bbafe72">https://github.com/heimdal/heimdal/compare/3e58559...bbafe72</a><br><a href="https://github.com/heimdal/heimdal/releases/tag/heimdal-7.6.0">https://github.com/heimdal/heimdal/releases/tag/heimdal-7.6.0</a><br><a href="https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/GIXEDVVMPD6ZAJSMI2EZ7FNEIVNWE5PD/">https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/GIXEDVVMPD6ZAJSMI2EZ7FNEIVNWE5PD/</a><br><a href="https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/SLXXIF4LOQEAEDAF4UGP2AO6WDNTDFUB/">https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/SLXXIF4LOQEAEDAF4UGP2AO6WDNTDFUB/</a><br><a href="https://seclists.org/bugtraq/2019/Jun/1">https://seclists.org/bugtraq/2019/Jun/1</a><br><a href="https://www.debian.org/security/2019/dsa-4455">https://www.debian.org/security/2019/dsa-4455</a><br></details>  |
| libhcrypto4-heimdal         |    CVE-2021-3671   |   LOW  |  7.5.0+dfsg-1 |  | <details><summary>Expand...</summary><a href="https://bugzilla.redhat.com/show_bug.cgi?id=2013080,">https://bugzilla.redhat.com/show_bug.cgi?id=2013080,</a><br><a href="https://bugzilla.samba.org/show_bug.cgi?id=14770,">https://bugzilla.samba.org/show_bug.cgi?id=14770,</a><br><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2021-3671">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2021-3671</a><br><a href="https://github.com/heimdal/heimdal/commit/04171147948d0a3636bc6374181926f0fb2ec83a">https://github.com/heimdal/heimdal/commit/04171147948d0a3636bc6374181926f0fb2ec83a</a><br><a href="https://ubuntu.com/security/notices/USN-5142-1">https://ubuntu.com/security/notices/USN-5142-1</a><br><a href="https://ubuntu.com/security/notices/USN-5174-1">https://ubuntu.com/security/notices/USN-5174-1</a><br></details>  |
| libheimbase1-heimdal         |    CVE-2019-12098   |   LOW  |  7.5.0+dfsg-1 |  | <details><summary>Expand...</summary><a href="http://lists.opensuse.org/opensuse-security-announce/2019-07/msg00002.html">http://lists.opensuse.org/opensuse-security-announce/2019-07/msg00002.html</a><br><a href="http://lists.opensuse.org/opensuse-security-announce/2019-07/msg00003.html">http://lists.opensuse.org/opensuse-security-announce/2019-07/msg00003.html</a><br><a href="http://lists.opensuse.org/opensuse-security-announce/2019-08/msg00026.html">http://lists.opensuse.org/opensuse-security-announce/2019-08/msg00026.html</a><br><a href="http://www.h5l.org/pipermail/heimdal-announce/2019-May/000009.html">http://www.h5l.org/pipermail/heimdal-announce/2019-May/000009.html</a><br><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2019-12098">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2019-12098</a><br><a href="https://github.com/heimdal/heimdal/commit/2f7f3d9960aa6ea21358bdf3687cee5149aa35cf">https://github.com/heimdal/heimdal/commit/2f7f3d9960aa6ea21358bdf3687cee5149aa35cf</a><br><a href="https://github.com/heimdal/heimdal/compare/3e58559...bbafe72">https://github.com/heimdal/heimdal/compare/3e58559...bbafe72</a><br><a href="https://github.com/heimdal/heimdal/releases/tag/heimdal-7.6.0">https://github.com/heimdal/heimdal/releases/tag/heimdal-7.6.0</a><br><a href="https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/GIXEDVVMPD6ZAJSMI2EZ7FNEIVNWE5PD/">https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/GIXEDVVMPD6ZAJSMI2EZ7FNEIVNWE5PD/</a><br><a href="https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/SLXXIF4LOQEAEDAF4UGP2AO6WDNTDFUB/">https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/SLXXIF4LOQEAEDAF4UGP2AO6WDNTDFUB/</a><br><a href="https://seclists.org/bugtraq/2019/Jun/1">https://seclists.org/bugtraq/2019/Jun/1</a><br><a href="https://www.debian.org/security/2019/dsa-4455">https://www.debian.org/security/2019/dsa-4455</a><br></details>  |
| libheimbase1-heimdal         |    CVE-2021-3671   |   LOW  |  7.5.0+dfsg-1 |  | <details><summary>Expand...</summary><a href="https://bugzilla.redhat.com/show_bug.cgi?id=2013080,">https://bugzilla.redhat.com/show_bug.cgi?id=2013080,</a><br><a href="https://bugzilla.samba.org/show_bug.cgi?id=14770,">https://bugzilla.samba.org/show_bug.cgi?id=14770,</a><br><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2021-3671">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2021-3671</a><br><a href="https://github.com/heimdal/heimdal/commit/04171147948d0a3636bc6374181926f0fb2ec83a">https://github.com/heimdal/heimdal/commit/04171147948d0a3636bc6374181926f0fb2ec83a</a><br><a href="https://ubuntu.com/security/notices/USN-5142-1">https://ubuntu.com/security/notices/USN-5142-1</a><br><a href="https://ubuntu.com/security/notices/USN-5174-1">https://ubuntu.com/security/notices/USN-5174-1</a><br></details>  |
| libheimntlm0-heimdal         |    CVE-2019-12098   |   LOW  |  7.5.0+dfsg-1 |  | <details><summary>Expand...</summary><a href="http://lists.opensuse.org/opensuse-security-announce/2019-07/msg00002.html">http://lists.opensuse.org/opensuse-security-announce/2019-07/msg00002.html</a><br><a href="http://lists.opensuse.org/opensuse-security-announce/2019-07/msg00003.html">http://lists.opensuse.org/opensuse-security-announce/2019-07/msg00003.html</a><br><a href="http://lists.opensuse.org/opensuse-security-announce/2019-08/msg00026.html">http://lists.opensuse.org/opensuse-security-announce/2019-08/msg00026.html</a><br><a href="http://www.h5l.org/pipermail/heimdal-announce/2019-May/000009.html">http://www.h5l.org/pipermail/heimdal-announce/2019-May/000009.html</a><br><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2019-12098">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2019-12098</a><br><a href="https://github.com/heimdal/heimdal/commit/2f7f3d9960aa6ea21358bdf3687cee5149aa35cf">https://github.com/heimdal/heimdal/commit/2f7f3d9960aa6ea21358bdf3687cee5149aa35cf</a><br><a href="https://github.com/heimdal/heimdal/compare/3e58559...bbafe72">https://github.com/heimdal/heimdal/compare/3e58559...bbafe72</a><br><a href="https://github.com/heimdal/heimdal/releases/tag/heimdal-7.6.0">https://github.com/heimdal/heimdal/releases/tag/heimdal-7.6.0</a><br><a href="https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/GIXEDVVMPD6ZAJSMI2EZ7FNEIVNWE5PD/">https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/GIXEDVVMPD6ZAJSMI2EZ7FNEIVNWE5PD/</a><br><a href="https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/SLXXIF4LOQEAEDAF4UGP2AO6WDNTDFUB/">https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/SLXXIF4LOQEAEDAF4UGP2AO6WDNTDFUB/</a><br><a href="https://seclists.org/bugtraq/2019/Jun/1">https://seclists.org/bugtraq/2019/Jun/1</a><br><a href="https://www.debian.org/security/2019/dsa-4455">https://www.debian.org/security/2019/dsa-4455</a><br></details>  |
| libheimntlm0-heimdal         |    CVE-2021-3671   |   LOW  |  7.5.0+dfsg-1 |  | <details><summary>Expand...</summary><a href="https://bugzilla.redhat.com/show_bug.cgi?id=2013080,">https://bugzilla.redhat.com/show_bug.cgi?id=2013080,</a><br><a href="https://bugzilla.samba.org/show_bug.cgi?id=14770,">https://bugzilla.samba.org/show_bug.cgi?id=14770,</a><br><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2021-3671">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2021-3671</a><br><a href="https://github.com/heimdal/heimdal/commit/04171147948d0a3636bc6374181926f0fb2ec83a">https://github.com/heimdal/heimdal/commit/04171147948d0a3636bc6374181926f0fb2ec83a</a><br><a href="https://ubuntu.com/security/notices/USN-5142-1">https://ubuntu.com/security/notices/USN-5142-1</a><br><a href="https://ubuntu.com/security/notices/USN-5174-1">https://ubuntu.com/security/notices/USN-5174-1</a><br></details>  |
| libhx509-5-heimdal         |    CVE-2019-12098   |   LOW  |  7.5.0+dfsg-1 |  | <details><summary>Expand...</summary><a href="http://lists.opensuse.org/opensuse-security-announce/2019-07/msg00002.html">http://lists.opensuse.org/opensuse-security-announce/2019-07/msg00002.html</a><br><a href="http://lists.opensuse.org/opensuse-security-announce/2019-07/msg00003.html">http://lists.opensuse.org/opensuse-security-announce/2019-07/msg00003.html</a><br><a href="http://lists.opensuse.org/opensuse-security-announce/2019-08/msg00026.html">http://lists.opensuse.org/opensuse-security-announce/2019-08/msg00026.html</a><br><a href="http://www.h5l.org/pipermail/heimdal-announce/2019-May/000009.html">http://www.h5l.org/pipermail/heimdal-announce/2019-May/000009.html</a><br><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2019-12098">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2019-12098</a><br><a href="https://github.com/heimdal/heimdal/commit/2f7f3d9960aa6ea21358bdf3687cee5149aa35cf">https://github.com/heimdal/heimdal/commit/2f7f3d9960aa6ea21358bdf3687cee5149aa35cf</a><br><a href="https://github.com/heimdal/heimdal/compare/3e58559...bbafe72">https://github.com/heimdal/heimdal/compare/3e58559...bbafe72</a><br><a href="https://github.com/heimdal/heimdal/releases/tag/heimdal-7.6.0">https://github.com/heimdal/heimdal/releases/tag/heimdal-7.6.0</a><br><a href="https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/GIXEDVVMPD6ZAJSMI2EZ7FNEIVNWE5PD/">https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/GIXEDVVMPD6ZAJSMI2EZ7FNEIVNWE5PD/</a><br><a href="https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/SLXXIF4LOQEAEDAF4UGP2AO6WDNTDFUB/">https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/SLXXIF4LOQEAEDAF4UGP2AO6WDNTDFUB/</a><br><a href="https://seclists.org/bugtraq/2019/Jun/1">https://seclists.org/bugtraq/2019/Jun/1</a><br><a href="https://www.debian.org/security/2019/dsa-4455">https://www.debian.org/security/2019/dsa-4455</a><br></details>  |
| libhx509-5-heimdal         |    CVE-2021-3671   |   LOW  |  7.5.0+dfsg-1 |  | <details><summary>Expand...</summary><a href="https://bugzilla.redhat.com/show_bug.cgi?id=2013080,">https://bugzilla.redhat.com/show_bug.cgi?id=2013080,</a><br><a href="https://bugzilla.samba.org/show_bug.cgi?id=14770,">https://bugzilla.samba.org/show_bug.cgi?id=14770,</a><br><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2021-3671">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2021-3671</a><br><a href="https://github.com/heimdal/heimdal/commit/04171147948d0a3636bc6374181926f0fb2ec83a">https://github.com/heimdal/heimdal/commit/04171147948d0a3636bc6374181926f0fb2ec83a</a><br><a href="https://ubuntu.com/security/notices/USN-5142-1">https://ubuntu.com/security/notices/USN-5142-1</a><br><a href="https://ubuntu.com/security/notices/USN-5174-1">https://ubuntu.com/security/notices/USN-5174-1</a><br></details>  |
| libk5crypto3         |    CVE-2018-20217   |   MEDIUM  |  1.16-2ubuntu0.2 |  | <details><summary>Expand...</summary><a href="http://krbdev.mit.edu/rt/Ticket/Display.html?id=8763">http://krbdev.mit.edu/rt/Ticket/Display.html?id=8763</a><br><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2018-20217">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2018-20217</a><br><a href="https://github.com/krb5/krb5/commit/5e6d1796106df8ba6bc1973ee0917c170d929086">https://github.com/krb5/krb5/commit/5e6d1796106df8ba6bc1973ee0917c170d929086</a><br><a href="https://lists.debian.org/debian-lts-announce/2019/01/msg00020.html">https://lists.debian.org/debian-lts-announce/2019/01/msg00020.html</a><br><a href="https://lists.debian.org/debian-lts-announce/2021/09/msg00019.html">https://lists.debian.org/debian-lts-announce/2021/09/msg00019.html</a><br><a href="https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/2KNHELH4YHNT6H2ESJWX2UIDXLBNGB2O/">https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/2KNHELH4YHNT6H2ESJWX2UIDXLBNGB2O/</a><br><a href="https://security.netapp.com/advisory/ntap-20190416-0006/">https://security.netapp.com/advisory/ntap-20190416-0006/</a><br></details>  |
| libk5crypto3         |    CVE-2021-36222   |   MEDIUM  |  1.16-2ubuntu0.2 |  | <details><summary>Expand...</summary><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2021-36222">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2021-36222</a><br><a href="https://github.com/krb5/krb5/commit/fc98f520caefff2e5ee9a0026fdf5109944b3562">https://github.com/krb5/krb5/commit/fc98f520caefff2e5ee9a0026fdf5109944b3562</a><br><a href="https://github.com/krb5/krb5/releases">https://github.com/krb5/krb5/releases</a><br><a href="https://linux.oracle.com/cve/CVE-2021-36222.html">https://linux.oracle.com/cve/CVE-2021-36222.html</a><br><a href="https://linux.oracle.com/errata/ELSA-2021-3576.html">https://linux.oracle.com/errata/ELSA-2021-3576.html</a><br><a href="https://security.netapp.com/advisory/ntap-20211022-0003/">https://security.netapp.com/advisory/ntap-20211022-0003/</a><br><a href="https://security.netapp.com/advisory/ntap-20211104-0007/">https://security.netapp.com/advisory/ntap-20211104-0007/</a><br><a href="https://web.mit.edu/kerberos/advisories/">https://web.mit.edu/kerberos/advisories/</a><br><a href="https://www.debian.org/security/2021/dsa-4944">https://www.debian.org/security/2021/dsa-4944</a><br><a href="https://www.oracle.com/security-alerts/cpuoct2021.html">https://www.oracle.com/security-alerts/cpuoct2021.html</a><br></details>  |
| libk5crypto3         |    CVE-2018-5709   |   LOW  |  1.16-2ubuntu0.2 |  | <details><summary>Expand...</summary><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2018-5709">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2018-5709</a><br><a href="https://github.com/poojamnit/Kerberos-V5-1.16-Vulnerabilities/tree/master/Integer%20Overflow">https://github.com/poojamnit/Kerberos-V5-1.16-Vulnerabilities/tree/master/Integer%20Overflow</a><br><a href="https://lists.apache.org/thread.html/rf9fa47ab66495c78bb4120b0754dd9531ca2ff0430f6685ac9b07772@%3Cdev.mina.apache.org%3E">https://lists.apache.org/thread.html/rf9fa47ab66495c78bb4120b0754dd9531ca2ff0430f6685ac9b07772@%3Cdev.mina.apache.org%3E</a><br></details>  |
| libk5crypto3         |    CVE-2018-5710   |   LOW  |  1.16-2ubuntu0.2 |  | <details><summary>Expand...</summary><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2018-5710">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2018-5710</a><br><a href="https://github.com/poojamnit/Kerberos-V5-1.16-Vulnerabilities/tree/master/Denial%20Of%20Service(DoS)">https://github.com/poojamnit/Kerberos-V5-1.16-Vulnerabilities/tree/master/Denial%20Of%20Service(DoS)</a><br></details>  |
| libkrb5-26-heimdal         |    CVE-2019-12098   |   LOW  |  7.5.0+dfsg-1 |  | <details><summary>Expand...</summary><a href="http://lists.opensuse.org/opensuse-security-announce/2019-07/msg00002.html">http://lists.opensuse.org/opensuse-security-announce/2019-07/msg00002.html</a><br><a href="http://lists.opensuse.org/opensuse-security-announce/2019-07/msg00003.html">http://lists.opensuse.org/opensuse-security-announce/2019-07/msg00003.html</a><br><a href="http://lists.opensuse.org/opensuse-security-announce/2019-08/msg00026.html">http://lists.opensuse.org/opensuse-security-announce/2019-08/msg00026.html</a><br><a href="http://www.h5l.org/pipermail/heimdal-announce/2019-May/000009.html">http://www.h5l.org/pipermail/heimdal-announce/2019-May/000009.html</a><br><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2019-12098">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2019-12098</a><br><a href="https://github.com/heimdal/heimdal/commit/2f7f3d9960aa6ea21358bdf3687cee5149aa35cf">https://github.com/heimdal/heimdal/commit/2f7f3d9960aa6ea21358bdf3687cee5149aa35cf</a><br><a href="https://github.com/heimdal/heimdal/compare/3e58559...bbafe72">https://github.com/heimdal/heimdal/compare/3e58559...bbafe72</a><br><a href="https://github.com/heimdal/heimdal/releases/tag/heimdal-7.6.0">https://github.com/heimdal/heimdal/releases/tag/heimdal-7.6.0</a><br><a href="https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/GIXEDVVMPD6ZAJSMI2EZ7FNEIVNWE5PD/">https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/GIXEDVVMPD6ZAJSMI2EZ7FNEIVNWE5PD/</a><br><a href="https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/SLXXIF4LOQEAEDAF4UGP2AO6WDNTDFUB/">https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/SLXXIF4LOQEAEDAF4UGP2AO6WDNTDFUB/</a><br><a href="https://seclists.org/bugtraq/2019/Jun/1">https://seclists.org/bugtraq/2019/Jun/1</a><br><a href="https://www.debian.org/security/2019/dsa-4455">https://www.debian.org/security/2019/dsa-4455</a><br></details>  |
| libkrb5-26-heimdal         |    CVE-2021-3671   |   LOW  |  7.5.0+dfsg-1 |  | <details><summary>Expand...</summary><a href="https://bugzilla.redhat.com/show_bug.cgi?id=2013080,">https://bugzilla.redhat.com/show_bug.cgi?id=2013080,</a><br><a href="https://bugzilla.samba.org/show_bug.cgi?id=14770,">https://bugzilla.samba.org/show_bug.cgi?id=14770,</a><br><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2021-3671">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2021-3671</a><br><a href="https://github.com/heimdal/heimdal/commit/04171147948d0a3636bc6374181926f0fb2ec83a">https://github.com/heimdal/heimdal/commit/04171147948d0a3636bc6374181926f0fb2ec83a</a><br><a href="https://ubuntu.com/security/notices/USN-5142-1">https://ubuntu.com/security/notices/USN-5142-1</a><br><a href="https://ubuntu.com/security/notices/USN-5174-1">https://ubuntu.com/security/notices/USN-5174-1</a><br></details>  |
| libkrb5-3         |    CVE-2018-20217   |   MEDIUM  |  1.16-2ubuntu0.2 |  | <details><summary>Expand...</summary><a href="http://krbdev.mit.edu/rt/Ticket/Display.html?id=8763">http://krbdev.mit.edu/rt/Ticket/Display.html?id=8763</a><br><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2018-20217">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2018-20217</a><br><a href="https://github.com/krb5/krb5/commit/5e6d1796106df8ba6bc1973ee0917c170d929086">https://github.com/krb5/krb5/commit/5e6d1796106df8ba6bc1973ee0917c170d929086</a><br><a href="https://lists.debian.org/debian-lts-announce/2019/01/msg00020.html">https://lists.debian.org/debian-lts-announce/2019/01/msg00020.html</a><br><a href="https://lists.debian.org/debian-lts-announce/2021/09/msg00019.html">https://lists.debian.org/debian-lts-announce/2021/09/msg00019.html</a><br><a href="https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/2KNHELH4YHNT6H2ESJWX2UIDXLBNGB2O/">https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/2KNHELH4YHNT6H2ESJWX2UIDXLBNGB2O/</a><br><a href="https://security.netapp.com/advisory/ntap-20190416-0006/">https://security.netapp.com/advisory/ntap-20190416-0006/</a><br></details>  |
| libkrb5-3         |    CVE-2021-36222   |   MEDIUM  |  1.16-2ubuntu0.2 |  | <details><summary>Expand...</summary><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2021-36222">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2021-36222</a><br><a href="https://github.com/krb5/krb5/commit/fc98f520caefff2e5ee9a0026fdf5109944b3562">https://github.com/krb5/krb5/commit/fc98f520caefff2e5ee9a0026fdf5109944b3562</a><br><a href="https://github.com/krb5/krb5/releases">https://github.com/krb5/krb5/releases</a><br><a href="https://linux.oracle.com/cve/CVE-2021-36222.html">https://linux.oracle.com/cve/CVE-2021-36222.html</a><br><a href="https://linux.oracle.com/errata/ELSA-2021-3576.html">https://linux.oracle.com/errata/ELSA-2021-3576.html</a><br><a href="https://security.netapp.com/advisory/ntap-20211022-0003/">https://security.netapp.com/advisory/ntap-20211022-0003/</a><br><a href="https://security.netapp.com/advisory/ntap-20211104-0007/">https://security.netapp.com/advisory/ntap-20211104-0007/</a><br><a href="https://web.mit.edu/kerberos/advisories/">https://web.mit.edu/kerberos/advisories/</a><br><a href="https://www.debian.org/security/2021/dsa-4944">https://www.debian.org/security/2021/dsa-4944</a><br><a href="https://www.oracle.com/security-alerts/cpuoct2021.html">https://www.oracle.com/security-alerts/cpuoct2021.html</a><br></details>  |
| libkrb5-3         |    CVE-2018-5709   |   LOW  |  1.16-2ubuntu0.2 |  | <details><summary>Expand...</summary><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2018-5709">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2018-5709</a><br><a href="https://github.com/poojamnit/Kerberos-V5-1.16-Vulnerabilities/tree/master/Integer%20Overflow">https://github.com/poojamnit/Kerberos-V5-1.16-Vulnerabilities/tree/master/Integer%20Overflow</a><br><a href="https://lists.apache.org/thread.html/rf9fa47ab66495c78bb4120b0754dd9531ca2ff0430f6685ac9b07772@%3Cdev.mina.apache.org%3E">https://lists.apache.org/thread.html/rf9fa47ab66495c78bb4120b0754dd9531ca2ff0430f6685ac9b07772@%3Cdev.mina.apache.org%3E</a><br></details>  |
| libkrb5-3         |    CVE-2018-5710   |   LOW  |  1.16-2ubuntu0.2 |  | <details><summary>Expand...</summary><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2018-5710">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2018-5710</a><br><a href="https://github.com/poojamnit/Kerberos-V5-1.16-Vulnerabilities/tree/master/Denial%20Of%20Service(DoS)">https://github.com/poojamnit/Kerberos-V5-1.16-Vulnerabilities/tree/master/Denial%20Of%20Service(DoS)</a><br></details>  |
| libkrb5support0         |    CVE-2018-20217   |   MEDIUM  |  1.16-2ubuntu0.2 |  | <details><summary>Expand...</summary><a href="http://krbdev.mit.edu/rt/Ticket/Display.html?id=8763">http://krbdev.mit.edu/rt/Ticket/Display.html?id=8763</a><br><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2018-20217">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2018-20217</a><br><a href="https://github.com/krb5/krb5/commit/5e6d1796106df8ba6bc1973ee0917c170d929086">https://github.com/krb5/krb5/commit/5e6d1796106df8ba6bc1973ee0917c170d929086</a><br><a href="https://lists.debian.org/debian-lts-announce/2019/01/msg00020.html">https://lists.debian.org/debian-lts-announce/2019/01/msg00020.html</a><br><a href="https://lists.debian.org/debian-lts-announce/2021/09/msg00019.html">https://lists.debian.org/debian-lts-announce/2021/09/msg00019.html</a><br><a href="https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/2KNHELH4YHNT6H2ESJWX2UIDXLBNGB2O/">https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/2KNHELH4YHNT6H2ESJWX2UIDXLBNGB2O/</a><br><a href="https://security.netapp.com/advisory/ntap-20190416-0006/">https://security.netapp.com/advisory/ntap-20190416-0006/</a><br></details>  |
| libkrb5support0         |    CVE-2021-36222   |   MEDIUM  |  1.16-2ubuntu0.2 |  | <details><summary>Expand...</summary><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2021-36222">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2021-36222</a><br><a href="https://github.com/krb5/krb5/commit/fc98f520caefff2e5ee9a0026fdf5109944b3562">https://github.com/krb5/krb5/commit/fc98f520caefff2e5ee9a0026fdf5109944b3562</a><br><a href="https://github.com/krb5/krb5/releases">https://github.com/krb5/krb5/releases</a><br><a href="https://linux.oracle.com/cve/CVE-2021-36222.html">https://linux.oracle.com/cve/CVE-2021-36222.html</a><br><a href="https://linux.oracle.com/errata/ELSA-2021-3576.html">https://linux.oracle.com/errata/ELSA-2021-3576.html</a><br><a href="https://security.netapp.com/advisory/ntap-20211022-0003/">https://security.netapp.com/advisory/ntap-20211022-0003/</a><br><a href="https://security.netapp.com/advisory/ntap-20211104-0007/">https://security.netapp.com/advisory/ntap-20211104-0007/</a><br><a href="https://web.mit.edu/kerberos/advisories/">https://web.mit.edu/kerberos/advisories/</a><br><a href="https://www.debian.org/security/2021/dsa-4944">https://www.debian.org/security/2021/dsa-4944</a><br><a href="https://www.oracle.com/security-alerts/cpuoct2021.html">https://www.oracle.com/security-alerts/cpuoct2021.html</a><br></details>  |
| libkrb5support0         |    CVE-2018-5709   |   LOW  |  1.16-2ubuntu0.2 |  | <details><summary>Expand...</summary><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2018-5709">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2018-5709</a><br><a href="https://github.com/poojamnit/Kerberos-V5-1.16-Vulnerabilities/tree/master/Integer%20Overflow">https://github.com/poojamnit/Kerberos-V5-1.16-Vulnerabilities/tree/master/Integer%20Overflow</a><br><a href="https://lists.apache.org/thread.html/rf9fa47ab66495c78bb4120b0754dd9531ca2ff0430f6685ac9b07772@%3Cdev.mina.apache.org%3E">https://lists.apache.org/thread.html/rf9fa47ab66495c78bb4120b0754dd9531ca2ff0430f6685ac9b07772@%3Cdev.mina.apache.org%3E</a><br></details>  |
| libkrb5support0         |    CVE-2018-5710   |   LOW  |  1.16-2ubuntu0.2 |  | <details><summary>Expand...</summary><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2018-5710">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2018-5710</a><br><a href="https://github.com/poojamnit/Kerberos-V5-1.16-Vulnerabilities/tree/master/Denial%20Of%20Service(DoS)">https://github.com/poojamnit/Kerberos-V5-1.16-Vulnerabilities/tree/master/Denial%20Of%20Service(DoS)</a><br></details>  |
| libncurses5         |    CVE-2019-17594   |   LOW  |  6.1-1ubuntu1.18.04 |  | <details><summary>Expand...</summary><a href="http://lists.opensuse.org/opensuse-security-announce/2019-11/msg00059.html">http://lists.opensuse.org/opensuse-security-announce/2019-11/msg00059.html</a><br><a href="http://lists.opensuse.org/opensuse-security-announce/2019-11/msg00061.html">http://lists.opensuse.org/opensuse-security-announce/2019-11/msg00061.html</a><br><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2019-17594">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2019-17594</a><br><a href="https://linux.oracle.com/cve/CVE-2019-17594.html">https://linux.oracle.com/cve/CVE-2019-17594.html</a><br><a href="https://linux.oracle.com/errata/ELSA-2021-4426.html">https://linux.oracle.com/errata/ELSA-2021-4426.html</a><br><a href="https://lists.gnu.org/archive/html/bug-ncurses/2019-10/msg00017.html">https://lists.gnu.org/archive/html/bug-ncurses/2019-10/msg00017.html</a><br><a href="https://lists.gnu.org/archive/html/bug-ncurses/2019-10/msg00045.html">https://lists.gnu.org/archive/html/bug-ncurses/2019-10/msg00045.html</a><br><a href="https://security.gentoo.org/glsa/202101-28">https://security.gentoo.org/glsa/202101-28</a><br></details>  |
| libncurses5         |    CVE-2019-17595   |   LOW  |  6.1-1ubuntu1.18.04 |  | <details><summary>Expand...</summary><a href="http://lists.opensuse.org/opensuse-security-announce/2019-11/msg00059.html">http://lists.opensuse.org/opensuse-security-announce/2019-11/msg00059.html</a><br><a href="http://lists.opensuse.org/opensuse-security-announce/2019-11/msg00061.html">http://lists.opensuse.org/opensuse-security-announce/2019-11/msg00061.html</a><br><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2019-17595">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2019-17595</a><br><a href="https://linux.oracle.com/cve/CVE-2019-17595.html">https://linux.oracle.com/cve/CVE-2019-17595.html</a><br><a href="https://linux.oracle.com/errata/ELSA-2021-4426.html">https://linux.oracle.com/errata/ELSA-2021-4426.html</a><br><a href="https://lists.gnu.org/archive/html/bug-ncurses/2019-10/msg00013.html">https://lists.gnu.org/archive/html/bug-ncurses/2019-10/msg00013.html</a><br><a href="https://lists.gnu.org/archive/html/bug-ncurses/2019-10/msg00045.html">https://lists.gnu.org/archive/html/bug-ncurses/2019-10/msg00045.html</a><br><a href="https://security.gentoo.org/glsa/202101-28">https://security.gentoo.org/glsa/202101-28</a><br></details>  |
| libncursesw5         |    CVE-2019-17594   |   LOW  |  6.1-1ubuntu1.18.04 |  | <details><summary>Expand...</summary><a href="http://lists.opensuse.org/opensuse-security-announce/2019-11/msg00059.html">http://lists.opensuse.org/opensuse-security-announce/2019-11/msg00059.html</a><br><a href="http://lists.opensuse.org/opensuse-security-announce/2019-11/msg00061.html">http://lists.opensuse.org/opensuse-security-announce/2019-11/msg00061.html</a><br><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2019-17594">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2019-17594</a><br><a href="https://linux.oracle.com/cve/CVE-2019-17594.html">https://linux.oracle.com/cve/CVE-2019-17594.html</a><br><a href="https://linux.oracle.com/errata/ELSA-2021-4426.html">https://linux.oracle.com/errata/ELSA-2021-4426.html</a><br><a href="https://lists.gnu.org/archive/html/bug-ncurses/2019-10/msg00017.html">https://lists.gnu.org/archive/html/bug-ncurses/2019-10/msg00017.html</a><br><a href="https://lists.gnu.org/archive/html/bug-ncurses/2019-10/msg00045.html">https://lists.gnu.org/archive/html/bug-ncurses/2019-10/msg00045.html</a><br><a href="https://security.gentoo.org/glsa/202101-28">https://security.gentoo.org/glsa/202101-28</a><br></details>  |
| libncursesw5         |    CVE-2019-17595   |   LOW  |  6.1-1ubuntu1.18.04 |  | <details><summary>Expand...</summary><a href="http://lists.opensuse.org/opensuse-security-announce/2019-11/msg00059.html">http://lists.opensuse.org/opensuse-security-announce/2019-11/msg00059.html</a><br><a href="http://lists.opensuse.org/opensuse-security-announce/2019-11/msg00061.html">http://lists.opensuse.org/opensuse-security-announce/2019-11/msg00061.html</a><br><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2019-17595">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2019-17595</a><br><a href="https://linux.oracle.com/cve/CVE-2019-17595.html">https://linux.oracle.com/cve/CVE-2019-17595.html</a><br><a href="https://linux.oracle.com/errata/ELSA-2021-4426.html">https://linux.oracle.com/errata/ELSA-2021-4426.html</a><br><a href="https://lists.gnu.org/archive/html/bug-ncurses/2019-10/msg00013.html">https://lists.gnu.org/archive/html/bug-ncurses/2019-10/msg00013.html</a><br><a href="https://lists.gnu.org/archive/html/bug-ncurses/2019-10/msg00045.html">https://lists.gnu.org/archive/html/bug-ncurses/2019-10/msg00045.html</a><br><a href="https://security.gentoo.org/glsa/202101-28">https://security.gentoo.org/glsa/202101-28</a><br></details>  |
| libnghttp2-14         |    CVE-2019-9511   |   MEDIUM  |  1.30.0-1ubuntu1 |  | <details><summary>Expand...</summary><a href="http://lists.opensuse.org/opensuse-security-announce/2019-09/msg00031.html">http://lists.opensuse.org/opensuse-security-announce/2019-09/msg00031.html</a><br><a href="http://lists.opensuse.org/opensuse-security-announce/2019-09/msg00032.html">http://lists.opensuse.org/opensuse-security-announce/2019-09/msg00032.html</a><br><a href="http://lists.opensuse.org/opensuse-security-announce/2019-09/msg00035.html">http://lists.opensuse.org/opensuse-security-announce/2019-09/msg00035.html</a><br><a href="http://lists.opensuse.org/opensuse-security-announce/2019-10/msg00003.html">http://lists.opensuse.org/opensuse-security-announce/2019-10/msg00003.html</a><br><a href="http://lists.opensuse.org/opensuse-security-announce/2019-10/msg00005.html">http://lists.opensuse.org/opensuse-security-announce/2019-10/msg00005.html</a><br><a href="http://lists.opensuse.org/opensuse-security-announce/2019-10/msg00014.html">http://lists.opensuse.org/opensuse-security-announce/2019-10/msg00014.html</a><br><a href="https://access.redhat.com/errata/RHSA-2019:2692">https://access.redhat.com/errata/RHSA-2019:2692</a><br><a href="https://access.redhat.com/errata/RHSA-2019:2745">https://access.redhat.com/errata/RHSA-2019:2745</a><br><a href="https://access.redhat.com/errata/RHSA-2019:2746">https://access.redhat.com/errata/RHSA-2019:2746</a><br><a href="https://access.redhat.com/errata/RHSA-2019:2775">https://access.redhat.com/errata/RHSA-2019:2775</a><br><a href="https://access.redhat.com/errata/RHSA-2019:2799">https://access.redhat.com/errata/RHSA-2019:2799</a><br><a href="https://access.redhat.com/errata/RHSA-2019:2925">https://access.redhat.com/errata/RHSA-2019:2925</a><br><a href="https://access.redhat.com/errata/RHSA-2019:2939">https://access.redhat.com/errata/RHSA-2019:2939</a><br><a href="https://access.redhat.com/errata/RHSA-2019:2949">https://access.redhat.com/errata/RHSA-2019:2949</a><br><a href="https://access.redhat.com/errata/RHSA-2019:2955">https://access.redhat.com/errata/RHSA-2019:2955</a><br><a href="https://access.redhat.com/errata/RHSA-2019:2966">https://access.redhat.com/errata/RHSA-2019:2966</a><br><a href="https://access.redhat.com/errata/RHSA-2019:3041">https://access.redhat.com/errata/RHSA-2019:3041</a><br><a href="https://access.redhat.com/errata/RHSA-2019:3932">https://access.redhat.com/errata/RHSA-2019:3932</a><br><a href="https://access.redhat.com/errata/RHSA-2019:3933">https://access.redhat.com/errata/RHSA-2019:3933</a><br><a href="https://access.redhat.com/errata/RHSA-2019:3935">https://access.redhat.com/errata/RHSA-2019:3935</a><br><a href="https://access.redhat.com/errata/RHSA-2019:4018">https://access.redhat.com/errata/RHSA-2019:4018</a><br><a href="https://access.redhat.com/errata/RHSA-2019:4019">https://access.redhat.com/errata/RHSA-2019:4019</a><br><a href="https://access.redhat.com/errata/RHSA-2019:4020">https://access.redhat.com/errata/RHSA-2019:4020</a><br><a href="https://access.redhat.com/errata/RHSA-2019:4021">https://access.redhat.com/errata/RHSA-2019:4021</a><br><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2019-9511">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2019-9511</a><br><a href="https://github.com/Netflix/security-bulletins/blob/master/advisories/third-party/2019-002.md">https://github.com/Netflix/security-bulletins/blob/master/advisories/third-party/2019-002.md</a><br><a href="https://kb.cert.org/vuls/id/605641/">https://kb.cert.org/vuls/id/605641/</a><br><a href="https://kc.mcafee.com/corporate/index?page=content&amp;id=SB10296">https://kc.mcafee.com/corporate/index?page=content&amp;id=SB10296</a><br><a href="https://linux.oracle.com/cve/CVE-2019-9511.html">https://linux.oracle.com/cve/CVE-2019-9511.html</a><br><a href="https://linux.oracle.com/errata/ELSA-2020-5862.html">https://linux.oracle.com/errata/ELSA-2020-5862.html</a><br><a href="https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/BP556LEG3WENHZI5TAQ6ZEBFTJB4E2IS/">https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/BP556LEG3WENHZI5TAQ6ZEBFTJB4E2IS/</a><br><a href="https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/JUBYAF6ED3O4XCHQ5C2HYENJLXYXZC4M/">https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/JUBYAF6ED3O4XCHQ5C2HYENJLXYXZC4M/</a><br><a href="https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/LZLUYPYY3RX4ZJDWZRJIKSULYRJ4PXW7/">https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/LZLUYPYY3RX4ZJDWZRJIKSULYRJ4PXW7/</a><br><a href="https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/POPAEC4FWL4UU4LDEGPY5NPALU24FFQD/">https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/POPAEC4FWL4UU4LDEGPY5NPALU24FFQD/</a><br><a href="https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/TAZZEVTCN2B4WT6AIBJ7XGYJMBTORJU5/">https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/TAZZEVTCN2B4WT6AIBJ7XGYJMBTORJU5/</a><br><a href="https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/XHTKU7YQ5EEP2XNSAV4M4VJ7QCBOJMOD/">https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/XHTKU7YQ5EEP2XNSAV4M4VJ7QCBOJMOD/</a><br><a href="https://nodejs.org/en/blog/vulnerability/aug-2019-security-releases/">https://nodejs.org/en/blog/vulnerability/aug-2019-security-releases/</a><br><a href="https://seclists.org/bugtraq/2019/Aug/40">https://seclists.org/bugtraq/2019/Aug/40</a><br><a href="https://seclists.org/bugtraq/2019/Sep/1">https://seclists.org/bugtraq/2019/Sep/1</a><br><a href="https://security.netapp.com/advisory/ntap-20190823-0002/">https://security.netapp.com/advisory/ntap-20190823-0002/</a><br><a href="https://security.netapp.com/advisory/ntap-20190823-0005/">https://security.netapp.com/advisory/ntap-20190823-0005/</a><br><a href="https://support.f5.com/csp/article/K02591030">https://support.f5.com/csp/article/K02591030</a><br><a href="https://support.f5.com/csp/article/K02591030?utm_source=f5support&amp;amp;utm_medium=RSS">https://support.f5.com/csp/article/K02591030?utm_source=f5support&amp;amp;utm_medium=RSS</a><br><a href="https://ubuntu.com/security/notices/USN-4099-1">https://ubuntu.com/security/notices/USN-4099-1</a><br><a href="https://usn.ubuntu.com/4099-1/">https://usn.ubuntu.com/4099-1/</a><br><a href="https://www.debian.org/security/2019/dsa-4505">https://www.debian.org/security/2019/dsa-4505</a><br><a href="https://www.debian.org/security/2019/dsa-4511">https://www.debian.org/security/2019/dsa-4511</a><br><a href="https://www.debian.org/security/2020/dsa-4669">https://www.debian.org/security/2020/dsa-4669</a><br><a href="https://www.nginx.com/blog/nginx-updates-mitigate-august-2019-http-2-vulnerabilities/">https://www.nginx.com/blog/nginx-updates-mitigate-august-2019-http-2-vulnerabilities/</a><br><a href="https://www.oracle.com/security-alerts/cpujan2021.html">https://www.oracle.com/security-alerts/cpujan2021.html</a><br><a href="https://www.oracle.com/security-alerts/cpuoct2020.html">https://www.oracle.com/security-alerts/cpuoct2020.html</a><br><a href="https://www.oracle.com/technetwork/security-advisory/cpuoct2019-5072832.html">https://www.oracle.com/technetwork/security-advisory/cpuoct2019-5072832.html</a><br><a href="https://www.synology.com/security/advisory/Synology_SA_19_33">https://www.synology.com/security/advisory/Synology_SA_19_33</a><br></details>  |
| libnghttp2-14         |    CVE-2019-9513   |   MEDIUM  |  1.30.0-1ubuntu1 |  | <details><summary>Expand...</summary><a href="http://lists.opensuse.org/opensuse-security-announce/2019-09/msg00031.html">http://lists.opensuse.org/opensuse-security-announce/2019-09/msg00031.html</a><br><a href="http://lists.opensuse.org/opensuse-security-announce/2019-09/msg00032.html">http://lists.opensuse.org/opensuse-security-announce/2019-09/msg00032.html</a><br><a href="http://lists.opensuse.org/opensuse-security-announce/2019-09/msg00035.html">http://lists.opensuse.org/opensuse-security-announce/2019-09/msg00035.html</a><br><a href="http://lists.opensuse.org/opensuse-security-announce/2019-10/msg00003.html">http://lists.opensuse.org/opensuse-security-announce/2019-10/msg00003.html</a><br><a href="http://lists.opensuse.org/opensuse-security-announce/2019-10/msg00005.html">http://lists.opensuse.org/opensuse-security-announce/2019-10/msg00005.html</a><br><a href="http://lists.opensuse.org/opensuse-security-announce/2019-10/msg00014.html">http://lists.opensuse.org/opensuse-security-announce/2019-10/msg00014.html</a><br><a href="https://access.redhat.com/errata/RHSA-2019:2692">https://access.redhat.com/errata/RHSA-2019:2692</a><br><a href="https://access.redhat.com/errata/RHSA-2019:2745">https://access.redhat.com/errata/RHSA-2019:2745</a><br><a href="https://access.redhat.com/errata/RHSA-2019:2746">https://access.redhat.com/errata/RHSA-2019:2746</a><br><a href="https://access.redhat.com/errata/RHSA-2019:2775">https://access.redhat.com/errata/RHSA-2019:2775</a><br><a href="https://access.redhat.com/errata/RHSA-2019:2799">https://access.redhat.com/errata/RHSA-2019:2799</a><br><a href="https://access.redhat.com/errata/RHSA-2019:2925">https://access.redhat.com/errata/RHSA-2019:2925</a><br><a href="https://access.redhat.com/errata/RHSA-2019:2939">https://access.redhat.com/errata/RHSA-2019:2939</a><br><a href="https://access.redhat.com/errata/RHSA-2019:2949">https://access.redhat.com/errata/RHSA-2019:2949</a><br><a href="https://access.redhat.com/errata/RHSA-2019:2955">https://access.redhat.com/errata/RHSA-2019:2955</a><br><a href="https://access.redhat.com/errata/RHSA-2019:2966">https://access.redhat.com/errata/RHSA-2019:2966</a><br><a href="https://access.redhat.com/errata/RHSA-2019:3041">https://access.redhat.com/errata/RHSA-2019:3041</a><br><a href="https://access.redhat.com/errata/RHSA-2019:3932">https://access.redhat.com/errata/RHSA-2019:3932</a><br><a href="https://access.redhat.com/errata/RHSA-2019:3933">https://access.redhat.com/errata/RHSA-2019:3933</a><br><a href="https://access.redhat.com/errata/RHSA-2019:3935">https://access.redhat.com/errata/RHSA-2019:3935</a><br><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2019-9513">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2019-9513</a><br><a href="https://github.com/Netflix/security-bulletins/blob/master/advisories/third-party/2019-002.md">https://github.com/Netflix/security-bulletins/blob/master/advisories/third-party/2019-002.md</a><br><a href="https://kb.cert.org/vuls/id/605641/">https://kb.cert.org/vuls/id/605641/</a><br><a href="https://kc.mcafee.com/corporate/index?page=content&amp;id=SB10296">https://kc.mcafee.com/corporate/index?page=content&amp;id=SB10296</a><br><a href="https://linux.oracle.com/cve/CVE-2019-9513.html">https://linux.oracle.com/cve/CVE-2019-9513.html</a><br><a href="https://linux.oracle.com/errata/ELSA-2019-2925.html">https://linux.oracle.com/errata/ELSA-2019-2925.html</a><br><a href="https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/4ZQGHE3WTYLYAYJEIDJVF2FIGQTAYPMC/">https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/4ZQGHE3WTYLYAYJEIDJVF2FIGQTAYPMC/</a><br><a href="https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/CMNFX5MNYRWWIMO4BTKYQCGUDMHO3AXP/">https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/CMNFX5MNYRWWIMO4BTKYQCGUDMHO3AXP/</a><br><a href="https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/JUBYAF6ED3O4XCHQ5C2HYENJLXYXZC4M/">https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/JUBYAF6ED3O4XCHQ5C2HYENJLXYXZC4M/</a><br><a href="https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/LZLUYPYY3RX4ZJDWZRJIKSULYRJ4PXW7/">https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/LZLUYPYY3RX4ZJDWZRJIKSULYRJ4PXW7/</a><br><a href="https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/POPAEC4FWL4UU4LDEGPY5NPALU24FFQD/">https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/POPAEC4FWL4UU4LDEGPY5NPALU24FFQD/</a><br><a href="https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/TAZZEVTCN2B4WT6AIBJ7XGYJMBTORJU5/">https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/TAZZEVTCN2B4WT6AIBJ7XGYJMBTORJU5/</a><br><a href="https://nghttp2.org/blog/2019/08/19/nghttp2-v1-39-2/">https://nghttp2.org/blog/2019/08/19/nghttp2-v1-39-2/</a><br><a href="https://nodejs.org/en/blog/vulnerability/aug-2019-security-releases/">https://nodejs.org/en/blog/vulnerability/aug-2019-security-releases/</a><br><a href="https://seclists.org/bugtraq/2019/Aug/40">https://seclists.org/bugtraq/2019/Aug/40</a><br><a href="https://seclists.org/bugtraq/2019/Sep/1">https://seclists.org/bugtraq/2019/Sep/1</a><br><a href="https://security.netapp.com/advisory/ntap-20190823-0002/">https://security.netapp.com/advisory/ntap-20190823-0002/</a><br><a href="https://security.netapp.com/advisory/ntap-20190823-0005/">https://security.netapp.com/advisory/ntap-20190823-0005/</a><br><a href="https://support.f5.com/csp/article/K02591030">https://support.f5.com/csp/article/K02591030</a><br><a href="https://support.f5.com/csp/article/K02591030?utm_source=f5support&amp;amp;utm_medium=RSS">https://support.f5.com/csp/article/K02591030?utm_source=f5support&amp;amp;utm_medium=RSS</a><br><a href="https://ubuntu.com/security/notices/USN-4099-1">https://ubuntu.com/security/notices/USN-4099-1</a><br><a href="https://usn.ubuntu.com/4099-1/">https://usn.ubuntu.com/4099-1/</a><br><a href="https://www.debian.org/security/2019/dsa-4505">https://www.debian.org/security/2019/dsa-4505</a><br><a href="https://www.debian.org/security/2019/dsa-4511">https://www.debian.org/security/2019/dsa-4511</a><br><a href="https://www.debian.org/security/2020/dsa-4669">https://www.debian.org/security/2020/dsa-4669</a><br><a href="https://www.nginx.com/blog/nginx-updates-mitigate-august-2019-http-2-vulnerabilities/">https://www.nginx.com/blog/nginx-updates-mitigate-august-2019-http-2-vulnerabilities/</a><br><a href="https://www.oracle.com/security-alerts/cpujan2021.html">https://www.oracle.com/security-alerts/cpujan2021.html</a><br><a href="https://www.oracle.com/security-alerts/cpuoct2020.html">https://www.oracle.com/security-alerts/cpuoct2020.html</a><br><a href="https://www.synology.com/security/advisory/Synology_SA_19_33">https://www.synology.com/security/advisory/Synology_SA_19_33</a><br></details>  |
| libpcre3         |    CVE-2017-11164   |   LOW  |  2:8.39-9 |  | <details><summary>Expand...</summary><a href="http://openwall.com/lists/oss-security/2017/07/11/3">http://openwall.com/lists/oss-security/2017/07/11/3</a><br><a href="http://www.securityfocus.com/bid/99575">http://www.securityfocus.com/bid/99575</a><br><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2017-11164">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2017-11164</a><br><a href="https://lists.apache.org/thread.html/rf9fa47ab66495c78bb4120b0754dd9531ca2ff0430f6685ac9b07772@%3Cdev.mina.apache.org%3E">https://lists.apache.org/thread.html/rf9fa47ab66495c78bb4120b0754dd9531ca2ff0430f6685ac9b07772@%3Cdev.mina.apache.org%3E</a><br></details>  |
| libpcre3         |    CVE-2019-20838   |   LOW  |  2:8.39-9 |  | <details><summary>Expand...</summary><a href="http://seclists.org/fulldisclosure/2020/Dec/32">http://seclists.org/fulldisclosure/2020/Dec/32</a><br><a href="http://seclists.org/fulldisclosure/2021/Feb/14">http://seclists.org/fulldisclosure/2021/Feb/14</a><br><a href="https://bugs.gentoo.org/717920">https://bugs.gentoo.org/717920</a><br><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2019-20838">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2019-20838</a><br><a href="https://linux.oracle.com/cve/CVE-2019-20838.html">https://linux.oracle.com/cve/CVE-2019-20838.html</a><br><a href="https://linux.oracle.com/errata/ELSA-2021-4373.html">https://linux.oracle.com/errata/ELSA-2021-4373.html</a><br><a href="https://lists.apache.org/thread.html/rf9fa47ab66495c78bb4120b0754dd9531ca2ff0430f6685ac9b07772@%3Cdev.mina.apache.org%3E">https://lists.apache.org/thread.html/rf9fa47ab66495c78bb4120b0754dd9531ca2ff0430f6685ac9b07772@%3Cdev.mina.apache.org%3E</a><br><a href="https://support.apple.com/kb/HT211931">https://support.apple.com/kb/HT211931</a><br><a href="https://support.apple.com/kb/HT212147">https://support.apple.com/kb/HT212147</a><br><a href="https://www.pcre.org/original/changelog.txt">https://www.pcre.org/original/changelog.txt</a><br></details>  |
| libpcre3         |    CVE-2020-14155   |   LOW  |  2:8.39-9 |  | <details><summary>Expand...</summary><a href="http://seclists.org/fulldisclosure/2020/Dec/32">http://seclists.org/fulldisclosure/2020/Dec/32</a><br><a href="http://seclists.org/fulldisclosure/2021/Feb/14">http://seclists.org/fulldisclosure/2021/Feb/14</a><br><a href="https://about.gitlab.com/releases/2020/07/01/security-release-13-1-2-release/">https://about.gitlab.com/releases/2020/07/01/security-release-13-1-2-release/</a><br><a href="https://bugs.gentoo.org/717920">https://bugs.gentoo.org/717920</a><br><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2020-14155">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2020-14155</a><br><a href="https://linux.oracle.com/cve/CVE-2020-14155.html">https://linux.oracle.com/cve/CVE-2020-14155.html</a><br><a href="https://linux.oracle.com/errata/ELSA-2021-4373.html">https://linux.oracle.com/errata/ELSA-2021-4373.html</a><br><a href="https://lists.apache.org/thread.html/rf9fa47ab66495c78bb4120b0754dd9531ca2ff0430f6685ac9b07772@%3Cdev.mina.apache.org%3E">https://lists.apache.org/thread.html/rf9fa47ab66495c78bb4120b0754dd9531ca2ff0430f6685ac9b07772@%3Cdev.mina.apache.org%3E</a><br><a href="https://support.apple.com/kb/HT211931">https://support.apple.com/kb/HT211931</a><br><a href="https://support.apple.com/kb/HT212147">https://support.apple.com/kb/HT212147</a><br><a href="https://www.pcre.org/original/changelog.txt">https://www.pcre.org/original/changelog.txt</a><br></details>  |
| libperl5.26         |    CVE-2020-16156   |   MEDIUM  |  5.26.1-6ubuntu0.5 |  | <details><summary>Expand...</summary><a href="http://blogs.perl.org/users/neilb/2021/11/addressing-cpan-vulnerabilities-related-to-checksums.html">http://blogs.perl.org/users/neilb/2021/11/addressing-cpan-vulnerabilities-related-to-checksums.html</a><br><a href="https://blog.hackeriet.no/cpan-signature-verification-vulnerabilities/">https://blog.hackeriet.no/cpan-signature-verification-vulnerabilities/</a><br><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2020-16156">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2020-16156</a><br><a href="https://github.com/andk/cpanpm/commit/b27c51adf0fda25dee84cb72cb2b1bf7d832148c">https://github.com/andk/cpanpm/commit/b27c51adf0fda25dee84cb72cb2b1bf7d832148c</a><br><a href="https://metacpan.org/pod/distribution/CPAN/scripts/cpan">https://metacpan.org/pod/distribution/CPAN/scripts/cpan</a><br></details>  |
| libroken18-heimdal         |    CVE-2019-12098   |   LOW  |  7.5.0+dfsg-1 |  | <details><summary>Expand...</summary><a href="http://lists.opensuse.org/opensuse-security-announce/2019-07/msg00002.html">http://lists.opensuse.org/opensuse-security-announce/2019-07/msg00002.html</a><br><a href="http://lists.opensuse.org/opensuse-security-announce/2019-07/msg00003.html">http://lists.opensuse.org/opensuse-security-announce/2019-07/msg00003.html</a><br><a href="http://lists.opensuse.org/opensuse-security-announce/2019-08/msg00026.html">http://lists.opensuse.org/opensuse-security-announce/2019-08/msg00026.html</a><br><a href="http://www.h5l.org/pipermail/heimdal-announce/2019-May/000009.html">http://www.h5l.org/pipermail/heimdal-announce/2019-May/000009.html</a><br><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2019-12098">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2019-12098</a><br><a href="https://github.com/heimdal/heimdal/commit/2f7f3d9960aa6ea21358bdf3687cee5149aa35cf">https://github.com/heimdal/heimdal/commit/2f7f3d9960aa6ea21358bdf3687cee5149aa35cf</a><br><a href="https://github.com/heimdal/heimdal/compare/3e58559...bbafe72">https://github.com/heimdal/heimdal/compare/3e58559...bbafe72</a><br><a href="https://github.com/heimdal/heimdal/releases/tag/heimdal-7.6.0">https://github.com/heimdal/heimdal/releases/tag/heimdal-7.6.0</a><br><a href="https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/GIXEDVVMPD6ZAJSMI2EZ7FNEIVNWE5PD/">https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/GIXEDVVMPD6ZAJSMI2EZ7FNEIVNWE5PD/</a><br><a href="https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/SLXXIF4LOQEAEDAF4UGP2AO6WDNTDFUB/">https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/SLXXIF4LOQEAEDAF4UGP2AO6WDNTDFUB/</a><br><a href="https://seclists.org/bugtraq/2019/Jun/1">https://seclists.org/bugtraq/2019/Jun/1</a><br><a href="https://www.debian.org/security/2019/dsa-4455">https://www.debian.org/security/2019/dsa-4455</a><br></details>  |
| libroken18-heimdal         |    CVE-2021-3671   |   LOW  |  7.5.0+dfsg-1 |  | <details><summary>Expand...</summary><a href="https://bugzilla.redhat.com/show_bug.cgi?id=2013080,">https://bugzilla.redhat.com/show_bug.cgi?id=2013080,</a><br><a href="https://bugzilla.samba.org/show_bug.cgi?id=14770,">https://bugzilla.samba.org/show_bug.cgi?id=14770,</a><br><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2021-3671">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2021-3671</a><br><a href="https://github.com/heimdal/heimdal/commit/04171147948d0a3636bc6374181926f0fb2ec83a">https://github.com/heimdal/heimdal/commit/04171147948d0a3636bc6374181926f0fb2ec83a</a><br><a href="https://ubuntu.com/security/notices/USN-5142-1">https://ubuntu.com/security/notices/USN-5142-1</a><br><a href="https://ubuntu.com/security/notices/USN-5174-1">https://ubuntu.com/security/notices/USN-5174-1</a><br></details>  |
| libsqlite3-0         |    CVE-2020-9794   |   MEDIUM  |  3.22.0-1ubuntu0.4 |  | <details><summary>Expand...</summary><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2020-9794">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2020-9794</a><br><a href="https://lists.apache.org/thread.html/rf9fa47ab66495c78bb4120b0754dd9531ca2ff0430f6685ac9b07772@%3Cdev.mina.apache.org%3E">https://lists.apache.org/thread.html/rf9fa47ab66495c78bb4120b0754dd9531ca2ff0430f6685ac9b07772@%3Cdev.mina.apache.org%3E</a><br><a href="https://support.apple.com/HT211168">https://support.apple.com/HT211168</a><br><a href="https://support.apple.com/HT211170">https://support.apple.com/HT211170</a><br><a href="https://support.apple.com/HT211171">https://support.apple.com/HT211171</a><br><a href="https://support.apple.com/HT211175">https://support.apple.com/HT211175</a><br><a href="https://support.apple.com/HT211178">https://support.apple.com/HT211178</a><br><a href="https://support.apple.com/HT211179">https://support.apple.com/HT211179</a><br><a href="https://support.apple.com/HT211181">https://support.apple.com/HT211181</a><br><a href="https://vuldb.com/?id.155768">https://vuldb.com/?id.155768</a><br></details>  |
| libsqlite3-0         |    CVE-2020-9849   |   LOW  |  3.22.0-1ubuntu0.4 |  | <details><summary>Expand...</summary><a href="http://seclists.org/fulldisclosure/2020/Dec/32">http://seclists.org/fulldisclosure/2020/Dec/32</a><br><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2020-9849">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2020-9849</a><br><a href="https://lists.apache.org/thread.html/rf9fa47ab66495c78bb4120b0754dd9531ca2ff0430f6685ac9b07772@%3Cdev.mina.apache.org%3E">https://lists.apache.org/thread.html/rf9fa47ab66495c78bb4120b0754dd9531ca2ff0430f6685ac9b07772@%3Cdev.mina.apache.org%3E</a><br><a href="https://support.apple.com/en-us/HT211843">https://support.apple.com/en-us/HT211843</a><br><a href="https://support.apple.com/en-us/HT211844">https://support.apple.com/en-us/HT211844</a><br><a href="https://support.apple.com/en-us/HT211850">https://support.apple.com/en-us/HT211850</a><br><a href="https://support.apple.com/en-us/HT211931">https://support.apple.com/en-us/HT211931</a><br><a href="https://support.apple.com/en-us/HT211935">https://support.apple.com/en-us/HT211935</a><br><a href="https://support.apple.com/en-us/HT211952">https://support.apple.com/en-us/HT211952</a><br><a href="https://www.rapid7.com/db/vulnerabilities/apple-osx-sqlite-cve-2020-9849/">https://www.rapid7.com/db/vulnerabilities/apple-osx-sqlite-cve-2020-9849/</a><br></details>  |
| libsqlite3-0         |    CVE-2020-9991   |   LOW  |  3.22.0-1ubuntu0.4 |  | <details><summary>Expand...</summary><a href="http://seclists.org/fulldisclosure/2020/Dec/32">http://seclists.org/fulldisclosure/2020/Dec/32</a><br><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2020-9991">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2020-9991</a><br><a href="https://lists.apache.org/thread.html/rf9fa47ab66495c78bb4120b0754dd9531ca2ff0430f6685ac9b07772@%3Cdev.mina.apache.org%3E">https://lists.apache.org/thread.html/rf9fa47ab66495c78bb4120b0754dd9531ca2ff0430f6685ac9b07772@%3Cdev.mina.apache.org%3E</a><br><a href="https://support.apple.com/en-us/HT211843">https://support.apple.com/en-us/HT211843</a><br><a href="https://support.apple.com/en-us/HT211844">https://support.apple.com/en-us/HT211844</a><br><a href="https://support.apple.com/en-us/HT211847">https://support.apple.com/en-us/HT211847</a><br><a href="https://support.apple.com/en-us/HT211850">https://support.apple.com/en-us/HT211850</a><br><a href="https://support.apple.com/en-us/HT211931">https://support.apple.com/en-us/HT211931</a><br><a href="https://support.apple.com/kb/HT211846">https://support.apple.com/kb/HT211846</a><br><a href="https://www.rapid7.com/db/vulnerabilities/apple-osx-sqlite-cve-2020-9991/">https://www.rapid7.com/db/vulnerabilities/apple-osx-sqlite-cve-2020-9991/</a><br></details>  |
| libstdc++6         |    CVE-2020-13844   |   MEDIUM  |  8.4.0-1ubuntu1~18.04 |  | <details><summary>Expand...</summary><a href="http://lists.llvm.org/pipermail/llvm-dev/2020-June/142109.html">http://lists.llvm.org/pipermail/llvm-dev/2020-June/142109.html</a><br><a href="http://lists.opensuse.org/opensuse-security-announce/2020-10/msg00039.html">http://lists.opensuse.org/opensuse-security-announce/2020-10/msg00039.html</a><br><a href="http://lists.opensuse.org/opensuse-security-announce/2020-10/msg00040.html">http://lists.opensuse.org/opensuse-security-announce/2020-10/msg00040.html</a><br><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2020-13844">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2020-13844</a><br><a href="https://developer.arm.com/support/arm-security-updates/speculative-processor-vulnerability">https://developer.arm.com/support/arm-security-updates/speculative-processor-vulnerability</a><br><a href="https://developer.arm.com/support/arm-security-updates/speculative-processor-vulnerability/downloads/straight-line-speculation">https://developer.arm.com/support/arm-security-updates/speculative-processor-vulnerability/downloads/straight-line-speculation</a><br><a href="https://developer.arm.com/support/arm-security-updates/speculative-processor-vulnerability/frequently-asked-questions">https://developer.arm.com/support/arm-security-updates/speculative-processor-vulnerability/frequently-asked-questions</a><br><a href="https://gcc.gnu.org/pipermail/gcc-patches/2020-June/547520.html">https://gcc.gnu.org/pipermail/gcc-patches/2020-June/547520.html</a><br><a href="https://git.kernel.org/pub/scm/linux/kernel/git/torvalds/linux.git/commit/?id=679db70801da9fda91d26caf13bf5b5ccc74e8e8">https://git.kernel.org/pub/scm/linux/kernel/git/torvalds/linux.git/commit/?id=679db70801da9fda91d26caf13bf5b5ccc74e8e8</a><br></details>  |
| libtasn1-6         |    CVE-2018-1000654   |   LOW  |  4.13-2 |  | <details><summary>Expand...</summary><a href="http://lists.opensuse.org/opensuse-security-announce/2019-06/msg00009.html">http://lists.opensuse.org/opensuse-security-announce/2019-06/msg00009.html</a><br><a href="http://lists.opensuse.org/opensuse-security-announce/2019-06/msg00018.html">http://lists.opensuse.org/opensuse-security-announce/2019-06/msg00018.html</a><br><a href="http://www.securityfocus.com/bid/105151">http://www.securityfocus.com/bid/105151</a><br><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2018-1000654">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2018-1000654</a><br><a href="https://gitlab.com/gnutls/libtasn1/issues/4">https://gitlab.com/gnutls/libtasn1/issues/4</a><br><a href="https://lists.apache.org/thread.html/rf9fa47ab66495c78bb4120b0754dd9531ca2ff0430f6685ac9b07772@%3Cdev.mina.apache.org%3E">https://lists.apache.org/thread.html/rf9fa47ab66495c78bb4120b0754dd9531ca2ff0430f6685ac9b07772@%3Cdev.mina.apache.org%3E</a><br></details>  |
| libtinfo5         |    CVE-2019-17594   |   LOW  |  6.1-1ubuntu1.18.04 |  | <details><summary>Expand...</summary><a href="http://lists.opensuse.org/opensuse-security-announce/2019-11/msg00059.html">http://lists.opensuse.org/opensuse-security-announce/2019-11/msg00059.html</a><br><a href="http://lists.opensuse.org/opensuse-security-announce/2019-11/msg00061.html">http://lists.opensuse.org/opensuse-security-announce/2019-11/msg00061.html</a><br><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2019-17594">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2019-17594</a><br><a href="https://linux.oracle.com/cve/CVE-2019-17594.html">https://linux.oracle.com/cve/CVE-2019-17594.html</a><br><a href="https://linux.oracle.com/errata/ELSA-2021-4426.html">https://linux.oracle.com/errata/ELSA-2021-4426.html</a><br><a href="https://lists.gnu.org/archive/html/bug-ncurses/2019-10/msg00017.html">https://lists.gnu.org/archive/html/bug-ncurses/2019-10/msg00017.html</a><br><a href="https://lists.gnu.org/archive/html/bug-ncurses/2019-10/msg00045.html">https://lists.gnu.org/archive/html/bug-ncurses/2019-10/msg00045.html</a><br><a href="https://security.gentoo.org/glsa/202101-28">https://security.gentoo.org/glsa/202101-28</a><br></details>  |
| libtinfo5         |    CVE-2019-17595   |   LOW  |  6.1-1ubuntu1.18.04 |  | <details><summary>Expand...</summary><a href="http://lists.opensuse.org/opensuse-security-announce/2019-11/msg00059.html">http://lists.opensuse.org/opensuse-security-announce/2019-11/msg00059.html</a><br><a href="http://lists.opensuse.org/opensuse-security-announce/2019-11/msg00061.html">http://lists.opensuse.org/opensuse-security-announce/2019-11/msg00061.html</a><br><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2019-17595">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2019-17595</a><br><a href="https://linux.oracle.com/cve/CVE-2019-17595.html">https://linux.oracle.com/cve/CVE-2019-17595.html</a><br><a href="https://linux.oracle.com/errata/ELSA-2021-4426.html">https://linux.oracle.com/errata/ELSA-2021-4426.html</a><br><a href="https://lists.gnu.org/archive/html/bug-ncurses/2019-10/msg00013.html">https://lists.gnu.org/archive/html/bug-ncurses/2019-10/msg00013.html</a><br><a href="https://lists.gnu.org/archive/html/bug-ncurses/2019-10/msg00045.html">https://lists.gnu.org/archive/html/bug-ncurses/2019-10/msg00045.html</a><br><a href="https://security.gentoo.org/glsa/202101-28">https://security.gentoo.org/glsa/202101-28</a><br></details>  |
| libwind0-heimdal         |    CVE-2019-12098   |   LOW  |  7.5.0+dfsg-1 |  | <details><summary>Expand...</summary><a href="http://lists.opensuse.org/opensuse-security-announce/2019-07/msg00002.html">http://lists.opensuse.org/opensuse-security-announce/2019-07/msg00002.html</a><br><a href="http://lists.opensuse.org/opensuse-security-announce/2019-07/msg00003.html">http://lists.opensuse.org/opensuse-security-announce/2019-07/msg00003.html</a><br><a href="http://lists.opensuse.org/opensuse-security-announce/2019-08/msg00026.html">http://lists.opensuse.org/opensuse-security-announce/2019-08/msg00026.html</a><br><a href="http://www.h5l.org/pipermail/heimdal-announce/2019-May/000009.html">http://www.h5l.org/pipermail/heimdal-announce/2019-May/000009.html</a><br><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2019-12098">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2019-12098</a><br><a href="https://github.com/heimdal/heimdal/commit/2f7f3d9960aa6ea21358bdf3687cee5149aa35cf">https://github.com/heimdal/heimdal/commit/2f7f3d9960aa6ea21358bdf3687cee5149aa35cf</a><br><a href="https://github.com/heimdal/heimdal/compare/3e58559...bbafe72">https://github.com/heimdal/heimdal/compare/3e58559...bbafe72</a><br><a href="https://github.com/heimdal/heimdal/releases/tag/heimdal-7.6.0">https://github.com/heimdal/heimdal/releases/tag/heimdal-7.6.0</a><br><a href="https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/GIXEDVVMPD6ZAJSMI2EZ7FNEIVNWE5PD/">https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/GIXEDVVMPD6ZAJSMI2EZ7FNEIVNWE5PD/</a><br><a href="https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/SLXXIF4LOQEAEDAF4UGP2AO6WDNTDFUB/">https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/SLXXIF4LOQEAEDAF4UGP2AO6WDNTDFUB/</a><br><a href="https://seclists.org/bugtraq/2019/Jun/1">https://seclists.org/bugtraq/2019/Jun/1</a><br><a href="https://www.debian.org/security/2019/dsa-4455">https://www.debian.org/security/2019/dsa-4455</a><br></details>  |
| libwind0-heimdal         |    CVE-2021-3671   |   LOW  |  7.5.0+dfsg-1 |  | <details><summary>Expand...</summary><a href="https://bugzilla.redhat.com/show_bug.cgi?id=2013080,">https://bugzilla.redhat.com/show_bug.cgi?id=2013080,</a><br><a href="https://bugzilla.samba.org/show_bug.cgi?id=14770,">https://bugzilla.samba.org/show_bug.cgi?id=14770,</a><br><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2021-3671">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2021-3671</a><br><a href="https://github.com/heimdal/heimdal/commit/04171147948d0a3636bc6374181926f0fb2ec83a">https://github.com/heimdal/heimdal/commit/04171147948d0a3636bc6374181926f0fb2ec83a</a><br><a href="https://ubuntu.com/security/notices/USN-5142-1">https://ubuntu.com/security/notices/USN-5142-1</a><br><a href="https://ubuntu.com/security/notices/USN-5174-1">https://ubuntu.com/security/notices/USN-5174-1</a><br></details>  |
| locales         |    CVE-2021-35942   |   MEDIUM  |  2.27-3ubuntu1.4 |  | <details><summary>Expand...</summary><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2021-35942">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2021-35942</a><br><a href="https://linux.oracle.com/cve/CVE-2021-35942.html">https://linux.oracle.com/cve/CVE-2021-35942.html</a><br><a href="https://linux.oracle.com/errata/ELSA-2021-9560.html">https://linux.oracle.com/errata/ELSA-2021-9560.html</a><br><a href="https://security.netapp.com/advisory/ntap-20210827-0005/">https://security.netapp.com/advisory/ntap-20210827-0005/</a><br><a href="https://sourceware.org/bugzilla/show_bug.cgi?id=28011">https://sourceware.org/bugzilla/show_bug.cgi?id=28011</a><br><a href="https://sourceware.org/git/?p=glibc.git;a=commit;h=5adda61f62b77384718b4c0d8336ade8f2b4b35c">https://sourceware.org/git/?p=glibc.git;a=commit;h=5adda61f62b77384718b4c0d8336ade8f2b4b35c</a><br><a href="https://sourceware.org/git/?p=glibc.git;a=commitdiff;h=5adda61f62b77384718b4c0d8336ade8f2b4b35c">https://sourceware.org/git/?p=glibc.git;a=commitdiff;h=5adda61f62b77384718b4c0d8336ade8f2b4b35c</a><br><a href="https://sourceware.org/glibc/wiki/Security%20Exceptions">https://sourceware.org/glibc/wiki/Security%20Exceptions</a><br></details>  |
| locales         |    CVE-2021-38604   |   MEDIUM  |  2.27-3ubuntu1.4 |  | <details><summary>Expand...</summary><a href="https://blog.tuxcare.com/cve/tuxcare-team-identifies-cve-2021-38604-a-new-vulnerability-in-glibc">https://blog.tuxcare.com/cve/tuxcare-team-identifies-cve-2021-38604-a-new-vulnerability-in-glibc</a><br><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2021-38604">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2021-38604</a><br><a href="https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/GYEXYM37RCJWJ6B5KQUYQI4NZBDDYSXP/">https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/GYEXYM37RCJWJ6B5KQUYQI4NZBDDYSXP/</a><br><a href="https://security.netapp.com/advisory/ntap-20210909-0005/">https://security.netapp.com/advisory/ntap-20210909-0005/</a><br><a href="https://sourceware.org/bugzilla/show_bug.cgi?id=28213">https://sourceware.org/bugzilla/show_bug.cgi?id=28213</a><br><a href="https://sourceware.org/git/?p=glibc.git;a=commit;h=4cc79c217744743077bf7a0ec5e0a4318f1e6641">https://sourceware.org/git/?p=glibc.git;a=commit;h=4cc79c217744743077bf7a0ec5e0a4318f1e6641</a><br><a href="https://sourceware.org/git/?p=glibc.git;a=commit;h=b805aebd42364fe696e417808a700fdb9800c9e8">https://sourceware.org/git/?p=glibc.git;a=commit;h=b805aebd42364fe696e417808a700fdb9800c9e8</a><br></details>  |
| locales         |    CVE-2009-5155   |   LOW  |  2.27-3ubuntu1.4 |  | <details><summary>Expand...</summary><a href="http://git.savannah.gnu.org/cgit/gnulib.git/commit/?id=5513b40999149090987a0341c018d05d3eea1272">http://git.savannah.gnu.org/cgit/gnulib.git/commit/?id=5513b40999149090987a0341c018d05d3eea1272</a><br><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2009-5155">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2009-5155</a><br><a href="https://debbugs.gnu.org/cgi/bugreport.cgi?bug=22793">https://debbugs.gnu.org/cgi/bugreport.cgi?bug=22793</a><br><a href="https://debbugs.gnu.org/cgi/bugreport.cgi?bug=32806">https://debbugs.gnu.org/cgi/bugreport.cgi?bug=32806</a><br><a href="https://debbugs.gnu.org/cgi/bugreport.cgi?bug=34238">https://debbugs.gnu.org/cgi/bugreport.cgi?bug=34238</a><br><a href="https://lists.apache.org/thread.html/r58af02e294bd07f487e2c64ffc0a29b837db5600e33b6e698b9d696b@%3Cissues.bookkeeper.apache.org%3E">https://lists.apache.org/thread.html/r58af02e294bd07f487e2c64ffc0a29b837db5600e33b6e698b9d696b@%3Cissues.bookkeeper.apache.org%3E</a><br><a href="https://lists.apache.org/thread.html/rf4c02775860db415b4955778a131c2795223f61cb8c6a450893651e4@%3Cissues.bookkeeper.apache.org%3E">https://lists.apache.org/thread.html/rf4c02775860db415b4955778a131c2795223f61cb8c6a450893651e4@%3Cissues.bookkeeper.apache.org%3E</a><br><a href="https://security.netapp.com/advisory/ntap-20190315-0002/">https://security.netapp.com/advisory/ntap-20190315-0002/</a><br><a href="https://sourceware.org/bugzilla/show_bug.cgi?id=11053">https://sourceware.org/bugzilla/show_bug.cgi?id=11053</a><br><a href="https://sourceware.org/bugzilla/show_bug.cgi?id=18986">https://sourceware.org/bugzilla/show_bug.cgi?id=18986</a><br><a href="https://sourceware.org/git/gitweb.cgi?p=glibc.git;h=eb04c21373e2a2885f3d52ff192b0499afe3c672">https://sourceware.org/git/gitweb.cgi?p=glibc.git;h=eb04c21373e2a2885f3d52ff192b0499afe3c672</a><br><a href="https://support.f5.com/csp/article/K64119434">https://support.f5.com/csp/article/K64119434</a><br><a href="https://support.f5.com/csp/article/K64119434?utm_source=f5support&amp;amp;utm_medium=RSS">https://support.f5.com/csp/article/K64119434?utm_source=f5support&amp;amp;utm_medium=RSS</a><br><a href="https://ubuntu.com/security/notices/USN-4954-1">https://ubuntu.com/security/notices/USN-4954-1</a><br></details>  |
| locales         |    CVE-2015-8985   |   LOW  |  2.27-3ubuntu1.4 |  | <details><summary>Expand...</summary><a href="http://www.openwall.com/lists/oss-security/2017/02/14/9">http://www.openwall.com/lists/oss-security/2017/02/14/9</a><br><a href="http://www.securityfocus.com/bid/76916">http://www.securityfocus.com/bid/76916</a><br><a href="https://bugs.debian.org/cgi-bin/bugreport.cgi?bug=779392">https://bugs.debian.org/cgi-bin/bugreport.cgi?bug=779392</a><br><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2015-8985">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2015-8985</a><br><a href="https://security.gentoo.org/glsa/201908-06">https://security.gentoo.org/glsa/201908-06</a><br></details>  |
| locales         |    CVE-2016-10228   |   LOW  |  2.27-3ubuntu1.4 |  | <details><summary>Expand...</summary><a href="http://openwall.com/lists/oss-security/2017/03/01/10">http://openwall.com/lists/oss-security/2017/03/01/10</a><br><a href="http://www.securityfocus.com/bid/96525">http://www.securityfocus.com/bid/96525</a><br><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2016-10228">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2016-10228</a><br><a href="https://linux.oracle.com/cve/CVE-2016-10228.html">https://linux.oracle.com/cve/CVE-2016-10228.html</a><br><a href="https://linux.oracle.com/errata/ELSA-2021-9344.html">https://linux.oracle.com/errata/ELSA-2021-9344.html</a><br><a href="https://lists.apache.org/thread.html/rf9fa47ab66495c78bb4120b0754dd9531ca2ff0430f6685ac9b07772@%3Cdev.mina.apache.org%3E">https://lists.apache.org/thread.html/rf9fa47ab66495c78bb4120b0754dd9531ca2ff0430f6685ac9b07772@%3Cdev.mina.apache.org%3E</a><br><a href="https://security.gentoo.org/glsa/202101-20">https://security.gentoo.org/glsa/202101-20</a><br><a href="https://sourceware.org/bugzilla/show_bug.cgi?id=19519">https://sourceware.org/bugzilla/show_bug.cgi?id=19519</a><br><a href="https://sourceware.org/bugzilla/show_bug.cgi?id=19519#c21">https://sourceware.org/bugzilla/show_bug.cgi?id=19519#c21</a><br><a href="https://sourceware.org/bugzilla/show_bug.cgi?id=26224">https://sourceware.org/bugzilla/show_bug.cgi?id=26224</a><br></details>  |
| locales         |    CVE-2016-10739   |   LOW  |  2.27-3ubuntu1.4 |  | <details><summary>Expand...</summary><a href="http://lists.opensuse.org/opensuse-security-announce/2019-04/msg00082.html">http://lists.opensuse.org/opensuse-security-announce/2019-04/msg00082.html</a><br><a href="http://www.securityfocus.com/bid/106672">http://www.securityfocus.com/bid/106672</a><br><a href="https://access.redhat.com/errata/RHSA-2019:2118">https://access.redhat.com/errata/RHSA-2019:2118</a><br><a href="https://access.redhat.com/errata/RHSA-2019:3513">https://access.redhat.com/errata/RHSA-2019:3513</a><br><a href="https://bugzilla.redhat.com/show_bug.cgi?id=1347549">https://bugzilla.redhat.com/show_bug.cgi?id=1347549</a><br><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2016-10739">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2016-10739</a><br><a href="https://linux.oracle.com/cve/CVE-2016-10739.html">https://linux.oracle.com/cve/CVE-2016-10739.html</a><br><a href="https://linux.oracle.com/errata/ELSA-2019-3513.html">https://linux.oracle.com/errata/ELSA-2019-3513.html</a><br><a href="https://sourceware.org/bugzilla/show_bug.cgi?id=20018">https://sourceware.org/bugzilla/show_bug.cgi?id=20018</a><br></details>  |
| locales         |    CVE-2019-25013   |   LOW  |  2.27-3ubuntu1.4 |  | <details><summary>Expand...</summary><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2019-25013">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2019-25013</a><br><a href="https://linux.oracle.com/cve/CVE-2019-25013.html">https://linux.oracle.com/cve/CVE-2019-25013.html</a><br><a href="https://linux.oracle.com/errata/ELSA-2021-9344.html">https://linux.oracle.com/errata/ELSA-2021-9344.html</a><br><a href="https://lists.apache.org/thread.html/r32d767ac804e9b8aad4355bb85960a6a1385eab7afff549a5e98660f@%3Cjira.kafka.apache.org%3E">https://lists.apache.org/thread.html/r32d767ac804e9b8aad4355bb85960a6a1385eab7afff549a5e98660f@%3Cjira.kafka.apache.org%3E</a><br><a href="https://lists.apache.org/thread.html/r448bb851cc8e6e3f93f3c28c70032b37062625d81214744474ac49e7@%3Cdev.kafka.apache.org%3E">https://lists.apache.org/thread.html/r448bb851cc8e6e3f93f3c28c70032b37062625d81214744474ac49e7@%3Cdev.kafka.apache.org%3E</a><br><a href="https://lists.apache.org/thread.html/r4806a391091e082bdea17266452ca656ebc176e51bb3932733b3a0a2@%3Cjira.kafka.apache.org%3E">https://lists.apache.org/thread.html/r4806a391091e082bdea17266452ca656ebc176e51bb3932733b3a0a2@%3Cjira.kafka.apache.org%3E</a><br><a href="https://lists.apache.org/thread.html/r499e4f96d0b5109ef083f2feccd33c51650c1b7d7068aa3bd47efca9@%3Cjira.kafka.apache.org%3E">https://lists.apache.org/thread.html/r499e4f96d0b5109ef083f2feccd33c51650c1b7d7068aa3bd47efca9@%3Cjira.kafka.apache.org%3E</a><br><a href="https://lists.apache.org/thread.html/r5af4430421bb6f9973294691a7904bbd260937e9eef96b20556f43ff@%3Cjira.kafka.apache.org%3E">https://lists.apache.org/thread.html/r5af4430421bb6f9973294691a7904bbd260937e9eef96b20556f43ff@%3Cjira.kafka.apache.org%3E</a><br><a href="https://lists.apache.org/thread.html/r750eee18542bc02bd8350861c424ee60a9b9b225568fa09436a37ece@%3Cissues.zookeeper.apache.org%3E">https://lists.apache.org/thread.html/r750eee18542bc02bd8350861c424ee60a9b9b225568fa09436a37ece@%3Cissues.zookeeper.apache.org%3E</a><br><a href="https://lists.apache.org/thread.html/r7a2e94adfe0a2f0a1d42e4927e8c32ecac97d37db9cb68095fe9ddbc@%3Cdev.zookeeper.apache.org%3E">https://lists.apache.org/thread.html/r7a2e94adfe0a2f0a1d42e4927e8c32ecac97d37db9cb68095fe9ddbc@%3Cdev.zookeeper.apache.org%3E</a><br><a href="https://lists.apache.org/thread.html/rd2354f9ccce41e494fbadcbc5ad87218de6ec0fff8a7b54c8462226c@%3Cissues.zookeeper.apache.org%3E">https://lists.apache.org/thread.html/rd2354f9ccce41e494fbadcbc5ad87218de6ec0fff8a7b54c8462226c@%3Cissues.zookeeper.apache.org%3E</a><br><a href="https://lists.apache.org/thread.html/rf9fa47ab66495c78bb4120b0754dd9531ca2ff0430f6685ac9b07772@%3Cdev.mina.apache.org%3E">https://lists.apache.org/thread.html/rf9fa47ab66495c78bb4120b0754dd9531ca2ff0430f6685ac9b07772@%3Cdev.mina.apache.org%3E</a><br><a href="https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/4Y6TX47P47KABSFOL26FLDNVCWXDKDEZ/">https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/4Y6TX47P47KABSFOL26FLDNVCWXDKDEZ/</a><br><a href="https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/TVCUNLQ3HXGS4VPUQKWTJGRAW2KTFGXS/">https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/TVCUNLQ3HXGS4VPUQKWTJGRAW2KTFGXS/</a><br><a href="https://security.netapp.com/advisory/ntap-20210205-0004/">https://security.netapp.com/advisory/ntap-20210205-0004/</a><br><a href="https://sourceware.org/bugzilla/show_bug.cgi?id=24973">https://sourceware.org/bugzilla/show_bug.cgi?id=24973</a><br><a href="https://sourceware.org/git/?p=glibc.git;a=commit;h=ee7a3144c9922808181009b7b3e50e852fb4999b">https://sourceware.org/git/?p=glibc.git;a=commit;h=ee7a3144c9922808181009b7b3e50e852fb4999b</a><br></details>  |
| locales         |    CVE-2020-27618   |   LOW  |  2.27-3ubuntu1.4 |  | <details><summary>Expand...</summary><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2020-27618">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2020-27618</a><br><a href="https://linux.oracle.com/cve/CVE-2020-27618.html">https://linux.oracle.com/cve/CVE-2020-27618.html</a><br><a href="https://linux.oracle.com/errata/ELSA-2021-9344.html">https://linux.oracle.com/errata/ELSA-2021-9344.html</a><br><a href="https://security.netapp.com/advisory/ntap-20210401-0006/">https://security.netapp.com/advisory/ntap-20210401-0006/</a><br><a href="https://sourceware.org/bugzilla/show_bug.cgi?id=19519#c21">https://sourceware.org/bugzilla/show_bug.cgi?id=19519#c21</a><br><a href="https://sourceware.org/bugzilla/show_bug.cgi?id=26224">https://sourceware.org/bugzilla/show_bug.cgi?id=26224</a><br></details>  |
| locales         |    CVE-2020-6096   |   LOW  |  2.27-3ubuntu1.4 |  | <details><summary>Expand...</summary><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2020-6096">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2020-6096</a><br><a href="https://lists.apache.org/thread.html/rf9fa47ab66495c78bb4120b0754dd9531ca2ff0430f6685ac9b07772@%3Cdev.mina.apache.org%3E">https://lists.apache.org/thread.html/rf9fa47ab66495c78bb4120b0754dd9531ca2ff0430f6685ac9b07772@%3Cdev.mina.apache.org%3E</a><br><a href="https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/SPYXTDOOB4PQGTYAMZAZNJIB3FF6YQXI/">https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/SPYXTDOOB4PQGTYAMZAZNJIB3FF6YQXI/</a><br><a href="https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/URXOIA2LDUKHQXK4BE55BQBRI6ZZG3Y6/">https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/URXOIA2LDUKHQXK4BE55BQBRI6ZZG3Y6/</a><br><a href="https://security.gentoo.org/glsa/202101-20">https://security.gentoo.org/glsa/202101-20</a><br><a href="https://sourceware.org/bugzilla/attachment.cgi?id=12334">https://sourceware.org/bugzilla/attachment.cgi?id=12334</a><br><a href="https://sourceware.org/bugzilla/show_bug.cgi?id=25620">https://sourceware.org/bugzilla/show_bug.cgi?id=25620</a><br><a href="https://talosintelligence.com/vulnerability_reports/TALOS-2020-1019">https://talosintelligence.com/vulnerability_reports/TALOS-2020-1019</a><br><a href="https://ubuntu.com/security/notices/USN-4954-1">https://ubuntu.com/security/notices/USN-4954-1</a><br><a href="https://www.talosintelligence.com/vulnerability_reports/TALOS-2020-1019">https://www.talosintelligence.com/vulnerability_reports/TALOS-2020-1019</a><br></details>  |
| locales         |    CVE-2021-3326   |   LOW  |  2.27-3ubuntu1.4 |  | <details><summary>Expand...</summary><a href="http://www.openwall.com/lists/oss-security/2021/01/28/2">http://www.openwall.com/lists/oss-security/2021/01/28/2</a><br><a href="https://bugs.chromium.org/p/project-zero/issues/detail?id=2146">https://bugs.chromium.org/p/project-zero/issues/detail?id=2146</a><br><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2021-3326">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2021-3326</a><br><a href="https://linux.oracle.com/cve/CVE-2021-3326.html">https://linux.oracle.com/cve/CVE-2021-3326.html</a><br><a href="https://linux.oracle.com/errata/ELSA-2021-9344.html">https://linux.oracle.com/errata/ELSA-2021-9344.html</a><br><a href="https://security.netapp.com/advisory/ntap-20210304-0007/">https://security.netapp.com/advisory/ntap-20210304-0007/</a><br><a href="https://sourceware.org/bugzilla/show_bug.cgi?id=27256">https://sourceware.org/bugzilla/show_bug.cgi?id=27256</a><br><a href="https://sourceware.org/git/?p=glibc.git;a=commit;h=7d88c6142c6efc160c0ee5e4f85cde382c072888">https://sourceware.org/git/?p=glibc.git;a=commit;h=7d88c6142c6efc160c0ee5e4f85cde382c072888</a><br><a href="https://sourceware.org/pipermail/libc-alpha/2021-January/122058.html">https://sourceware.org/pipermail/libc-alpha/2021-January/122058.html</a><br></details>  |
| locales         |    CVE-2021-33574   |   LOW  |  2.27-3ubuntu1.4 |  | <details><summary>Expand...</summary><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2021-33574">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2021-33574</a><br><a href="https://linux.oracle.com/cve/CVE-2021-33574.html">https://linux.oracle.com/cve/CVE-2021-33574.html</a><br><a href="https://linux.oracle.com/errata/ELSA-2021-9560.html">https://linux.oracle.com/errata/ELSA-2021-9560.html</a><br><a href="https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/RBUUWUGXVILQXVWEOU7N42ICHPJNAEUP/">https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/RBUUWUGXVILQXVWEOU7N42ICHPJNAEUP/</a><br><a href="https://security.gentoo.org/glsa/202107-07">https://security.gentoo.org/glsa/202107-07</a><br><a href="https://security.netapp.com/advisory/ntap-20210629-0005/">https://security.netapp.com/advisory/ntap-20210629-0005/</a><br><a href="https://sourceware.org/bugzilla/show_bug.cgi?id=27896">https://sourceware.org/bugzilla/show_bug.cgi?id=27896</a><br><a href="https://sourceware.org/bugzilla/show_bug.cgi?id=27896#c1">https://sourceware.org/bugzilla/show_bug.cgi?id=27896#c1</a><br></details>  |
| login         |    CVE-2013-4235   |   LOW  |  1:4.5-1ubuntu2 |  | <details><summary>Expand...</summary><a href="https://access.redhat.com/security/cve/cve-2013-4235">https://access.redhat.com/security/cve/cve-2013-4235</a><br><a href="https://bugzilla.redhat.com/show_bug.cgi?id=CVE-2013-4235">https://bugzilla.redhat.com/show_bug.cgi?id=CVE-2013-4235</a><br><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2013-4235">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2013-4235</a><br><a href="https://lists.apache.org/thread.html/rf9fa47ab66495c78bb4120b0754dd9531ca2ff0430f6685ac9b07772@%3Cdev.mina.apache.org%3E">https://lists.apache.org/thread.html/rf9fa47ab66495c78bb4120b0754dd9531ca2ff0430f6685ac9b07772@%3Cdev.mina.apache.org%3E</a><br><a href="https://security-tracker.debian.org/tracker/CVE-2013-4235">https://security-tracker.debian.org/tracker/CVE-2013-4235</a><br></details>  |
| login         |    CVE-2018-7169   |   LOW  |  1:4.5-1ubuntu2 |  | <details><summary>Expand...</summary><a href="https://bugs.launchpad.net/ubuntu/+source/shadow/+bug/1729357">https://bugs.launchpad.net/ubuntu/+source/shadow/+bug/1729357</a><br><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2018-7169">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2018-7169</a><br><a href="https://github.com/shadow-maint/shadow/pull/97">https://github.com/shadow-maint/shadow/pull/97</a><br><a href="https://security.gentoo.org/glsa/201805-09">https://security.gentoo.org/glsa/201805-09</a><br></details>  |
| multiarch-support         |    CVE-2021-35942   |   MEDIUM  |  2.27-3ubuntu1.4 |  | <details><summary>Expand...</summary><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2021-35942">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2021-35942</a><br><a href="https://linux.oracle.com/cve/CVE-2021-35942.html">https://linux.oracle.com/cve/CVE-2021-35942.html</a><br><a href="https://linux.oracle.com/errata/ELSA-2021-9560.html">https://linux.oracle.com/errata/ELSA-2021-9560.html</a><br><a href="https://security.netapp.com/advisory/ntap-20210827-0005/">https://security.netapp.com/advisory/ntap-20210827-0005/</a><br><a href="https://sourceware.org/bugzilla/show_bug.cgi?id=28011">https://sourceware.org/bugzilla/show_bug.cgi?id=28011</a><br><a href="https://sourceware.org/git/?p=glibc.git;a=commit;h=5adda61f62b77384718b4c0d8336ade8f2b4b35c">https://sourceware.org/git/?p=glibc.git;a=commit;h=5adda61f62b77384718b4c0d8336ade8f2b4b35c</a><br><a href="https://sourceware.org/git/?p=glibc.git;a=commitdiff;h=5adda61f62b77384718b4c0d8336ade8f2b4b35c">https://sourceware.org/git/?p=glibc.git;a=commitdiff;h=5adda61f62b77384718b4c0d8336ade8f2b4b35c</a><br><a href="https://sourceware.org/glibc/wiki/Security%20Exceptions">https://sourceware.org/glibc/wiki/Security%20Exceptions</a><br></details>  |
| multiarch-support         |    CVE-2021-38604   |   MEDIUM  |  2.27-3ubuntu1.4 |  | <details><summary>Expand...</summary><a href="https://blog.tuxcare.com/cve/tuxcare-team-identifies-cve-2021-38604-a-new-vulnerability-in-glibc">https://blog.tuxcare.com/cve/tuxcare-team-identifies-cve-2021-38604-a-new-vulnerability-in-glibc</a><br><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2021-38604">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2021-38604</a><br><a href="https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/GYEXYM37RCJWJ6B5KQUYQI4NZBDDYSXP/">https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/GYEXYM37RCJWJ6B5KQUYQI4NZBDDYSXP/</a><br><a href="https://security.netapp.com/advisory/ntap-20210909-0005/">https://security.netapp.com/advisory/ntap-20210909-0005/</a><br><a href="https://sourceware.org/bugzilla/show_bug.cgi?id=28213">https://sourceware.org/bugzilla/show_bug.cgi?id=28213</a><br><a href="https://sourceware.org/git/?p=glibc.git;a=commit;h=4cc79c217744743077bf7a0ec5e0a4318f1e6641">https://sourceware.org/git/?p=glibc.git;a=commit;h=4cc79c217744743077bf7a0ec5e0a4318f1e6641</a><br><a href="https://sourceware.org/git/?p=glibc.git;a=commit;h=b805aebd42364fe696e417808a700fdb9800c9e8">https://sourceware.org/git/?p=glibc.git;a=commit;h=b805aebd42364fe696e417808a700fdb9800c9e8</a><br></details>  |
| multiarch-support         |    CVE-2009-5155   |   LOW  |  2.27-3ubuntu1.4 |  | <details><summary>Expand...</summary><a href="http://git.savannah.gnu.org/cgit/gnulib.git/commit/?id=5513b40999149090987a0341c018d05d3eea1272">http://git.savannah.gnu.org/cgit/gnulib.git/commit/?id=5513b40999149090987a0341c018d05d3eea1272</a><br><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2009-5155">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2009-5155</a><br><a href="https://debbugs.gnu.org/cgi/bugreport.cgi?bug=22793">https://debbugs.gnu.org/cgi/bugreport.cgi?bug=22793</a><br><a href="https://debbugs.gnu.org/cgi/bugreport.cgi?bug=32806">https://debbugs.gnu.org/cgi/bugreport.cgi?bug=32806</a><br><a href="https://debbugs.gnu.org/cgi/bugreport.cgi?bug=34238">https://debbugs.gnu.org/cgi/bugreport.cgi?bug=34238</a><br><a href="https://lists.apache.org/thread.html/r58af02e294bd07f487e2c64ffc0a29b837db5600e33b6e698b9d696b@%3Cissues.bookkeeper.apache.org%3E">https://lists.apache.org/thread.html/r58af02e294bd07f487e2c64ffc0a29b837db5600e33b6e698b9d696b@%3Cissues.bookkeeper.apache.org%3E</a><br><a href="https://lists.apache.org/thread.html/rf4c02775860db415b4955778a131c2795223f61cb8c6a450893651e4@%3Cissues.bookkeeper.apache.org%3E">https://lists.apache.org/thread.html/rf4c02775860db415b4955778a131c2795223f61cb8c6a450893651e4@%3Cissues.bookkeeper.apache.org%3E</a><br><a href="https://security.netapp.com/advisory/ntap-20190315-0002/">https://security.netapp.com/advisory/ntap-20190315-0002/</a><br><a href="https://sourceware.org/bugzilla/show_bug.cgi?id=11053">https://sourceware.org/bugzilla/show_bug.cgi?id=11053</a><br><a href="https://sourceware.org/bugzilla/show_bug.cgi?id=18986">https://sourceware.org/bugzilla/show_bug.cgi?id=18986</a><br><a href="https://sourceware.org/git/gitweb.cgi?p=glibc.git;h=eb04c21373e2a2885f3d52ff192b0499afe3c672">https://sourceware.org/git/gitweb.cgi?p=glibc.git;h=eb04c21373e2a2885f3d52ff192b0499afe3c672</a><br><a href="https://support.f5.com/csp/article/K64119434">https://support.f5.com/csp/article/K64119434</a><br><a href="https://support.f5.com/csp/article/K64119434?utm_source=f5support&amp;amp;utm_medium=RSS">https://support.f5.com/csp/article/K64119434?utm_source=f5support&amp;amp;utm_medium=RSS</a><br><a href="https://ubuntu.com/security/notices/USN-4954-1">https://ubuntu.com/security/notices/USN-4954-1</a><br></details>  |
| multiarch-support         |    CVE-2015-8985   |   LOW  |  2.27-3ubuntu1.4 |  | <details><summary>Expand...</summary><a href="http://www.openwall.com/lists/oss-security/2017/02/14/9">http://www.openwall.com/lists/oss-security/2017/02/14/9</a><br><a href="http://www.securityfocus.com/bid/76916">http://www.securityfocus.com/bid/76916</a><br><a href="https://bugs.debian.org/cgi-bin/bugreport.cgi?bug=779392">https://bugs.debian.org/cgi-bin/bugreport.cgi?bug=779392</a><br><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2015-8985">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2015-8985</a><br><a href="https://security.gentoo.org/glsa/201908-06">https://security.gentoo.org/glsa/201908-06</a><br></details>  |
| multiarch-support         |    CVE-2016-10228   |   LOW  |  2.27-3ubuntu1.4 |  | <details><summary>Expand...</summary><a href="http://openwall.com/lists/oss-security/2017/03/01/10">http://openwall.com/lists/oss-security/2017/03/01/10</a><br><a href="http://www.securityfocus.com/bid/96525">http://www.securityfocus.com/bid/96525</a><br><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2016-10228">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2016-10228</a><br><a href="https://linux.oracle.com/cve/CVE-2016-10228.html">https://linux.oracle.com/cve/CVE-2016-10228.html</a><br><a href="https://linux.oracle.com/errata/ELSA-2021-9344.html">https://linux.oracle.com/errata/ELSA-2021-9344.html</a><br><a href="https://lists.apache.org/thread.html/rf9fa47ab66495c78bb4120b0754dd9531ca2ff0430f6685ac9b07772@%3Cdev.mina.apache.org%3E">https://lists.apache.org/thread.html/rf9fa47ab66495c78bb4120b0754dd9531ca2ff0430f6685ac9b07772@%3Cdev.mina.apache.org%3E</a><br><a href="https://security.gentoo.org/glsa/202101-20">https://security.gentoo.org/glsa/202101-20</a><br><a href="https://sourceware.org/bugzilla/show_bug.cgi?id=19519">https://sourceware.org/bugzilla/show_bug.cgi?id=19519</a><br><a href="https://sourceware.org/bugzilla/show_bug.cgi?id=19519#c21">https://sourceware.org/bugzilla/show_bug.cgi?id=19519#c21</a><br><a href="https://sourceware.org/bugzilla/show_bug.cgi?id=26224">https://sourceware.org/bugzilla/show_bug.cgi?id=26224</a><br></details>  |
| multiarch-support         |    CVE-2016-10739   |   LOW  |  2.27-3ubuntu1.4 |  | <details><summary>Expand...</summary><a href="http://lists.opensuse.org/opensuse-security-announce/2019-04/msg00082.html">http://lists.opensuse.org/opensuse-security-announce/2019-04/msg00082.html</a><br><a href="http://www.securityfocus.com/bid/106672">http://www.securityfocus.com/bid/106672</a><br><a href="https://access.redhat.com/errata/RHSA-2019:2118">https://access.redhat.com/errata/RHSA-2019:2118</a><br><a href="https://access.redhat.com/errata/RHSA-2019:3513">https://access.redhat.com/errata/RHSA-2019:3513</a><br><a href="https://bugzilla.redhat.com/show_bug.cgi?id=1347549">https://bugzilla.redhat.com/show_bug.cgi?id=1347549</a><br><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2016-10739">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2016-10739</a><br><a href="https://linux.oracle.com/cve/CVE-2016-10739.html">https://linux.oracle.com/cve/CVE-2016-10739.html</a><br><a href="https://linux.oracle.com/errata/ELSA-2019-3513.html">https://linux.oracle.com/errata/ELSA-2019-3513.html</a><br><a href="https://sourceware.org/bugzilla/show_bug.cgi?id=20018">https://sourceware.org/bugzilla/show_bug.cgi?id=20018</a><br></details>  |
| multiarch-support         |    CVE-2019-25013   |   LOW  |  2.27-3ubuntu1.4 |  | <details><summary>Expand...</summary><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2019-25013">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2019-25013</a><br><a href="https://linux.oracle.com/cve/CVE-2019-25013.html">https://linux.oracle.com/cve/CVE-2019-25013.html</a><br><a href="https://linux.oracle.com/errata/ELSA-2021-9344.html">https://linux.oracle.com/errata/ELSA-2021-9344.html</a><br><a href="https://lists.apache.org/thread.html/r32d767ac804e9b8aad4355bb85960a6a1385eab7afff549a5e98660f@%3Cjira.kafka.apache.org%3E">https://lists.apache.org/thread.html/r32d767ac804e9b8aad4355bb85960a6a1385eab7afff549a5e98660f@%3Cjira.kafka.apache.org%3E</a><br><a href="https://lists.apache.org/thread.html/r448bb851cc8e6e3f93f3c28c70032b37062625d81214744474ac49e7@%3Cdev.kafka.apache.org%3E">https://lists.apache.org/thread.html/r448bb851cc8e6e3f93f3c28c70032b37062625d81214744474ac49e7@%3Cdev.kafka.apache.org%3E</a><br><a href="https://lists.apache.org/thread.html/r4806a391091e082bdea17266452ca656ebc176e51bb3932733b3a0a2@%3Cjira.kafka.apache.org%3E">https://lists.apache.org/thread.html/r4806a391091e082bdea17266452ca656ebc176e51bb3932733b3a0a2@%3Cjira.kafka.apache.org%3E</a><br><a href="https://lists.apache.org/thread.html/r499e4f96d0b5109ef083f2feccd33c51650c1b7d7068aa3bd47efca9@%3Cjira.kafka.apache.org%3E">https://lists.apache.org/thread.html/r499e4f96d0b5109ef083f2feccd33c51650c1b7d7068aa3bd47efca9@%3Cjira.kafka.apache.org%3E</a><br><a href="https://lists.apache.org/thread.html/r5af4430421bb6f9973294691a7904bbd260937e9eef96b20556f43ff@%3Cjira.kafka.apache.org%3E">https://lists.apache.org/thread.html/r5af4430421bb6f9973294691a7904bbd260937e9eef96b20556f43ff@%3Cjira.kafka.apache.org%3E</a><br><a href="https://lists.apache.org/thread.html/r750eee18542bc02bd8350861c424ee60a9b9b225568fa09436a37ece@%3Cissues.zookeeper.apache.org%3E">https://lists.apache.org/thread.html/r750eee18542bc02bd8350861c424ee60a9b9b225568fa09436a37ece@%3Cissues.zookeeper.apache.org%3E</a><br><a href="https://lists.apache.org/thread.html/r7a2e94adfe0a2f0a1d42e4927e8c32ecac97d37db9cb68095fe9ddbc@%3Cdev.zookeeper.apache.org%3E">https://lists.apache.org/thread.html/r7a2e94adfe0a2f0a1d42e4927e8c32ecac97d37db9cb68095fe9ddbc@%3Cdev.zookeeper.apache.org%3E</a><br><a href="https://lists.apache.org/thread.html/rd2354f9ccce41e494fbadcbc5ad87218de6ec0fff8a7b54c8462226c@%3Cissues.zookeeper.apache.org%3E">https://lists.apache.org/thread.html/rd2354f9ccce41e494fbadcbc5ad87218de6ec0fff8a7b54c8462226c@%3Cissues.zookeeper.apache.org%3E</a><br><a href="https://lists.apache.org/thread.html/rf9fa47ab66495c78bb4120b0754dd9531ca2ff0430f6685ac9b07772@%3Cdev.mina.apache.org%3E">https://lists.apache.org/thread.html/rf9fa47ab66495c78bb4120b0754dd9531ca2ff0430f6685ac9b07772@%3Cdev.mina.apache.org%3E</a><br><a href="https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/4Y6TX47P47KABSFOL26FLDNVCWXDKDEZ/">https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/4Y6TX47P47KABSFOL26FLDNVCWXDKDEZ/</a><br><a href="https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/TVCUNLQ3HXGS4VPUQKWTJGRAW2KTFGXS/">https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/TVCUNLQ3HXGS4VPUQKWTJGRAW2KTFGXS/</a><br><a href="https://security.netapp.com/advisory/ntap-20210205-0004/">https://security.netapp.com/advisory/ntap-20210205-0004/</a><br><a href="https://sourceware.org/bugzilla/show_bug.cgi?id=24973">https://sourceware.org/bugzilla/show_bug.cgi?id=24973</a><br><a href="https://sourceware.org/git/?p=glibc.git;a=commit;h=ee7a3144c9922808181009b7b3e50e852fb4999b">https://sourceware.org/git/?p=glibc.git;a=commit;h=ee7a3144c9922808181009b7b3e50e852fb4999b</a><br></details>  |
| multiarch-support         |    CVE-2020-27618   |   LOW  |  2.27-3ubuntu1.4 |  | <details><summary>Expand...</summary><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2020-27618">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2020-27618</a><br><a href="https://linux.oracle.com/cve/CVE-2020-27618.html">https://linux.oracle.com/cve/CVE-2020-27618.html</a><br><a href="https://linux.oracle.com/errata/ELSA-2021-9344.html">https://linux.oracle.com/errata/ELSA-2021-9344.html</a><br><a href="https://security.netapp.com/advisory/ntap-20210401-0006/">https://security.netapp.com/advisory/ntap-20210401-0006/</a><br><a href="https://sourceware.org/bugzilla/show_bug.cgi?id=19519#c21">https://sourceware.org/bugzilla/show_bug.cgi?id=19519#c21</a><br><a href="https://sourceware.org/bugzilla/show_bug.cgi?id=26224">https://sourceware.org/bugzilla/show_bug.cgi?id=26224</a><br></details>  |
| multiarch-support         |    CVE-2020-6096   |   LOW  |  2.27-3ubuntu1.4 |  | <details><summary>Expand...</summary><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2020-6096">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2020-6096</a><br><a href="https://lists.apache.org/thread.html/rf9fa47ab66495c78bb4120b0754dd9531ca2ff0430f6685ac9b07772@%3Cdev.mina.apache.org%3E">https://lists.apache.org/thread.html/rf9fa47ab66495c78bb4120b0754dd9531ca2ff0430f6685ac9b07772@%3Cdev.mina.apache.org%3E</a><br><a href="https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/SPYXTDOOB4PQGTYAMZAZNJIB3FF6YQXI/">https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/SPYXTDOOB4PQGTYAMZAZNJIB3FF6YQXI/</a><br><a href="https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/URXOIA2LDUKHQXK4BE55BQBRI6ZZG3Y6/">https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/URXOIA2LDUKHQXK4BE55BQBRI6ZZG3Y6/</a><br><a href="https://security.gentoo.org/glsa/202101-20">https://security.gentoo.org/glsa/202101-20</a><br><a href="https://sourceware.org/bugzilla/attachment.cgi?id=12334">https://sourceware.org/bugzilla/attachment.cgi?id=12334</a><br><a href="https://sourceware.org/bugzilla/show_bug.cgi?id=25620">https://sourceware.org/bugzilla/show_bug.cgi?id=25620</a><br><a href="https://talosintelligence.com/vulnerability_reports/TALOS-2020-1019">https://talosintelligence.com/vulnerability_reports/TALOS-2020-1019</a><br><a href="https://ubuntu.com/security/notices/USN-4954-1">https://ubuntu.com/security/notices/USN-4954-1</a><br><a href="https://www.talosintelligence.com/vulnerability_reports/TALOS-2020-1019">https://www.talosintelligence.com/vulnerability_reports/TALOS-2020-1019</a><br></details>  |
| multiarch-support         |    CVE-2021-3326   |   LOW  |  2.27-3ubuntu1.4 |  | <details><summary>Expand...</summary><a href="http://www.openwall.com/lists/oss-security/2021/01/28/2">http://www.openwall.com/lists/oss-security/2021/01/28/2</a><br><a href="https://bugs.chromium.org/p/project-zero/issues/detail?id=2146">https://bugs.chromium.org/p/project-zero/issues/detail?id=2146</a><br><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2021-3326">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2021-3326</a><br><a href="https://linux.oracle.com/cve/CVE-2021-3326.html">https://linux.oracle.com/cve/CVE-2021-3326.html</a><br><a href="https://linux.oracle.com/errata/ELSA-2021-9344.html">https://linux.oracle.com/errata/ELSA-2021-9344.html</a><br><a href="https://security.netapp.com/advisory/ntap-20210304-0007/">https://security.netapp.com/advisory/ntap-20210304-0007/</a><br><a href="https://sourceware.org/bugzilla/show_bug.cgi?id=27256">https://sourceware.org/bugzilla/show_bug.cgi?id=27256</a><br><a href="https://sourceware.org/git/?p=glibc.git;a=commit;h=7d88c6142c6efc160c0ee5e4f85cde382c072888">https://sourceware.org/git/?p=glibc.git;a=commit;h=7d88c6142c6efc160c0ee5e4f85cde382c072888</a><br><a href="https://sourceware.org/pipermail/libc-alpha/2021-January/122058.html">https://sourceware.org/pipermail/libc-alpha/2021-January/122058.html</a><br></details>  |
| multiarch-support         |    CVE-2021-33574   |   LOW  |  2.27-3ubuntu1.4 |  | <details><summary>Expand...</summary><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2021-33574">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2021-33574</a><br><a href="https://linux.oracle.com/cve/CVE-2021-33574.html">https://linux.oracle.com/cve/CVE-2021-33574.html</a><br><a href="https://linux.oracle.com/errata/ELSA-2021-9560.html">https://linux.oracle.com/errata/ELSA-2021-9560.html</a><br><a href="https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/RBUUWUGXVILQXVWEOU7N42ICHPJNAEUP/">https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/RBUUWUGXVILQXVWEOU7N42ICHPJNAEUP/</a><br><a href="https://security.gentoo.org/glsa/202107-07">https://security.gentoo.org/glsa/202107-07</a><br><a href="https://security.netapp.com/advisory/ntap-20210629-0005/">https://security.netapp.com/advisory/ntap-20210629-0005/</a><br><a href="https://sourceware.org/bugzilla/show_bug.cgi?id=27896">https://sourceware.org/bugzilla/show_bug.cgi?id=27896</a><br><a href="https://sourceware.org/bugzilla/show_bug.cgi?id=27896#c1">https://sourceware.org/bugzilla/show_bug.cgi?id=27896#c1</a><br></details>  |
| ncurses-base         |    CVE-2019-17594   |   LOW  |  6.1-1ubuntu1.18.04 |  | <details><summary>Expand...</summary><a href="http://lists.opensuse.org/opensuse-security-announce/2019-11/msg00059.html">http://lists.opensuse.org/opensuse-security-announce/2019-11/msg00059.html</a><br><a href="http://lists.opensuse.org/opensuse-security-announce/2019-11/msg00061.html">http://lists.opensuse.org/opensuse-security-announce/2019-11/msg00061.html</a><br><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2019-17594">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2019-17594</a><br><a href="https://linux.oracle.com/cve/CVE-2019-17594.html">https://linux.oracle.com/cve/CVE-2019-17594.html</a><br><a href="https://linux.oracle.com/errata/ELSA-2021-4426.html">https://linux.oracle.com/errata/ELSA-2021-4426.html</a><br><a href="https://lists.gnu.org/archive/html/bug-ncurses/2019-10/msg00017.html">https://lists.gnu.org/archive/html/bug-ncurses/2019-10/msg00017.html</a><br><a href="https://lists.gnu.org/archive/html/bug-ncurses/2019-10/msg00045.html">https://lists.gnu.org/archive/html/bug-ncurses/2019-10/msg00045.html</a><br><a href="https://security.gentoo.org/glsa/202101-28">https://security.gentoo.org/glsa/202101-28</a><br></details>  |
| ncurses-base         |    CVE-2019-17595   |   LOW  |  6.1-1ubuntu1.18.04 |  | <details><summary>Expand...</summary><a href="http://lists.opensuse.org/opensuse-security-announce/2019-11/msg00059.html">http://lists.opensuse.org/opensuse-security-announce/2019-11/msg00059.html</a><br><a href="http://lists.opensuse.org/opensuse-security-announce/2019-11/msg00061.html">http://lists.opensuse.org/opensuse-security-announce/2019-11/msg00061.html</a><br><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2019-17595">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2019-17595</a><br><a href="https://linux.oracle.com/cve/CVE-2019-17595.html">https://linux.oracle.com/cve/CVE-2019-17595.html</a><br><a href="https://linux.oracle.com/errata/ELSA-2021-4426.html">https://linux.oracle.com/errata/ELSA-2021-4426.html</a><br><a href="https://lists.gnu.org/archive/html/bug-ncurses/2019-10/msg00013.html">https://lists.gnu.org/archive/html/bug-ncurses/2019-10/msg00013.html</a><br><a href="https://lists.gnu.org/archive/html/bug-ncurses/2019-10/msg00045.html">https://lists.gnu.org/archive/html/bug-ncurses/2019-10/msg00045.html</a><br><a href="https://security.gentoo.org/glsa/202101-28">https://security.gentoo.org/glsa/202101-28</a><br></details>  |
| ncurses-bin         |    CVE-2019-17594   |   LOW  |  6.1-1ubuntu1.18.04 |  | <details><summary>Expand...</summary><a href="http://lists.opensuse.org/opensuse-security-announce/2019-11/msg00059.html">http://lists.opensuse.org/opensuse-security-announce/2019-11/msg00059.html</a><br><a href="http://lists.opensuse.org/opensuse-security-announce/2019-11/msg00061.html">http://lists.opensuse.org/opensuse-security-announce/2019-11/msg00061.html</a><br><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2019-17594">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2019-17594</a><br><a href="https://linux.oracle.com/cve/CVE-2019-17594.html">https://linux.oracle.com/cve/CVE-2019-17594.html</a><br><a href="https://linux.oracle.com/errata/ELSA-2021-4426.html">https://linux.oracle.com/errata/ELSA-2021-4426.html</a><br><a href="https://lists.gnu.org/archive/html/bug-ncurses/2019-10/msg00017.html">https://lists.gnu.org/archive/html/bug-ncurses/2019-10/msg00017.html</a><br><a href="https://lists.gnu.org/archive/html/bug-ncurses/2019-10/msg00045.html">https://lists.gnu.org/archive/html/bug-ncurses/2019-10/msg00045.html</a><br><a href="https://security.gentoo.org/glsa/202101-28">https://security.gentoo.org/glsa/202101-28</a><br></details>  |
| ncurses-bin         |    CVE-2019-17595   |   LOW  |  6.1-1ubuntu1.18.04 |  | <details><summary>Expand...</summary><a href="http://lists.opensuse.org/opensuse-security-announce/2019-11/msg00059.html">http://lists.opensuse.org/opensuse-security-announce/2019-11/msg00059.html</a><br><a href="http://lists.opensuse.org/opensuse-security-announce/2019-11/msg00061.html">http://lists.opensuse.org/opensuse-security-announce/2019-11/msg00061.html</a><br><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2019-17595">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2019-17595</a><br><a href="https://linux.oracle.com/cve/CVE-2019-17595.html">https://linux.oracle.com/cve/CVE-2019-17595.html</a><br><a href="https://linux.oracle.com/errata/ELSA-2021-4426.html">https://linux.oracle.com/errata/ELSA-2021-4426.html</a><br><a href="https://lists.gnu.org/archive/html/bug-ncurses/2019-10/msg00013.html">https://lists.gnu.org/archive/html/bug-ncurses/2019-10/msg00013.html</a><br><a href="https://lists.gnu.org/archive/html/bug-ncurses/2019-10/msg00045.html">https://lists.gnu.org/archive/html/bug-ncurses/2019-10/msg00045.html</a><br><a href="https://security.gentoo.org/glsa/202101-28">https://security.gentoo.org/glsa/202101-28</a><br></details>  |
| passwd         |    CVE-2013-4235   |   LOW  |  1:4.5-1ubuntu2 |  | <details><summary>Expand...</summary><a href="https://access.redhat.com/security/cve/cve-2013-4235">https://access.redhat.com/security/cve/cve-2013-4235</a><br><a href="https://bugzilla.redhat.com/show_bug.cgi?id=CVE-2013-4235">https://bugzilla.redhat.com/show_bug.cgi?id=CVE-2013-4235</a><br><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2013-4235">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2013-4235</a><br><a href="https://lists.apache.org/thread.html/rf9fa47ab66495c78bb4120b0754dd9531ca2ff0430f6685ac9b07772@%3Cdev.mina.apache.org%3E">https://lists.apache.org/thread.html/rf9fa47ab66495c78bb4120b0754dd9531ca2ff0430f6685ac9b07772@%3Cdev.mina.apache.org%3E</a><br><a href="https://security-tracker.debian.org/tracker/CVE-2013-4235">https://security-tracker.debian.org/tracker/CVE-2013-4235</a><br></details>  |
| passwd         |    CVE-2018-7169   |   LOW  |  1:4.5-1ubuntu2 |  | <details><summary>Expand...</summary><a href="https://bugs.launchpad.net/ubuntu/+source/shadow/+bug/1729357">https://bugs.launchpad.net/ubuntu/+source/shadow/+bug/1729357</a><br><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2018-7169">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2018-7169</a><br><a href="https://github.com/shadow-maint/shadow/pull/97">https://github.com/shadow-maint/shadow/pull/97</a><br><a href="https://security.gentoo.org/glsa/201805-09">https://security.gentoo.org/glsa/201805-09</a><br></details>  |
| perl         |    CVE-2020-16156   |   MEDIUM  |  5.26.1-6ubuntu0.5 |  | <details><summary>Expand...</summary><a href="http://blogs.perl.org/users/neilb/2021/11/addressing-cpan-vulnerabilities-related-to-checksums.html">http://blogs.perl.org/users/neilb/2021/11/addressing-cpan-vulnerabilities-related-to-checksums.html</a><br><a href="https://blog.hackeriet.no/cpan-signature-verification-vulnerabilities/">https://blog.hackeriet.no/cpan-signature-verification-vulnerabilities/</a><br><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2020-16156">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2020-16156</a><br><a href="https://github.com/andk/cpanpm/commit/b27c51adf0fda25dee84cb72cb2b1bf7d832148c">https://github.com/andk/cpanpm/commit/b27c51adf0fda25dee84cb72cb2b1bf7d832148c</a><br><a href="https://metacpan.org/pod/distribution/CPAN/scripts/cpan">https://metacpan.org/pod/distribution/CPAN/scripts/cpan</a><br></details>  |
| perl-base         |    CVE-2020-16156   |   MEDIUM  |  5.26.1-6ubuntu0.5 |  | <details><summary>Expand...</summary><a href="http://blogs.perl.org/users/neilb/2021/11/addressing-cpan-vulnerabilities-related-to-checksums.html">http://blogs.perl.org/users/neilb/2021/11/addressing-cpan-vulnerabilities-related-to-checksums.html</a><br><a href="https://blog.hackeriet.no/cpan-signature-verification-vulnerabilities/">https://blog.hackeriet.no/cpan-signature-verification-vulnerabilities/</a><br><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2020-16156">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2020-16156</a><br><a href="https://github.com/andk/cpanpm/commit/b27c51adf0fda25dee84cb72cb2b1bf7d832148c">https://github.com/andk/cpanpm/commit/b27c51adf0fda25dee84cb72cb2b1bf7d832148c</a><br><a href="https://metacpan.org/pod/distribution/CPAN/scripts/cpan">https://metacpan.org/pod/distribution/CPAN/scripts/cpan</a><br></details>  |
| perl-modules-5.26         |    CVE-2020-16156   |   MEDIUM  |  5.26.1-6ubuntu0.5 |  | <details><summary>Expand...</summary><a href="http://blogs.perl.org/users/neilb/2021/11/addressing-cpan-vulnerabilities-related-to-checksums.html">http://blogs.perl.org/users/neilb/2021/11/addressing-cpan-vulnerabilities-related-to-checksums.html</a><br><a href="https://blog.hackeriet.no/cpan-signature-verification-vulnerabilities/">https://blog.hackeriet.no/cpan-signature-verification-vulnerabilities/</a><br><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2020-16156">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2020-16156</a><br><a href="https://github.com/andk/cpanpm/commit/b27c51adf0fda25dee84cb72cb2b1bf7d832148c">https://github.com/andk/cpanpm/commit/b27c51adf0fda25dee84cb72cb2b1bf7d832148c</a><br><a href="https://metacpan.org/pod/distribution/CPAN/scripts/cpan">https://metacpan.org/pod/distribution/CPAN/scripts/cpan</a><br></details>  |

**node-pkg**

      
| Package         |    Vulnerability   |   Severity  |  Installed Version | Fixed Version |                   Links                   |
|:----------------|:------------------:|:-----------:|:------------------:|:-------------:|-----------------------------------------|
| bl         |    CVE-2020-8244   |   MEDIUM  |  1.1.2 | 2.2.1, 1.2.3, 4.0.3, 3.0.1 | <details><summary>Expand...</summary><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2020-8244">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2020-8244</a><br><a href="https://github.com/advisories/GHSA-pp7h-53gx-mx7r">https://github.com/advisories/GHSA-pp7h-53gx-mx7r</a><br><a href="https://github.com/rvagg/bl/commit/8a8c13c880e2bef519133ea43e0e9b78b5d0c91e">https://github.com/rvagg/bl/commit/8a8c13c880e2bef519133ea43e0e9b78b5d0c91e</a><br><a href="https://github.com/rvagg/bl/commit/d3e240e3b8ba4048d3c76ef5fb9dd1f8872d3190">https://github.com/rvagg/bl/commit/d3e240e3b8ba4048d3c76ef5fb9dd1f8872d3190</a><br><a href="https://github.com/rvagg/bl/commit/dacc4ac7d5fcd6201bcf26fbd886951be9537466">https://github.com/rvagg/bl/commit/dacc4ac7d5fcd6201bcf26fbd886951be9537466</a><br><a href="https://hackerone.com/reports/966347">https://hackerone.com/reports/966347</a><br><a href="https://nvd.nist.gov/vuln/detail/CVE-2020-8244">https://nvd.nist.gov/vuln/detail/CVE-2020-8244</a><br><a href="https://ubuntu.com/security/notices/USN-5098-1">https://ubuntu.com/security/notices/USN-5098-1</a><br></details>  |
| brace-expansion         |    CVE-2017-18077   |   HIGH  |  1.1.3 | 1.1.7 | <details><summary>Expand...</summary><a href="https://bugs.debian.org/862712">https://bugs.debian.org/862712</a><br><a href="https://github.com/advisories/GHSA-832h-xg76-4gv6">https://github.com/advisories/GHSA-832h-xg76-4gv6</a><br><a href="https://github.com/juliangruber/brace-expansion/issues/33">https://github.com/juliangruber/brace-expansion/issues/33</a><br><a href="https://github.com/juliangruber/brace-expansion/pull/35">https://github.com/juliangruber/brace-expansion/pull/35</a><br><a href="https://github.com/juliangruber/brace-expansion/pull/35/commits/b13381281cead487cbdbfd6a69fb097ea5e456c3">https://github.com/juliangruber/brace-expansion/pull/35/commits/b13381281cead487cbdbfd6a69fb097ea5e456c3</a><br><a href="https://nodesecurity.io/advisories/338">https://nodesecurity.io/advisories/338</a><br><a href="https://nvd.nist.gov/vuln/detail/CVE-2017-18077">https://nvd.nist.gov/vuln/detail/CVE-2017-18077</a><br><a href="https://www.npmjs.com/advisories/338">https://www.npmjs.com/advisories/338</a><br></details>  |
| brace-expansion         |    NSWG-ECO-338   |   MEDIUM  |  1.1.3 | &gt;=1.1.7 | <details><summary>Expand...</summary><a href="https://github.com/juliangruber/brace-expansion/issues/33">https://github.com/juliangruber/brace-expansion/issues/33</a><br><a href="https://github.com/juliangruber/brace-expansion/pull/35">https://github.com/juliangruber/brace-expansion/pull/35</a><br><a href="https://github.com/juliangruber/brace-expansion/pull/35/commits/b13381281cead487cbdbfd6a69fb097ea5e456c3">https://github.com/juliangruber/brace-expansion/pull/35/commits/b13381281cead487cbdbfd6a69fb097ea5e456c3</a><br></details>  |
| brace-expansion         |    CVE-2017-18077   |   HIGH  |  1.1.4 | 1.1.7 | <details><summary>Expand...</summary><a href="https://bugs.debian.org/862712">https://bugs.debian.org/862712</a><br><a href="https://github.com/advisories/GHSA-832h-xg76-4gv6">https://github.com/advisories/GHSA-832h-xg76-4gv6</a><br><a href="https://github.com/juliangruber/brace-expansion/issues/33">https://github.com/juliangruber/brace-expansion/issues/33</a><br><a href="https://github.com/juliangruber/brace-expansion/pull/35">https://github.com/juliangruber/brace-expansion/pull/35</a><br><a href="https://github.com/juliangruber/brace-expansion/pull/35/commits/b13381281cead487cbdbfd6a69fb097ea5e456c3">https://github.com/juliangruber/brace-expansion/pull/35/commits/b13381281cead487cbdbfd6a69fb097ea5e456c3</a><br><a href="https://nodesecurity.io/advisories/338">https://nodesecurity.io/advisories/338</a><br><a href="https://nvd.nist.gov/vuln/detail/CVE-2017-18077">https://nvd.nist.gov/vuln/detail/CVE-2017-18077</a><br><a href="https://www.npmjs.com/advisories/338">https://www.npmjs.com/advisories/338</a><br></details>  |
| brace-expansion         |    NSWG-ECO-338   |   MEDIUM  |  1.1.4 | &gt;=1.1.7 | <details><summary>Expand...</summary><a href="https://github.com/juliangruber/brace-expansion/issues/33">https://github.com/juliangruber/brace-expansion/issues/33</a><br><a href="https://github.com/juliangruber/brace-expansion/pull/35">https://github.com/juliangruber/brace-expansion/pull/35</a><br><a href="https://github.com/juliangruber/brace-expansion/pull/35/commits/b13381281cead487cbdbfd6a69fb097ea5e456c3">https://github.com/juliangruber/brace-expansion/pull/35/commits/b13381281cead487cbdbfd6a69fb097ea5e456c3</a><br></details>  |
| brace-expansion         |    CVE-2017-18077   |   HIGH  |  1.1.5 | 1.1.7 | <details><summary>Expand...</summary><a href="https://bugs.debian.org/862712">https://bugs.debian.org/862712</a><br><a href="https://github.com/advisories/GHSA-832h-xg76-4gv6">https://github.com/advisories/GHSA-832h-xg76-4gv6</a><br><a href="https://github.com/juliangruber/brace-expansion/issues/33">https://github.com/juliangruber/brace-expansion/issues/33</a><br><a href="https://github.com/juliangruber/brace-expansion/pull/35">https://github.com/juliangruber/brace-expansion/pull/35</a><br><a href="https://github.com/juliangruber/brace-expansion/pull/35/commits/b13381281cead487cbdbfd6a69fb097ea5e456c3">https://github.com/juliangruber/brace-expansion/pull/35/commits/b13381281cead487cbdbfd6a69fb097ea5e456c3</a><br><a href="https://nodesecurity.io/advisories/338">https://nodesecurity.io/advisories/338</a><br><a href="https://nvd.nist.gov/vuln/detail/CVE-2017-18077">https://nvd.nist.gov/vuln/detail/CVE-2017-18077</a><br><a href="https://www.npmjs.com/advisories/338">https://www.npmjs.com/advisories/338</a><br></details>  |
| brace-expansion         |    NSWG-ECO-338   |   MEDIUM  |  1.1.5 | &gt;=1.1.7 | <details><summary>Expand...</summary><a href="https://github.com/juliangruber/brace-expansion/issues/33">https://github.com/juliangruber/brace-expansion/issues/33</a><br><a href="https://github.com/juliangruber/brace-expansion/pull/35">https://github.com/juliangruber/brace-expansion/pull/35</a><br><a href="https://github.com/juliangruber/brace-expansion/pull/35/commits/b13381281cead487cbdbfd6a69fb097ea5e456c3">https://github.com/juliangruber/brace-expansion/pull/35/commits/b13381281cead487cbdbfd6a69fb097ea5e456c3</a><br></details>  |
| concat-stream         |    GHSA-g74r-ffvr-5q9f   |   MEDIUM  |  1.5.1 | 1.3.2, 1.4.11, 1.5.2 | <details><summary>Expand...</summary><a href="https://gist.github.com/ChALkeR/c2d2fd3f1d72d51ad883df195be03a85">https://gist.github.com/ChALkeR/c2d2fd3f1d72d51ad883df195be03a85</a><br><a href="https://github.com/advisories/GHSA-g74r-ffvr-5q9f">https://github.com/advisories/GHSA-g74r-ffvr-5q9f</a><br><a href="https://github.com/maxogden/concat-stream/pull/47">https://github.com/maxogden/concat-stream/pull/47</a><br><a href="https://github.com/maxogden/concat-stream/pull/47/commits/3e285ba5e5b10b7c98552217f5c1023829efe69e">https://github.com/maxogden/concat-stream/pull/47/commits/3e285ba5e5b10b7c98552217f5c1023829efe69e</a><br><a href="https://nodesecurity.io/advisories/597">https://nodesecurity.io/advisories/597</a><br><a href="https://www.npmjs.com/advisories/597">https://www.npmjs.com/advisories/597</a><br></details>  |
| concat-stream         |    NSWG-ECO-392   |   MEDIUM  |  1.5.1 | &gt;=1.5.2, &gt;=1.4.11 &lt;1.5.0, &gt;=1.3.2 &lt;1.4.0 | <details><summary>Expand...</summary><a href="https://gist.github.com/ChALkeR/c2d2fd3f1d72d51ad883df195be03a85">https://gist.github.com/ChALkeR/c2d2fd3f1d72d51ad883df195be03a85</a><br><a href="https://github.com/maxogden/concat-stream/pull/47">https://github.com/maxogden/concat-stream/pull/47</a><br></details>  |
| cookie-signature         |    CVE-2016-1000236   |   MEDIUM  |  1.0.1 | &gt;=1.0.6 | <details><summary>Expand...</summary><a href="https://bugs.debian.org/cgi-bin/bugreport.cgi?bug=838618">https://bugs.debian.org/cgi-bin/bugreport.cgi?bug=838618</a><br><a href="https://bugzilla.redhat.com/show_bug.cgi?id=1371409">https://bugzilla.redhat.com/show_bug.cgi?id=1371409</a><br><a href="https://bugzilla.redhat.com/show_bug.cgi?id=CVE-2016-1000236">https://bugzilla.redhat.com/show_bug.cgi?id=CVE-2016-1000236</a><br><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2016-1000236">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2016-1000236</a><br><a href="https://github.com/advisories/GHSA-92vm-wfm5-mxvv">https://github.com/advisories/GHSA-92vm-wfm5-mxvv</a><br><a href="https://github.com/tj/node-cookie-signature/commit/2c4df6b6cee540f30876198cd0b5bebf28528c07">https://github.com/tj/node-cookie-signature/commit/2c4df6b6cee540f30876198cd0b5bebf28528c07</a><br><a href="https://github.com/tj/node-cookie-signature/commit/39791081692e9e14aa62855369e1c7f80fbfd50e">https://github.com/tj/node-cookie-signature/commit/39791081692e9e14aa62855369e1c7f80fbfd50e</a><br><a href="https://github.com/tj/node-cookie-signature/commit/4cc5e21e7f59a4ea0b51cd5e9634772d48fab590">https://github.com/tj/node-cookie-signature/commit/4cc5e21e7f59a4ea0b51cd5e9634772d48fab590</a><br><a href="https://nodesecurity.io/advisories/134">https://nodesecurity.io/advisories/134</a><br><a href="https://nvd.nist.gov/vuln/detail/CVE-2016-1000236">https://nvd.nist.gov/vuln/detail/CVE-2016-1000236</a><br><a href="https://security-tracker.debian.org/tracker/CVE-2016-1000236">https://security-tracker.debian.org/tracker/CVE-2016-1000236</a><br><a href="https://travis-ci.com/nodejs/security-wg/builds/76423102">https://travis-ci.com/nodejs/security-wg/builds/76423102</a><br><a href="https://www.mail-archive.com/secure-testing-team@lists.alioth.debian.org/msg06583.html">https://www.mail-archive.com/secure-testing-team@lists.alioth.debian.org/msg06583.html</a><br><a href="https://www.npmjs.com/advisories/134">https://www.npmjs.com/advisories/134</a><br></details>  |
| cryptiles         |    CVE-2018-1000620   |   CRITICAL  |  2.0.5 | 4.1.2 | <details><summary>Expand...</summary><a href="https://github.com/advisories/GHSA-rq8g-5pc5-wrhr">https://github.com/advisories/GHSA-rq8g-5pc5-wrhr</a><br><a href="https://github.com/hapijs/cryptiles/issues/34">https://github.com/hapijs/cryptiles/issues/34</a><br><a href="https://github.com/nodejs/security-wg/blob/master/vuln/npm/476.json">https://github.com/nodejs/security-wg/blob/master/vuln/npm/476.json</a><br><a href="https://nvd.nist.gov/vuln/detail/CVE-2018-1000620">https://nvd.nist.gov/vuln/detail/CVE-2018-1000620</a><br><a href="https://www.npmjs.com/advisories/1464">https://www.npmjs.com/advisories/1464</a><br><a href="https://www.npmjs.com/advisories/720">https://www.npmjs.com/advisories/720</a><br></details>  |
| debug         |    CVE-2017-16137   |   MEDIUM  |  0.7.4 | 3.1.0, 2.6.9 | <details><summary>Expand...</summary><a href="https://github.com/advisories/GHSA-gxpj-cx7g-858c">https://github.com/advisories/GHSA-gxpj-cx7g-858c</a><br><a href="https://github.com/visionmedia/debug/issues/501">https://github.com/visionmedia/debug/issues/501</a><br><a href="https://github.com/visionmedia/debug/pull/504">https://github.com/visionmedia/debug/pull/504</a><br><a href="https://lists.apache.org/thread.html/r8ba4c628fba7181af58817d452119481adce4ba92e889c643e4c7dd3@%3Ccommits.netbeans.apache.org%3E">https://lists.apache.org/thread.html/r8ba4c628fba7181af58817d452119481adce4ba92e889c643e4c7dd3@%3Ccommits.netbeans.apache.org%3E</a><br><a href="https://lists.apache.org/thread.html/rb5ac16fad337d1f3bb7079549f97d8166d0ef3082629417c39f12d63@%3Cnotifications.netbeans.apache.org%3E">https://lists.apache.org/thread.html/rb5ac16fad337d1f3bb7079549f97d8166d0ef3082629417c39f12d63@%3Cnotifications.netbeans.apache.org%3E</a><br><a href="https://nodesecurity.io/advisories/534">https://nodesecurity.io/advisories/534</a><br><a href="https://nvd.nist.gov/vuln/detail/CVE-2017-16137">https://nvd.nist.gov/vuln/detail/CVE-2017-16137</a><br><a href="https://www.npmjs.com/advisories/534">https://www.npmjs.com/advisories/534</a><br></details>  |
| debug         |    CVE-2017-16137   |   MEDIUM  |  2.2.0 | 3.1.0, 2.6.9 | <details><summary>Expand...</summary><a href="https://github.com/advisories/GHSA-gxpj-cx7g-858c">https://github.com/advisories/GHSA-gxpj-cx7g-858c</a><br><a href="https://github.com/visionmedia/debug/issues/501">https://github.com/visionmedia/debug/issues/501</a><br><a href="https://github.com/visionmedia/debug/pull/504">https://github.com/visionmedia/debug/pull/504</a><br><a href="https://lists.apache.org/thread.html/r8ba4c628fba7181af58817d452119481adce4ba92e889c643e4c7dd3@%3Ccommits.netbeans.apache.org%3E">https://lists.apache.org/thread.html/r8ba4c628fba7181af58817d452119481adce4ba92e889c643e4c7dd3@%3Ccommits.netbeans.apache.org%3E</a><br><a href="https://lists.apache.org/thread.html/rb5ac16fad337d1f3bb7079549f97d8166d0ef3082629417c39f12d63@%3Cnotifications.netbeans.apache.org%3E">https://lists.apache.org/thread.html/rb5ac16fad337d1f3bb7079549f97d8166d0ef3082629417c39f12d63@%3Cnotifications.netbeans.apache.org%3E</a><br><a href="https://nodesecurity.io/advisories/534">https://nodesecurity.io/advisories/534</a><br><a href="https://nvd.nist.gov/vuln/detail/CVE-2017-16137">https://nvd.nist.gov/vuln/detail/CVE-2017-16137</a><br><a href="https://www.npmjs.com/advisories/534">https://www.npmjs.com/advisories/534</a><br></details>  |
| deep-extend         |    CVE-2018-3750   |   CRITICAL  |  0.4.1 | 0.5.1 | <details><summary>Expand...</summary><a href="https://github.com/advisories/GHSA-hr2v-3952-633q">https://github.com/advisories/GHSA-hr2v-3952-633q</a><br><a href="https://hackerone.com/reports/311333">https://hackerone.com/reports/311333</a><br><a href="https://nodesecurity.io/advisories/612">https://nodesecurity.io/advisories/612</a><br><a href="https://nvd.nist.gov/vuln/detail/CVE-2018-3750">https://nvd.nist.gov/vuln/detail/CVE-2018-3750</a><br><a href="https://www.npmjs.com/advisories/612">https://www.npmjs.com/advisories/612</a><br></details>  |
| deep-extend         |    NSWG-ECO-408   |   LOW  |  0.4.1 | &gt;=0.5.1 | <details><summary>Expand...</summary><a href="https://hackerone.com/reports/311333">https://hackerone.com/reports/311333</a><br></details>  |
| diff         |    GHSA-h6ch-v84p-w6p9   |   HIGH  |  1.0.2 | 3.5.0 | <details><summary>Expand...</summary><a href="https://bugzilla.redhat.com/show_bug.cgi?id=1552148">https://bugzilla.redhat.com/show_bug.cgi?id=1552148</a><br><a href="https://github.com/advisories/GHSA-h6ch-v84p-w6p9">https://github.com/advisories/GHSA-h6ch-v84p-w6p9</a><br><a href="https://github.com/kpdecker/jsdiff/commit/2aec4298639bf30fb88a00b356bf404d3551b8c0">https://github.com/kpdecker/jsdiff/commit/2aec4298639bf30fb88a00b356bf404d3551b8c0</a><br><a href="https://snyk.io/vuln/npm:diff:20180305">https://snyk.io/vuln/npm:diff:20180305</a><br><a href="https://www.npmjs.com/advisories/1631">https://www.npmjs.com/advisories/1631</a><br><a href="https://www.whitesourcesoftware.com/vulnerability-database/WS-2018-0590">https://www.whitesourcesoftware.com/vulnerability-database/WS-2018-0590</a><br></details>  |
| ejs         |    CVE-2017-1000228   |   CRITICAL  |  1.0.0 | 2.5.5 | <details><summary>Expand...</summary><a href="http://www.securityfocus.com/bid/101897">http://www.securityfocus.com/bid/101897</a><br><a href="https://github.com/advisories/GHSA-3w5v-p54c-f74x">https://github.com/advisories/GHSA-3w5v-p54c-f74x</a><br><a href="https://nvd.nist.gov/vuln/detail/CVE-2017-1000228">https://nvd.nist.gov/vuln/detail/CVE-2017-1000228</a><br><a href="https://snyk.io/vuln/npm:ejs:20161128">https://snyk.io/vuln/npm:ejs:20161128</a><br></details>  |
| ejs         |    CVE-2017-1000189   |   HIGH  |  1.0.0 | 2.5.5 | <details><summary>Expand...</summary><a href="http://www.securityfocus.com/bid/101893">http://www.securityfocus.com/bid/101893</a><br><a href="https://github.com/advisories/GHSA-6x77-rpqf-j6mw">https://github.com/advisories/GHSA-6x77-rpqf-j6mw</a><br><a href="https://github.com/mde/ejs/commit/49264e0037e313a0a3e033450b5c184112516d8f">https://github.com/mde/ejs/commit/49264e0037e313a0a3e033450b5c184112516d8f</a><br><a href="https://nvd.nist.gov/vuln/detail/CVE-2017-1000189">https://nvd.nist.gov/vuln/detail/CVE-2017-1000189</a><br><a href="https://snyk.io/vuln/npm:ejs:20161130-1">https://snyk.io/vuln/npm:ejs:20161130-1</a><br></details>  |
| ejs         |    CVE-2017-1000188   |   MEDIUM  |  1.0.0 | 2.5.5 | <details><summary>Expand...</summary><a href="http://www.securityfocus.com/bid/101889">http://www.securityfocus.com/bid/101889</a><br><a href="https://github.com/advisories/GHSA-hwcf-pp87-7x6p">https://github.com/advisories/GHSA-hwcf-pp87-7x6p</a><br><a href="https://github.com/mde/ejs/commit/49264e0037e313a0a3e033450b5c184112516d8f">https://github.com/mde/ejs/commit/49264e0037e313a0a3e033450b5c184112516d8f</a><br><a href="https://nvd.nist.gov/vuln/detail/CVE-2017-1000188">https://nvd.nist.gov/vuln/detail/CVE-2017-1000188</a><br><a href="https://snyk.io/vuln/npm:ejs:20161130">https://snyk.io/vuln/npm:ejs:20161130</a><br></details>  |
| extend         |    CVE-2018-16492   |   CRITICAL  |  3.0.0 | 2.0.2, 3.0.2 | <details><summary>Expand...</summary><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2018-16492">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2018-16492</a><br><a href="https://github.com/advisories/GHSA-qrmc-fj45-qfc2">https://github.com/advisories/GHSA-qrmc-fj45-qfc2</a><br><a href="https://hackerone.com/reports/381185">https://hackerone.com/reports/381185</a><br><a href="https://nvd.nist.gov/vuln/detail/CVE-2018-16492">https://nvd.nist.gov/vuln/detail/CVE-2018-16492</a><br><a href="https://snyk.io/vuln/npm:extend:20180424">https://snyk.io/vuln/npm:extend:20180424</a><br><a href="https://www.npmjs.com/advisories/996">https://www.npmjs.com/advisories/996</a><br></details>  |
| fresh         |    CVE-2017-16119   |   HIGH  |  0.2.0 | 0.5.2 | <details><summary>Expand...</summary><a href="https://github.com/advisories/GHSA-9qj9-36jm-prpv">https://github.com/advisories/GHSA-9qj9-36jm-prpv</a><br><a href="https://nodesecurity.io/advisories/526">https://nodesecurity.io/advisories/526</a><br><a href="https://nvd.nist.gov/vuln/detail/CVE-2017-16119">https://nvd.nist.gov/vuln/detail/CVE-2017-16119</a><br><a href="https://www.npmjs.com/advisories/526">https://www.npmjs.com/advisories/526</a><br></details>  |
| fstream         |    CVE-2019-13173   |   HIGH  |  1.0.10 | 1.0.12 | <details><summary>Expand...</summary><a href="http://lists.opensuse.org/opensuse-security-announce/2019-08/msg00010.html">http://lists.opensuse.org/opensuse-security-announce/2019-08/msg00010.html</a><br><a href="http://lists.opensuse.org/opensuse-security-announce/2019-08/msg00052.html">http://lists.opensuse.org/opensuse-security-announce/2019-08/msg00052.html</a><br><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2019-13173">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2019-13173</a><br><a href="https://github.com/advisories/GHSA-xf7w-r453-m56c">https://github.com/advisories/GHSA-xf7w-r453-m56c</a><br><a href="https://github.com/npm/fstream/commit/6a77d2fa6e1462693cf8e46f930da96ec1b0bb22">https://github.com/npm/fstream/commit/6a77d2fa6e1462693cf8e46f930da96ec1b0bb22</a><br><a href="https://nvd.nist.gov/vuln/detail/CVE-2019-13173">https://nvd.nist.gov/vuln/detail/CVE-2019-13173</a><br><a href="https://ubuntu.com/security/notices/USN-4123-1">https://ubuntu.com/security/notices/USN-4123-1</a><br><a href="https://usn.ubuntu.com/4123-1/">https://usn.ubuntu.com/4123-1/</a><br><a href="https://www.npmjs.com/advisories/886">https://www.npmjs.com/advisories/886</a><br></details>  |
| fstream         |    CVE-2019-13173   |   HIGH  |  1.0.9 | 1.0.12 | <details><summary>Expand...</summary><a href="http://lists.opensuse.org/opensuse-security-announce/2019-08/msg00010.html">http://lists.opensuse.org/opensuse-security-announce/2019-08/msg00010.html</a><br><a href="http://lists.opensuse.org/opensuse-security-announce/2019-08/msg00052.html">http://lists.opensuse.org/opensuse-security-announce/2019-08/msg00052.html</a><br><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2019-13173">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2019-13173</a><br><a href="https://github.com/advisories/GHSA-xf7w-r453-m56c">https://github.com/advisories/GHSA-xf7w-r453-m56c</a><br><a href="https://github.com/npm/fstream/commit/6a77d2fa6e1462693cf8e46f930da96ec1b0bb22">https://github.com/npm/fstream/commit/6a77d2fa6e1462693cf8e46f930da96ec1b0bb22</a><br><a href="https://nvd.nist.gov/vuln/detail/CVE-2019-13173">https://nvd.nist.gov/vuln/detail/CVE-2019-13173</a><br><a href="https://ubuntu.com/security/notices/USN-4123-1">https://ubuntu.com/security/notices/USN-4123-1</a><br><a href="https://usn.ubuntu.com/4123-1/">https://usn.ubuntu.com/4123-1/</a><br><a href="https://www.npmjs.com/advisories/886">https://www.npmjs.com/advisories/886</a><br></details>  |
| growl         |    CVE-2017-16042   |   CRITICAL  |  1.7.0 | 1.10.0 | <details><summary>Expand...</summary><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2017-16042">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2017-16042</a><br><a href="https://github.com/advisories/GHSA-qh2h-chj9-jffq">https://github.com/advisories/GHSA-qh2h-chj9-jffq</a><br><a href="https://github.com/tj/node-growl/issues/60">https://github.com/tj/node-growl/issues/60</a><br><a href="https://github.com/tj/node-growl/pull/61">https://github.com/tj/node-growl/pull/61</a><br><a href="https://nodesecurity.io/advisories/146">https://nodesecurity.io/advisories/146</a><br><a href="https://nvd.nist.gov/vuln/detail/CVE-2017-16042">https://nvd.nist.gov/vuln/detail/CVE-2017-16042</a><br><a href="https://www.npmjs.com/advisories/146">https://www.npmjs.com/advisories/146</a><br></details>  |
| hoek         |    CVE-2018-3728   |   HIGH  |  2.16.3 | &gt;=5.0.3 &gt;=4.2.1 | <details><summary>Expand...</summary><a href="http://www.securityfocus.com/bid/103108">http://www.securityfocus.com/bid/103108</a><br><a href="https://access.redhat.com/errata/RHSA-2018:1263">https://access.redhat.com/errata/RHSA-2018:1263</a><br><a href="https://access.redhat.com/errata/RHSA-2018:1264">https://access.redhat.com/errata/RHSA-2018:1264</a><br><a href="https://github.com/advisories/GHSA-jp4x-w63m-7wgm">https://github.com/advisories/GHSA-jp4x-w63m-7wgm</a><br><a href="https://github.com/hapijs/hoek/commit/32ed5c9413321fbc37da5ca81a7cbab693786dee">https://github.com/hapijs/hoek/commit/32ed5c9413321fbc37da5ca81a7cbab693786dee</a><br><a href="https://hackerone.com/reports/310439">https://hackerone.com/reports/310439</a><br><a href="https://nodesecurity.io/advisories/566">https://nodesecurity.io/advisories/566</a><br><a href="https://nvd.nist.gov/vuln/detail/CVE-2018-3728">https://nvd.nist.gov/vuln/detail/CVE-2018-3728</a><br><a href="https://snyk.io/vuln/npm:hoek:20180212">https://snyk.io/vuln/npm:hoek:20180212</a><br><a href="https://www.npmjs.com/advisories/566">https://www.npmjs.com/advisories/566</a><br></details>  |
| hosted-git-info         |    CVE-2021-23362   |   MEDIUM  |  2.1.5 | 2.8.9, 3.0.8 | <details><summary>Expand...</summary><a href="https://github.com/advisories/GHSA-43f8-2h32-f4cj">https://github.com/advisories/GHSA-43f8-2h32-f4cj</a><br><a href="https://github.com/npm/hosted-git-info/commit/29adfe5ef789784c861b2cdeb15051ec2ba651a7">https://github.com/npm/hosted-git-info/commit/29adfe5ef789784c861b2cdeb15051ec2ba651a7</a><br><a href="https://github.com/npm/hosted-git-info/commit/8d4b3697d79bcd89cdb36d1db165e3696c783a01">https://github.com/npm/hosted-git-info/commit/8d4b3697d79bcd89cdb36d1db165e3696c783a01</a><br><a href="https://github.com/npm/hosted-git-info/commit/bede0dc38e1785e732bf0a48ba6f81a4a908eba3">https://github.com/npm/hosted-git-info/commit/bede0dc38e1785e732bf0a48ba6f81a4a908eba3</a><br><a href="https://github.com/npm/hosted-git-info/commits/v2">https://github.com/npm/hosted-git-info/commits/v2</a><br><a href="https://github.com/npm/hosted-git-info/pull/76">https://github.com/npm/hosted-git-info/pull/76</a><br><a href="https://linux.oracle.com/cve/CVE-2021-23362.html">https://linux.oracle.com/cve/CVE-2021-23362.html</a><br><a href="https://linux.oracle.com/errata/ELSA-2021-3074.html">https://linux.oracle.com/errata/ELSA-2021-3074.html</a><br><a href="https://nvd.nist.gov/vuln/detail/CVE-2021-23362">https://nvd.nist.gov/vuln/detail/CVE-2021-23362</a><br><a href="https://snyk.io/vuln/SNYK-JAVA-ORGWEBJARSNPM-1088356">https://snyk.io/vuln/SNYK-JAVA-ORGWEBJARSNPM-1088356</a><br><a href="https://snyk.io/vuln/SNYK-JS-HOSTEDGITINFO-1088355">https://snyk.io/vuln/SNYK-JS-HOSTEDGITINFO-1088355</a><br></details>  |
| ini         |    CVE-2020-7788   |   HIGH  |  1.3.4 | 1.3.6 | <details><summary>Expand...</summary><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2020-7788">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2020-7788</a><br><a href="https://github.com/advisories/GHSA-qqgx-2p2h-9c37">https://github.com/advisories/GHSA-qqgx-2p2h-9c37</a><br><a href="https://github.com/npm/ini/commit/56d2805e07ccd94e2ba0984ac9240ff02d44b6f1">https://github.com/npm/ini/commit/56d2805e07ccd94e2ba0984ac9240ff02d44b6f1</a><br><a href="https://github.com/npm/ini/commit/56d2805e07ccd94e2ba0984ac9240ff02d44b6f1 (v1.3.6)">https://github.com/npm/ini/commit/56d2805e07ccd94e2ba0984ac9240ff02d44b6f1 (v1.3.6)</a><br><a href="https://linux.oracle.com/cve/CVE-2020-7788.html">https://linux.oracle.com/cve/CVE-2020-7788.html</a><br><a href="https://linux.oracle.com/errata/ELSA-2021-5171.html">https://linux.oracle.com/errata/ELSA-2021-5171.html</a><br><a href="https://lists.debian.org/debian-lts-announce/2020/12/msg00032.html">https://lists.debian.org/debian-lts-announce/2020/12/msg00032.html</a><br><a href="https://nvd.nist.gov/vuln/detail/CVE-2020-7788">https://nvd.nist.gov/vuln/detail/CVE-2020-7788</a><br><a href="https://snyk.io/vuln/SNYK-JS-INI-1048974">https://snyk.io/vuln/SNYK-JS-INI-1048974</a><br><a href="https://www.npmjs.com/advisories/1589">https://www.npmjs.com/advisories/1589</a><br></details>  |
| ini         |    CVE-2020-7788   |   HIGH  |  1.3.5 | 1.3.6 | <details><summary>Expand...</summary><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2020-7788">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2020-7788</a><br><a href="https://github.com/advisories/GHSA-qqgx-2p2h-9c37">https://github.com/advisories/GHSA-qqgx-2p2h-9c37</a><br><a href="https://github.com/npm/ini/commit/56d2805e07ccd94e2ba0984ac9240ff02d44b6f1">https://github.com/npm/ini/commit/56d2805e07ccd94e2ba0984ac9240ff02d44b6f1</a><br><a href="https://github.com/npm/ini/commit/56d2805e07ccd94e2ba0984ac9240ff02d44b6f1 (v1.3.6)">https://github.com/npm/ini/commit/56d2805e07ccd94e2ba0984ac9240ff02d44b6f1 (v1.3.6)</a><br><a href="https://linux.oracle.com/cve/CVE-2020-7788.html">https://linux.oracle.com/cve/CVE-2020-7788.html</a><br><a href="https://linux.oracle.com/errata/ELSA-2021-5171.html">https://linux.oracle.com/errata/ELSA-2021-5171.html</a><br><a href="https://lists.debian.org/debian-lts-announce/2020/12/msg00032.html">https://lists.debian.org/debian-lts-announce/2020/12/msg00032.html</a><br><a href="https://nvd.nist.gov/vuln/detail/CVE-2020-7788">https://nvd.nist.gov/vuln/detail/CVE-2020-7788</a><br><a href="https://snyk.io/vuln/SNYK-JS-INI-1048974">https://snyk.io/vuln/SNYK-JS-INI-1048974</a><br><a href="https://www.npmjs.com/advisories/1589">https://www.npmjs.com/advisories/1589</a><br></details>  |
| is-my-json-valid         |    CVE-2016-2537   |   HIGH  |  2.13.1 | 1.4.1, 2.17.2 | <details><summary>Expand...</summary><a href="https://github.com/advisories/GHSA-f522-ffg8-j8r6">https://github.com/advisories/GHSA-f522-ffg8-j8r6</a><br><a href="https://github.com/mafintosh/is-my-json-valid/commit/b3051b277f7caa08cd2edc6f74f50aeda65d2976">https://github.com/mafintosh/is-my-json-valid/commit/b3051b277f7caa08cd2edc6f74f50aeda65d2976</a><br><a href="https://github.com/mafintosh/is-my-json-valid/commit/eca4beb21e61877d76fdf6bea771f72f39544d9b">https://github.com/mafintosh/is-my-json-valid/commit/eca4beb21e61877d76fdf6bea771f72f39544d9b</a><br><a href="https://github.com/mafintosh/is-my-json-valid/pull/159">https://github.com/mafintosh/is-my-json-valid/pull/159</a><br><a href="https://hackerone.com/reports/317548">https://hackerone.com/reports/317548</a><br><a href="https://nodesecurity.io/advisories/76">https://nodesecurity.io/advisories/76</a><br><a href="https://nvd.nist.gov/vuln/detail/CVE-2016-2537">https://nvd.nist.gov/vuln/detail/CVE-2016-2537</a><br><a href="https://www.npmjs.com/advisories/572">https://www.npmjs.com/advisories/572</a><br><a href="https://www.npmjs.com/advisories/76">https://www.npmjs.com/advisories/76</a><br><a href="https://www.owasp.org/index.php/Regular_expression_Denial_of_Service_-_ReDoS">https://www.owasp.org/index.php/Regular_expression_Denial_of_Service_-_ReDoS</a><br></details>  |
| is-my-json-valid         |    NSWG-ECO-375   |   LOW  |  2.13.1 | &gt;=1.4.1 &lt;2.0.0, &gt;=2.17.2 | <details><summary>Expand...</summary><a href="https://github.com/mafintosh/is-my-json-valid/commit/b3051b277f7caa08cd2edc6f74f50aeda65d2976">https://github.com/mafintosh/is-my-json-valid/commit/b3051b277f7caa08cd2edc6f74f50aeda65d2976</a><br><a href="https://github.com/mafintosh/is-my-json-valid/pull/159">https://github.com/mafintosh/is-my-json-valid/pull/159</a><br><a href="https://hackerone.com/reports/317548">https://hackerone.com/reports/317548</a><br></details>  |
| json-schema         |    CVE-2021-3918   |   CRITICAL  |  0.2.2 | 0.4.0 | <details><summary>Expand...</summary><a href="https://github.com/advisories/GHSA-896r-f27r-55mw">https://github.com/advisories/GHSA-896r-f27r-55mw</a><br><a href="https://github.com/kriszyp/json-schema/commit/22f146111f541d9737e832823699ad3528ca7741">https://github.com/kriszyp/json-schema/commit/22f146111f541d9737e832823699ad3528ca7741</a><br><a href="https://github.com/kriszyp/json-schema/commit/b62f1da1ff5442f23443d6be6a92d00e65cba93a">https://github.com/kriszyp/json-schema/commit/b62f1da1ff5442f23443d6be6a92d00e65cba93a</a><br><a href="https://github.com/kriszyp/json-schema/commit/f6f6a3b02d667aa4ba2d5d50cc19208c4462abfa">https://github.com/kriszyp/json-schema/commit/f6f6a3b02d667aa4ba2d5d50cc19208c4462abfa</a><br><a href="https://huntr.dev/bounties/bb6ccd63-f505-4e3a-b55f-cd2662c261a9">https://huntr.dev/bounties/bb6ccd63-f505-4e3a-b55f-cd2662c261a9</a><br><a href="https://linux.oracle.com/cve/CVE-2021-3918.html">https://linux.oracle.com/cve/CVE-2021-3918.html</a><br><a href="https://linux.oracle.com/errata/ELSA-2021-5171.html">https://linux.oracle.com/errata/ELSA-2021-5171.html</a><br><a href="https://nvd.nist.gov/vuln/detail/CVE-2021-3918">https://nvd.nist.gov/vuln/detail/CVE-2021-3918</a><br></details>  |
| json-schema         |    CVE-2021-3918   |   CRITICAL  |  0.2.3 | 0.4.0 | <details><summary>Expand...</summary><a href="https://github.com/advisories/GHSA-896r-f27r-55mw">https://github.com/advisories/GHSA-896r-f27r-55mw</a><br><a href="https://github.com/kriszyp/json-schema/commit/22f146111f541d9737e832823699ad3528ca7741">https://github.com/kriszyp/json-schema/commit/22f146111f541d9737e832823699ad3528ca7741</a><br><a href="https://github.com/kriszyp/json-schema/commit/b62f1da1ff5442f23443d6be6a92d00e65cba93a">https://github.com/kriszyp/json-schema/commit/b62f1da1ff5442f23443d6be6a92d00e65cba93a</a><br><a href="https://github.com/kriszyp/json-schema/commit/f6f6a3b02d667aa4ba2d5d50cc19208c4462abfa">https://github.com/kriszyp/json-schema/commit/f6f6a3b02d667aa4ba2d5d50cc19208c4462abfa</a><br><a href="https://huntr.dev/bounties/bb6ccd63-f505-4e3a-b55f-cd2662c261a9">https://huntr.dev/bounties/bb6ccd63-f505-4e3a-b55f-cd2662c261a9</a><br><a href="https://linux.oracle.com/cve/CVE-2021-3918.html">https://linux.oracle.com/cve/CVE-2021-3918.html</a><br><a href="https://linux.oracle.com/errata/ELSA-2021-5171.html">https://linux.oracle.com/errata/ELSA-2021-5171.html</a><br><a href="https://nvd.nist.gov/vuln/detail/CVE-2021-3918">https://nvd.nist.gov/vuln/detail/CVE-2021-3918</a><br></details>  |
| jsonpointer         |    CVE-2021-23807   |   CRITICAL  |  2.0.0 | 5.0.0 | <details><summary>Expand...</summary><a href="https://github.com/advisories/GHSA-282f-qqgm-c34q">https://github.com/advisories/GHSA-282f-qqgm-c34q</a><br><a href="https://github.com/janl/node-jsonpointer/commit/a0345f3550cd9c4d89f33b126390202b89510ad4">https://github.com/janl/node-jsonpointer/commit/a0345f3550cd9c4d89f33b126390202b89510ad4</a><br><a href="https://github.com/janl/node-jsonpointer/pull/51">https://github.com/janl/node-jsonpointer/pull/51</a><br><a href="https://nvd.nist.gov/vuln/detail/CVE-2021-23807">https://nvd.nist.gov/vuln/detail/CVE-2021-23807</a><br><a href="https://snyk.io/vuln/SNYK-JAVA-ORGWEBJARSNPM-1910273">https://snyk.io/vuln/SNYK-JAVA-ORGWEBJARSNPM-1910273</a><br><a href="https://snyk.io/vuln/SNYK-JS-JSONPOINTER-1577288">https://snyk.io/vuln/SNYK-JS-JSONPOINTER-1577288</a><br></details>  |
| lodash         |    CVE-2019-10744   |   CRITICAL  |  1.3.1 | 4.17.12 | <details><summary>Expand...</summary><a href="https://access.redhat.com/errata/RHSA-2019:3024">https://access.redhat.com/errata/RHSA-2019:3024</a><br><a href="https://github.com/advisories/GHSA-jf85-cpcp-j695">https://github.com/advisories/GHSA-jf85-cpcp-j695</a><br><a href="https://github.com/lodash/lodash/pull/4336">https://github.com/lodash/lodash/pull/4336</a><br><a href="https://nvd.nist.gov/vuln/detail/CVE-2019-10744">https://nvd.nist.gov/vuln/detail/CVE-2019-10744</a><br><a href="https://security.netapp.com/advisory/ntap-20191004-0005/">https://security.netapp.com/advisory/ntap-20191004-0005/</a><br><a href="https://snyk.io/vuln/SNYK-JS-LODASH-450202">https://snyk.io/vuln/SNYK-JS-LODASH-450202</a><br><a href="https://support.f5.com/csp/article/K47105354?utm_source=f5support&amp;amp;utm_medium=RSS">https://support.f5.com/csp/article/K47105354?utm_source=f5support&amp;amp;utm_medium=RSS</a><br><a href="https://www.npmjs.com/advisories/1065">https://www.npmjs.com/advisories/1065</a><br><a href="https://www.oracle.com/security-alerts/cpujan2021.html">https://www.oracle.com/security-alerts/cpujan2021.html</a><br><a href="https://www.oracle.com/security-alerts/cpuoct2020.html">https://www.oracle.com/security-alerts/cpuoct2020.html</a><br></details>  |
| lodash         |    CVE-2020-8203   |   HIGH  |  1.3.1 | 4.17.19 | <details><summary>Expand...</summary><a href="https://github.com/advisories/GHSA-p6mc-m468-83gw">https://github.com/advisories/GHSA-p6mc-m468-83gw</a><br><a href="https://github.com/lodash/lodash/commit/c84fe82760fb2d3e03a63379b297a1cc1a2fce12">https://github.com/lodash/lodash/commit/c84fe82760fb2d3e03a63379b297a1cc1a2fce12</a><br><a href="https://github.com/lodash/lodash/issues/4744">https://github.com/lodash/lodash/issues/4744</a><br><a href="https://github.com/lodash/lodash/issues/4874">https://github.com/lodash/lodash/issues/4874</a><br><a href="https://hackerone.com/reports/712065">https://hackerone.com/reports/712065</a><br><a href="https://nvd.nist.gov/vuln/detail/CVE-2020-8203">https://nvd.nist.gov/vuln/detail/CVE-2020-8203</a><br><a href="https://security.netapp.com/advisory/ntap-20200724-0006/">https://security.netapp.com/advisory/ntap-20200724-0006/</a><br><a href="https://www.npmjs.com/advisories/1523">https://www.npmjs.com/advisories/1523</a><br><a href="https://www.oracle.com//security-alerts/cpujul2021.html">https://www.oracle.com//security-alerts/cpujul2021.html</a><br><a href="https://www.oracle.com/security-alerts/cpuApr2021.html">https://www.oracle.com/security-alerts/cpuApr2021.html</a><br><a href="https://www.oracle.com/security-alerts/cpuoct2021.html">https://www.oracle.com/security-alerts/cpuoct2021.html</a><br></details>  |
| lodash         |    CVE-2021-23337   |   HIGH  |  1.3.1 | 4.17.21 | <details><summary>Expand...</summary><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2021-23337">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2021-23337</a><br><a href="https://github.com/advisories/GHSA-35jh-r3h4-6jhm">https://github.com/advisories/GHSA-35jh-r3h4-6jhm</a><br><a href="https://github.com/lodash/lodash/blob/ddfd9b11a0126db2302cb70ec9973b66baec0975/lodash.js#L14851">https://github.com/lodash/lodash/blob/ddfd9b11a0126db2302cb70ec9973b66baec0975/lodash.js#L14851</a><br><a href="https://github.com/lodash/lodash/blob/ddfd9b11a0126db2302cb70ec9973b66baec0975/lodash.js%23L14851">https://github.com/lodash/lodash/blob/ddfd9b11a0126db2302cb70ec9973b66baec0975/lodash.js%23L14851</a><br><a href="https://github.com/lodash/lodash/commit/3469357cff396a26c363f8c1b5a91dde28ba4b1c">https://github.com/lodash/lodash/commit/3469357cff396a26c363f8c1b5a91dde28ba4b1c</a><br><a href="https://nvd.nist.gov/vuln/detail/CVE-2021-23337">https://nvd.nist.gov/vuln/detail/CVE-2021-23337</a><br><a href="https://security.netapp.com/advisory/ntap-20210312-0006/">https://security.netapp.com/advisory/ntap-20210312-0006/</a><br><a href="https://snyk.io/vuln/SNYK-JAVA-ORGFUJIONWEBJARS-1074932">https://snyk.io/vuln/SNYK-JAVA-ORGFUJIONWEBJARS-1074932</a><br><a href="https://snyk.io/vuln/SNYK-JAVA-ORGWEBJARS-1074930">https://snyk.io/vuln/SNYK-JAVA-ORGWEBJARS-1074930</a><br><a href="https://snyk.io/vuln/SNYK-JAVA-ORGWEBJARSBOWER-1074928">https://snyk.io/vuln/SNYK-JAVA-ORGWEBJARSBOWER-1074928</a><br><a href="https://snyk.io/vuln/SNYK-JAVA-ORGWEBJARSBOWERGITHUBLODASH-1074931">https://snyk.io/vuln/SNYK-JAVA-ORGWEBJARSBOWERGITHUBLODASH-1074931</a><br><a href="https://snyk.io/vuln/SNYK-JAVA-ORGWEBJARSNPM-1074929">https://snyk.io/vuln/SNYK-JAVA-ORGWEBJARSNPM-1074929</a><br><a href="https://snyk.io/vuln/SNYK-JS-LODASH-1040724">https://snyk.io/vuln/SNYK-JS-LODASH-1040724</a><br><a href="https://www.oracle.com//security-alerts/cpujul2021.html">https://www.oracle.com//security-alerts/cpujul2021.html</a><br><a href="https://www.oracle.com/security-alerts/cpuoct2021.html">https://www.oracle.com/security-alerts/cpuoct2021.html</a><br></details>  |
| lodash         |    CVE-2018-16487   |   MEDIUM  |  1.3.1 | &gt;=4.17.11 | <details><summary>Expand...</summary><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2018-16487">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2018-16487</a><br><a href="https://github.com/advisories/GHSA-4xc9-xhrj-v574">https://github.com/advisories/GHSA-4xc9-xhrj-v574</a><br><a href="https://hackerone.com/reports/380873">https://hackerone.com/reports/380873</a><br><a href="https://nvd.nist.gov/vuln/detail/CVE-2018-16487">https://nvd.nist.gov/vuln/detail/CVE-2018-16487</a><br><a href="https://security.netapp.com/advisory/ntap-20190919-0004/">https://security.netapp.com/advisory/ntap-20190919-0004/</a><br><a href="https://www.npmjs.com/advisories/782">https://www.npmjs.com/advisories/782</a><br></details>  |
| lodash         |    CVE-2018-3721   |   MEDIUM  |  1.3.1 | &gt;=4.17.5 | <details><summary>Expand...</summary><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2018-3721">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2018-3721</a><br><a href="https://github.com/advisories/GHSA-fvqr-27wr-82fm">https://github.com/advisories/GHSA-fvqr-27wr-82fm</a><br><a href="https://github.com/lodash/lodash/commit/d8e069cc3410082e44eb18fcf8e7f3d08ebe1d4a">https://github.com/lodash/lodash/commit/d8e069cc3410082e44eb18fcf8e7f3d08ebe1d4a</a><br><a href="https://hackerone.com/reports/310443">https://hackerone.com/reports/310443</a><br><a href="https://nvd.nist.gov/vuln/detail/CVE-2018-3721">https://nvd.nist.gov/vuln/detail/CVE-2018-3721</a><br><a href="https://security.netapp.com/advisory/ntap-20190919-0004/">https://security.netapp.com/advisory/ntap-20190919-0004/</a><br><a href="https://snyk.io/vuln/npm:lodash:20180130">https://snyk.io/vuln/npm:lodash:20180130</a><br><a href="https://www.npmjs.com/advisories/577">https://www.npmjs.com/advisories/577</a><br></details>  |
| lodash         |    CVE-2019-1010266   |   MEDIUM  |  1.3.1 | 4.17.11 | <details><summary>Expand...</summary><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2019-1010266">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2019-1010266</a><br><a href="https://github.com/advisories/GHSA-x5rq-j2xg-h7qm">https://github.com/advisories/GHSA-x5rq-j2xg-h7qm</a><br><a href="https://github.com/lodash/lodash/commit/5c08f18d365b64063bfbfa686cbb97cdd6267347">https://github.com/lodash/lodash/commit/5c08f18d365b64063bfbfa686cbb97cdd6267347</a><br><a href="https://github.com/lodash/lodash/issues/3359">https://github.com/lodash/lodash/issues/3359</a><br><a href="https://github.com/lodash/lodash/wiki/Changelog">https://github.com/lodash/lodash/wiki/Changelog</a><br><a href="https://nvd.nist.gov/vuln/detail/CVE-2019-1010266">https://nvd.nist.gov/vuln/detail/CVE-2019-1010266</a><br><a href="https://security.netapp.com/advisory/ntap-20190919-0004/">https://security.netapp.com/advisory/ntap-20190919-0004/</a><br><a href="https://snyk.io/vuln/SNYK-JS-LODASH-73639">https://snyk.io/vuln/SNYK-JS-LODASH-73639</a><br></details>  |
| mime         |    CVE-2017-16138   |   HIGH  |  1.2.11 | 2.0.3, 1.4.1 | <details><summary>Expand...</summary><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2017-16138">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2017-16138</a><br><a href="https://github.com/advisories/GHSA-wrvr-8mpx-r7pp">https://github.com/advisories/GHSA-wrvr-8mpx-r7pp</a><br><a href="https://github.com/broofa/node-mime/commit/1df903fdeb9ae7eaa048795b8d580ce2c98f40b0 (2.x)">https://github.com/broofa/node-mime/commit/1df903fdeb9ae7eaa048795b8d580ce2c98f40b0 (2.x)</a><br><a href="https://github.com/broofa/node-mime/commit/855d0c4b8b22e4a80b9401a81f2872058eae274d (1.x)">https://github.com/broofa/node-mime/commit/855d0c4b8b22e4a80b9401a81f2872058eae274d (1.x)</a><br><a href="https://github.com/broofa/node-mime/issues/167">https://github.com/broofa/node-mime/issues/167</a><br><a href="https://nodesecurity.io/advisories/535">https://nodesecurity.io/advisories/535</a><br><a href="https://nvd.nist.gov/vuln/detail/CVE-2017-16138">https://nvd.nist.gov/vuln/detail/CVE-2017-16138</a><br><a href="https://www.npmjs.com/advisories/535">https://www.npmjs.com/advisories/535</a><br></details>  |
| mime         |    CVE-2017-16138   |   HIGH  |  1.2.7 | 2.0.3, 1.4.1 | <details><summary>Expand...</summary><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2017-16138">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2017-16138</a><br><a href="https://github.com/advisories/GHSA-wrvr-8mpx-r7pp">https://github.com/advisories/GHSA-wrvr-8mpx-r7pp</a><br><a href="https://github.com/broofa/node-mime/commit/1df903fdeb9ae7eaa048795b8d580ce2c98f40b0 (2.x)">https://github.com/broofa/node-mime/commit/1df903fdeb9ae7eaa048795b8d580ce2c98f40b0 (2.x)</a><br><a href="https://github.com/broofa/node-mime/commit/855d0c4b8b22e4a80b9401a81f2872058eae274d (1.x)">https://github.com/broofa/node-mime/commit/855d0c4b8b22e4a80b9401a81f2872058eae274d (1.x)</a><br><a href="https://github.com/broofa/node-mime/issues/167">https://github.com/broofa/node-mime/issues/167</a><br><a href="https://nodesecurity.io/advisories/535">https://nodesecurity.io/advisories/535</a><br><a href="https://nvd.nist.gov/vuln/detail/CVE-2017-16138">https://nvd.nist.gov/vuln/detail/CVE-2017-16138</a><br><a href="https://www.npmjs.com/advisories/535">https://www.npmjs.com/advisories/535</a><br></details>  |
| minimatch         |    CVE-2016-10540   |   HIGH  |  0.2.14 | 3.0.2 | <details><summary>Expand...</summary><a href="https://github.com/advisories/GHSA-hxm2-r34f-qmc5">https://github.com/advisories/GHSA-hxm2-r34f-qmc5</a><br><a href="https://nodesecurity.io/advisories/118">https://nodesecurity.io/advisories/118</a><br><a href="https://nvd.nist.gov/vuln/detail/CVE-2016-10540">https://nvd.nist.gov/vuln/detail/CVE-2016-10540</a><br><a href="https://www.npmjs.com/advisories/118">https://www.npmjs.com/advisories/118</a><br></details>  |
| minimatch         |    NSWG-ECO-118   |   HIGH  |  0.2.14 | &gt;=3.0.2 | <details><summary>Expand...</summary><a href="https://www.owasp.org/index.php/Regular_expression_Denial_of_Service_-_ReDoS">https://www.owasp.org/index.php/Regular_expression_Denial_of_Service_-_ReDoS</a><br></details>  |
| minimatch         |    CVE-2016-10540   |   HIGH  |  0.3.0 | 3.0.2 | <details><summary>Expand...</summary><a href="https://github.com/advisories/GHSA-hxm2-r34f-qmc5">https://github.com/advisories/GHSA-hxm2-r34f-qmc5</a><br><a href="https://nodesecurity.io/advisories/118">https://nodesecurity.io/advisories/118</a><br><a href="https://nvd.nist.gov/vuln/detail/CVE-2016-10540">https://nvd.nist.gov/vuln/detail/CVE-2016-10540</a><br><a href="https://www.npmjs.com/advisories/118">https://www.npmjs.com/advisories/118</a><br></details>  |
| minimatch         |    NSWG-ECO-118   |   HIGH  |  0.3.0 | &gt;=3.0.2 | <details><summary>Expand...</summary><a href="https://www.owasp.org/index.php/Regular_expression_Denial_of_Service_-_ReDoS">https://www.owasp.org/index.php/Regular_expression_Denial_of_Service_-_ReDoS</a><br></details>  |
| minimatch         |    CVE-2016-10540   |   HIGH  |  1.0.0 | 3.0.2 | <details><summary>Expand...</summary><a href="https://github.com/advisories/GHSA-hxm2-r34f-qmc5">https://github.com/advisories/GHSA-hxm2-r34f-qmc5</a><br><a href="https://nodesecurity.io/advisories/118">https://nodesecurity.io/advisories/118</a><br><a href="https://nvd.nist.gov/vuln/detail/CVE-2016-10540">https://nvd.nist.gov/vuln/detail/CVE-2016-10540</a><br><a href="https://www.npmjs.com/advisories/118">https://www.npmjs.com/advisories/118</a><br></details>  |
| minimatch         |    NSWG-ECO-118   |   HIGH  |  1.0.0 | &gt;=3.0.2 | <details><summary>Expand...</summary><a href="https://www.owasp.org/index.php/Regular_expression_Denial_of_Service_-_ReDoS">https://www.owasp.org/index.php/Regular_expression_Denial_of_Service_-_ReDoS</a><br></details>  |
| minimatch         |    CVE-2016-10540   |   HIGH  |  2.0.10 | 3.0.2 | <details><summary>Expand...</summary><a href="https://github.com/advisories/GHSA-hxm2-r34f-qmc5">https://github.com/advisories/GHSA-hxm2-r34f-qmc5</a><br><a href="https://nodesecurity.io/advisories/118">https://nodesecurity.io/advisories/118</a><br><a href="https://nvd.nist.gov/vuln/detail/CVE-2016-10540">https://nvd.nist.gov/vuln/detail/CVE-2016-10540</a><br><a href="https://www.npmjs.com/advisories/118">https://www.npmjs.com/advisories/118</a><br></details>  |
| minimatch         |    NSWG-ECO-118   |   HIGH  |  2.0.10 | &gt;=3.0.2 | <details><summary>Expand...</summary><a href="https://www.owasp.org/index.php/Regular_expression_Denial_of_Service_-_ReDoS">https://www.owasp.org/index.php/Regular_expression_Denial_of_Service_-_ReDoS</a><br></details>  |
| minimatch         |    CVE-2016-10540   |   HIGH  |  3.0.0 | 3.0.2 | <details><summary>Expand...</summary><a href="https://github.com/advisories/GHSA-hxm2-r34f-qmc5">https://github.com/advisories/GHSA-hxm2-r34f-qmc5</a><br><a href="https://nodesecurity.io/advisories/118">https://nodesecurity.io/advisories/118</a><br><a href="https://nvd.nist.gov/vuln/detail/CVE-2016-10540">https://nvd.nist.gov/vuln/detail/CVE-2016-10540</a><br><a href="https://www.npmjs.com/advisories/118">https://www.npmjs.com/advisories/118</a><br></details>  |
| minimatch         |    NSWG-ECO-118   |   HIGH  |  3.0.0 | &gt;=3.0.2 | <details><summary>Expand...</summary><a href="https://www.owasp.org/index.php/Regular_expression_Denial_of_Service_-_ReDoS">https://www.owasp.org/index.php/Regular_expression_Denial_of_Service_-_ReDoS</a><br></details>  |
| minimist         |    CVE-2020-7598   |   MEDIUM  |  0.0.10 | 1.2.3, 0.2.1 | <details><summary>Expand...</summary><a href="http://lists.opensuse.org/opensuse-security-announce/2020-06/msg00024.html">http://lists.opensuse.org/opensuse-security-announce/2020-06/msg00024.html</a><br><a href="https://github.com/advisories/GHSA-vh95-rmgr-6w4m">https://github.com/advisories/GHSA-vh95-rmgr-6w4m</a><br><a href="https://github.com/substack/minimist/commit/38a4d1caead72ef99e824bb420a2528eec03d9ab">https://github.com/substack/minimist/commit/38a4d1caead72ef99e824bb420a2528eec03d9ab</a><br><a href="https://github.com/substack/minimist/commit/4cf1354839cb972e38496d35e12f806eea92c11f#diff-a1e0ee62c91705696ddb71aa30ad4f95">https://github.com/substack/minimist/commit/4cf1354839cb972e38496d35e12f806eea92c11f#diff-a1e0ee62c91705696ddb71aa30ad4f95</a><br><a href="https://github.com/substack/minimist/commit/63e7ed05aa4b1889ec2f3b196426db4500cbda94">https://github.com/substack/minimist/commit/63e7ed05aa4b1889ec2f3b196426db4500cbda94</a><br><a href="https://linux.oracle.com/cve/CVE-2020-7598.html">https://linux.oracle.com/cve/CVE-2020-7598.html</a><br><a href="https://linux.oracle.com/errata/ELSA-2020-2852.html">https://linux.oracle.com/errata/ELSA-2020-2852.html</a><br><a href="https://nvd.nist.gov/vuln/detail/CVE-2020-7598">https://nvd.nist.gov/vuln/detail/CVE-2020-7598</a><br><a href="https://snyk.io/vuln/SNYK-JS-MINIMIST-559764">https://snyk.io/vuln/SNYK-JS-MINIMIST-559764</a><br><a href="https://www.npmjs.com/advisories/1179">https://www.npmjs.com/advisories/1179</a><br></details>  |
| minimist         |    CVE-2020-7598   |   MEDIUM  |  0.0.8 | 1.2.3, 0.2.1 | <details><summary>Expand...</summary><a href="http://lists.opensuse.org/opensuse-security-announce/2020-06/msg00024.html">http://lists.opensuse.org/opensuse-security-announce/2020-06/msg00024.html</a><br><a href="https://github.com/advisories/GHSA-vh95-rmgr-6w4m">https://github.com/advisories/GHSA-vh95-rmgr-6w4m</a><br><a href="https://github.com/substack/minimist/commit/38a4d1caead72ef99e824bb420a2528eec03d9ab">https://github.com/substack/minimist/commit/38a4d1caead72ef99e824bb420a2528eec03d9ab</a><br><a href="https://github.com/substack/minimist/commit/4cf1354839cb972e38496d35e12f806eea92c11f#diff-a1e0ee62c91705696ddb71aa30ad4f95">https://github.com/substack/minimist/commit/4cf1354839cb972e38496d35e12f806eea92c11f#diff-a1e0ee62c91705696ddb71aa30ad4f95</a><br><a href="https://github.com/substack/minimist/commit/63e7ed05aa4b1889ec2f3b196426db4500cbda94">https://github.com/substack/minimist/commit/63e7ed05aa4b1889ec2f3b196426db4500cbda94</a><br><a href="https://linux.oracle.com/cve/CVE-2020-7598.html">https://linux.oracle.com/cve/CVE-2020-7598.html</a><br><a href="https://linux.oracle.com/errata/ELSA-2020-2852.html">https://linux.oracle.com/errata/ELSA-2020-2852.html</a><br><a href="https://nvd.nist.gov/vuln/detail/CVE-2020-7598">https://nvd.nist.gov/vuln/detail/CVE-2020-7598</a><br><a href="https://snyk.io/vuln/SNYK-JS-MINIMIST-559764">https://snyk.io/vuln/SNYK-JS-MINIMIST-559764</a><br><a href="https://www.npmjs.com/advisories/1179">https://www.npmjs.com/advisories/1179</a><br></details>  |
| minimist         |    CVE-2020-7598   |   MEDIUM  |  1.2.0 | 1.2.3, 0.2.1 | <details><summary>Expand...</summary><a href="http://lists.opensuse.org/opensuse-security-announce/2020-06/msg00024.html">http://lists.opensuse.org/opensuse-security-announce/2020-06/msg00024.html</a><br><a href="https://github.com/advisories/GHSA-vh95-rmgr-6w4m">https://github.com/advisories/GHSA-vh95-rmgr-6w4m</a><br><a href="https://github.com/substack/minimist/commit/38a4d1caead72ef99e824bb420a2528eec03d9ab">https://github.com/substack/minimist/commit/38a4d1caead72ef99e824bb420a2528eec03d9ab</a><br><a href="https://github.com/substack/minimist/commit/4cf1354839cb972e38496d35e12f806eea92c11f#diff-a1e0ee62c91705696ddb71aa30ad4f95">https://github.com/substack/minimist/commit/4cf1354839cb972e38496d35e12f806eea92c11f#diff-a1e0ee62c91705696ddb71aa30ad4f95</a><br><a href="https://github.com/substack/minimist/commit/63e7ed05aa4b1889ec2f3b196426db4500cbda94">https://github.com/substack/minimist/commit/63e7ed05aa4b1889ec2f3b196426db4500cbda94</a><br><a href="https://linux.oracle.com/cve/CVE-2020-7598.html">https://linux.oracle.com/cve/CVE-2020-7598.html</a><br><a href="https://linux.oracle.com/errata/ELSA-2020-2852.html">https://linux.oracle.com/errata/ELSA-2020-2852.html</a><br><a href="https://nvd.nist.gov/vuln/detail/CVE-2020-7598">https://nvd.nist.gov/vuln/detail/CVE-2020-7598</a><br><a href="https://snyk.io/vuln/SNYK-JS-MINIMIST-559764">https://snyk.io/vuln/SNYK-JS-MINIMIST-559764</a><br><a href="https://www.npmjs.com/advisories/1179">https://www.npmjs.com/advisories/1179</a><br></details>  |
| moment         |    CVE-2017-18214   |   HIGH  |  2.1.0 | 2.19.3 | <details><summary>Expand...</summary><a href="https://github.com/advisories/GHSA-446m-mv8f-q348">https://github.com/advisories/GHSA-446m-mv8f-q348</a><br><a href="https://github.com/moment/moment/issues/4163">https://github.com/moment/moment/issues/4163</a><br><a href="https://github.com/moment/moment/pull/4326">https://github.com/moment/moment/pull/4326</a><br><a href="https://nodesecurity.io/advisories/532">https://nodesecurity.io/advisories/532</a><br><a href="https://nvd.nist.gov/vuln/detail/CVE-2017-18214">https://nvd.nist.gov/vuln/detail/CVE-2017-18214</a><br><a href="https://www.npmjs.com/advisories/532">https://www.npmjs.com/advisories/532</a><br><a href="https://www.tenable.com/security/tns-2019-02">https://www.tenable.com/security/tns-2019-02</a><br></details>  |
| moment         |    CVE-2016-4055   |   MEDIUM  |  2.1.0 | &gt;=2.11.2 | <details><summary>Expand...</summary><a href="http://www.openwall.com/lists/oss-security/2016/04/20/11">http://www.openwall.com/lists/oss-security/2016/04/20/11</a><br><a href="http://www.oracle.com/technetwork/security-advisory/cpujul2018-4258247.html">http://www.oracle.com/technetwork/security-advisory/cpujul2018-4258247.html</a><br><a href="http://www.securityfocus.com/bid/95849">http://www.securityfocus.com/bid/95849</a><br><a href="https://github.com/advisories/GHSA-87vv-r9j6-g5qv">https://github.com/advisories/GHSA-87vv-r9j6-g5qv</a><br><a href="https://lists.apache.org/thread.html/10f0f3aefd51444d1198c65f44ffdf2d78ca3359423dbc1c168c9731@%3Cdev.flink.apache.org%3E">https://lists.apache.org/thread.html/10f0f3aefd51444d1198c65f44ffdf2d78ca3359423dbc1c168c9731@%3Cdev.flink.apache.org%3E</a><br><a href="https://lists.apache.org/thread.html/17ff53f7999e74fbe3cc0ceb4e1c3b00b180b7c5afec8e978837bc49@%3Cuser.flink.apache.org%3E">https://lists.apache.org/thread.html/17ff53f7999e74fbe3cc0ceb4e1c3b00b180b7c5afec8e978837bc49@%3Cuser.flink.apache.org%3E</a><br><a href="https://lists.apache.org/thread.html/52bafac05ad174000ea465fe275fd3cc7bd5c25535a7631c0bc9bfb2@%3Cuser.flink.apache.org%3E">https://lists.apache.org/thread.html/52bafac05ad174000ea465fe275fd3cc7bd5c25535a7631c0bc9bfb2@%3Cuser.flink.apache.org%3E</a><br><a href="https://lists.apache.org/thread.html/54df3aeb4239b64b50b356f0ca6f986e3c4ca5b84c515dce077c7854@%3Cuser.flink.apache.org%3E">https://lists.apache.org/thread.html/54df3aeb4239b64b50b356f0ca6f986e3c4ca5b84c515dce077c7854@%3Cuser.flink.apache.org%3E</a><br><a href="https://nodesecurity.io/advisories/55">https://nodesecurity.io/advisories/55</a><br><a href="https://nvd.nist.gov/vuln/detail/CVE-2016-4055">https://nvd.nist.gov/vuln/detail/CVE-2016-4055</a><br><a href="https://www.npmjs.com/advisories/55">https://www.npmjs.com/advisories/55</a><br><a href="https://www.owasp.org/index.php/Regular_expression_Denial_of_Service_-_ReDoS">https://www.owasp.org/index.php/Regular_expression_Denial_of_Service_-_ReDoS</a><br><a href="https://www.tenable.com/security/tns-2019-02">https://www.tenable.com/security/tns-2019-02</a><br></details>  |
| ms         |    CVE-2015-8315   |   HIGH  |  0.3.0 | &gt;0.7.0 | <details><summary>Expand...</summary><a href="http://www.openwall.com/lists/oss-security/2016/04/20/11">http://www.openwall.com/lists/oss-security/2016/04/20/11</a><br><a href="http://www.securityfocus.com/bid/96389">http://www.securityfocus.com/bid/96389</a><br><a href="https://github.com/advisories/GHSA-3fx5-fwvr-xrjg">https://github.com/advisories/GHSA-3fx5-fwvr-xrjg</a><br><a href="https://github.com/unshiftio/millisecond/pull/4">https://github.com/unshiftio/millisecond/pull/4</a><br><a href="https://nodesecurity.io/advisories/46">https://nodesecurity.io/advisories/46</a><br><a href="https://nvd.nist.gov/vuln/detail/CVE-2015-8315">https://nvd.nist.gov/vuln/detail/CVE-2015-8315</a><br><a href="https://support.f5.com/csp/article/K46337613?utm_source=f5support&amp;amp;utm_medium=RSS">https://support.f5.com/csp/article/K46337613?utm_source=f5support&amp;amp;utm_medium=RSS</a><br><a href="https://www.npmjs.com/advisories/46">https://www.npmjs.com/advisories/46</a><br><a href="https://www.owasp.org/index.php/Regular_expression_Denial_of_Service_-_ReDoS">https://www.owasp.org/index.php/Regular_expression_Denial_of_Service_-_ReDoS</a><br></details>  |
| negotiator         |    CVE-2016-10539   |   HIGH  |  0.3.0 | 0.6.1 | <details><summary>Expand...</summary><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2016-10539">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2016-10539</a><br><a href="https://github.com/advisories/GHSA-7mc5-chhp-fmc3">https://github.com/advisories/GHSA-7mc5-chhp-fmc3</a><br><a href="https://nodesecurity.io/advisories/106">https://nodesecurity.io/advisories/106</a><br><a href="https://nvd.nist.gov/vuln/detail/CVE-2016-10539">https://nvd.nist.gov/vuln/detail/CVE-2016-10539</a><br><a href="https://www.npmjs.com/advisories/106">https://www.npmjs.com/advisories/106</a><br></details>  |
| negotiator         |    NSWG-ECO-106   |   HIGH  |  0.3.0 | &gt;= 0.6.1 | <details><summary>Expand...</summary><a href="https://www.owasp.org/index.php/Regular_expression_Denial_of_Service_-_ReDoS">https://www.owasp.org/index.php/Regular_expression_Denial_of_Service_-_ReDoS</a><br></details>  |
| negotiator         |    CVE-2016-10539   |   HIGH  |  0.4.9 | 0.6.1 | <details><summary>Expand...</summary><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2016-10539">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2016-10539</a><br><a href="https://github.com/advisories/GHSA-7mc5-chhp-fmc3">https://github.com/advisories/GHSA-7mc5-chhp-fmc3</a><br><a href="https://nodesecurity.io/advisories/106">https://nodesecurity.io/advisories/106</a><br><a href="https://nvd.nist.gov/vuln/detail/CVE-2016-10539">https://nvd.nist.gov/vuln/detail/CVE-2016-10539</a><br><a href="https://www.npmjs.com/advisories/106">https://www.npmjs.com/advisories/106</a><br></details>  |
| negotiator         |    NSWG-ECO-106   |   HIGH  |  0.4.9 | &gt;= 0.6.1 | <details><summary>Expand...</summary><a href="https://www.owasp.org/index.php/Regular_expression_Denial_of_Service_-_ReDoS">https://www.owasp.org/index.php/Regular_expression_Denial_of_Service_-_ReDoS</a><br></details>  |
| npm         |    CVE-2019-16776   |   HIGH  |  3.10.3 | 6.13.3 | <details><summary>Expand...</summary><a href="http://lists.opensuse.org/opensuse-security-announce/2020-01/msg00027.html">http://lists.opensuse.org/opensuse-security-announce/2020-01/msg00027.html</a><br><a href="https://access.redhat.com/errata/RHEA-2020:0330">https://access.redhat.com/errata/RHEA-2020:0330</a><br><a href="https://access.redhat.com/errata/RHSA-2020:0573">https://access.redhat.com/errata/RHSA-2020:0573</a><br><a href="https://access.redhat.com/errata/RHSA-2020:0579">https://access.redhat.com/errata/RHSA-2020:0579</a><br><a href="https://access.redhat.com/errata/RHSA-2020:0597">https://access.redhat.com/errata/RHSA-2020:0597</a><br><a href="https://access.redhat.com/errata/RHSA-2020:0602">https://access.redhat.com/errata/RHSA-2020:0602</a><br><a href="https://blog.npmjs.org/post/189618601100/binary-planting-with-the-npm-cli">https://blog.npmjs.org/post/189618601100/binary-planting-with-the-npm-cli</a><br><a href="https://github.com/advisories/GHSA-x8qc-rrcw-4r46">https://github.com/advisories/GHSA-x8qc-rrcw-4r46</a><br><a href="https://github.com/npm/cli/security/advisories/GHSA-x8qc-rrcw-4r46">https://github.com/npm/cli/security/advisories/GHSA-x8qc-rrcw-4r46</a><br><a href="https://linux.oracle.com/cve/CVE-2019-16776.html">https://linux.oracle.com/cve/CVE-2019-16776.html</a><br><a href="https://linux.oracle.com/errata/ELSA-2020-0579.html">https://linux.oracle.com/errata/ELSA-2020-0579.html</a><br><a href="https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/Z36UKPO5F3PQ3Q2POMF5LEKXWAH5RUFP/">https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/Z36UKPO5F3PQ3Q2POMF5LEKXWAH5RUFP/</a><br><a href="https://nvd.nist.gov/vuln/detail/CVE-2019-16776">https://nvd.nist.gov/vuln/detail/CVE-2019-16776</a><br><a href="https://www.npmjs.com/advisories/1436">https://www.npmjs.com/advisories/1436</a><br><a href="https://www.oracle.com/security-alerts/cpujan2020.html">https://www.oracle.com/security-alerts/cpujan2020.html</a><br></details>  |
| npm         |    CVE-2019-16775   |   MEDIUM  |  3.10.3 | 6.13.3 | <details><summary>Expand...</summary><a href="http://lists.opensuse.org/opensuse-security-announce/2020-01/msg00027.html">http://lists.opensuse.org/opensuse-security-announce/2020-01/msg00027.html</a><br><a href="https://access.redhat.com/errata/RHEA-2020:0330">https://access.redhat.com/errata/RHEA-2020:0330</a><br><a href="https://access.redhat.com/errata/RHSA-2020:0573">https://access.redhat.com/errata/RHSA-2020:0573</a><br><a href="https://access.redhat.com/errata/RHSA-2020:0579">https://access.redhat.com/errata/RHSA-2020:0579</a><br><a href="https://access.redhat.com/errata/RHSA-2020:0597">https://access.redhat.com/errata/RHSA-2020:0597</a><br><a href="https://access.redhat.com/errata/RHSA-2020:0602">https://access.redhat.com/errata/RHSA-2020:0602</a><br><a href="https://blog.npmjs.org/post/189618601100/binary-planting-with-the-npm-cli">https://blog.npmjs.org/post/189618601100/binary-planting-with-the-npm-cli</a><br><a href="https://github.com/advisories/GHSA-m6cx-g6qm-p2cx">https://github.com/advisories/GHSA-m6cx-g6qm-p2cx</a><br><a href="https://github.com/npm/cli/security/advisories/GHSA-m6cx-g6qm-p2cx">https://github.com/npm/cli/security/advisories/GHSA-m6cx-g6qm-p2cx</a><br><a href="https://linux.oracle.com/cve/CVE-2019-16775.html">https://linux.oracle.com/cve/CVE-2019-16775.html</a><br><a href="https://linux.oracle.com/errata/ELSA-2020-0579.html">https://linux.oracle.com/errata/ELSA-2020-0579.html</a><br><a href="https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/Z36UKPO5F3PQ3Q2POMF5LEKXWAH5RUFP/">https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/Z36UKPO5F3PQ3Q2POMF5LEKXWAH5RUFP/</a><br><a href="https://nvd.nist.gov/vuln/detail/CVE-2019-16775">https://nvd.nist.gov/vuln/detail/CVE-2019-16775</a><br><a href="https://www.npmjs.com/advisories/1434">https://www.npmjs.com/advisories/1434</a><br><a href="https://www.oracle.com/security-alerts/cpujan2020.html">https://www.oracle.com/security-alerts/cpujan2020.html</a><br><a href="https://www.oracle.com/security-alerts/cpuoct2021.html">https://www.oracle.com/security-alerts/cpuoct2021.html</a><br></details>  |
| npm         |    CVE-2019-16777   |   MEDIUM  |  3.10.3 | 6.13.4 | <details><summary>Expand...</summary><a href="http://lists.opensuse.org/opensuse-security-announce/2020-01/msg00027.html">http://lists.opensuse.org/opensuse-security-announce/2020-01/msg00027.html</a><br><a href="https://access.redhat.com/errata/RHEA-2020:0330">https://access.redhat.com/errata/RHEA-2020:0330</a><br><a href="https://access.redhat.com/errata/RHSA-2020:0573">https://access.redhat.com/errata/RHSA-2020:0573</a><br><a href="https://access.redhat.com/errata/RHSA-2020:0579">https://access.redhat.com/errata/RHSA-2020:0579</a><br><a href="https://access.redhat.com/errata/RHSA-2020:0597">https://access.redhat.com/errata/RHSA-2020:0597</a><br><a href="https://access.redhat.com/errata/RHSA-2020:0602">https://access.redhat.com/errata/RHSA-2020:0602</a><br><a href="https://blog.npmjs.org/post/189618601100/binary-planting-with-the-npm-cli">https://blog.npmjs.org/post/189618601100/binary-planting-with-the-npm-cli</a><br><a href="https://github.com/advisories/GHSA-4328-8hgf-7wjr">https://github.com/advisories/GHSA-4328-8hgf-7wjr</a><br><a href="https://github.com/npm/cli/security/advisories/GHSA-4328-8hgf-7wjr">https://github.com/npm/cli/security/advisories/GHSA-4328-8hgf-7wjr</a><br><a href="https://linux.oracle.com/cve/CVE-2019-16777.html">https://linux.oracle.com/cve/CVE-2019-16777.html</a><br><a href="https://linux.oracle.com/errata/ELSA-2020-0579.html">https://linux.oracle.com/errata/ELSA-2020-0579.html</a><br><a href="https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/Z36UKPO5F3PQ3Q2POMF5LEKXWAH5RUFP/">https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/Z36UKPO5F3PQ3Q2POMF5LEKXWAH5RUFP/</a><br><a href="https://nvd.nist.gov/vuln/detail/CVE-2019-16777">https://nvd.nist.gov/vuln/detail/CVE-2019-16777</a><br><a href="https://security.gentoo.org/glsa/202003-48">https://security.gentoo.org/glsa/202003-48</a><br><a href="https://www.npmjs.com/advisories/1437">https://www.npmjs.com/advisories/1437</a><br><a href="https://www.oracle.com/security-alerts/cpujan2020.html">https://www.oracle.com/security-alerts/cpujan2020.html</a><br></details>  |
| npm         |    CVE-2020-15095   |   MEDIUM  |  3.10.3 | 6.14.6 | <details><summary>Expand...</summary><a href="http://lists.opensuse.org/opensuse-security-announce/2020-10/msg00011.html">http://lists.opensuse.org/opensuse-security-announce/2020-10/msg00011.html</a><br><a href="http://lists.opensuse.org/opensuse-security-announce/2020-10/msg00015.html">http://lists.opensuse.org/opensuse-security-announce/2020-10/msg00015.html</a><br><a href="http://lists.opensuse.org/opensuse-security-announce/2020-10/msg00023.html">http://lists.opensuse.org/opensuse-security-announce/2020-10/msg00023.html</a><br><a href="https://github.com/advisories/GHSA-93f3-23rq-pjfp">https://github.com/advisories/GHSA-93f3-23rq-pjfp</a><br><a href="https://github.com/npm/cli/blob/66aab417f836a901f8afb265251f761bb0422463/CHANGELOG.md#6146-2020-07-07">https://github.com/npm/cli/blob/66aab417f836a901f8afb265251f761bb0422463/CHANGELOG.md#6146-2020-07-07</a><br><a href="https://github.com/npm/cli/commit/a9857b8f6869451ff058789c4631fadfde5bbcbc">https://github.com/npm/cli/commit/a9857b8f6869451ff058789c4631fadfde5bbcbc</a><br><a href="https://github.com/npm/cli/security/advisories/GHSA-93f3-23rq-pjfp">https://github.com/npm/cli/security/advisories/GHSA-93f3-23rq-pjfp</a><br><a href="https://linux.oracle.com/cve/CVE-2020-15095.html">https://linux.oracle.com/cve/CVE-2020-15095.html</a><br><a href="https://linux.oracle.com/errata/ELSA-2021-0548.html">https://linux.oracle.com/errata/ELSA-2021-0548.html</a><br><a href="https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/4OOYAMJVLLCLXDTHW3V5UXNULZBBK4O6/">https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/4OOYAMJVLLCLXDTHW3V5UXNULZBBK4O6/</a><br><a href="https://nvd.nist.gov/vuln/detail/CVE-2020-15095">https://nvd.nist.gov/vuln/detail/CVE-2020-15095</a><br><a href="https://security.gentoo.org/glsa/202101-07">https://security.gentoo.org/glsa/202101-07</a><br></details>  |
| npm-user-validate         |    CVE-2020-7754   |   HIGH  |  0.1.4 | 1.0.1 | <details><summary>Expand...</summary><a href="https://github.com/advisories/GHSA-pw54-mh39-w3hc">https://github.com/advisories/GHSA-pw54-mh39-w3hc</a><br><a href="https://github.com/npm/npm-user-validate/commit/c8a87dac1a4cc6988b5418f30411a8669bef204e">https://github.com/npm/npm-user-validate/commit/c8a87dac1a4cc6988b5418f30411a8669bef204e</a><br><a href="https://github.com/npm/npm-user-validate/security/advisories/GHSA-xgh6-85xh-479p">https://github.com/npm/npm-user-validate/security/advisories/GHSA-xgh6-85xh-479p</a><br><a href="https://linux.oracle.com/cve/CVE-2020-7754.html">https://linux.oracle.com/cve/CVE-2020-7754.html</a><br><a href="https://linux.oracle.com/errata/ELSA-2021-0551.html">https://linux.oracle.com/errata/ELSA-2021-0551.html</a><br><a href="https://nvd.nist.gov/vuln/detail/CVE-2020-7754">https://nvd.nist.gov/vuln/detail/CVE-2020-7754</a><br><a href="https://snyk.io/vuln/SNYK-JAVA-ORGWEBJARSNPM-1019353">https://snyk.io/vuln/SNYK-JAVA-ORGWEBJARSNPM-1019353</a><br><a href="https://snyk.io/vuln/SNYK-JS-NPMUSERVALIDATE-1019352">https://snyk.io/vuln/SNYK-JS-NPMUSERVALIDATE-1019352</a><br></details>  |
| npm-user-validate         |    GHSA-xgh6-85xh-479p   |   LOW  |  0.1.4 | 1.0.1 | <details><summary>Expand...</summary><a href="https://github.com/advisories/GHSA-xgh6-85xh-479p">https://github.com/advisories/GHSA-xgh6-85xh-479p</a><br><a href="https://github.com/npm/npm-user-validate/security/advisories/GHSA-xgh6-85xh-479p">https://github.com/npm/npm-user-validate/security/advisories/GHSA-xgh6-85xh-479p</a><br></details>  |
| parsejson         |    CVE-2017-16113   |   HIGH  |  0.0.1 |  | <details><summary>Expand...</summary><a href="https://github.com/advisories/GHSA-q75g-2496-mxpp">https://github.com/advisories/GHSA-q75g-2496-mxpp</a><br><a href="https://github.com/get/parsejson/issues/4">https://github.com/get/parsejson/issues/4</a><br><a href="https://nodesecurity.io/advisories/528">https://nodesecurity.io/advisories/528</a><br><a href="https://nvd.nist.gov/vuln/detail/CVE-2017-16113">https://nvd.nist.gov/vuln/detail/CVE-2017-16113</a><br><a href="https://www.npmjs.com/advisories/528">https://www.npmjs.com/advisories/528</a><br></details>  |
| qs         |    CVE-2014-10064   |   HIGH  |  0.6.6 | 1.0.0 | <details><summary>Expand...</summary><a href="https://github.com/advisories/GHSA-f9cm-p3w6-xvr3">https://github.com/advisories/GHSA-f9cm-p3w6-xvr3</a><br><a href="https://nodesecurity.io/advisories/28">https://nodesecurity.io/advisories/28</a><br><a href="https://nvd.nist.gov/vuln/detail/CVE-2014-10064">https://nvd.nist.gov/vuln/detail/CVE-2014-10064</a><br><a href="https://www.npmjs.com/advisories/28">https://www.npmjs.com/advisories/28</a><br></details>  |
| qs         |    CVE-2017-1000048   |   HIGH  |  0.6.6 | 6.3.2, 6.2.3, 6.1.2, 6.0.4 | <details><summary>Expand...</summary><a href="https://access.redhat.com/errata/RHSA-2017:2672">https://access.redhat.com/errata/RHSA-2017:2672</a><br><a href="https://github.com/advisories/GHSA-gqgv-6jq5-jjj9">https://github.com/advisories/GHSA-gqgv-6jq5-jjj9</a><br><a href="https://github.com/ljharb/qs/commit/beade029171b8cef9cee0d03ebe577e2dd84976d">https://github.com/ljharb/qs/commit/beade029171b8cef9cee0d03ebe577e2dd84976d</a><br><a href="https://github.com/ljharb/qs/issues/200">https://github.com/ljharb/qs/issues/200</a><br><a href="https://nvd.nist.gov/vuln/detail/CVE-2017-1000048">https://nvd.nist.gov/vuln/detail/CVE-2017-1000048</a><br><a href="https://snyk.io/vuln/npm:qs:20170213">https://snyk.io/vuln/npm:qs:20170213</a><br><a href="https://www.npmjs.com/advisories/1469">https://www.npmjs.com/advisories/1469</a><br></details>  |
| qs         |    CVE-2014-7191   |   MEDIUM  |  0.6.6 | &gt;= 1.x | <details><summary>Expand...</summary><a href="http://secunia.com/advisories/60026">http://secunia.com/advisories/60026</a><br><a href="http://secunia.com/advisories/62170">http://secunia.com/advisories/62170</a><br><a href="http://www-01.ibm.com/support/docview.wss?uid=swg21685987">http://www-01.ibm.com/support/docview.wss?uid=swg21685987</a><br><a href="http://www-01.ibm.com/support/docview.wss?uid=swg21687263">http://www-01.ibm.com/support/docview.wss?uid=swg21687263</a><br><a href="http://www-01.ibm.com/support/docview.wss?uid=swg21687928">http://www-01.ibm.com/support/docview.wss?uid=swg21687928</a><br><a href="https://access.redhat.com/errata/RHSA-2016:1380">https://access.redhat.com/errata/RHSA-2016:1380</a><br><a href="https://exchange.xforce.ibmcloud.com/vulnerabilities/96729">https://exchange.xforce.ibmcloud.com/vulnerabilities/96729</a><br><a href="https://github.com/advisories/GHSA-jjv7-qpx3-h62q">https://github.com/advisories/GHSA-jjv7-qpx3-h62q</a><br><a href="https://github.com/raymondfeng/node-querystring/commit/43a604b7847e56bba49d0ce3e222fe89569354d8">https://github.com/raymondfeng/node-querystring/commit/43a604b7847e56bba49d0ce3e222fe89569354d8</a><br><a href="https://github.com/visionmedia/node-querystring/issues/104">https://github.com/visionmedia/node-querystring/issues/104</a><br><a href="https://nodesecurity.io/advisories/qs_dos_memory_exhaustion">https://nodesecurity.io/advisories/qs_dos_memory_exhaustion</a><br><a href="https://nvd.nist.gov/vuln/detail/CVE-2014-7191">https://nvd.nist.gov/vuln/detail/CVE-2014-7191</a><br><a href="https://www.npmjs.com/advisories/29">https://www.npmjs.com/advisories/29</a><br></details>  |
| qs         |    NSWG-ECO-28   |   MEDIUM  |  0.6.6 | &gt;= 1.x | <details><summary>Expand...</summary></details>  |
| qs         |    CVE-2017-1000048   |   HIGH  |  6.1.0 | 6.3.2, 6.2.3, 6.1.2, 6.0.4 | <details><summary>Expand...</summary><a href="https://access.redhat.com/errata/RHSA-2017:2672">https://access.redhat.com/errata/RHSA-2017:2672</a><br><a href="https://github.com/advisories/GHSA-gqgv-6jq5-jjj9">https://github.com/advisories/GHSA-gqgv-6jq5-jjj9</a><br><a href="https://github.com/ljharb/qs/commit/beade029171b8cef9cee0d03ebe577e2dd84976d">https://github.com/ljharb/qs/commit/beade029171b8cef9cee0d03ebe577e2dd84976d</a><br><a href="https://github.com/ljharb/qs/issues/200">https://github.com/ljharb/qs/issues/200</a><br><a href="https://nvd.nist.gov/vuln/detail/CVE-2017-1000048">https://nvd.nist.gov/vuln/detail/CVE-2017-1000048</a><br><a href="https://snyk.io/vuln/npm:qs:20170213">https://snyk.io/vuln/npm:qs:20170213</a><br><a href="https://www.npmjs.com/advisories/1469">https://www.npmjs.com/advisories/1469</a><br></details>  |
| request         |    CVE-2017-16026   |   MEDIUM  |  2.12.0 | 2.68.0, 2.68.0 | <details><summary>Expand...</summary><a href="https://github.com/advisories/GHSA-7xfp-9c55-5vqj">https://github.com/advisories/GHSA-7xfp-9c55-5vqj</a><br><a href="https://github.com/request/request/issues/1904">https://github.com/request/request/issues/1904</a><br><a href="https://github.com/request/request/pull/2018">https://github.com/request/request/pull/2018</a><br><a href="https://nodesecurity.io/advisories/309">https://nodesecurity.io/advisories/309</a><br><a href="https://nvd.nist.gov/vuln/detail/CVE-2017-16026">https://nvd.nist.gov/vuln/detail/CVE-2017-16026</a><br><a href="https://www.npmjs.com/advisories/309">https://www.npmjs.com/advisories/309</a><br></details>  |
| request         |    NSWG-ECO-309   |   MEDIUM  |  2.12.0 | &gt;=2.68.0 | <details><summary>Expand...</summary><a href="https://github.com/request/request/issues/1904">https://github.com/request/request/issues/1904</a><br><a href="https://github.com/request/request/pull/2018">https://github.com/request/request/pull/2018</a><br></details>  |
| send         |    CVE-2014-6394   |   HIGH  |  0.1.4 | &gt;= 0.8.4 | <details><summary>Expand...</summary><a href="http://lists.apple.com/archives/security-announce/2015/Sep/msg00002.html">http://lists.apple.com/archives/security-announce/2015/Sep/msg00002.html</a><br><a href="http://lists.fedoraproject.org/pipermail/package-announce/2014-October/139938.html">http://lists.fedoraproject.org/pipermail/package-announce/2014-October/139938.html</a><br><a href="http://lists.fedoraproject.org/pipermail/package-announce/2014-October/140020.html">http://lists.fedoraproject.org/pipermail/package-announce/2014-October/140020.html</a><br><a href="http://lists.fedoraproject.org/pipermail/package-announce/2014-September/139415.html">http://lists.fedoraproject.org/pipermail/package-announce/2014-September/139415.html</a><br><a href="http://secunia.com/advisories/62170">http://secunia.com/advisories/62170</a><br><a href="http://www-01.ibm.com/support/docview.wss?uid=swg21687263">http://www-01.ibm.com/support/docview.wss?uid=swg21687263</a><br><a href="http://www.openwall.com/lists/oss-security/2014/09/24/1">http://www.openwall.com/lists/oss-security/2014/09/24/1</a><br><a href="http://www.openwall.com/lists/oss-security/2014/09/30/10">http://www.openwall.com/lists/oss-security/2014/09/30/10</a><br><a href="http://www.securityfocus.com/bid/70100">http://www.securityfocus.com/bid/70100</a><br><a href="https://bugzilla.redhat.com/show_bug.cgi?id=1146063">https://bugzilla.redhat.com/show_bug.cgi?id=1146063</a><br><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2014-6394">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2014-6394</a><br><a href="https://exchange.xforce.ibmcloud.com/vulnerabilities/96727">https://exchange.xforce.ibmcloud.com/vulnerabilities/96727</a><br><a href="https://github.com/advisories/GHSA-xwg4-93c6-3h42">https://github.com/advisories/GHSA-xwg4-93c6-3h42</a><br><a href="https://github.com/visionmedia/send/commit/9c6ca9b2c0b880afd3ff91ce0d211213c5fa5f9a">https://github.com/visionmedia/send/commit/9c6ca9b2c0b880afd3ff91ce0d211213c5fa5f9a</a><br><a href="https://github.com/visionmedia/send/pull/59">https://github.com/visionmedia/send/pull/59</a><br><a href="https://nodesecurity.io/advisories/send-directory-traversal">https://nodesecurity.io/advisories/send-directory-traversal</a><br><a href="https://nvd.nist.gov/vuln/detail/CVE-2014-6394">https://nvd.nist.gov/vuln/detail/CVE-2014-6394</a><br><a href="https://support.apple.com/HT205217">https://support.apple.com/HT205217</a><br><a href="https://www.npmjs.com/advisories/32">https://www.npmjs.com/advisories/32</a><br></details>  |
| send         |    CVE-2015-8859   |   MEDIUM  |  0.1.4 | &gt;=0.11.1 | <details><summary>Expand...</summary><a href="http://www.openwall.com/lists/oss-security/2016/04/20/11">http://www.openwall.com/lists/oss-security/2016/04/20/11</a><br><a href="http://www.securityfocus.com/bid/96435">http://www.securityfocus.com/bid/96435</a><br><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2015-8859">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2015-8859</a><br><a href="https://github.com/advisories/GHSA-jgqf-hwc5-hh37">https://github.com/advisories/GHSA-jgqf-hwc5-hh37</a><br><a href="https://github.com/expressjs/serve-static/blob/master/HISTORY.md#181--2015-01-20">https://github.com/expressjs/serve-static/blob/master/HISTORY.md#181--2015-01-20</a><br><a href="https://github.com/pillarjs/send/pull/70">https://github.com/pillarjs/send/pull/70</a><br><a href="https://nodesecurity.io/advisories/56">https://nodesecurity.io/advisories/56</a><br><a href="https://nvd.nist.gov/vuln/detail/CVE-2015-8859">https://nvd.nist.gov/vuln/detail/CVE-2015-8859</a><br><a href="https://www.npmjs.com/advisories/56">https://www.npmjs.com/advisories/56</a><br></details>  |
| sequelize         |    CVE-2015-1369   |   HIGH  |  2.0.0-beta.0 | &gt;=2.0.0-rc8 | <details><summary>Expand...</summary><a href="http://www.openwall.com/lists/oss-security/2015/01/23/2">http://www.openwall.com/lists/oss-security/2015/01/23/2</a><br><a href="https://github.com/advisories/GHSA-xqg8-cv3h-xppv">https://github.com/advisories/GHSA-xqg8-cv3h-xppv</a><br><a href="https://github.com/sequelize/sequelize/issues/2906">https://github.com/sequelize/sequelize/issues/2906</a><br><a href="https://github.com/sequelize/sequelize/pull/2919">https://github.com/sequelize/sequelize/pull/2919</a><br><a href="https://nodesecurity.io/advisories/sequelize-sql-injection-order">https://nodesecurity.io/advisories/sequelize-sql-injection-order</a><br><a href="https://nvd.nist.gov/vuln/detail/CVE-2015-1369">https://nvd.nist.gov/vuln/detail/CVE-2015-1369</a><br><a href="https://www.npmjs.com/advisories/33">https://www.npmjs.com/advisories/33</a><br></details>  |
| sql         |    GHSA-8f93-rv4p-x4jw   |   MEDIUM  |  0.26.0 |  | <details><summary>Expand...</summary><a href="https://github.com/advisories/GHSA-8f93-rv4p-x4jw">https://github.com/advisories/GHSA-8f93-rv4p-x4jw</a><br><a href="https://hackerone.com/reports/319465">https://hackerone.com/reports/319465</a><br><a href="https://nodesecurity.io/advisories/662">https://nodesecurity.io/advisories/662</a><br><a href="https://www.npmjs.com/advisories/662">https://www.npmjs.com/advisories/662</a><br></details>  |
| sql         |    NSWG-ECO-432   |   MEDIUM  |  0.26.0 |  | <details><summary>Expand...</summary><a href="https://hackerone.com/reports/319465">https://hackerone.com/reports/319465</a><br></details>  |
| sshpk         |    CVE-2018-3737   |   HIGH  |  1.7.4 | 1.13.2 | <details><summary>Expand...</summary><a href="https://github.com/advisories/GHSA-2m39-62fm-q8r3">https://github.com/advisories/GHSA-2m39-62fm-q8r3</a><br><a href="https://github.com/joyent/node-sshpk/blob/v1.13.1/lib/formats/ssh.js#L17">https://github.com/joyent/node-sshpk/blob/v1.13.1/lib/formats/ssh.js#L17</a><br><a href="https://github.com/joyent/node-sshpk/commit/46065d38a5e6d1bccf86d3efb2fb83c14e3f9957">https://github.com/joyent/node-sshpk/commit/46065d38a5e6d1bccf86d3efb2fb83c14e3f9957</a><br><a href="https://hackerone.com/reports/319593">https://hackerone.com/reports/319593</a><br><a href="https://nvd.nist.gov/vuln/detail/CVE-2018-3737">https://nvd.nist.gov/vuln/detail/CVE-2018-3737</a><br><a href="https://www.npmjs.com/advisories/606">https://www.npmjs.com/advisories/606</a><br></details>  |
| sshpk         |    NSWG-ECO-401   |   HIGH  |  1.7.4 | &gt;=1.13.2 | <details><summary>Expand...</summary><a href="https://github.com/joyent/node-sshpk/blob/v1.13.1/lib/formats/ssh.js#L17">https://github.com/joyent/node-sshpk/blob/v1.13.1/lib/formats/ssh.js#L17</a><br><a href="https://hackerone.com/reports/319593">https://hackerone.com/reports/319593</a><br></details>  |
| sshpk         |    CVE-2018-3737   |   HIGH  |  1.8.3 | 1.13.2 | <details><summary>Expand...</summary><a href="https://github.com/advisories/GHSA-2m39-62fm-q8r3">https://github.com/advisories/GHSA-2m39-62fm-q8r3</a><br><a href="https://github.com/joyent/node-sshpk/blob/v1.13.1/lib/formats/ssh.js#L17">https://github.com/joyent/node-sshpk/blob/v1.13.1/lib/formats/ssh.js#L17</a><br><a href="https://github.com/joyent/node-sshpk/commit/46065d38a5e6d1bccf86d3efb2fb83c14e3f9957">https://github.com/joyent/node-sshpk/commit/46065d38a5e6d1bccf86d3efb2fb83c14e3f9957</a><br><a href="https://hackerone.com/reports/319593">https://hackerone.com/reports/319593</a><br><a href="https://nvd.nist.gov/vuln/detail/CVE-2018-3737">https://nvd.nist.gov/vuln/detail/CVE-2018-3737</a><br><a href="https://www.npmjs.com/advisories/606">https://www.npmjs.com/advisories/606</a><br></details>  |
| sshpk         |    NSWG-ECO-401   |   HIGH  |  1.8.3 | &gt;=1.13.2 | <details><summary>Expand...</summary><a href="https://github.com/joyent/node-sshpk/blob/v1.13.1/lib/formats/ssh.js#L17">https://github.com/joyent/node-sshpk/blob/v1.13.1/lib/formats/ssh.js#L17</a><br><a href="https://hackerone.com/reports/319593">https://hackerone.com/reports/319593</a><br></details>  |
| stringstream         |    CVE-2018-21270   |   MEDIUM  |  0.0.5 | 0.0.6 | <details><summary>Expand...</summary><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2018-21270">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2018-21270</a><br><a href="https://github.com/advisories/GHSA-mf6x-7mm4-x2g7">https://github.com/advisories/GHSA-mf6x-7mm4-x2g7</a><br><a href="https://github.com/mhart/StringStream/blob/v0.0.5/stringstream.js#L32">https://github.com/mhart/StringStream/blob/v0.0.5/stringstream.js#L32</a><br><a href="https://github.com/mhart/StringStream/commit/afbc7442220358419e330618e47f3a65fc265b1b">https://github.com/mhart/StringStream/commit/afbc7442220358419e330618e47f3a65fc265b1b</a><br><a href="https://github.com/mhart/StringStream/issues/7">https://github.com/mhart/StringStream/issues/7</a><br><a href="https://hackerone.com/reports/321670">https://hackerone.com/reports/321670</a><br><a href="https://www.npmjs.com/advisories/664">https://www.npmjs.com/advisories/664</a><br></details>  |
| stringstream         |    NSWG-ECO-422   |   MEDIUM  |  0.0.5 | &gt;=0.0.6 | <details><summary>Expand...</summary><a href="https://github.com/mhart/StringStream/blob/v0.0.5/stringstream.js#L32">https://github.com/mhart/StringStream/blob/v0.0.5/stringstream.js#L32</a><br><a href="https://hackerone.com/reports/321670">https://hackerone.com/reports/321670</a><br></details>  |
| tar         |    CVE-2018-20834   |   HIGH  |  2.2.1 | 4.4.2, 2.2.2 | <details><summary>Expand...</summary><a href="https://access.redhat.com/errata/RHSA-2019:1821">https://access.redhat.com/errata/RHSA-2019:1821</a><br><a href="https://github.com/advisories/GHSA-j44m-qm6p-hp7m">https://github.com/advisories/GHSA-j44m-qm6p-hp7m</a><br><a href="https://github.com/npm/node-tar/commit/7ecef07da6a9e72cc0c4d0c9c6a8e85b6b52395d">https://github.com/npm/node-tar/commit/7ecef07da6a9e72cc0c4d0c9c6a8e85b6b52395d</a><br><a href="https://github.com/npm/node-tar/commit/b0c58433c22f5e7fe8b1c76373f27e3f81dcd4c8">https://github.com/npm/node-tar/commit/b0c58433c22f5e7fe8b1c76373f27e3f81dcd4c8</a><br><a href="https://github.com/npm/node-tar/commits/v2.2.2">https://github.com/npm/node-tar/commits/v2.2.2</a><br><a href="https://github.com/npm/node-tar/compare/58a8d43...a5f7779">https://github.com/npm/node-tar/compare/58a8d43...a5f7779</a><br><a href="https://hackerone.com/reports/344595">https://hackerone.com/reports/344595</a><br><a href="https://nvd.nist.gov/vuln/detail/CVE-2018-20834">https://nvd.nist.gov/vuln/detail/CVE-2018-20834</a><br><a href="https://www.npmjs.com/advisories/803">https://www.npmjs.com/advisories/803</a><br></details>  |
| tar         |    CVE-2021-32803   |   HIGH  |  2.2.1 | 6.1.2, 5.0.7, 4.4.15, 3.2.3 | <details><summary>Expand...</summary><a href="https://github.com/advisories/GHSA-r628-mhmh-qjhw">https://github.com/advisories/GHSA-r628-mhmh-qjhw</a><br><a href="https://github.com/npm/node-tar/commit/9dbdeb6df8e9dbd96fa9e84341b9d74734be6c20">https://github.com/npm/node-tar/commit/9dbdeb6df8e9dbd96fa9e84341b9d74734be6c20</a><br><a href="https://github.com/npm/node-tar/security/advisories/GHSA-r628-mhmh-qjhw">https://github.com/npm/node-tar/security/advisories/GHSA-r628-mhmh-qjhw</a><br><a href="https://linux.oracle.com/cve/CVE-2021-32803.html">https://linux.oracle.com/cve/CVE-2021-32803.html</a><br><a href="https://linux.oracle.com/errata/ELSA-2021-3666.html">https://linux.oracle.com/errata/ELSA-2021-3666.html</a><br><a href="https://nvd.nist.gov/vuln/detail/CVE-2021-32803">https://nvd.nist.gov/vuln/detail/CVE-2021-32803</a><br><a href="https://www.npmjs.com/advisories/1771">https://www.npmjs.com/advisories/1771</a><br><a href="https://www.npmjs.com/package/tar">https://www.npmjs.com/package/tar</a><br><a href="https://www.oracle.com/security-alerts/cpuoct2021.html">https://www.oracle.com/security-alerts/cpuoct2021.html</a><br></details>  |
| tar         |    CVE-2021-32804   |   HIGH  |  2.2.1 | 6.1.1, 5.0.6, 4.4.14, 3.2.2 | <details><summary>Expand...</summary><a href="https://github.com/advisories/GHSA-3jfq-g458-7qm9">https://github.com/advisories/GHSA-3jfq-g458-7qm9</a><br><a href="https://github.com/npm/node-tar/commit/1f036ca23f64a547bdd6c79c1a44bc62e8115da4">https://github.com/npm/node-tar/commit/1f036ca23f64a547bdd6c79c1a44bc62e8115da4</a><br><a href="https://github.com/npm/node-tar/security/advisories/GHSA-3jfq-g458-7qm9">https://github.com/npm/node-tar/security/advisories/GHSA-3jfq-g458-7qm9</a><br><a href="https://linux.oracle.com/cve/CVE-2021-32804.html">https://linux.oracle.com/cve/CVE-2021-32804.html</a><br><a href="https://linux.oracle.com/errata/ELSA-2021-3666.html">https://linux.oracle.com/errata/ELSA-2021-3666.html</a><br><a href="https://nvd.nist.gov/vuln/detail/CVE-2021-32804">https://nvd.nist.gov/vuln/detail/CVE-2021-32804</a><br><a href="https://www.npmjs.com/advisories/1770">https://www.npmjs.com/advisories/1770</a><br><a href="https://www.npmjs.com/package/tar">https://www.npmjs.com/package/tar</a><br><a href="https://www.oracle.com/security-alerts/cpuoct2021.html">https://www.oracle.com/security-alerts/cpuoct2021.html</a><br></details>  |
| tar         |    CVE-2021-37701   |   HIGH  |  2.2.1 | 6.1.7, 5.0.8, 4.4.16 | <details><summary>Expand...</summary><a href="https://github.com/advisories/GHSA-9r2w-394v-53qc">https://github.com/advisories/GHSA-9r2w-394v-53qc</a><br><a href="https://github.com/npm/node-tar/security/advisories/GHSA-9r2w-394v-53qc">https://github.com/npm/node-tar/security/advisories/GHSA-9r2w-394v-53qc</a><br><a href="https://nvd.nist.gov/vuln/detail/CVE-2021-37701">https://nvd.nist.gov/vuln/detail/CVE-2021-37701</a><br><a href="https://www.debian.org/security/2021/dsa-5008">https://www.debian.org/security/2021/dsa-5008</a><br><a href="https://www.npmjs.com/advisories/1779">https://www.npmjs.com/advisories/1779</a><br><a href="https://www.npmjs.com/package/tar">https://www.npmjs.com/package/tar</a><br><a href="https://www.oracle.com/security-alerts/cpuoct2021.html">https://www.oracle.com/security-alerts/cpuoct2021.html</a><br></details>  |
| tar         |    CVE-2021-37712   |   HIGH  |  2.2.1 | 6.1.9, 5.0.10, 4.4.18 | <details><summary>Expand...</summary><a href="https://github.com/advisories/GHSA-qq89-hq3f-393p">https://github.com/advisories/GHSA-qq89-hq3f-393p</a><br><a href="https://github.com/npm/node-tar/security/advisories/GHSA-qq89-hq3f-393p">https://github.com/npm/node-tar/security/advisories/GHSA-qq89-hq3f-393p</a><br><a href="https://nvd.nist.gov/vuln/detail/CVE-2021-37712">https://nvd.nist.gov/vuln/detail/CVE-2021-37712</a><br><a href="https://www.debian.org/security/2021/dsa-5008">https://www.debian.org/security/2021/dsa-5008</a><br><a href="https://www.npmjs.com/advisories/1780">https://www.npmjs.com/advisories/1780</a><br><a href="https://www.npmjs.com/package/tar">https://www.npmjs.com/package/tar</a><br><a href="https://www.oracle.com/security-alerts/cpuoct2021.html">https://www.oracle.com/security-alerts/cpuoct2021.html</a><br></details>  |
| tar         |    CVE-2021-37713   |   HIGH  |  2.2.1 | 6.1.9, 5.0.10, 4.4.18 | <details><summary>Expand...</summary><a href="https://github.com/advisories/GHSA-5955-9wpr-37jh">https://github.com/advisories/GHSA-5955-9wpr-37jh</a><br><a href="https://github.com/npm/node-tar/security/advisories/GHSA-5955-9wpr-37jh">https://github.com/npm/node-tar/security/advisories/GHSA-5955-9wpr-37jh</a><br><a href="https://nvd.nist.gov/vuln/detail/CVE-2021-37713">https://nvd.nist.gov/vuln/detail/CVE-2021-37713</a><br><a href="https://www.npmjs.com/package/tar">https://www.npmjs.com/package/tar</a><br><a href="https://www.oracle.com/security-alerts/cpuoct2021.html">https://www.oracle.com/security-alerts/cpuoct2021.html</a><br></details>  |
| tough-cookie         |    CVE-2017-15010   |   HIGH  |  2.2.2 | 2.3.3 | <details><summary>Expand...</summary><a href="http://www.securityfocus.com/bid/101185">http://www.securityfocus.com/bid/101185</a><br><a href="https://access.redhat.com/errata/RHSA-2017:2912">https://access.redhat.com/errata/RHSA-2017:2912</a><br><a href="https://access.redhat.com/errata/RHSA-2017:2913">https://access.redhat.com/errata/RHSA-2017:2913</a><br><a href="https://access.redhat.com/errata/RHSA-2018:1263">https://access.redhat.com/errata/RHSA-2018:1263</a><br><a href="https://access.redhat.com/errata/RHSA-2018:1264">https://access.redhat.com/errata/RHSA-2018:1264</a><br><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2017-15010">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2017-15010</a><br><a href="https://github.com/advisories/GHSA-g7q5-pjjr-gqvp">https://github.com/advisories/GHSA-g7q5-pjjr-gqvp</a><br><a href="https://github.com/salesforce/tough-cookie/issues/92">https://github.com/salesforce/tough-cookie/issues/92</a><br><a href="https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/6VEBDTGNHVM677SLZDEHMWOP3ISMZSFT/">https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/6VEBDTGNHVM677SLZDEHMWOP3ISMZSFT/</a><br><a href="https://nodesecurity.io/advisories/525">https://nodesecurity.io/advisories/525</a><br><a href="https://nvd.nist.gov/vuln/detail/CVE-2017-15010">https://nvd.nist.gov/vuln/detail/CVE-2017-15010</a><br><a href="https://snyk.io/vuln/npm:tough-cookie:20170905">https://snyk.io/vuln/npm:tough-cookie:20170905</a><br><a href="https://www.npmjs.com/advisories/525">https://www.npmjs.com/advisories/525</a><br></details>  |
| tough-cookie         |    CVE-2016-1000232   |   MEDIUM  |  2.2.2 | &gt;=2.3.0 | <details><summary>Expand...</summary><a href="https://access.redhat.com/errata/RHSA-2016:2101">https://access.redhat.com/errata/RHSA-2016:2101</a><br><a href="https://access.redhat.com/errata/RHSA-2017:2912">https://access.redhat.com/errata/RHSA-2017:2912</a><br><a href="https://access.redhat.com/security/cve/cve-2016-1000232">https://access.redhat.com/security/cve/cve-2016-1000232</a><br><a href="https://github.com/advisories/GHSA-qhv9-728r-6jqg">https://github.com/advisories/GHSA-qhv9-728r-6jqg</a><br><a href="https://github.com/salesforce/tough-cookie/commit/615627206357d997d5e6ff9da158997de05235ae">https://github.com/salesforce/tough-cookie/commit/615627206357d997d5e6ff9da158997de05235ae</a><br><a href="https://github.com/salesforce/tough-cookie/commit/e4fc2e0f9ee1b7a818d68f0ac7ea696f377b1534">https://github.com/salesforce/tough-cookie/commit/e4fc2e0f9ee1b7a818d68f0ac7ea696f377b1534</a><br><a href="https://nodesecurity.io/advisories/130">https://nodesecurity.io/advisories/130</a><br><a href="https://nvd.nist.gov/vuln/detail/CVE-2016-1000232">https://nvd.nist.gov/vuln/detail/CVE-2016-1000232</a><br><a href="https://www.ibm.com/blogs/psirt/ibm-security-bulletin-ibm-api-connect-is-affected-by-node-js-tough-cookie-module-vulnerability-to-a-denial-of-service-cve-2016-1000232/">https://www.ibm.com/blogs/psirt/ibm-security-bulletin-ibm-api-connect-is-affected-by-node-js-tough-cookie-module-vulnerability-to-a-denial-of-service-cve-2016-1000232/</a><br><a href="https://www.npmjs.com/advisories/130">https://www.npmjs.com/advisories/130</a><br></details>  |
| tunnel-agent         |    GHSA-xc7v-wxcw-j472   |   MEDIUM  |  0.4.2 | 0.6.0 | <details><summary>Expand...</summary><a href="https://gist.github.com/ChALkeR/fd6b2c445834244e7d440a043f9d2ff4">https://gist.github.com/ChALkeR/fd6b2c445834244e7d440a043f9d2ff4</a><br><a href="https://github.com/advisories/GHSA-xc7v-wxcw-j472">https://github.com/advisories/GHSA-xc7v-wxcw-j472</a><br><a href="https://github.com/request/tunnel-agent/commit/9ca95ec7219daface8a6fc2674000653de0922c0">https://github.com/request/tunnel-agent/commit/9ca95ec7219daface8a6fc2674000653de0922c0</a><br><a href="https://www.npmjs.com/advisories/598">https://www.npmjs.com/advisories/598</a><br></details>  |
| tunnel-agent         |    NSWG-ECO-393   |   MEDIUM  |  0.4.2 | &gt;=0.6.0 | <details><summary>Expand...</summary><a href="https://gist.github.com/ChALkeR/fd6b2c445834244e7d440a043f9d2ff4">https://gist.github.com/ChALkeR/fd6b2c445834244e7d440a043f9d2ff4</a><br><a href="https://github.com/request/tunnel-agent/commit/9ca95ec7219daface8a6fc2674000653de0922c0">https://github.com/request/tunnel-agent/commit/9ca95ec7219daface8a6fc2674000653de0922c0</a><br></details>  |
| tunnel-agent         |    GHSA-xc7v-wxcw-j472   |   MEDIUM  |  0.4.3 | 0.6.0 | <details><summary>Expand...</summary><a href="https://gist.github.com/ChALkeR/fd6b2c445834244e7d440a043f9d2ff4">https://gist.github.com/ChALkeR/fd6b2c445834244e7d440a043f9d2ff4</a><br><a href="https://github.com/advisories/GHSA-xc7v-wxcw-j472">https://github.com/advisories/GHSA-xc7v-wxcw-j472</a><br><a href="https://github.com/request/tunnel-agent/commit/9ca95ec7219daface8a6fc2674000653de0922c0">https://github.com/request/tunnel-agent/commit/9ca95ec7219daface8a6fc2674000653de0922c0</a><br><a href="https://www.npmjs.com/advisories/598">https://www.npmjs.com/advisories/598</a><br></details>  |
| tunnel-agent         |    NSWG-ECO-393   |   MEDIUM  |  0.4.3 | &gt;=0.6.0 | <details><summary>Expand...</summary><a href="https://gist.github.com/ChALkeR/fd6b2c445834244e7d440a043f9d2ff4">https://gist.github.com/ChALkeR/fd6b2c445834244e7d440a043f9d2ff4</a><br><a href="https://github.com/request/tunnel-agent/commit/9ca95ec7219daface8a6fc2674000653de0922c0">https://github.com/request/tunnel-agent/commit/9ca95ec7219daface8a6fc2674000653de0922c0</a><br></details>  |
| ua-parser-js         |    CVE-2021-27292   |   HIGH  |  0.7.22 | 0.7.24 | <details><summary>Expand...</summary><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2021-27292">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2021-27292</a><br><a href="https://gist.github.com/b-c-ds/6941d80d6b4e694df4bc269493b7be76">https://gist.github.com/b-c-ds/6941d80d6b4e694df4bc269493b7be76</a><br><a href="https://github.com/advisories/GHSA-78cj-fxph-m83p">https://github.com/advisories/GHSA-78cj-fxph-m83p</a><br><a href="https://github.com/faisalman/ua-parser-js/commit/809439e20e273ce0d25c1d04e111dcf6011eb566">https://github.com/faisalman/ua-parser-js/commit/809439e20e273ce0d25c1d04e111dcf6011eb566</a><br><a href="https://github.com/pygments/pygments/commit/2e7e8c4a7b318f4032493773732754e418279a14">https://github.com/pygments/pygments/commit/2e7e8c4a7b318f4032493773732754e418279a14</a><br><a href="https://nvd.nist.gov/vuln/detail/CVE-2021-27292">https://nvd.nist.gov/vuln/detail/CVE-2021-27292</a><br></details>  |
| underscore.string         |    GHSA-v2p6-4mp7-3r9v   |   MEDIUM  |  2.3.3 | 3.3.5 | <details><summary>Expand...</summary><a href="https://github.com/advisories/GHSA-v2p6-4mp7-3r9v">https://github.com/advisories/GHSA-v2p6-4mp7-3r9v</a><br><a href="https://github.com/epeli/underscore.string/commit/f486cd684c94c12db48b45d52b1472a1b9661029">https://github.com/epeli/underscore.string/commit/f486cd684c94c12db48b45d52b1472a1b9661029</a><br><a href="https://github.com/epeli/underscore.string/issues/510">https://github.com/epeli/underscore.string/issues/510</a><br><a href="https://github.com/epeli/underscore.string/pull/517">https://github.com/epeli/underscore.string/pull/517</a><br><a href="https://www.npmjs.com/advisories/745">https://www.npmjs.com/advisories/745</a><br></details>  |
| validator         |    CVE-2014-8882   |   HIGH  |  1.5.1 | &gt;=3.22.1 | <details><summary>Expand...</summary><a href="http://en.wikipedia.org/wiki/ReDoS">http://en.wikipedia.org/wiki/ReDoS</a><br><a href="http://lab.cs.ttu.ee/dl93)">http://lab.cs.ttu.ee/dl93)</a><br><a href="https://github.com/advisories/GHSA-f5w6-r7rg-mcgq">https://github.com/advisories/GHSA-f5w6-r7rg-mcgq</a><br><a href="https://github.com/chriso/validator.js/issues/152#issuecomment-48107184">https://github.com/chriso/validator.js/issues/152#issuecomment-48107184</a><br><a href="https://nvd.nist.gov/vuln/detail/CVE-2014-8882">https://nvd.nist.gov/vuln/detail/CVE-2014-8882</a><br><a href="https://snyk.io/vuln/npm:validator:20130705">https://snyk.io/vuln/npm:validator:20130705</a><br><a href="https://www.npmjs.com/advisories/42">https://www.npmjs.com/advisories/42</a><br></details>  |
| validator         |    CVE-2021-3765   |   HIGH  |  1.5.1 | 13.7.0 | <details><summary>Expand...</summary><a href="https://github.com/advisories/GHSA-qgmg-gppg-76g5">https://github.com/advisories/GHSA-qgmg-gppg-76g5</a><br><a href="https://github.com/validatorjs/validator.js/commit/496fc8b2a7f5997acaaec33cc44d0b8dba5fb5e1">https://github.com/validatorjs/validator.js/commit/496fc8b2a7f5997acaaec33cc44d0b8dba5fb5e1</a><br><a href="https://huntr.dev/bounties/c37e975c-21a3-4c5f-9b57-04d63b28cfc9">https://huntr.dev/bounties/c37e975c-21a3-4c5f-9b57-04d63b28cfc9</a><br><a href="https://nvd.nist.gov/vuln/detail/CVE-2021-3765">https://nvd.nist.gov/vuln/detail/CVE-2021-3765</a><br></details>  |
| validator         |    CVE-2014-9772   |   MEDIUM  |  1.5.1 | &gt;=2.0.0 | <details><summary>Expand...</summary><a href="http://www.openwall.com/lists/oss-security/2016/04/20/11">http://www.openwall.com/lists/oss-security/2016/04/20/11</a><br><a href="http://www.securityfocus.com/bid/97102">http://www.securityfocus.com/bid/97102</a><br><a href="https://github.com/advisories/GHSA-79mx-88w7-8f7q">https://github.com/advisories/GHSA-79mx-88w7-8f7q</a><br><a href="https://github.com/chriso/validator.js/issues/181">https://github.com/chriso/validator.js/issues/181</a><br><a href="https://nodesecurity.io/advisories/43">https://nodesecurity.io/advisories/43</a><br><a href="https://nvd.nist.gov/vuln/detail/CVE-2014-9772">https://nvd.nist.gov/vuln/detail/CVE-2014-9772</a><br><a href="https://www.npmjs.com/advisories/43">https://www.npmjs.com/advisories/43</a><br></details>  |
| ws         |    CVE-2016-10542   |   HIGH  |  1.0.1 | 1.1.1 | <details><summary>Expand...</summary><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2016-10542">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2016-10542</a><br><a href="https://github.com/advisories/GHSA-6663-c963-2gqg">https://github.com/advisories/GHSA-6663-c963-2gqg</a><br><a href="https://github.com/nodejs/node/issues/7388">https://github.com/nodejs/node/issues/7388</a><br><a href="https://nodesecurity.io/advisories/120">https://nodesecurity.io/advisories/120</a><br><a href="https://nvd.nist.gov/vuln/detail/CVE-2016-10542">https://nvd.nist.gov/vuln/detail/CVE-2016-10542</a><br><a href="https://www.npmjs.com/advisories/120">https://www.npmjs.com/advisories/120</a><br></details>  |
| ws         |    GHSA-5v72-xg48-5rpm   |   HIGH  |  1.0.1 | 3.3.1, 1.1.5 | <details><summary>Expand...</summary><a href="https://github.com/advisories/GHSA-5v72-xg48-5rpm">https://github.com/advisories/GHSA-5v72-xg48-5rpm</a><br><a href="https://github.com/websockets/ws/commit/c4fe46608acd61fbf7397eadc47378903f95b78a">https://github.com/websockets/ws/commit/c4fe46608acd61fbf7397eadc47378903f95b78a</a><br><a href="https://nodesecurity.io/advisories/550">https://nodesecurity.io/advisories/550</a><br><a href="https://snyk.io/vuln/npm:ws:20171108">https://snyk.io/vuln/npm:ws:20171108</a><br><a href="https://www.npmjs.com/advisories/550">https://www.npmjs.com/advisories/550</a><br><a href="https://www.npmjs.com/advisories/550/versions">https://www.npmjs.com/advisories/550/versions</a><br></details>  |
| ws         |    NSWG-ECO-120   |   HIGH  |  1.0.1 | &gt;=1.1.1 | <details><summary>Expand...</summary><a href="https://github.com/nodejs/node/issues/7388">https://github.com/nodejs/node/issues/7388</a><br></details>  |
| xmlhttprequest-ssl         |    CVE-2021-31597   |   CRITICAL  |  1.5.1 | 1.6.1 | <details><summary>Expand...</summary><a href="https://github.com/advisories/GHSA-72mh-269x-7mh5">https://github.com/advisories/GHSA-72mh-269x-7mh5</a><br><a href="https://github.com/mjwwit/node-XMLHttpRequest/commit/bf53329b61ca6afc5d28f6b8d2dc2e3ca740a9b2">https://github.com/mjwwit/node-XMLHttpRequest/commit/bf53329b61ca6afc5d28f6b8d2dc2e3ca740a9b2</a><br><a href="https://github.com/mjwwit/node-XMLHttpRequest/compare/v1.6.0...1.6.1">https://github.com/mjwwit/node-XMLHttpRequest/compare/v1.6.0...1.6.1</a><br><a href="https://nvd.nist.gov/vuln/detail/CVE-2021-31597">https://nvd.nist.gov/vuln/detail/CVE-2021-31597</a><br><a href="https://people.kingsds.network/wesgarland/xmlhttprequest-ssl-vuln.txt">https://people.kingsds.network/wesgarland/xmlhttprequest-ssl-vuln.txt</a><br><a href="https://security.netapp.com/advisory/ntap-20210618-0004/">https://security.netapp.com/advisory/ntap-20210618-0004/</a><br></details>  |
| xmlhttprequest-ssl         |    CVE-2020-28502   |   HIGH  |  1.5.1 | 1.6.2 | <details><summary>Expand...</summary><a href="https://github.com/advisories/GHSA-h4j5-c7cj-74xg">https://github.com/advisories/GHSA-h4j5-c7cj-74xg</a><br><a href="https://github.com/driverdan/node-XMLHttpRequest/blob/1.6.0/lib/XMLHttpRequest.js#L480">https://github.com/driverdan/node-XMLHttpRequest/blob/1.6.0/lib/XMLHttpRequest.js#L480</a><br><a href="https://github.com/driverdan/node-XMLHttpRequest/blob/1.6.0/lib/XMLHttpRequest.js%23L480">https://github.com/driverdan/node-XMLHttpRequest/blob/1.6.0/lib/XMLHttpRequest.js%23L480</a><br><a href="https://github.com/driverdan/node-XMLHttpRequest/commit/983cfc244c7567ad6a59e366e55a8037e0497fe6">https://github.com/driverdan/node-XMLHttpRequest/commit/983cfc244c7567ad6a59e366e55a8037e0497fe6</a><br><a href="https://github.com/mjwwit/node-XMLHttpRequest/blob/ae38832a0f1347c5e96dda665402509a3458e302/lib/XMLHttpRequest.js#L531">https://github.com/mjwwit/node-XMLHttpRequest/blob/ae38832a0f1347c5e96dda665402509a3458e302/lib/XMLHttpRequest.js#L531</a><br><a href="https://github.com/mjwwit/node-XMLHttpRequest/commit/ee1e81fc67729c7c0eba5537ed7fe1e30a6b3291">https://github.com/mjwwit/node-XMLHttpRequest/commit/ee1e81fc67729c7c0eba5537ed7fe1e30a6b3291</a><br><a href="https://nvd.nist.gov/vuln/detail/CVE-2020-28502">https://nvd.nist.gov/vuln/detail/CVE-2020-28502</a><br><a href="https://snyk.io/vuln/SNYK-JAVA-ORGWEBJARSNPM-1082937">https://snyk.io/vuln/SNYK-JAVA-ORGWEBJARSNPM-1082937</a><br><a href="https://snyk.io/vuln/SNYK-JAVA-ORGWEBJARSNPM-1082938">https://snyk.io/vuln/SNYK-JAVA-ORGWEBJARSNPM-1082938</a><br><a href="https://snyk.io/vuln/SNYK-JS-XMLHTTPREQUEST-1082935">https://snyk.io/vuln/SNYK-JS-XMLHTTPREQUEST-1082935</a><br><a href="https://snyk.io/vuln/SNYK-JS-XMLHTTPREQUESTSSL-1082936">https://snyk.io/vuln/SNYK-JS-XMLHTTPREQUESTSSL-1082936</a><br></details>  |

**gobinary**

      
| No Vulnerabilities found         |
|:---------------------------------|

      

**gobinary**

      
| Package         |    Vulnerability   |   Severity  |  Installed Version | Fixed Version |                   Links                   |
|:----------------|:------------------:|:-----------:|:------------------:|:-------------:|-----------------------------------------|
| github.com/containerd/containerd         |    CVE-2021-41103   |   HIGH  |  v1.5.4 | v1.4.11, v1.5.7 | <details><summary>Expand...</summary><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2021-41103">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2021-41103</a><br><a href="https://github.com/containerd/containerd/commit/5b46e404f6b9f661a205e28d59c982d3634148f8">https://github.com/containerd/containerd/commit/5b46e404f6b9f661a205e28d59c982d3634148f8</a><br><a href="https://github.com/containerd/containerd/security/advisories/GHSA-c2h3-6mxw-7mvq">https://github.com/containerd/containerd/security/advisories/GHSA-c2h3-6mxw-7mvq</a><br><a href="https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/B5Q6G6I4W5COQE25QMC7FJY3I3PAYFBB/">https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/B5Q6G6I4W5COQE25QMC7FJY3I3PAYFBB/</a><br><a href="https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/ZNFADTCHHYWVM6W4NJ6CB4FNFM2VMBIB/">https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/ZNFADTCHHYWVM6W4NJ6CB4FNFM2VMBIB/</a><br><a href="https://nvd.nist.gov/vuln/detail/CVE-2021-41103">https://nvd.nist.gov/vuln/detail/CVE-2021-41103</a><br><a href="https://ubuntu.com/security/notices/USN-5100-1">https://ubuntu.com/security/notices/USN-5100-1</a><br><a href="https://www.debian.org/security/2021/dsa-5002">https://www.debian.org/security/2021/dsa-5002</a><br></details>  |
| github.com/docker/cli         |    CVE-2021-41092   |   HIGH  |  v20.10.3-0.20210702143511-f782d1355eff+incompatible | v20.10.9 | <details><summary>Expand...</summary><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2021-41092">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2021-41092</a><br><a href="https://github.com/docker/cli/commit/893e52cf4ba4b048d72e99748e0f86b2767c6c6b">https://github.com/docker/cli/commit/893e52cf4ba4b048d72e99748e0f86b2767c6c6b</a><br><a href="https://github.com/docker/cli/security/advisories/GHSA-99pg-grm5-qq3v">https://github.com/docker/cli/security/advisories/GHSA-99pg-grm5-qq3v</a><br><a href="https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/B5Q6G6I4W5COQE25QMC7FJY3I3PAYFBB/">https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/B5Q6G6I4W5COQE25QMC7FJY3I3PAYFBB/</a><br><a href="https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/ZNFADTCHHYWVM6W4NJ6CB4FNFM2VMBIB/">https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/ZNFADTCHHYWVM6W4NJ6CB4FNFM2VMBIB/</a><br><a href="https://nvd.nist.gov/vuln/detail/CVE-2021-41092">https://nvd.nist.gov/vuln/detail/CVE-2021-41092</a><br><a href="https://ubuntu.com/security/notices/USN-5134-1">https://ubuntu.com/security/notices/USN-5134-1</a><br></details>  |
| golang.org/x/text         |    CVE-2021-38561   |   UNKNOWN  |  v0.3.4 | 0.3.7 | <details><summary>Expand...</summary></details>  |

