---
hide:
  - toc
---

# Security Overview

<link href="https://truecharts.org/_static/trivy.css" type="text/css" rel="stylesheet" />

## Helm-Chart

##### Scan Results

#### Chart Object: lidarr/templates/common.yaml
    

      
| Type         |    Misconfiguration ID   |   Check  |  Severity |                   Explaination                   | Links  |
|:----------------|:------------------:|:-----------:|:------------------:|-----------------------------------------|-----------------------------------------|
| Kubernetes Security Check         |    KSV003   |   Default capabilities not dropped  |  LOW | <details><summary>Expand...</summary> The container should drop all default capabilities and add only those that are needed for its execution. <br> <hr> <br> Container &#39;RELEASE-NAME-lidarr&#39; of Deployment &#39;RELEASE-NAME-lidarr&#39; should add &#39;ALL&#39; to &#39;securityContext.capabilities.drop&#39; </details>| <details><summary>Expand...</summary><a href="https://kubesec.io/basics/containers-securitycontext-capabilities-drop-index-all/">https://kubesec.io/basics/containers-securitycontext-capabilities-drop-index-all/</a><br><a href="https://avd.aquasec.com/appshield/ksv003">https://avd.aquasec.com/appshield/ksv003</a><br></details>  |
| Kubernetes Security Check         |    KSV012   |   Runs as root user  |  MEDIUM | <details><summary>Expand...</summary> &#39;runAsNonRoot&#39; forces the running image to run as a non-root user to ensure least privileges. <br> <hr> <br> Container &#39;autopermissions&#39; of Deployment &#39;RELEASE-NAME-lidarr&#39; should set &#39;securityContext.runAsNonRoot&#39; to true </details>| <details><summary>Expand...</summary><a href="https://kubernetes.io/docs/concepts/security/pod-security-standards/#restricted">https://kubernetes.io/docs/concepts/security/pod-security-standards/#restricted</a><br><a href="https://avd.aquasec.com/appshield/ksv012">https://avd.aquasec.com/appshield/ksv012</a><br></details>  |
| Kubernetes Security Check         |    KSV014   |   Root file system is not read-only  |  LOW | <details><summary>Expand...</summary> An immutable root file system prevents applications from writing to their local disk. This can limit intrusions, as attackers will not be able to tamper with the file system or write foreign executables to disk. <br> <hr> <br> Container &#39;RELEASE-NAME-lidarr&#39; of Deployment &#39;RELEASE-NAME-lidarr&#39; should set &#39;securityContext.readOnlyRootFilesystem&#39; to true </details>| <details><summary>Expand...</summary><a href="https://kubesec.io/basics/containers-securitycontext-readonlyrootfilesystem-true/">https://kubesec.io/basics/containers-securitycontext-readonlyrootfilesystem-true/</a><br><a href="https://avd.aquasec.com/appshield/ksv014">https://avd.aquasec.com/appshield/ksv014</a><br></details>  |
| Kubernetes Security Check         |    KSV014   |   Root file system is not read-only  |  LOW | <details><summary>Expand...</summary> An immutable root file system prevents applications from writing to their local disk. This can limit intrusions, as attackers will not be able to tamper with the file system or write foreign executables to disk. <br> <hr> <br> Container &#39;autopermissions&#39; of Deployment &#39;RELEASE-NAME-lidarr&#39; should set &#39;securityContext.readOnlyRootFilesystem&#39; to true </details>| <details><summary>Expand...</summary><a href="https://kubesec.io/basics/containers-securitycontext-readonlyrootfilesystem-true/">https://kubesec.io/basics/containers-securitycontext-readonlyrootfilesystem-true/</a><br><a href="https://avd.aquasec.com/appshield/ksv014">https://avd.aquasec.com/appshield/ksv014</a><br></details>  |
| Kubernetes Security Check         |    KSV020   |   Runs with low user ID  |  MEDIUM | <details><summary>Expand...</summary> Force the container to run with user ID &gt; 10000 to avoid conflicts with the host’s user table. <br> <hr> <br> Container &#39;RELEASE-NAME-lidarr&#39; of Deployment &#39;RELEASE-NAME-lidarr&#39; should set &#39;securityContext.runAsUser&#39; &gt; 10000 </details>| <details><summary>Expand...</summary><a href="https://kubesec.io/basics/containers-securitycontext-runasuser/">https://kubesec.io/basics/containers-securitycontext-runasuser/</a><br><a href="https://avd.aquasec.com/appshield/ksv020">https://avd.aquasec.com/appshield/ksv020</a><br></details>  |
| Kubernetes Security Check         |    KSV020   |   Runs with low user ID  |  MEDIUM | <details><summary>Expand...</summary> Force the container to run with user ID &gt; 10000 to avoid conflicts with the host’s user table. <br> <hr> <br> Container &#39;autopermissions&#39; of Deployment &#39;RELEASE-NAME-lidarr&#39; should set &#39;securityContext.runAsUser&#39; &gt; 10000 </details>| <details><summary>Expand...</summary><a href="https://kubesec.io/basics/containers-securitycontext-runasuser/">https://kubesec.io/basics/containers-securitycontext-runasuser/</a><br><a href="https://avd.aquasec.com/appshield/ksv020">https://avd.aquasec.com/appshield/ksv020</a><br></details>  |
| Kubernetes Security Check         |    KSV021   |   Runs with low group ID  |  MEDIUM | <details><summary>Expand...</summary> Force the container to run with group ID &gt; 10000 to avoid conflicts with the host’s user table. <br> <hr> <br> Container &#39;RELEASE-NAME-lidarr&#39; of Deployment &#39;RELEASE-NAME-lidarr&#39; should set &#39;securityContext.runAsGroup&#39; &gt; 10000 </details>| <details><summary>Expand...</summary><a href="https://kubesec.io/basics/containers-securitycontext-runasuser/">https://kubesec.io/basics/containers-securitycontext-runasuser/</a><br><a href="https://avd.aquasec.com/appshield/ksv021">https://avd.aquasec.com/appshield/ksv021</a><br></details>  |
| Kubernetes Security Check         |    KSV021   |   Runs with low group ID  |  MEDIUM | <details><summary>Expand...</summary> Force the container to run with group ID &gt; 10000 to avoid conflicts with the host’s user table. <br> <hr> <br> Container &#39;autopermissions&#39; of Deployment &#39;RELEASE-NAME-lidarr&#39; should set &#39;securityContext.runAsGroup&#39; &gt; 10000 </details>| <details><summary>Expand...</summary><a href="https://kubesec.io/basics/containers-securitycontext-runasuser/">https://kubesec.io/basics/containers-securitycontext-runasuser/</a><br><a href="https://avd.aquasec.com/appshield/ksv021">https://avd.aquasec.com/appshield/ksv021</a><br></details>  |
| Kubernetes Security Check         |    KSV029   |   A root primary or supplementary GID set  |  LOW | <details><summary>Expand...</summary> Containers should be forbidden from running with a root primary or supplementary GID. <br> <hr> <br> Deployment &#39;RELEASE-NAME-lidarr&#39; should set &#39;spec.securityContext.runAsGroup&#39;, &#39;spec.securityContext.supplementalGroups[*]&#39; and &#39;spec.securityContext.fsGroup&#39; to integer greater than 0 </details>| <details><summary>Expand...</summary><a href="https://kubernetes.io/docs/concepts/security/pod-security-standards/#restricted">https://kubernetes.io/docs/concepts/security/pod-security-standards/#restricted</a><br><a href="https://avd.aquasec.com/appshield/ksv029">https://avd.aquasec.com/appshield/ksv029</a><br></details>  |

## Containers

##### Detected Containers

          tccr.io/truecharts/alpine:v3.14.2@sha256:4095394abbae907e94b1f2fd2e2de6c4f201a5b9704573243ca8eb16db8cdb7c
          tccr.io/truecharts/lidarr:v1.0.0.2385@sha256:cce6c8cf6531583772881c4dacfb9021edac566c15a326722bd695509c31ce5c

##### Scan Results


#### Container: tccr.io/truecharts/alpine:v3.14.2@sha256:4095394abbae907e94b1f2fd2e2de6c4f201a5b9704573243ca8eb16db8cdb7c (alpine 3.14.2)
    

**alpine**

      
| Package         |    Vulnerability   |   Severity  |  Installed Version | Fixed Version |                   Links                   |
|:----------------|:------------------:|:-----------:|:------------------:|:-------------:|-----------------------------------------|
| busybox         |    CVE-2021-42378   |   HIGH  |  1.33.1-r3 | 1.33.1-r6 | <details><summary>Expand...</summary><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2021-42378">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2021-42378</a><br><a href="https://jfrog.com/blog/unboxing-busybox-14-new-vulnerabilities-uncovered-by-claroty-and-jfrog/">https://jfrog.com/blog/unboxing-busybox-14-new-vulnerabilities-uncovered-by-claroty-and-jfrog/</a><br><a href="https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/6T2TURBYYJGBMQTTN2DSOAIQGP7WCPGV/">https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/6T2TURBYYJGBMQTTN2DSOAIQGP7WCPGV/</a><br><a href="https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/UQXGOGWBIYWOIVXJVRKHZR34UMEHQBXS/">https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/UQXGOGWBIYWOIVXJVRKHZR34UMEHQBXS/</a><br><a href="https://ubuntu.com/security/notices/USN-5179-1">https://ubuntu.com/security/notices/USN-5179-1</a><br></details>  |
| busybox         |    CVE-2021-42379   |   HIGH  |  1.33.1-r3 | 1.33.1-r6 | <details><summary>Expand...</summary><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2021-42379">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2021-42379</a><br><a href="https://jfrog.com/blog/unboxing-busybox-14-new-vulnerabilities-uncovered-by-claroty-and-jfrog/">https://jfrog.com/blog/unboxing-busybox-14-new-vulnerabilities-uncovered-by-claroty-and-jfrog/</a><br><a href="https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/6T2TURBYYJGBMQTTN2DSOAIQGP7WCPGV/">https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/6T2TURBYYJGBMQTTN2DSOAIQGP7WCPGV/</a><br><a href="https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/UQXGOGWBIYWOIVXJVRKHZR34UMEHQBXS/">https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/UQXGOGWBIYWOIVXJVRKHZR34UMEHQBXS/</a><br><a href="https://ubuntu.com/security/notices/USN-5179-1">https://ubuntu.com/security/notices/USN-5179-1</a><br></details>  |
| busybox         |    CVE-2021-42380   |   HIGH  |  1.33.1-r3 | 1.33.1-r6 | <details><summary>Expand...</summary><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2021-42380">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2021-42380</a><br><a href="https://jfrog.com/blog/unboxing-busybox-14-new-vulnerabilities-uncovered-by-claroty-and-jfrog/">https://jfrog.com/blog/unboxing-busybox-14-new-vulnerabilities-uncovered-by-claroty-and-jfrog/</a><br><a href="https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/6T2TURBYYJGBMQTTN2DSOAIQGP7WCPGV/">https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/6T2TURBYYJGBMQTTN2DSOAIQGP7WCPGV/</a><br><a href="https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/UQXGOGWBIYWOIVXJVRKHZR34UMEHQBXS/">https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/UQXGOGWBIYWOIVXJVRKHZR34UMEHQBXS/</a><br><a href="https://ubuntu.com/security/notices/USN-5179-1">https://ubuntu.com/security/notices/USN-5179-1</a><br></details>  |
| busybox         |    CVE-2021-42381   |   HIGH  |  1.33.1-r3 | 1.33.1-r6 | <details><summary>Expand...</summary><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2021-42381">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2021-42381</a><br><a href="https://jfrog.com/blog/unboxing-busybox-14-new-vulnerabilities-uncovered-by-claroty-and-jfrog/">https://jfrog.com/blog/unboxing-busybox-14-new-vulnerabilities-uncovered-by-claroty-and-jfrog/</a><br><a href="https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/6T2TURBYYJGBMQTTN2DSOAIQGP7WCPGV/">https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/6T2TURBYYJGBMQTTN2DSOAIQGP7WCPGV/</a><br><a href="https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/UQXGOGWBIYWOIVXJVRKHZR34UMEHQBXS/">https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/UQXGOGWBIYWOIVXJVRKHZR34UMEHQBXS/</a><br><a href="https://ubuntu.com/security/notices/USN-5179-1">https://ubuntu.com/security/notices/USN-5179-1</a><br></details>  |
| busybox         |    CVE-2021-42382   |   HIGH  |  1.33.1-r3 | 1.33.1-r6 | <details><summary>Expand...</summary><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2021-42382">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2021-42382</a><br><a href="https://jfrog.com/blog/unboxing-busybox-14-new-vulnerabilities-uncovered-by-claroty-and-jfrog/">https://jfrog.com/blog/unboxing-busybox-14-new-vulnerabilities-uncovered-by-claroty-and-jfrog/</a><br><a href="https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/6T2TURBYYJGBMQTTN2DSOAIQGP7WCPGV/">https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/6T2TURBYYJGBMQTTN2DSOAIQGP7WCPGV/</a><br><a href="https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/UQXGOGWBIYWOIVXJVRKHZR34UMEHQBXS/">https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/UQXGOGWBIYWOIVXJVRKHZR34UMEHQBXS/</a><br><a href="https://ubuntu.com/security/notices/USN-5179-1">https://ubuntu.com/security/notices/USN-5179-1</a><br></details>  |
| busybox         |    CVE-2021-42383   |   HIGH  |  1.33.1-r3 | 1.33.1-r6 | <details><summary>Expand...</summary><a href="https://jfrog.com/blog/unboxing-busybox-14-new-vulnerabilities-uncovered-by-claroty-and-jfrog/">https://jfrog.com/blog/unboxing-busybox-14-new-vulnerabilities-uncovered-by-claroty-and-jfrog/</a><br><a href="https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/6T2TURBYYJGBMQTTN2DSOAIQGP7WCPGV/">https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/6T2TURBYYJGBMQTTN2DSOAIQGP7WCPGV/</a><br><a href="https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/UQXGOGWBIYWOIVXJVRKHZR34UMEHQBXS/">https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/UQXGOGWBIYWOIVXJVRKHZR34UMEHQBXS/</a><br></details>  |
| busybox         |    CVE-2021-42384   |   HIGH  |  1.33.1-r3 | 1.33.1-r6 | <details><summary>Expand...</summary><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2021-42384">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2021-42384</a><br><a href="https://jfrog.com/blog/unboxing-busybox-14-new-vulnerabilities-uncovered-by-claroty-and-jfrog/">https://jfrog.com/blog/unboxing-busybox-14-new-vulnerabilities-uncovered-by-claroty-and-jfrog/</a><br><a href="https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/6T2TURBYYJGBMQTTN2DSOAIQGP7WCPGV/">https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/6T2TURBYYJGBMQTTN2DSOAIQGP7WCPGV/</a><br><a href="https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/UQXGOGWBIYWOIVXJVRKHZR34UMEHQBXS/">https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/UQXGOGWBIYWOIVXJVRKHZR34UMEHQBXS/</a><br><a href="https://ubuntu.com/security/notices/USN-5179-1">https://ubuntu.com/security/notices/USN-5179-1</a><br></details>  |
| busybox         |    CVE-2021-42385   |   HIGH  |  1.33.1-r3 | 1.33.1-r6 | <details><summary>Expand...</summary><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2021-42385">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2021-42385</a><br><a href="https://jfrog.com/blog/unboxing-busybox-14-new-vulnerabilities-uncovered-by-claroty-and-jfrog/">https://jfrog.com/blog/unboxing-busybox-14-new-vulnerabilities-uncovered-by-claroty-and-jfrog/</a><br><a href="https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/6T2TURBYYJGBMQTTN2DSOAIQGP7WCPGV/">https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/6T2TURBYYJGBMQTTN2DSOAIQGP7WCPGV/</a><br><a href="https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/UQXGOGWBIYWOIVXJVRKHZR34UMEHQBXS/">https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/UQXGOGWBIYWOIVXJVRKHZR34UMEHQBXS/</a><br><a href="https://ubuntu.com/security/notices/USN-5179-1">https://ubuntu.com/security/notices/USN-5179-1</a><br></details>  |
| busybox         |    CVE-2021-42386   |   HIGH  |  1.33.1-r3 | 1.33.1-r6 | <details><summary>Expand...</summary><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2021-42386">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2021-42386</a><br><a href="https://jfrog.com/blog/unboxing-busybox-14-new-vulnerabilities-uncovered-by-claroty-and-jfrog/">https://jfrog.com/blog/unboxing-busybox-14-new-vulnerabilities-uncovered-by-claroty-and-jfrog/</a><br><a href="https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/6T2TURBYYJGBMQTTN2DSOAIQGP7WCPGV/">https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/6T2TURBYYJGBMQTTN2DSOAIQGP7WCPGV/</a><br><a href="https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/UQXGOGWBIYWOIVXJVRKHZR34UMEHQBXS/">https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/UQXGOGWBIYWOIVXJVRKHZR34UMEHQBXS/</a><br><a href="https://ubuntu.com/security/notices/USN-5179-1">https://ubuntu.com/security/notices/USN-5179-1</a><br></details>  |
| busybox         |    CVE-2021-42374   |   MEDIUM  |  1.33.1-r3 | 1.33.1-r4 | <details><summary>Expand...</summary><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2021-42374">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2021-42374</a><br><a href="https://jfrog.com/blog/unboxing-busybox-14-new-vulnerabilities-uncovered-by-claroty-and-jfrog/">https://jfrog.com/blog/unboxing-busybox-14-new-vulnerabilities-uncovered-by-claroty-and-jfrog/</a><br><a href="https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/6T2TURBYYJGBMQTTN2DSOAIQGP7WCPGV/">https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/6T2TURBYYJGBMQTTN2DSOAIQGP7WCPGV/</a><br><a href="https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/UQXGOGWBIYWOIVXJVRKHZR34UMEHQBXS/">https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/UQXGOGWBIYWOIVXJVRKHZR34UMEHQBXS/</a><br><a href="https://ubuntu.com/security/notices/USN-5179-1">https://ubuntu.com/security/notices/USN-5179-1</a><br></details>  |
| busybox         |    CVE-2021-42375   |   MEDIUM  |  1.33.1-r3 | 1.33.1-r5 | <details><summary>Expand...</summary><a href="https://jfrog.com/blog/unboxing-busybox-14-new-vulnerabilities-uncovered-by-claroty-and-jfrog/">https://jfrog.com/blog/unboxing-busybox-14-new-vulnerabilities-uncovered-by-claroty-and-jfrog/</a><br><a href="https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/6T2TURBYYJGBMQTTN2DSOAIQGP7WCPGV/">https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/6T2TURBYYJGBMQTTN2DSOAIQGP7WCPGV/</a><br><a href="https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/UQXGOGWBIYWOIVXJVRKHZR34UMEHQBXS/">https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/UQXGOGWBIYWOIVXJVRKHZR34UMEHQBXS/</a><br></details>  |
| ssl_client         |    CVE-2021-42378   |   HIGH  |  1.33.1-r3 | 1.33.1-r6 | <details><summary>Expand...</summary><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2021-42378">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2021-42378</a><br><a href="https://jfrog.com/blog/unboxing-busybox-14-new-vulnerabilities-uncovered-by-claroty-and-jfrog/">https://jfrog.com/blog/unboxing-busybox-14-new-vulnerabilities-uncovered-by-claroty-and-jfrog/</a><br><a href="https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/6T2TURBYYJGBMQTTN2DSOAIQGP7WCPGV/">https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/6T2TURBYYJGBMQTTN2DSOAIQGP7WCPGV/</a><br><a href="https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/UQXGOGWBIYWOIVXJVRKHZR34UMEHQBXS/">https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/UQXGOGWBIYWOIVXJVRKHZR34UMEHQBXS/</a><br><a href="https://ubuntu.com/security/notices/USN-5179-1">https://ubuntu.com/security/notices/USN-5179-1</a><br></details>  |
| ssl_client         |    CVE-2021-42379   |   HIGH  |  1.33.1-r3 | 1.33.1-r6 | <details><summary>Expand...</summary><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2021-42379">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2021-42379</a><br><a href="https://jfrog.com/blog/unboxing-busybox-14-new-vulnerabilities-uncovered-by-claroty-and-jfrog/">https://jfrog.com/blog/unboxing-busybox-14-new-vulnerabilities-uncovered-by-claroty-and-jfrog/</a><br><a href="https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/6T2TURBYYJGBMQTTN2DSOAIQGP7WCPGV/">https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/6T2TURBYYJGBMQTTN2DSOAIQGP7WCPGV/</a><br><a href="https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/UQXGOGWBIYWOIVXJVRKHZR34UMEHQBXS/">https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/UQXGOGWBIYWOIVXJVRKHZR34UMEHQBXS/</a><br><a href="https://ubuntu.com/security/notices/USN-5179-1">https://ubuntu.com/security/notices/USN-5179-1</a><br></details>  |
| ssl_client         |    CVE-2021-42380   |   HIGH  |  1.33.1-r3 | 1.33.1-r6 | <details><summary>Expand...</summary><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2021-42380">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2021-42380</a><br><a href="https://jfrog.com/blog/unboxing-busybox-14-new-vulnerabilities-uncovered-by-claroty-and-jfrog/">https://jfrog.com/blog/unboxing-busybox-14-new-vulnerabilities-uncovered-by-claroty-and-jfrog/</a><br><a href="https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/6T2TURBYYJGBMQTTN2DSOAIQGP7WCPGV/">https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/6T2TURBYYJGBMQTTN2DSOAIQGP7WCPGV/</a><br><a href="https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/UQXGOGWBIYWOIVXJVRKHZR34UMEHQBXS/">https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/UQXGOGWBIYWOIVXJVRKHZR34UMEHQBXS/</a><br><a href="https://ubuntu.com/security/notices/USN-5179-1">https://ubuntu.com/security/notices/USN-5179-1</a><br></details>  |
| ssl_client         |    CVE-2021-42381   |   HIGH  |  1.33.1-r3 | 1.33.1-r6 | <details><summary>Expand...</summary><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2021-42381">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2021-42381</a><br><a href="https://jfrog.com/blog/unboxing-busybox-14-new-vulnerabilities-uncovered-by-claroty-and-jfrog/">https://jfrog.com/blog/unboxing-busybox-14-new-vulnerabilities-uncovered-by-claroty-and-jfrog/</a><br><a href="https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/6T2TURBYYJGBMQTTN2DSOAIQGP7WCPGV/">https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/6T2TURBYYJGBMQTTN2DSOAIQGP7WCPGV/</a><br><a href="https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/UQXGOGWBIYWOIVXJVRKHZR34UMEHQBXS/">https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/UQXGOGWBIYWOIVXJVRKHZR34UMEHQBXS/</a><br><a href="https://ubuntu.com/security/notices/USN-5179-1">https://ubuntu.com/security/notices/USN-5179-1</a><br></details>  |
| ssl_client         |    CVE-2021-42382   |   HIGH  |  1.33.1-r3 | 1.33.1-r6 | <details><summary>Expand...</summary><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2021-42382">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2021-42382</a><br><a href="https://jfrog.com/blog/unboxing-busybox-14-new-vulnerabilities-uncovered-by-claroty-and-jfrog/">https://jfrog.com/blog/unboxing-busybox-14-new-vulnerabilities-uncovered-by-claroty-and-jfrog/</a><br><a href="https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/6T2TURBYYJGBMQTTN2DSOAIQGP7WCPGV/">https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/6T2TURBYYJGBMQTTN2DSOAIQGP7WCPGV/</a><br><a href="https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/UQXGOGWBIYWOIVXJVRKHZR34UMEHQBXS/">https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/UQXGOGWBIYWOIVXJVRKHZR34UMEHQBXS/</a><br><a href="https://ubuntu.com/security/notices/USN-5179-1">https://ubuntu.com/security/notices/USN-5179-1</a><br></details>  |
| ssl_client         |    CVE-2021-42383   |   HIGH  |  1.33.1-r3 | 1.33.1-r6 | <details><summary>Expand...</summary><a href="https://jfrog.com/blog/unboxing-busybox-14-new-vulnerabilities-uncovered-by-claroty-and-jfrog/">https://jfrog.com/blog/unboxing-busybox-14-new-vulnerabilities-uncovered-by-claroty-and-jfrog/</a><br><a href="https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/6T2TURBYYJGBMQTTN2DSOAIQGP7WCPGV/">https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/6T2TURBYYJGBMQTTN2DSOAIQGP7WCPGV/</a><br><a href="https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/UQXGOGWBIYWOIVXJVRKHZR34UMEHQBXS/">https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/UQXGOGWBIYWOIVXJVRKHZR34UMEHQBXS/</a><br></details>  |
| ssl_client         |    CVE-2021-42384   |   HIGH  |  1.33.1-r3 | 1.33.1-r6 | <details><summary>Expand...</summary><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2021-42384">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2021-42384</a><br><a href="https://jfrog.com/blog/unboxing-busybox-14-new-vulnerabilities-uncovered-by-claroty-and-jfrog/">https://jfrog.com/blog/unboxing-busybox-14-new-vulnerabilities-uncovered-by-claroty-and-jfrog/</a><br><a href="https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/6T2TURBYYJGBMQTTN2DSOAIQGP7WCPGV/">https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/6T2TURBYYJGBMQTTN2DSOAIQGP7WCPGV/</a><br><a href="https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/UQXGOGWBIYWOIVXJVRKHZR34UMEHQBXS/">https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/UQXGOGWBIYWOIVXJVRKHZR34UMEHQBXS/</a><br><a href="https://ubuntu.com/security/notices/USN-5179-1">https://ubuntu.com/security/notices/USN-5179-1</a><br></details>  |
| ssl_client         |    CVE-2021-42385   |   HIGH  |  1.33.1-r3 | 1.33.1-r6 | <details><summary>Expand...</summary><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2021-42385">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2021-42385</a><br><a href="https://jfrog.com/blog/unboxing-busybox-14-new-vulnerabilities-uncovered-by-claroty-and-jfrog/">https://jfrog.com/blog/unboxing-busybox-14-new-vulnerabilities-uncovered-by-claroty-and-jfrog/</a><br><a href="https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/6T2TURBYYJGBMQTTN2DSOAIQGP7WCPGV/">https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/6T2TURBYYJGBMQTTN2DSOAIQGP7WCPGV/</a><br><a href="https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/UQXGOGWBIYWOIVXJVRKHZR34UMEHQBXS/">https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/UQXGOGWBIYWOIVXJVRKHZR34UMEHQBXS/</a><br><a href="https://ubuntu.com/security/notices/USN-5179-1">https://ubuntu.com/security/notices/USN-5179-1</a><br></details>  |
| ssl_client         |    CVE-2021-42386   |   HIGH  |  1.33.1-r3 | 1.33.1-r6 | <details><summary>Expand...</summary><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2021-42386">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2021-42386</a><br><a href="https://jfrog.com/blog/unboxing-busybox-14-new-vulnerabilities-uncovered-by-claroty-and-jfrog/">https://jfrog.com/blog/unboxing-busybox-14-new-vulnerabilities-uncovered-by-claroty-and-jfrog/</a><br><a href="https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/6T2TURBYYJGBMQTTN2DSOAIQGP7WCPGV/">https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/6T2TURBYYJGBMQTTN2DSOAIQGP7WCPGV/</a><br><a href="https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/UQXGOGWBIYWOIVXJVRKHZR34UMEHQBXS/">https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/UQXGOGWBIYWOIVXJVRKHZR34UMEHQBXS/</a><br><a href="https://ubuntu.com/security/notices/USN-5179-1">https://ubuntu.com/security/notices/USN-5179-1</a><br></details>  |
| ssl_client         |    CVE-2021-42374   |   MEDIUM  |  1.33.1-r3 | 1.33.1-r4 | <details><summary>Expand...</summary><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2021-42374">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2021-42374</a><br><a href="https://jfrog.com/blog/unboxing-busybox-14-new-vulnerabilities-uncovered-by-claroty-and-jfrog/">https://jfrog.com/blog/unboxing-busybox-14-new-vulnerabilities-uncovered-by-claroty-and-jfrog/</a><br><a href="https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/6T2TURBYYJGBMQTTN2DSOAIQGP7WCPGV/">https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/6T2TURBYYJGBMQTTN2DSOAIQGP7WCPGV/</a><br><a href="https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/UQXGOGWBIYWOIVXJVRKHZR34UMEHQBXS/">https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/UQXGOGWBIYWOIVXJVRKHZR34UMEHQBXS/</a><br><a href="https://ubuntu.com/security/notices/USN-5179-1">https://ubuntu.com/security/notices/USN-5179-1</a><br></details>  |
| ssl_client         |    CVE-2021-42375   |   MEDIUM  |  1.33.1-r3 | 1.33.1-r5 | <details><summary>Expand...</summary><a href="https://jfrog.com/blog/unboxing-busybox-14-new-vulnerabilities-uncovered-by-claroty-and-jfrog/">https://jfrog.com/blog/unboxing-busybox-14-new-vulnerabilities-uncovered-by-claroty-and-jfrog/</a><br><a href="https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/6T2TURBYYJGBMQTTN2DSOAIQGP7WCPGV/">https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/6T2TURBYYJGBMQTTN2DSOAIQGP7WCPGV/</a><br><a href="https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/UQXGOGWBIYWOIVXJVRKHZR34UMEHQBXS/">https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/UQXGOGWBIYWOIVXJVRKHZR34UMEHQBXS/</a><br></details>  |


#### Container: tccr.io/truecharts/lidarr:v1.0.0.2385@sha256:cce6c8cf6531583772881c4dacfb9021edac566c15a326722bd695509c31ce5c (ubuntu 20.04)
    

**ubuntu**

      
| Package         |    Vulnerability   |   Severity  |  Installed Version | Fixed Version |                   Links                   |
|:----------------|:------------------:|:-----------:|:------------------:|:-------------:|-----------------------------------------|
| bash         |    CVE-2019-18276   |   LOW  |  5.0-6ubuntu1.1 |  | <details><summary>Expand...</summary><a href="http://packetstormsecurity.com/files/155498/Bash-5.0-Patch-11-Privilege-Escalation.html">http://packetstormsecurity.com/files/155498/Bash-5.0-Patch-11-Privilege-Escalation.html</a><br><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2019-18276">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2019-18276</a><br><a href="https://github.com/bminor/bash/commit/951bdaad7a18cc0dc1036bba86b18b90874d39ff">https://github.com/bminor/bash/commit/951bdaad7a18cc0dc1036bba86b18b90874d39ff</a><br><a href="https://linux.oracle.com/cve/CVE-2019-18276.html">https://linux.oracle.com/cve/CVE-2019-18276.html</a><br><a href="https://linux.oracle.com/errata/ELSA-2021-1679.html">https://linux.oracle.com/errata/ELSA-2021-1679.html</a><br><a href="https://lists.apache.org/thread.html/rf9fa47ab66495c78bb4120b0754dd9531ca2ff0430f6685ac9b07772@%3Cdev.mina.apache.org%3E">https://lists.apache.org/thread.html/rf9fa47ab66495c78bb4120b0754dd9531ca2ff0430f6685ac9b07772@%3Cdev.mina.apache.org%3E</a><br><a href="https://security.gentoo.org/glsa/202105-34">https://security.gentoo.org/glsa/202105-34</a><br><a href="https://security.netapp.com/advisory/ntap-20200430-0003/">https://security.netapp.com/advisory/ntap-20200430-0003/</a><br><a href="https://www.youtube.com/watch?v=-wGtxJ8opa8">https://www.youtube.com/watch?v=-wGtxJ8opa8</a><br></details>  |
| coreutils         |    CVE-2016-2781   |   LOW  |  8.30-3ubuntu2 |  | <details><summary>Expand...</summary><a href="http://seclists.org/oss-sec/2016/q1/452">http://seclists.org/oss-sec/2016/q1/452</a><br><a href="http://www.openwall.com/lists/oss-security/2016/02/28/2">http://www.openwall.com/lists/oss-security/2016/02/28/2</a><br><a href="http://www.openwall.com/lists/oss-security/2016/02/28/3">http://www.openwall.com/lists/oss-security/2016/02/28/3</a><br><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2016-2781">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2016-2781</a><br><a href="https://lists.apache.org/thread.html/rf9fa47ab66495c78bb4120b0754dd9531ca2ff0430f6685ac9b07772@%3Cdev.mina.apache.org%3E">https://lists.apache.org/thread.html/rf9fa47ab66495c78bb4120b0754dd9531ca2ff0430f6685ac9b07772@%3Cdev.mina.apache.org%3E</a><br><a href="https://lore.kernel.org/patchwork/patch/793178/">https://lore.kernel.org/patchwork/patch/793178/</a><br></details>  |
| libaom0         |    CVE-2020-36129   |   MEDIUM  |  1.0.0.errata1-3build1 |  | <details><summary>Expand...</summary><a href="https://aomedia.googlesource.com/aom/+/7a20d10027fd91fbe11e38182a1d45238e102c4a%5E%21/#F0 (v3.0.0)">https://aomedia.googlesource.com/aom/+/7a20d10027fd91fbe11e38182a1d45238e102c4a%5E%21/#F0 (v3.0.0)</a><br><a href="https://bugs.chromium.org/p/aomedia/issues/detail?id=2912&amp;q=&amp;can=1">https://bugs.chromium.org/p/aomedia/issues/detail?id=2912&amp;q=&amp;can=1</a><br><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2020-36129">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2020-36129</a><br></details>  |
| libaom0         |    CVE-2020-36130   |   MEDIUM  |  1.0.0.errata1-3build1 |  | <details><summary>Expand...</summary><a href="https://aomedia.googlesource.com/aom/+/be4ee75fd762d361d0679cc892e4c74af8140093%5E%21/#F0 (v2.0.1)">https://aomedia.googlesource.com/aom/+/be4ee75fd762d361d0679cc892e4c74af8140093%5E%21/#F0 (v2.0.1)</a><br><a href="https://bugs.chromium.org/p/aomedia/issues/detail?id=2905&amp;q=&amp;can=1">https://bugs.chromium.org/p/aomedia/issues/detail?id=2905&amp;q=&amp;can=1</a><br><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2020-36130">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2020-36130</a><br></details>  |
| libaom0         |    CVE-2020-36131   |   MEDIUM  |  1.0.0.errata1-3build1 |  | <details><summary>Expand...</summary><a href="https://aomedia.googlesource.com/aom/+/94bcbfe76b0fd5b8ac03645082dc23a88730c949 (v2.0.1)">https://aomedia.googlesource.com/aom/+/94bcbfe76b0fd5b8ac03645082dc23a88730c949 (v2.0.1)</a><br><a href="https://bugs.chromium.org/p/aomedia/issues/detail?id=2911&amp;q=&amp;can=1">https://bugs.chromium.org/p/aomedia/issues/detail?id=2911&amp;q=&amp;can=1</a><br><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2020-36131">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2020-36131</a><br></details>  |
| libaom0         |    CVE-2020-36133   |   MEDIUM  |  1.0.0.errata1-3build1 |  | <details><summary>Expand...</summary><a href="https://aomedia.googlesource.com/aom/+/5c9bc4181071684d157fc47c736acf6c69a85d85 (v3.0.0)">https://aomedia.googlesource.com/aom/+/5c9bc4181071684d157fc47c736acf6c69a85d85 (v3.0.0)</a><br><a href="https://bugs.chromium.org/p/aomedia/issues/detail?id=2913&amp;q=&amp;can=1">https://bugs.chromium.org/p/aomedia/issues/detail?id=2913&amp;q=&amp;can=1</a><br><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2020-36133">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2020-36133</a><br></details>  |
| libaom0         |    CVE-2020-36135   |   MEDIUM  |  1.0.0.errata1-3build1 |  | <details><summary>Expand...</summary><a href="https://aomedia.googlesource.com/aom/+/94bcbfe76b0fd5b8ac03645082dc23a88730c949 (v2.0.1)">https://aomedia.googlesource.com/aom/+/94bcbfe76b0fd5b8ac03645082dc23a88730c949 (v2.0.1)</a><br><a href="https://bugs.chromium.org/p/aomedia/issues/detail?id=2910&amp;q=&amp;can=1">https://bugs.chromium.org/p/aomedia/issues/detail?id=2910&amp;q=&amp;can=1</a><br><a href="https://bugs.chromium.org/p/aomedia/issues/detail?id=2911">https://bugs.chromium.org/p/aomedia/issues/detail?id=2911</a><br><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2020-36135">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2020-36135</a><br></details>  |
| libasn1-8-heimdal         |    CVE-2021-3671   |   LOW  |  7.7.0+dfsg-1ubuntu1 |  | <details><summary>Expand...</summary><a href="https://bugzilla.redhat.com/show_bug.cgi?id=2013080,">https://bugzilla.redhat.com/show_bug.cgi?id=2013080,</a><br><a href="https://bugzilla.samba.org/show_bug.cgi?id=14770,">https://bugzilla.samba.org/show_bug.cgi?id=14770,</a><br><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2021-3671">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2021-3671</a><br><a href="https://github.com/heimdal/heimdal/commit/04171147948d0a3636bc6374181926f0fb2ec83a">https://github.com/heimdal/heimdal/commit/04171147948d0a3636bc6374181926f0fb2ec83a</a><br><a href="https://ubuntu.com/security/notices/USN-5142-1">https://ubuntu.com/security/notices/USN-5142-1</a><br><a href="https://ubuntu.com/security/notices/USN-5174-1">https://ubuntu.com/security/notices/USN-5174-1</a><br></details>  |
| libavcodec58         |    CVE-2020-14212   |   MEDIUM  |  7:4.2.4-1ubuntu0.1 |  | <details><summary>Expand...</summary><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2020-14212">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2020-14212</a><br><a href="https://patchwork.ffmpeg.org/project/ffmpeg/list/?series=1463">https://patchwork.ffmpeg.org/project/ffmpeg/list/?series=1463</a><br><a href="https://security.gentoo.org/glsa/202007-58">https://security.gentoo.org/glsa/202007-58</a><br><a href="https://trac.ffmpeg.org/ticket/8716">https://trac.ffmpeg.org/ticket/8716</a><br></details>  |
| libavcodec58         |    CVE-2020-20891   |   MEDIUM  |  7:4.2.4-1ubuntu0.1 |  | <details><summary>Expand...</summary><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2020-20891">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2020-20891</a><br><a href="https://git.ffmpeg.org/gitweb/ffmpeg.git/commit/64a805883d7223c868a683f0030837d859edd2ab">https://git.ffmpeg.org/gitweb/ffmpeg.git/commit/64a805883d7223c868a683f0030837d859edd2ab</a><br><a href="https://trac.ffmpeg.org/ticket/8282">https://trac.ffmpeg.org/ticket/8282</a><br></details>  |
| libavcodec58         |    CVE-2020-20892   |   MEDIUM  |  7:4.2.4-1ubuntu0.1 |  | <details><summary>Expand...</summary><a href="http://git.videolan.org/?p=ffmpeg.git;a=commit;h=19587c9332f5be4f6bc6d7b2b8ef3fd21dfeaa01">http://git.videolan.org/?p=ffmpeg.git;a=commit;h=19587c9332f5be4f6bc6d7b2b8ef3fd21dfeaa01</a><br><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2020-20892">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2020-20892</a><br><a href="https://trac.ffmpeg.org/ticket/8265">https://trac.ffmpeg.org/ticket/8265</a><br></details>  |
| libavcodec58         |    CVE-2020-20896   |   MEDIUM  |  7:4.2.4-1ubuntu0.1 |  | <details><summary>Expand...</summary><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2020-20896">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2020-20896</a><br><a href="https://git.ffmpeg.org/gitweb/ffmpeg.git/commit/dd01947397b98e94c3f2a79d5820aaf4594f4d3b">https://git.ffmpeg.org/gitweb/ffmpeg.git/commit/dd01947397b98e94c3f2a79d5820aaf4594f4d3b</a><br><a href="https://trac.ffmpeg.org/ticket/8273">https://trac.ffmpeg.org/ticket/8273</a><br></details>  |
| libavcodec58         |    CVE-2020-20898   |   MEDIUM  |  7:4.2.4-1ubuntu0.1 |  | <details><summary>Expand...</summary><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2020-20898">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2020-20898</a><br><a href="https://git.ffmpeg.org/gitweb/ffmpeg.git/commit/99f8d32129dd233d4eb2efa44678a0bc44869f23">https://git.ffmpeg.org/gitweb/ffmpeg.git/commit/99f8d32129dd233d4eb2efa44678a0bc44869f23</a><br><a href="https://trac.ffmpeg.org/ticket/8263">https://trac.ffmpeg.org/ticket/8263</a><br></details>  |
| libavcodec58         |    CVE-2020-21041   |   MEDIUM  |  7:4.2.4-1ubuntu0.1 |  | <details><summary>Expand...</summary><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2020-21041">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2020-21041</a><br><a href="https://git.videolan.org/?p=ffmpeg.git;a=commitdiff;h=5d9f44da460f781a1604d537d0555b78e29438ba">https://git.videolan.org/?p=ffmpeg.git;a=commitdiff;h=5d9f44da460f781a1604d537d0555b78e29438ba</a><br><a href="https://lists.debian.org/debian-lts-announce/2021/08/msg00018.html">https://lists.debian.org/debian-lts-announce/2021/08/msg00018.html</a><br><a href="https://trac.ffmpeg.org/ticket/7989">https://trac.ffmpeg.org/ticket/7989</a><br><a href="https://www.debian.org/security/2021/dsa-4990">https://www.debian.org/security/2021/dsa-4990</a><br></details>  |
| libavcodec58         |    CVE-2020-21688   |   MEDIUM  |  7:4.2.4-1ubuntu0.1 |  | <details><summary>Expand...</summary><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2020-21688">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2020-21688</a><br><a href="https://trac.ffmpeg.org/ticket/8186">https://trac.ffmpeg.org/ticket/8186</a><br><a href="https://www.debian.org/security/2021/dsa-4998">https://www.debian.org/security/2021/dsa-4998</a><br></details>  |
| libavcodec58         |    CVE-2020-21697   |   MEDIUM  |  7:4.2.4-1ubuntu0.1 |  | <details><summary>Expand...</summary><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2020-21697">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2020-21697</a><br><a href="https://trac.ffmpeg.org/ticket/8188">https://trac.ffmpeg.org/ticket/8188</a><br><a href="https://www.debian.org/security/2021/dsa-4998">https://www.debian.org/security/2021/dsa-4998</a><br></details>  |
| libavcodec58         |    CVE-2020-22015   |   MEDIUM  |  7:4.2.4-1ubuntu0.1 |  | <details><summary>Expand...</summary><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2020-22015">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2020-22015</a><br><a href="https://lists.debian.org/debian-lts-announce/2021/08/msg00018.html">https://lists.debian.org/debian-lts-announce/2021/08/msg00018.html</a><br><a href="https://trac.ffmpeg.org/ticket/8190">https://trac.ffmpeg.org/ticket/8190</a><br><a href="https://www.debian.org/security/2021/dsa-4990">https://www.debian.org/security/2021/dsa-4990</a><br></details>  |
| libavcodec58         |    CVE-2020-22017   |   MEDIUM  |  7:4.2.4-1ubuntu0.1 |  | <details><summary>Expand...</summary><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2020-22017">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2020-22017</a><br><a href="https://trac.ffmpeg.org/ticket/8309">https://trac.ffmpeg.org/ticket/8309</a><br><a href="https://www.debian.org/security/2021/dsa-4990">https://www.debian.org/security/2021/dsa-4990</a><br></details>  |
| libavcodec58         |    CVE-2020-22019   |   MEDIUM  |  7:4.2.4-1ubuntu0.1 |  | <details><summary>Expand...</summary><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2020-22019">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2020-22019</a><br><a href="https://trac.ffmpeg.org/ticket/8241">https://trac.ffmpeg.org/ticket/8241</a><br><a href="https://www.debian.org/security/2021/dsa-4990">https://www.debian.org/security/2021/dsa-4990</a><br></details>  |
| libavcodec58         |    CVE-2020-22020   |   MEDIUM  |  7:4.2.4-1ubuntu0.1 |  | <details><summary>Expand...</summary><a href="http://git.videolan.org/?p=ffmpeg.git;a=commitdiff;h=ce5274c1385d55892a692998923802023526b765">http://git.videolan.org/?p=ffmpeg.git;a=commitdiff;h=ce5274c1385d55892a692998923802023526b765</a><br><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2020-22020">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2020-22020</a><br><a href="https://lists.debian.org/debian-lts-announce/2021/08/msg00018.html">https://lists.debian.org/debian-lts-announce/2021/08/msg00018.html</a><br><a href="https://trac.ffmpeg.org/ticket/8239">https://trac.ffmpeg.org/ticket/8239</a><br><a href="https://www.debian.org/security/2021/dsa-4990">https://www.debian.org/security/2021/dsa-4990</a><br></details>  |
| libavcodec58         |    CVE-2020-22021   |   MEDIUM  |  7:4.2.4-1ubuntu0.1 |  | <details><summary>Expand...</summary><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2020-22021">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2020-22021</a><br><a href="https://lists.debian.org/debian-lts-announce/2021/08/msg00018.html">https://lists.debian.org/debian-lts-announce/2021/08/msg00018.html</a><br><a href="https://trac.ffmpeg.org/ticket/8240">https://trac.ffmpeg.org/ticket/8240</a><br><a href="https://www.debian.org/security/2021/dsa-4990">https://www.debian.org/security/2021/dsa-4990</a><br></details>  |
| libavcodec58         |    CVE-2020-22022   |   MEDIUM  |  7:4.2.4-1ubuntu0.1 |  | <details><summary>Expand...</summary><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2020-22022">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2020-22022</a><br><a href="https://lists.debian.org/debian-lts-announce/2021/08/msg00018.html">https://lists.debian.org/debian-lts-announce/2021/08/msg00018.html</a><br><a href="https://trac.ffmpeg.org/ticket/8264">https://trac.ffmpeg.org/ticket/8264</a><br><a href="https://www.debian.org/security/2021/dsa-4990">https://www.debian.org/security/2021/dsa-4990</a><br></details>  |
| libavcodec58         |    CVE-2020-22023   |   MEDIUM  |  7:4.2.4-1ubuntu0.1 |  | <details><summary>Expand...</summary><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2020-22023">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2020-22023</a><br><a href="https://lists.debian.org/debian-lts-announce/2021/08/msg00018.html">https://lists.debian.org/debian-lts-announce/2021/08/msg00018.html</a><br><a href="https://trac.ffmpeg.org/ticket/8244">https://trac.ffmpeg.org/ticket/8244</a><br><a href="https://www.debian.org/security/2021/dsa-4990">https://www.debian.org/security/2021/dsa-4990</a><br></details>  |
| libavcodec58         |    CVE-2020-22024   |   MEDIUM  |  7:4.2.4-1ubuntu0.1 |  | <details><summary>Expand...</summary><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2020-22024">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2020-22024</a><br><a href="https://trac.ffmpeg.org/ticket/8310">https://trac.ffmpeg.org/ticket/8310</a><br></details>  |
| libavcodec58         |    CVE-2020-22025   |   MEDIUM  |  7:4.2.4-1ubuntu0.1 |  | <details><summary>Expand...</summary><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2020-22025">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2020-22025</a><br><a href="https://lists.debian.org/debian-lts-announce/2021/08/msg00018.html">https://lists.debian.org/debian-lts-announce/2021/08/msg00018.html</a><br><a href="https://trac.ffmpeg.org/ticket/8260">https://trac.ffmpeg.org/ticket/8260</a><br><a href="https://www.debian.org/security/2021/dsa-4990">https://www.debian.org/security/2021/dsa-4990</a><br></details>  |
| libavcodec58         |    CVE-2020-22026   |   MEDIUM  |  7:4.2.4-1ubuntu0.1 |  | <details><summary>Expand...</summary><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2020-22026">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2020-22026</a><br><a href="https://lists.debian.org/debian-lts-announce/2021/08/msg00018.html">https://lists.debian.org/debian-lts-announce/2021/08/msg00018.html</a><br><a href="https://trac.ffmpeg.org/ticket/8317">https://trac.ffmpeg.org/ticket/8317</a><br><a href="https://www.debian.org/security/2021/dsa-4990">https://www.debian.org/security/2021/dsa-4990</a><br></details>  |
| libavcodec58         |    CVE-2020-22027   |   MEDIUM  |  7:4.2.4-1ubuntu0.1 |  | <details><summary>Expand...</summary><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2020-22027">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2020-22027</a><br><a href="https://trac.ffmpeg.org/attachment/ticket/8242/gdb-vf_neighbor_191">https://trac.ffmpeg.org/attachment/ticket/8242/gdb-vf_neighbor_191</a><br><a href="https://trac.ffmpeg.org/ticket/8242">https://trac.ffmpeg.org/ticket/8242</a><br><a href="https://www.debian.org/security/2021/dsa-4990">https://www.debian.org/security/2021/dsa-4990</a><br></details>  |
| libavcodec58         |    CVE-2020-22028   |   MEDIUM  |  7:4.2.4-1ubuntu0.1 |  | <details><summary>Expand...</summary><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2020-22028">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2020-22028</a><br><a href="https://lists.debian.org/debian-lts-announce/2021/08/msg00018.html">https://lists.debian.org/debian-lts-announce/2021/08/msg00018.html</a><br><a href="https://trac.ffmpeg.org/ticket/8274">https://trac.ffmpeg.org/ticket/8274</a><br><a href="https://www.debian.org/security/2021/dsa-4990">https://www.debian.org/security/2021/dsa-4990</a><br></details>  |
| libavcodec58         |    CVE-2020-22029   |   MEDIUM  |  7:4.2.4-1ubuntu0.1 |  | <details><summary>Expand...</summary><a href="http://git.videolan.org/?p=ffmpeg.git;a=commitdiff;h=a7fd1279703683ebb548ef7baa2f1519994496ae">http://git.videolan.org/?p=ffmpeg.git;a=commitdiff;h=a7fd1279703683ebb548ef7baa2f1519994496ae</a><br><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2020-22029">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2020-22029</a><br><a href="https://trac.ffmpeg.org/ticket/8250">https://trac.ffmpeg.org/ticket/8250</a><br><a href="https://www.debian.org/security/2021/dsa-4990">https://www.debian.org/security/2021/dsa-4990</a><br></details>  |
| libavcodec58         |    CVE-2020-22030   |   MEDIUM  |  7:4.2.4-1ubuntu0.1 |  | <details><summary>Expand...</summary><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2020-22030">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2020-22030</a><br><a href="https://trac.ffmpeg.org/ticket/8276">https://trac.ffmpeg.org/ticket/8276</a><br><a href="https://www.debian.org/security/2021/dsa-4990">https://www.debian.org/security/2021/dsa-4990</a><br></details>  |
| libavcodec58         |    CVE-2020-22031   |   MEDIUM  |  7:4.2.4-1ubuntu0.1 |  | <details><summary>Expand...</summary><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2020-22031">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2020-22031</a><br><a href="https://lists.debian.org/debian-lts-announce/2021/08/msg00018.html">https://lists.debian.org/debian-lts-announce/2021/08/msg00018.html</a><br><a href="https://trac.ffmpeg.org/attachment/ticket/8243/gdb-vf_w3fdif_191">https://trac.ffmpeg.org/attachment/ticket/8243/gdb-vf_w3fdif_191</a><br><a href="https://trac.ffmpeg.org/ticket/8243">https://trac.ffmpeg.org/ticket/8243</a><br><a href="https://www.debian.org/security/2021/dsa-4990">https://www.debian.org/security/2021/dsa-4990</a><br></details>  |
| libavcodec58         |    CVE-2020-22032   |   MEDIUM  |  7:4.2.4-1ubuntu0.1 |  | <details><summary>Expand...</summary><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2020-22032">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2020-22032</a><br><a href="https://lists.debian.org/debian-lts-announce/2021/08/msg00018.html">https://lists.debian.org/debian-lts-announce/2021/08/msg00018.html</a><br><a href="https://trac.ffmpeg.org/ticket/8275">https://trac.ffmpeg.org/ticket/8275</a><br><a href="https://www.debian.org/security/2021/dsa-4990">https://www.debian.org/security/2021/dsa-4990</a><br></details>  |
| libavcodec58         |    CVE-2020-22033   |   MEDIUM  |  7:4.2.4-1ubuntu0.1 |  | <details><summary>Expand...</summary><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2020-22033">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2020-22033</a><br><a href="https://trac.ffmpeg.org/ticket/8246">https://trac.ffmpeg.org/ticket/8246</a><br><a href="https://www.debian.org/security/2021/dsa-4990">https://www.debian.org/security/2021/dsa-4990</a><br></details>  |
| libavcodec58         |    CVE-2020-22034   |   MEDIUM  |  7:4.2.4-1ubuntu0.1 |  | <details><summary>Expand...</summary><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2020-22034">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2020-22034</a><br><a href="https://trac.ffmpeg.org/ticket/8236">https://trac.ffmpeg.org/ticket/8236</a><br><a href="https://www.debian.org/security/2021/dsa-4990">https://www.debian.org/security/2021/dsa-4990</a><br></details>  |
| libavcodec58         |    CVE-2020-22035   |   MEDIUM  |  7:4.2.4-1ubuntu0.1 |  | <details><summary>Expand...</summary><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2020-22035">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2020-22035</a><br><a href="https://trac.ffmpeg.org/ticket/8262">https://trac.ffmpeg.org/ticket/8262</a><br><a href="https://www.debian.org/security/2021/dsa-4990">https://www.debian.org/security/2021/dsa-4990</a><br></details>  |
| libavcodec58         |    CVE-2020-22036   |   MEDIUM  |  7:4.2.4-1ubuntu0.1 |  | <details><summary>Expand...</summary><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2020-22036">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2020-22036</a><br><a href="https://lists.debian.org/debian-lts-announce/2021/08/msg00018.html">https://lists.debian.org/debian-lts-announce/2021/08/msg00018.html</a><br><a href="https://trac.ffmpeg.org/ticket/8261">https://trac.ffmpeg.org/ticket/8261</a><br><a href="https://www.debian.org/security/2021/dsa-4990">https://www.debian.org/security/2021/dsa-4990</a><br></details>  |
| libavcodec58         |    CVE-2020-22037   |   MEDIUM  |  7:4.2.4-1ubuntu0.1 |  | <details><summary>Expand...</summary><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2020-22037">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2020-22037</a><br><a href="https://lists.debian.org/debian-lts-announce/2021/11/msg00012.html">https://lists.debian.org/debian-lts-announce/2021/11/msg00012.html</a><br><a href="https://trac.ffmpeg.org/ticket/8281">https://trac.ffmpeg.org/ticket/8281</a><br><a href="https://www.debian.org/security/2021/dsa-4990">https://www.debian.org/security/2021/dsa-4990</a><br><a href="https://www.debian.org/security/2021/dsa-4998">https://www.debian.org/security/2021/dsa-4998</a><br></details>  |
| libavcodec58         |    CVE-2020-22038   |   MEDIUM  |  7:4.2.4-1ubuntu0.1 |  | <details><summary>Expand...</summary><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2020-22038">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2020-22038</a><br><a href="https://git.videolan.org/?p=ffmpeg.git;a=commitdiff;h=7c32e9cf93b712f8463573a59ed4e98fd10fa013">https://git.videolan.org/?p=ffmpeg.git;a=commitdiff;h=7c32e9cf93b712f8463573a59ed4e98fd10fa013</a><br><a href="https://trac.ffmpeg.org/ticket/8285">https://trac.ffmpeg.org/ticket/8285</a><br></details>  |
| libavcodec58         |    CVE-2020-22039   |   MEDIUM  |  7:4.2.4-1ubuntu0.1 |  | <details><summary>Expand...</summary><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2020-22039">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2020-22039</a><br><a href="https://git.videolan.org/?p=ffmpeg.git;a=commitdiff;h=a581bb66ea5eb981e2e498ca301df7d1ef15a6a3">https://git.videolan.org/?p=ffmpeg.git;a=commitdiff;h=a581bb66ea5eb981e2e498ca301df7d1ef15a6a3</a><br><a href="https://trac.ffmpeg.org/ticket/8302">https://trac.ffmpeg.org/ticket/8302</a><br></details>  |
| libavcodec58         |    CVE-2020-22040   |   MEDIUM  |  7:4.2.4-1ubuntu0.1 |  | <details><summary>Expand...</summary><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2020-22040">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2020-22040</a><br><a href="https://git.videolan.org/?p=ffmpeg.git;a=commitdiff;h=1a0c584abc9709b1d11dbafef05d22e0937d7d19">https://git.videolan.org/?p=ffmpeg.git;a=commitdiff;h=1a0c584abc9709b1d11dbafef05d22e0937d7d19</a><br><a href="https://trac.ffmpeg.org/ticket/8283">https://trac.ffmpeg.org/ticket/8283</a><br></details>  |
| libavcodec58         |    CVE-2020-22041   |   MEDIUM  |  7:4.2.4-1ubuntu0.1 |  | <details><summary>Expand...</summary><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2020-22041">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2020-22041</a><br><a href="https://git.videolan.org/?p=ffmpeg.git;a=commitdiff;h=3488e0977c671568731afa12b811adce9d4d807f">https://git.videolan.org/?p=ffmpeg.git;a=commitdiff;h=3488e0977c671568731afa12b811adce9d4d807f</a><br><a href="https://lists.debian.org/debian-lts-announce/2021/11/msg00012.html">https://lists.debian.org/debian-lts-announce/2021/11/msg00012.html</a><br><a href="https://trac.ffmpeg.org/ticket/8296">https://trac.ffmpeg.org/ticket/8296</a><br></details>  |
| libavcodec58         |    CVE-2020-22042   |   MEDIUM  |  7:4.2.4-1ubuntu0.1 |  | <details><summary>Expand...</summary><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2020-22042">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2020-22042</a><br><a href="https://git.videolan.org/?p=ffmpeg.git;a=commitdiff;h=426c16d61a9b5056a157a1a2a057a4e4d13eef84">https://git.videolan.org/?p=ffmpeg.git;a=commitdiff;h=426c16d61a9b5056a157a1a2a057a4e4d13eef84</a><br><a href="https://trac.ffmpeg.org/ticket/8267">https://trac.ffmpeg.org/ticket/8267</a><br><a href="https://www.debian.org/security/2021/dsa-4998">https://www.debian.org/security/2021/dsa-4998</a><br></details>  |
| libavcodec58         |    CVE-2020-22043   |   MEDIUM  |  7:4.2.4-1ubuntu0.1 |  | <details><summary>Expand...</summary><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2020-22043">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2020-22043</a><br><a href="https://git.videolan.org/?p=ffmpeg.git;a=commitdiff;h=b288a7eb3d963a175e177b6219c8271076ee8590">https://git.videolan.org/?p=ffmpeg.git;a=commitdiff;h=b288a7eb3d963a175e177b6219c8271076ee8590</a><br><a href="https://trac.ffmpeg.org/ticket/8284">https://trac.ffmpeg.org/ticket/8284</a><br></details>  |
| libavcodec58         |    CVE-2020-22044   |   MEDIUM  |  7:4.2.4-1ubuntu0.1 |  | <details><summary>Expand...</summary><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2020-22044">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2020-22044</a><br><a href="https://git.videolan.org/?p=ffmpeg.git;a=commitdiff;h=1d479300cbe0522c233b7d51148aea2b29bd29ad">https://git.videolan.org/?p=ffmpeg.git;a=commitdiff;h=1d479300cbe0522c233b7d51148aea2b29bd29ad</a><br><a href="https://lists.debian.org/debian-lts-announce/2021/11/msg00012.html">https://lists.debian.org/debian-lts-announce/2021/11/msg00012.html</a><br><a href="https://trac.ffmpeg.org/ticket/8295">https://trac.ffmpeg.org/ticket/8295</a><br></details>  |
| libavcodec58         |    CVE-2020-22048   |   MEDIUM  |  7:4.2.4-1ubuntu0.1 |  | <details><summary>Expand...</summary><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2020-22048">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2020-22048</a><br><a href="https://lists.debian.org/debian-lts-announce/2021/11/msg00012.html">https://lists.debian.org/debian-lts-announce/2021/11/msg00012.html</a><br><a href="https://trac.ffmpeg.org/ticket/8303">https://trac.ffmpeg.org/ticket/8303</a><br></details>  |
| libavcodec58         |    CVE-2020-22051   |   MEDIUM  |  7:4.2.4-1ubuntu0.1 |  | <details><summary>Expand...</summary><a href="http://git.videolan.org/?p=ffmpeg.git;a=commitdiff;h=673fce6d40d9a594fb7a0ea17d296b7d3d9ea856">http://git.videolan.org/?p=ffmpeg.git;a=commitdiff;h=673fce6d40d9a594fb7a0ea17d296b7d3d9ea856</a><br><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2020-22051">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2020-22051</a><br><a href="https://trac.ffmpeg.org/ticket/8313">https://trac.ffmpeg.org/ticket/8313</a><br></details>  |
| libavcodec58         |    CVE-2020-22056   |   MEDIUM  |  7:4.2.4-1ubuntu0.1 |  | <details><summary>Expand...</summary><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2020-22056">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2020-22056</a><br><a href="https://trac.ffmpeg.org/ticket/8304">https://trac.ffmpeg.org/ticket/8304</a><br></details>  |
| libavcodec58         |    CVE-2020-35964   |   MEDIUM  |  7:4.2.4-1ubuntu0.1 |  | <details><summary>Expand...</summary><a href="https://bugs.chromium.org/p/oss-fuzz/issues/detail?id=26622">https://bugs.chromium.org/p/oss-fuzz/issues/detail?id=26622</a><br><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2020-35964">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2020-35964</a><br><a href="https://github.com/FFmpeg/FFmpeg/commit/27a99e2c7d450fef15594671eef4465c8a166bd7">https://github.com/FFmpeg/FFmpeg/commit/27a99e2c7d450fef15594671eef4465c8a166bd7</a><br><a href="https://security.gentoo.org/glsa/202105-24">https://security.gentoo.org/glsa/202105-24</a><br></details>  |
| libavcodec58         |    CVE-2020-35965   |   MEDIUM  |  7:4.2.4-1ubuntu0.1 |  | <details><summary>Expand...</summary><a href="https://bugs.chromium.org/p/oss-fuzz/issues/detail?id=26532">https://bugs.chromium.org/p/oss-fuzz/issues/detail?id=26532</a><br><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2020-35965">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2020-35965</a><br><a href="https://github.com/FFmpeg/FFmpeg/commit/3e5959b3457f7f1856d997261e6ac672bba49e8b">https://github.com/FFmpeg/FFmpeg/commit/3e5959b3457f7f1856d997261e6ac672bba49e8b</a><br><a href="https://github.com/FFmpeg/FFmpeg/commit/b0a8b40294ea212c1938348ff112ef1b9bf16bb3">https://github.com/FFmpeg/FFmpeg/commit/b0a8b40294ea212c1938348ff112ef1b9bf16bb3</a><br><a href="https://lists.debian.org/debian-lts-announce/2021/01/msg00026.html">https://lists.debian.org/debian-lts-announce/2021/01/msg00026.html</a><br><a href="https://security.gentoo.org/glsa/202105-24">https://security.gentoo.org/glsa/202105-24</a><br><a href="https://www.debian.org/security/2021/dsa-4990">https://www.debian.org/security/2021/dsa-4990</a><br></details>  |
| libavcodec58         |    CVE-2021-3566   |   MEDIUM  |  7:4.2.4-1ubuntu0.1 |  | <details><summary>Expand...</summary><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2021-3566">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2021-3566</a><br><a href="https://github.com/FFmpeg/FFmpeg/commit/3bce9e9b3ea35c54bacccc793d7da99ea5157532#diff-74f6b92a0541378ad15de9c29c0a2b0c69881ad9ffc71abe568b88b535e00a7f">https://github.com/FFmpeg/FFmpeg/commit/3bce9e9b3ea35c54bacccc793d7da99ea5157532#diff-74f6b92a0541378ad15de9c29c0a2b0c69881ad9ffc71abe568b88b535e00a7f</a><br><a href="https://lists.debian.org/debian-lts-announce/2021/08/msg00018.html">https://lists.debian.org/debian-lts-announce/2021/08/msg00018.html</a><br></details>  |
| libavcodec58         |    CVE-2021-38090   |   MEDIUM  |  7:4.2.4-1ubuntu0.1 |  | <details><summary>Expand...</summary><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2021-38090">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2021-38090</a><br><a href="https://git.ffmpeg.org/gitweb/ffmpeg.git/commit/99f8d32129dd233d4eb2efa44678a0bc44869f23">https://git.ffmpeg.org/gitweb/ffmpeg.git/commit/99f8d32129dd233d4eb2efa44678a0bc44869f23</a><br><a href="https://trac.ffmpeg.org/ticket/8263">https://trac.ffmpeg.org/ticket/8263</a><br></details>  |
| libavcodec58         |    CVE-2021-38091   |   MEDIUM  |  7:4.2.4-1ubuntu0.1 |  | <details><summary>Expand...</summary><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2021-38091">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2021-38091</a><br><a href="https://git.ffmpeg.org/gitweb/ffmpeg.git/commit/99f8d32129dd233d4eb2efa44678a0bc44869f23">https://git.ffmpeg.org/gitweb/ffmpeg.git/commit/99f8d32129dd233d4eb2efa44678a0bc44869f23</a><br><a href="https://trac.ffmpeg.org/ticket/8263">https://trac.ffmpeg.org/ticket/8263</a><br></details>  |
| libavcodec58         |    CVE-2021-38092   |   MEDIUM  |  7:4.2.4-1ubuntu0.1 |  | <details><summary>Expand...</summary><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2021-38092">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2021-38092</a><br><a href="https://git.ffmpeg.org/gitweb/ffmpeg.git/commit/99f8d32129dd233d4eb2efa44678a0bc44869f23">https://git.ffmpeg.org/gitweb/ffmpeg.git/commit/99f8d32129dd233d4eb2efa44678a0bc44869f23</a><br><a href="https://trac.ffmpeg.org/ticket/8263">https://trac.ffmpeg.org/ticket/8263</a><br></details>  |
| libavcodec58         |    CVE-2021-38093   |   MEDIUM  |  7:4.2.4-1ubuntu0.1 |  | <details><summary>Expand...</summary><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2021-38093">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2021-38093</a><br><a href="https://git.ffmpeg.org/gitweb/ffmpeg.git/commit/99f8d32129dd233d4eb2efa44678a0bc44869f23">https://git.ffmpeg.org/gitweb/ffmpeg.git/commit/99f8d32129dd233d4eb2efa44678a0bc44869f23</a><br><a href="https://trac.ffmpeg.org/ticket/8263">https://trac.ffmpeg.org/ticket/8263</a><br></details>  |
| libavcodec58         |    CVE-2021-38094   |   MEDIUM  |  7:4.2.4-1ubuntu0.1 |  | <details><summary>Expand...</summary><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2021-38094">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2021-38094</a><br><a href="https://git.ffmpeg.org/gitweb/ffmpeg.git/commit/99f8d32129dd233d4eb2efa44678a0bc44869f23">https://git.ffmpeg.org/gitweb/ffmpeg.git/commit/99f8d32129dd233d4eb2efa44678a0bc44869f23</a><br><a href="https://trac.ffmpeg.org/ticket/8263">https://trac.ffmpeg.org/ticket/8263</a><br></details>  |
| libavcodec58         |    CVE-2021-38114   |   MEDIUM  |  7:4.2.4-1ubuntu0.1 |  | <details><summary>Expand...</summary><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2021-38114">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2021-38114</a><br><a href="https://github.com/FFmpeg/FFmpeg/commit/7150f9575671f898382c370acae35f9087a30ba1">https://github.com/FFmpeg/FFmpeg/commit/7150f9575671f898382c370acae35f9087a30ba1</a><br><a href="https://lists.debian.org/debian-lts-announce/2021/08/msg00018.html">https://lists.debian.org/debian-lts-announce/2021/08/msg00018.html</a><br><a href="https://patchwork.ffmpeg.org/project/ffmpeg/patch/PAXP193MB12624C21AE412BE95BA4D4A4B6F09@PAXP193MB1262.EURP193.PROD.OUTLOOK.COM/">https://patchwork.ffmpeg.org/project/ffmpeg/patch/PAXP193MB12624C21AE412BE95BA4D4A4B6F09@PAXP193MB1262.EURP193.PROD.OUTLOOK.COM/</a><br><a href="https://www.debian.org/security/2021/dsa-4990">https://www.debian.org/security/2021/dsa-4990</a><br><a href="https://www.debian.org/security/2021/dsa-4998">https://www.debian.org/security/2021/dsa-4998</a><br></details>  |
| libavcodec58         |    CVE-2021-38171   |   MEDIUM  |  7:4.2.4-1ubuntu0.1 |  | <details><summary>Expand...</summary><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2021-38171">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2021-38171</a><br><a href="https://github.com/FFmpeg/FFmpeg/commit/9ffa49496d1aae4cbbb387aac28a9e061a6ab0a6">https://github.com/FFmpeg/FFmpeg/commit/9ffa49496d1aae4cbbb387aac28a9e061a6ab0a6</a><br><a href="https://lists.debian.org/debian-lts-announce/2021/11/msg00012.html">https://lists.debian.org/debian-lts-announce/2021/11/msg00012.html</a><br><a href="https://patchwork.ffmpeg.org/project/ffmpeg/patch/AS8P193MB12542A86E22F8207EC971930B6F19@AS8P193MB1254.EURP193.PROD.OUTLOOK.COM/">https://patchwork.ffmpeg.org/project/ffmpeg/patch/AS8P193MB12542A86E22F8207EC971930B6F19@AS8P193MB1254.EURP193.PROD.OUTLOOK.COM/</a><br><a href="https://www.debian.org/security/2021/dsa-4990">https://www.debian.org/security/2021/dsa-4990</a><br><a href="https://www.debian.org/security/2021/dsa-4998">https://www.debian.org/security/2021/dsa-4998</a><br></details>  |
| libavcodec58         |    CVE-2021-38291   |   MEDIUM  |  7:4.2.4-1ubuntu0.1 |  | <details><summary>Expand...</summary><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2021-38291">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2021-38291</a><br><a href="https://lists.debian.org/debian-lts-announce/2021/11/msg00012.html">https://lists.debian.org/debian-lts-announce/2021/11/msg00012.html</a><br><a href="https://trac.ffmpeg.org/ticket/9312">https://trac.ffmpeg.org/ticket/9312</a><br><a href="https://www.debian.org/security/2021/dsa-4990">https://www.debian.org/security/2021/dsa-4990</a><br><a href="https://www.debian.org/security/2021/dsa-4998">https://www.debian.org/security/2021/dsa-4998</a><br></details>  |
| libavcodec58         |    CVE-2020-20445   |   LOW  |  7:4.2.4-1ubuntu0.1 |  | <details><summary>Expand...</summary><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2020-20445">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2020-20445</a><br><a href="https://lists.debian.org/debian-lts-announce/2021/11/msg00012.html">https://lists.debian.org/debian-lts-announce/2021/11/msg00012.html</a><br><a href="https://trac.ffmpeg.org/ticket/7996">https://trac.ffmpeg.org/ticket/7996</a><br><a href="https://www.debian.org/security/2021/dsa-4990">https://www.debian.org/security/2021/dsa-4990</a><br><a href="https://www.debian.org/security/2021/dsa-4998">https://www.debian.org/security/2021/dsa-4998</a><br></details>  |
| libavcodec58         |    CVE-2020-20446   |   LOW  |  7:4.2.4-1ubuntu0.1 |  | <details><summary>Expand...</summary><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2020-20446">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2020-20446</a><br><a href="https://lists.debian.org/debian-lts-announce/2021/11/msg00012.html">https://lists.debian.org/debian-lts-announce/2021/11/msg00012.html</a><br><a href="https://trac.ffmpeg.org/ticket/7995">https://trac.ffmpeg.org/ticket/7995</a><br><a href="https://www.debian.org/security/2021/dsa-4990">https://www.debian.org/security/2021/dsa-4990</a><br><a href="https://www.debian.org/security/2021/dsa-4998">https://www.debian.org/security/2021/dsa-4998</a><br></details>  |
| libavcodec58         |    CVE-2020-20450   |   LOW  |  7:4.2.4-1ubuntu0.1 |  | <details><summary>Expand...</summary><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2020-20450">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2020-20450</a><br><a href="https://git.videolan.org/?p=ffmpeg.git;a=commitdiff;h=3865b1952e5cf993b016d83ba78fe1deb63bbfad (4.3)">https://git.videolan.org/?p=ffmpeg.git;a=commitdiff;h=3865b1952e5cf993b016d83ba78fe1deb63bbfad (4.3)</a><br><a href="https://git.videolan.org/?p=ffmpeg.git;a=commitdiff;h=5400e4a50c61e53e1bc50b3e77201649bbe9c510">https://git.videolan.org/?p=ffmpeg.git;a=commitdiff;h=5400e4a50c61e53e1bc50b3e77201649bbe9c510</a><br><a href="https://trac.ffmpeg.org/ticket/7993">https://trac.ffmpeg.org/ticket/7993</a><br><a href="https://www.debian.org/security/2021/dsa-4998">https://www.debian.org/security/2021/dsa-4998</a><br></details>  |
| libavcodec58         |    CVE-2020-20451   |   LOW  |  7:4.2.4-1ubuntu0.1 |  | <details><summary>Expand...</summary><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2020-20451">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2020-20451</a><br><a href="https://git.videolan.org/?p=ffmpeg.git;a=commitdiff;h=21265f42ecb265debe9fec1dbfd0cb7de5a8aefb">https://git.videolan.org/?p=ffmpeg.git;a=commitdiff;h=21265f42ecb265debe9fec1dbfd0cb7de5a8aefb</a><br><a href="https://lists.debian.org/debian-lts-announce/2021/11/msg00012.html">https://lists.debian.org/debian-lts-announce/2021/11/msg00012.html</a><br><a href="https://trac.ffmpeg.org/ticket/8094">https://trac.ffmpeg.org/ticket/8094</a><br></details>  |
| libavcodec58         |    CVE-2020-20453   |   LOW  |  7:4.2.4-1ubuntu0.1 |  | <details><summary>Expand...</summary><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2020-20453">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2020-20453</a><br><a href="https://lists.debian.org/debian-lts-announce/2021/11/msg00012.html">https://lists.debian.org/debian-lts-announce/2021/11/msg00012.html</a><br><a href="https://trac.ffmpeg.org/ticket/8003">https://trac.ffmpeg.org/ticket/8003</a><br><a href="https://www.debian.org/security/2021/dsa-4990">https://www.debian.org/security/2021/dsa-4990</a><br><a href="https://www.debian.org/security/2021/dsa-4998">https://www.debian.org/security/2021/dsa-4998</a><br></details>  |
| libavformat58         |    CVE-2020-14212   |   MEDIUM  |  7:4.2.4-1ubuntu0.1 |  | <details><summary>Expand...</summary><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2020-14212">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2020-14212</a><br><a href="https://patchwork.ffmpeg.org/project/ffmpeg/list/?series=1463">https://patchwork.ffmpeg.org/project/ffmpeg/list/?series=1463</a><br><a href="https://security.gentoo.org/glsa/202007-58">https://security.gentoo.org/glsa/202007-58</a><br><a href="https://trac.ffmpeg.org/ticket/8716">https://trac.ffmpeg.org/ticket/8716</a><br></details>  |
| libavformat58         |    CVE-2020-20891   |   MEDIUM  |  7:4.2.4-1ubuntu0.1 |  | <details><summary>Expand...</summary><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2020-20891">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2020-20891</a><br><a href="https://git.ffmpeg.org/gitweb/ffmpeg.git/commit/64a805883d7223c868a683f0030837d859edd2ab">https://git.ffmpeg.org/gitweb/ffmpeg.git/commit/64a805883d7223c868a683f0030837d859edd2ab</a><br><a href="https://trac.ffmpeg.org/ticket/8282">https://trac.ffmpeg.org/ticket/8282</a><br></details>  |
| libavformat58         |    CVE-2020-20892   |   MEDIUM  |  7:4.2.4-1ubuntu0.1 |  | <details><summary>Expand...</summary><a href="http://git.videolan.org/?p=ffmpeg.git;a=commit;h=19587c9332f5be4f6bc6d7b2b8ef3fd21dfeaa01">http://git.videolan.org/?p=ffmpeg.git;a=commit;h=19587c9332f5be4f6bc6d7b2b8ef3fd21dfeaa01</a><br><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2020-20892">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2020-20892</a><br><a href="https://trac.ffmpeg.org/ticket/8265">https://trac.ffmpeg.org/ticket/8265</a><br></details>  |
| libavformat58         |    CVE-2020-20896   |   MEDIUM  |  7:4.2.4-1ubuntu0.1 |  | <details><summary>Expand...</summary><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2020-20896">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2020-20896</a><br><a href="https://git.ffmpeg.org/gitweb/ffmpeg.git/commit/dd01947397b98e94c3f2a79d5820aaf4594f4d3b">https://git.ffmpeg.org/gitweb/ffmpeg.git/commit/dd01947397b98e94c3f2a79d5820aaf4594f4d3b</a><br><a href="https://trac.ffmpeg.org/ticket/8273">https://trac.ffmpeg.org/ticket/8273</a><br></details>  |
| libavformat58         |    CVE-2020-20898   |   MEDIUM  |  7:4.2.4-1ubuntu0.1 |  | <details><summary>Expand...</summary><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2020-20898">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2020-20898</a><br><a href="https://git.ffmpeg.org/gitweb/ffmpeg.git/commit/99f8d32129dd233d4eb2efa44678a0bc44869f23">https://git.ffmpeg.org/gitweb/ffmpeg.git/commit/99f8d32129dd233d4eb2efa44678a0bc44869f23</a><br><a href="https://trac.ffmpeg.org/ticket/8263">https://trac.ffmpeg.org/ticket/8263</a><br></details>  |
| libavformat58         |    CVE-2020-21041   |   MEDIUM  |  7:4.2.4-1ubuntu0.1 |  | <details><summary>Expand...</summary><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2020-21041">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2020-21041</a><br><a href="https://git.videolan.org/?p=ffmpeg.git;a=commitdiff;h=5d9f44da460f781a1604d537d0555b78e29438ba">https://git.videolan.org/?p=ffmpeg.git;a=commitdiff;h=5d9f44da460f781a1604d537d0555b78e29438ba</a><br><a href="https://lists.debian.org/debian-lts-announce/2021/08/msg00018.html">https://lists.debian.org/debian-lts-announce/2021/08/msg00018.html</a><br><a href="https://trac.ffmpeg.org/ticket/7989">https://trac.ffmpeg.org/ticket/7989</a><br><a href="https://www.debian.org/security/2021/dsa-4990">https://www.debian.org/security/2021/dsa-4990</a><br></details>  |
| libavformat58         |    CVE-2020-21688   |   MEDIUM  |  7:4.2.4-1ubuntu0.1 |  | <details><summary>Expand...</summary><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2020-21688">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2020-21688</a><br><a href="https://trac.ffmpeg.org/ticket/8186">https://trac.ffmpeg.org/ticket/8186</a><br><a href="https://www.debian.org/security/2021/dsa-4998">https://www.debian.org/security/2021/dsa-4998</a><br></details>  |
| libavformat58         |    CVE-2020-21697   |   MEDIUM  |  7:4.2.4-1ubuntu0.1 |  | <details><summary>Expand...</summary><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2020-21697">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2020-21697</a><br><a href="https://trac.ffmpeg.org/ticket/8188">https://trac.ffmpeg.org/ticket/8188</a><br><a href="https://www.debian.org/security/2021/dsa-4998">https://www.debian.org/security/2021/dsa-4998</a><br></details>  |
| libavformat58         |    CVE-2020-22015   |   MEDIUM  |  7:4.2.4-1ubuntu0.1 |  | <details><summary>Expand...</summary><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2020-22015">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2020-22015</a><br><a href="https://lists.debian.org/debian-lts-announce/2021/08/msg00018.html">https://lists.debian.org/debian-lts-announce/2021/08/msg00018.html</a><br><a href="https://trac.ffmpeg.org/ticket/8190">https://trac.ffmpeg.org/ticket/8190</a><br><a href="https://www.debian.org/security/2021/dsa-4990">https://www.debian.org/security/2021/dsa-4990</a><br></details>  |
| libavformat58         |    CVE-2020-22017   |   MEDIUM  |  7:4.2.4-1ubuntu0.1 |  | <details><summary>Expand...</summary><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2020-22017">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2020-22017</a><br><a href="https://trac.ffmpeg.org/ticket/8309">https://trac.ffmpeg.org/ticket/8309</a><br><a href="https://www.debian.org/security/2021/dsa-4990">https://www.debian.org/security/2021/dsa-4990</a><br></details>  |
| libavformat58         |    CVE-2020-22019   |   MEDIUM  |  7:4.2.4-1ubuntu0.1 |  | <details><summary>Expand...</summary><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2020-22019">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2020-22019</a><br><a href="https://trac.ffmpeg.org/ticket/8241">https://trac.ffmpeg.org/ticket/8241</a><br><a href="https://www.debian.org/security/2021/dsa-4990">https://www.debian.org/security/2021/dsa-4990</a><br></details>  |
| libavformat58         |    CVE-2020-22020   |   MEDIUM  |  7:4.2.4-1ubuntu0.1 |  | <details><summary>Expand...</summary><a href="http://git.videolan.org/?p=ffmpeg.git;a=commitdiff;h=ce5274c1385d55892a692998923802023526b765">http://git.videolan.org/?p=ffmpeg.git;a=commitdiff;h=ce5274c1385d55892a692998923802023526b765</a><br><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2020-22020">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2020-22020</a><br><a href="https://lists.debian.org/debian-lts-announce/2021/08/msg00018.html">https://lists.debian.org/debian-lts-announce/2021/08/msg00018.html</a><br><a href="https://trac.ffmpeg.org/ticket/8239">https://trac.ffmpeg.org/ticket/8239</a><br><a href="https://www.debian.org/security/2021/dsa-4990">https://www.debian.org/security/2021/dsa-4990</a><br></details>  |
| libavformat58         |    CVE-2020-22021   |   MEDIUM  |  7:4.2.4-1ubuntu0.1 |  | <details><summary>Expand...</summary><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2020-22021">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2020-22021</a><br><a href="https://lists.debian.org/debian-lts-announce/2021/08/msg00018.html">https://lists.debian.org/debian-lts-announce/2021/08/msg00018.html</a><br><a href="https://trac.ffmpeg.org/ticket/8240">https://trac.ffmpeg.org/ticket/8240</a><br><a href="https://www.debian.org/security/2021/dsa-4990">https://www.debian.org/security/2021/dsa-4990</a><br></details>  |
| libavformat58         |    CVE-2020-22022   |   MEDIUM  |  7:4.2.4-1ubuntu0.1 |  | <details><summary>Expand...</summary><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2020-22022">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2020-22022</a><br><a href="https://lists.debian.org/debian-lts-announce/2021/08/msg00018.html">https://lists.debian.org/debian-lts-announce/2021/08/msg00018.html</a><br><a href="https://trac.ffmpeg.org/ticket/8264">https://trac.ffmpeg.org/ticket/8264</a><br><a href="https://www.debian.org/security/2021/dsa-4990">https://www.debian.org/security/2021/dsa-4990</a><br></details>  |
| libavformat58         |    CVE-2020-22023   |   MEDIUM  |  7:4.2.4-1ubuntu0.1 |  | <details><summary>Expand...</summary><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2020-22023">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2020-22023</a><br><a href="https://lists.debian.org/debian-lts-announce/2021/08/msg00018.html">https://lists.debian.org/debian-lts-announce/2021/08/msg00018.html</a><br><a href="https://trac.ffmpeg.org/ticket/8244">https://trac.ffmpeg.org/ticket/8244</a><br><a href="https://www.debian.org/security/2021/dsa-4990">https://www.debian.org/security/2021/dsa-4990</a><br></details>  |
| libavformat58         |    CVE-2020-22024   |   MEDIUM  |  7:4.2.4-1ubuntu0.1 |  | <details><summary>Expand...</summary><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2020-22024">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2020-22024</a><br><a href="https://trac.ffmpeg.org/ticket/8310">https://trac.ffmpeg.org/ticket/8310</a><br></details>  |
| libavformat58         |    CVE-2020-22025   |   MEDIUM  |  7:4.2.4-1ubuntu0.1 |  | <details><summary>Expand...</summary><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2020-22025">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2020-22025</a><br><a href="https://lists.debian.org/debian-lts-announce/2021/08/msg00018.html">https://lists.debian.org/debian-lts-announce/2021/08/msg00018.html</a><br><a href="https://trac.ffmpeg.org/ticket/8260">https://trac.ffmpeg.org/ticket/8260</a><br><a href="https://www.debian.org/security/2021/dsa-4990">https://www.debian.org/security/2021/dsa-4990</a><br></details>  |
| libavformat58         |    CVE-2020-22026   |   MEDIUM  |  7:4.2.4-1ubuntu0.1 |  | <details><summary>Expand...</summary><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2020-22026">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2020-22026</a><br><a href="https://lists.debian.org/debian-lts-announce/2021/08/msg00018.html">https://lists.debian.org/debian-lts-announce/2021/08/msg00018.html</a><br><a href="https://trac.ffmpeg.org/ticket/8317">https://trac.ffmpeg.org/ticket/8317</a><br><a href="https://www.debian.org/security/2021/dsa-4990">https://www.debian.org/security/2021/dsa-4990</a><br></details>  |
| libavformat58         |    CVE-2020-22027   |   MEDIUM  |  7:4.2.4-1ubuntu0.1 |  | <details><summary>Expand...</summary><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2020-22027">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2020-22027</a><br><a href="https://trac.ffmpeg.org/attachment/ticket/8242/gdb-vf_neighbor_191">https://trac.ffmpeg.org/attachment/ticket/8242/gdb-vf_neighbor_191</a><br><a href="https://trac.ffmpeg.org/ticket/8242">https://trac.ffmpeg.org/ticket/8242</a><br><a href="https://www.debian.org/security/2021/dsa-4990">https://www.debian.org/security/2021/dsa-4990</a><br></details>  |
| libavformat58         |    CVE-2020-22028   |   MEDIUM  |  7:4.2.4-1ubuntu0.1 |  | <details><summary>Expand...</summary><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2020-22028">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2020-22028</a><br><a href="https://lists.debian.org/debian-lts-announce/2021/08/msg00018.html">https://lists.debian.org/debian-lts-announce/2021/08/msg00018.html</a><br><a href="https://trac.ffmpeg.org/ticket/8274">https://trac.ffmpeg.org/ticket/8274</a><br><a href="https://www.debian.org/security/2021/dsa-4990">https://www.debian.org/security/2021/dsa-4990</a><br></details>  |
| libavformat58         |    CVE-2020-22029   |   MEDIUM  |  7:4.2.4-1ubuntu0.1 |  | <details><summary>Expand...</summary><a href="http://git.videolan.org/?p=ffmpeg.git;a=commitdiff;h=a7fd1279703683ebb548ef7baa2f1519994496ae">http://git.videolan.org/?p=ffmpeg.git;a=commitdiff;h=a7fd1279703683ebb548ef7baa2f1519994496ae</a><br><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2020-22029">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2020-22029</a><br><a href="https://trac.ffmpeg.org/ticket/8250">https://trac.ffmpeg.org/ticket/8250</a><br><a href="https://www.debian.org/security/2021/dsa-4990">https://www.debian.org/security/2021/dsa-4990</a><br></details>  |
| libavformat58         |    CVE-2020-22030   |   MEDIUM  |  7:4.2.4-1ubuntu0.1 |  | <details><summary>Expand...</summary><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2020-22030">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2020-22030</a><br><a href="https://trac.ffmpeg.org/ticket/8276">https://trac.ffmpeg.org/ticket/8276</a><br><a href="https://www.debian.org/security/2021/dsa-4990">https://www.debian.org/security/2021/dsa-4990</a><br></details>  |
| libavformat58         |    CVE-2020-22031   |   MEDIUM  |  7:4.2.4-1ubuntu0.1 |  | <details><summary>Expand...</summary><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2020-22031">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2020-22031</a><br><a href="https://lists.debian.org/debian-lts-announce/2021/08/msg00018.html">https://lists.debian.org/debian-lts-announce/2021/08/msg00018.html</a><br><a href="https://trac.ffmpeg.org/attachment/ticket/8243/gdb-vf_w3fdif_191">https://trac.ffmpeg.org/attachment/ticket/8243/gdb-vf_w3fdif_191</a><br><a href="https://trac.ffmpeg.org/ticket/8243">https://trac.ffmpeg.org/ticket/8243</a><br><a href="https://www.debian.org/security/2021/dsa-4990">https://www.debian.org/security/2021/dsa-4990</a><br></details>  |
| libavformat58         |    CVE-2020-22032   |   MEDIUM  |  7:4.2.4-1ubuntu0.1 |  | <details><summary>Expand...</summary><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2020-22032">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2020-22032</a><br><a href="https://lists.debian.org/debian-lts-announce/2021/08/msg00018.html">https://lists.debian.org/debian-lts-announce/2021/08/msg00018.html</a><br><a href="https://trac.ffmpeg.org/ticket/8275">https://trac.ffmpeg.org/ticket/8275</a><br><a href="https://www.debian.org/security/2021/dsa-4990">https://www.debian.org/security/2021/dsa-4990</a><br></details>  |
| libavformat58         |    CVE-2020-22033   |   MEDIUM  |  7:4.2.4-1ubuntu0.1 |  | <details><summary>Expand...</summary><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2020-22033">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2020-22033</a><br><a href="https://trac.ffmpeg.org/ticket/8246">https://trac.ffmpeg.org/ticket/8246</a><br><a href="https://www.debian.org/security/2021/dsa-4990">https://www.debian.org/security/2021/dsa-4990</a><br></details>  |
| libavformat58         |    CVE-2020-22034   |   MEDIUM  |  7:4.2.4-1ubuntu0.1 |  | <details><summary>Expand...</summary><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2020-22034">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2020-22034</a><br><a href="https://trac.ffmpeg.org/ticket/8236">https://trac.ffmpeg.org/ticket/8236</a><br><a href="https://www.debian.org/security/2021/dsa-4990">https://www.debian.org/security/2021/dsa-4990</a><br></details>  |
| libavformat58         |    CVE-2020-22035   |   MEDIUM  |  7:4.2.4-1ubuntu0.1 |  | <details><summary>Expand...</summary><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2020-22035">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2020-22035</a><br><a href="https://trac.ffmpeg.org/ticket/8262">https://trac.ffmpeg.org/ticket/8262</a><br><a href="https://www.debian.org/security/2021/dsa-4990">https://www.debian.org/security/2021/dsa-4990</a><br></details>  |
| libavformat58         |    CVE-2020-22036   |   MEDIUM  |  7:4.2.4-1ubuntu0.1 |  | <details><summary>Expand...</summary><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2020-22036">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2020-22036</a><br><a href="https://lists.debian.org/debian-lts-announce/2021/08/msg00018.html">https://lists.debian.org/debian-lts-announce/2021/08/msg00018.html</a><br><a href="https://trac.ffmpeg.org/ticket/8261">https://trac.ffmpeg.org/ticket/8261</a><br><a href="https://www.debian.org/security/2021/dsa-4990">https://www.debian.org/security/2021/dsa-4990</a><br></details>  |
| libavformat58         |    CVE-2020-22037   |   MEDIUM  |  7:4.2.4-1ubuntu0.1 |  | <details><summary>Expand...</summary><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2020-22037">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2020-22037</a><br><a href="https://lists.debian.org/debian-lts-announce/2021/11/msg00012.html">https://lists.debian.org/debian-lts-announce/2021/11/msg00012.html</a><br><a href="https://trac.ffmpeg.org/ticket/8281">https://trac.ffmpeg.org/ticket/8281</a><br><a href="https://www.debian.org/security/2021/dsa-4990">https://www.debian.org/security/2021/dsa-4990</a><br><a href="https://www.debian.org/security/2021/dsa-4998">https://www.debian.org/security/2021/dsa-4998</a><br></details>  |
| libavformat58         |    CVE-2020-22038   |   MEDIUM  |  7:4.2.4-1ubuntu0.1 |  | <details><summary>Expand...</summary><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2020-22038">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2020-22038</a><br><a href="https://git.videolan.org/?p=ffmpeg.git;a=commitdiff;h=7c32e9cf93b712f8463573a59ed4e98fd10fa013">https://git.videolan.org/?p=ffmpeg.git;a=commitdiff;h=7c32e9cf93b712f8463573a59ed4e98fd10fa013</a><br><a href="https://trac.ffmpeg.org/ticket/8285">https://trac.ffmpeg.org/ticket/8285</a><br></details>  |
| libavformat58         |    CVE-2020-22039   |   MEDIUM  |  7:4.2.4-1ubuntu0.1 |  | <details><summary>Expand...</summary><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2020-22039">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2020-22039</a><br><a href="https://git.videolan.org/?p=ffmpeg.git;a=commitdiff;h=a581bb66ea5eb981e2e498ca301df7d1ef15a6a3">https://git.videolan.org/?p=ffmpeg.git;a=commitdiff;h=a581bb66ea5eb981e2e498ca301df7d1ef15a6a3</a><br><a href="https://trac.ffmpeg.org/ticket/8302">https://trac.ffmpeg.org/ticket/8302</a><br></details>  |
| libavformat58         |    CVE-2020-22040   |   MEDIUM  |  7:4.2.4-1ubuntu0.1 |  | <details><summary>Expand...</summary><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2020-22040">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2020-22040</a><br><a href="https://git.videolan.org/?p=ffmpeg.git;a=commitdiff;h=1a0c584abc9709b1d11dbafef05d22e0937d7d19">https://git.videolan.org/?p=ffmpeg.git;a=commitdiff;h=1a0c584abc9709b1d11dbafef05d22e0937d7d19</a><br><a href="https://trac.ffmpeg.org/ticket/8283">https://trac.ffmpeg.org/ticket/8283</a><br></details>  |
| libavformat58         |    CVE-2020-22041   |   MEDIUM  |  7:4.2.4-1ubuntu0.1 |  | <details><summary>Expand...</summary><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2020-22041">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2020-22041</a><br><a href="https://git.videolan.org/?p=ffmpeg.git;a=commitdiff;h=3488e0977c671568731afa12b811adce9d4d807f">https://git.videolan.org/?p=ffmpeg.git;a=commitdiff;h=3488e0977c671568731afa12b811adce9d4d807f</a><br><a href="https://lists.debian.org/debian-lts-announce/2021/11/msg00012.html">https://lists.debian.org/debian-lts-announce/2021/11/msg00012.html</a><br><a href="https://trac.ffmpeg.org/ticket/8296">https://trac.ffmpeg.org/ticket/8296</a><br></details>  |
| libavformat58         |    CVE-2020-22042   |   MEDIUM  |  7:4.2.4-1ubuntu0.1 |  | <details><summary>Expand...</summary><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2020-22042">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2020-22042</a><br><a href="https://git.videolan.org/?p=ffmpeg.git;a=commitdiff;h=426c16d61a9b5056a157a1a2a057a4e4d13eef84">https://git.videolan.org/?p=ffmpeg.git;a=commitdiff;h=426c16d61a9b5056a157a1a2a057a4e4d13eef84</a><br><a href="https://trac.ffmpeg.org/ticket/8267">https://trac.ffmpeg.org/ticket/8267</a><br><a href="https://www.debian.org/security/2021/dsa-4998">https://www.debian.org/security/2021/dsa-4998</a><br></details>  |
| libavformat58         |    CVE-2020-22043   |   MEDIUM  |  7:4.2.4-1ubuntu0.1 |  | <details><summary>Expand...</summary><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2020-22043">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2020-22043</a><br><a href="https://git.videolan.org/?p=ffmpeg.git;a=commitdiff;h=b288a7eb3d963a175e177b6219c8271076ee8590">https://git.videolan.org/?p=ffmpeg.git;a=commitdiff;h=b288a7eb3d963a175e177b6219c8271076ee8590</a><br><a href="https://trac.ffmpeg.org/ticket/8284">https://trac.ffmpeg.org/ticket/8284</a><br></details>  |
| libavformat58         |    CVE-2020-22044   |   MEDIUM  |  7:4.2.4-1ubuntu0.1 |  | <details><summary>Expand...</summary><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2020-22044">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2020-22044</a><br><a href="https://git.videolan.org/?p=ffmpeg.git;a=commitdiff;h=1d479300cbe0522c233b7d51148aea2b29bd29ad">https://git.videolan.org/?p=ffmpeg.git;a=commitdiff;h=1d479300cbe0522c233b7d51148aea2b29bd29ad</a><br><a href="https://lists.debian.org/debian-lts-announce/2021/11/msg00012.html">https://lists.debian.org/debian-lts-announce/2021/11/msg00012.html</a><br><a href="https://trac.ffmpeg.org/ticket/8295">https://trac.ffmpeg.org/ticket/8295</a><br></details>  |
| libavformat58         |    CVE-2020-22048   |   MEDIUM  |  7:4.2.4-1ubuntu0.1 |  | <details><summary>Expand...</summary><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2020-22048">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2020-22048</a><br><a href="https://lists.debian.org/debian-lts-announce/2021/11/msg00012.html">https://lists.debian.org/debian-lts-announce/2021/11/msg00012.html</a><br><a href="https://trac.ffmpeg.org/ticket/8303">https://trac.ffmpeg.org/ticket/8303</a><br></details>  |
| libavformat58         |    CVE-2020-22051   |   MEDIUM  |  7:4.2.4-1ubuntu0.1 |  | <details><summary>Expand...</summary><a href="http://git.videolan.org/?p=ffmpeg.git;a=commitdiff;h=673fce6d40d9a594fb7a0ea17d296b7d3d9ea856">http://git.videolan.org/?p=ffmpeg.git;a=commitdiff;h=673fce6d40d9a594fb7a0ea17d296b7d3d9ea856</a><br><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2020-22051">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2020-22051</a><br><a href="https://trac.ffmpeg.org/ticket/8313">https://trac.ffmpeg.org/ticket/8313</a><br></details>  |
| libavformat58         |    CVE-2020-22056   |   MEDIUM  |  7:4.2.4-1ubuntu0.1 |  | <details><summary>Expand...</summary><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2020-22056">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2020-22056</a><br><a href="https://trac.ffmpeg.org/ticket/8304">https://trac.ffmpeg.org/ticket/8304</a><br></details>  |
| libavformat58         |    CVE-2020-35964   |   MEDIUM  |  7:4.2.4-1ubuntu0.1 |  | <details><summary>Expand...</summary><a href="https://bugs.chromium.org/p/oss-fuzz/issues/detail?id=26622">https://bugs.chromium.org/p/oss-fuzz/issues/detail?id=26622</a><br><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2020-35964">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2020-35964</a><br><a href="https://github.com/FFmpeg/FFmpeg/commit/27a99e2c7d450fef15594671eef4465c8a166bd7">https://github.com/FFmpeg/FFmpeg/commit/27a99e2c7d450fef15594671eef4465c8a166bd7</a><br><a href="https://security.gentoo.org/glsa/202105-24">https://security.gentoo.org/glsa/202105-24</a><br></details>  |
| libavformat58         |    CVE-2020-35965   |   MEDIUM  |  7:4.2.4-1ubuntu0.1 |  | <details><summary>Expand...</summary><a href="https://bugs.chromium.org/p/oss-fuzz/issues/detail?id=26532">https://bugs.chromium.org/p/oss-fuzz/issues/detail?id=26532</a><br><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2020-35965">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2020-35965</a><br><a href="https://github.com/FFmpeg/FFmpeg/commit/3e5959b3457f7f1856d997261e6ac672bba49e8b">https://github.com/FFmpeg/FFmpeg/commit/3e5959b3457f7f1856d997261e6ac672bba49e8b</a><br><a href="https://github.com/FFmpeg/FFmpeg/commit/b0a8b40294ea212c1938348ff112ef1b9bf16bb3">https://github.com/FFmpeg/FFmpeg/commit/b0a8b40294ea212c1938348ff112ef1b9bf16bb3</a><br><a href="https://lists.debian.org/debian-lts-announce/2021/01/msg00026.html">https://lists.debian.org/debian-lts-announce/2021/01/msg00026.html</a><br><a href="https://security.gentoo.org/glsa/202105-24">https://security.gentoo.org/glsa/202105-24</a><br><a href="https://www.debian.org/security/2021/dsa-4990">https://www.debian.org/security/2021/dsa-4990</a><br></details>  |
| libavformat58         |    CVE-2021-3566   |   MEDIUM  |  7:4.2.4-1ubuntu0.1 |  | <details><summary>Expand...</summary><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2021-3566">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2021-3566</a><br><a href="https://github.com/FFmpeg/FFmpeg/commit/3bce9e9b3ea35c54bacccc793d7da99ea5157532#diff-74f6b92a0541378ad15de9c29c0a2b0c69881ad9ffc71abe568b88b535e00a7f">https://github.com/FFmpeg/FFmpeg/commit/3bce9e9b3ea35c54bacccc793d7da99ea5157532#diff-74f6b92a0541378ad15de9c29c0a2b0c69881ad9ffc71abe568b88b535e00a7f</a><br><a href="https://lists.debian.org/debian-lts-announce/2021/08/msg00018.html">https://lists.debian.org/debian-lts-announce/2021/08/msg00018.html</a><br></details>  |
| libavformat58         |    CVE-2021-38090   |   MEDIUM  |  7:4.2.4-1ubuntu0.1 |  | <details><summary>Expand...</summary><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2021-38090">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2021-38090</a><br><a href="https://git.ffmpeg.org/gitweb/ffmpeg.git/commit/99f8d32129dd233d4eb2efa44678a0bc44869f23">https://git.ffmpeg.org/gitweb/ffmpeg.git/commit/99f8d32129dd233d4eb2efa44678a0bc44869f23</a><br><a href="https://trac.ffmpeg.org/ticket/8263">https://trac.ffmpeg.org/ticket/8263</a><br></details>  |
| libavformat58         |    CVE-2021-38091   |   MEDIUM  |  7:4.2.4-1ubuntu0.1 |  | <details><summary>Expand...</summary><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2021-38091">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2021-38091</a><br><a href="https://git.ffmpeg.org/gitweb/ffmpeg.git/commit/99f8d32129dd233d4eb2efa44678a0bc44869f23">https://git.ffmpeg.org/gitweb/ffmpeg.git/commit/99f8d32129dd233d4eb2efa44678a0bc44869f23</a><br><a href="https://trac.ffmpeg.org/ticket/8263">https://trac.ffmpeg.org/ticket/8263</a><br></details>  |
| libavformat58         |    CVE-2021-38092   |   MEDIUM  |  7:4.2.4-1ubuntu0.1 |  | <details><summary>Expand...</summary><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2021-38092">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2021-38092</a><br><a href="https://git.ffmpeg.org/gitweb/ffmpeg.git/commit/99f8d32129dd233d4eb2efa44678a0bc44869f23">https://git.ffmpeg.org/gitweb/ffmpeg.git/commit/99f8d32129dd233d4eb2efa44678a0bc44869f23</a><br><a href="https://trac.ffmpeg.org/ticket/8263">https://trac.ffmpeg.org/ticket/8263</a><br></details>  |
| libavformat58         |    CVE-2021-38093   |   MEDIUM  |  7:4.2.4-1ubuntu0.1 |  | <details><summary>Expand...</summary><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2021-38093">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2021-38093</a><br><a href="https://git.ffmpeg.org/gitweb/ffmpeg.git/commit/99f8d32129dd233d4eb2efa44678a0bc44869f23">https://git.ffmpeg.org/gitweb/ffmpeg.git/commit/99f8d32129dd233d4eb2efa44678a0bc44869f23</a><br><a href="https://trac.ffmpeg.org/ticket/8263">https://trac.ffmpeg.org/ticket/8263</a><br></details>  |
| libavformat58         |    CVE-2021-38094   |   MEDIUM  |  7:4.2.4-1ubuntu0.1 |  | <details><summary>Expand...</summary><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2021-38094">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2021-38094</a><br><a href="https://git.ffmpeg.org/gitweb/ffmpeg.git/commit/99f8d32129dd233d4eb2efa44678a0bc44869f23">https://git.ffmpeg.org/gitweb/ffmpeg.git/commit/99f8d32129dd233d4eb2efa44678a0bc44869f23</a><br><a href="https://trac.ffmpeg.org/ticket/8263">https://trac.ffmpeg.org/ticket/8263</a><br></details>  |
| libavformat58         |    CVE-2021-38114   |   MEDIUM  |  7:4.2.4-1ubuntu0.1 |  | <details><summary>Expand...</summary><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2021-38114">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2021-38114</a><br><a href="https://github.com/FFmpeg/FFmpeg/commit/7150f9575671f898382c370acae35f9087a30ba1">https://github.com/FFmpeg/FFmpeg/commit/7150f9575671f898382c370acae35f9087a30ba1</a><br><a href="https://lists.debian.org/debian-lts-announce/2021/08/msg00018.html">https://lists.debian.org/debian-lts-announce/2021/08/msg00018.html</a><br><a href="https://patchwork.ffmpeg.org/project/ffmpeg/patch/PAXP193MB12624C21AE412BE95BA4D4A4B6F09@PAXP193MB1262.EURP193.PROD.OUTLOOK.COM/">https://patchwork.ffmpeg.org/project/ffmpeg/patch/PAXP193MB12624C21AE412BE95BA4D4A4B6F09@PAXP193MB1262.EURP193.PROD.OUTLOOK.COM/</a><br><a href="https://www.debian.org/security/2021/dsa-4990">https://www.debian.org/security/2021/dsa-4990</a><br><a href="https://www.debian.org/security/2021/dsa-4998">https://www.debian.org/security/2021/dsa-4998</a><br></details>  |
| libavformat58         |    CVE-2021-38171   |   MEDIUM  |  7:4.2.4-1ubuntu0.1 |  | <details><summary>Expand...</summary><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2021-38171">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2021-38171</a><br><a href="https://github.com/FFmpeg/FFmpeg/commit/9ffa49496d1aae4cbbb387aac28a9e061a6ab0a6">https://github.com/FFmpeg/FFmpeg/commit/9ffa49496d1aae4cbbb387aac28a9e061a6ab0a6</a><br><a href="https://lists.debian.org/debian-lts-announce/2021/11/msg00012.html">https://lists.debian.org/debian-lts-announce/2021/11/msg00012.html</a><br><a href="https://patchwork.ffmpeg.org/project/ffmpeg/patch/AS8P193MB12542A86E22F8207EC971930B6F19@AS8P193MB1254.EURP193.PROD.OUTLOOK.COM/">https://patchwork.ffmpeg.org/project/ffmpeg/patch/AS8P193MB12542A86E22F8207EC971930B6F19@AS8P193MB1254.EURP193.PROD.OUTLOOK.COM/</a><br><a href="https://www.debian.org/security/2021/dsa-4990">https://www.debian.org/security/2021/dsa-4990</a><br><a href="https://www.debian.org/security/2021/dsa-4998">https://www.debian.org/security/2021/dsa-4998</a><br></details>  |
| libavformat58         |    CVE-2021-38291   |   MEDIUM  |  7:4.2.4-1ubuntu0.1 |  | <details><summary>Expand...</summary><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2021-38291">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2021-38291</a><br><a href="https://lists.debian.org/debian-lts-announce/2021/11/msg00012.html">https://lists.debian.org/debian-lts-announce/2021/11/msg00012.html</a><br><a href="https://trac.ffmpeg.org/ticket/9312">https://trac.ffmpeg.org/ticket/9312</a><br><a href="https://www.debian.org/security/2021/dsa-4990">https://www.debian.org/security/2021/dsa-4990</a><br><a href="https://www.debian.org/security/2021/dsa-4998">https://www.debian.org/security/2021/dsa-4998</a><br></details>  |
| libavformat58         |    CVE-2020-20445   |   LOW  |  7:4.2.4-1ubuntu0.1 |  | <details><summary>Expand...</summary><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2020-20445">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2020-20445</a><br><a href="https://lists.debian.org/debian-lts-announce/2021/11/msg00012.html">https://lists.debian.org/debian-lts-announce/2021/11/msg00012.html</a><br><a href="https://trac.ffmpeg.org/ticket/7996">https://trac.ffmpeg.org/ticket/7996</a><br><a href="https://www.debian.org/security/2021/dsa-4990">https://www.debian.org/security/2021/dsa-4990</a><br><a href="https://www.debian.org/security/2021/dsa-4998">https://www.debian.org/security/2021/dsa-4998</a><br></details>  |
| libavformat58         |    CVE-2020-20446   |   LOW  |  7:4.2.4-1ubuntu0.1 |  | <details><summary>Expand...</summary><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2020-20446">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2020-20446</a><br><a href="https://lists.debian.org/debian-lts-announce/2021/11/msg00012.html">https://lists.debian.org/debian-lts-announce/2021/11/msg00012.html</a><br><a href="https://trac.ffmpeg.org/ticket/7995">https://trac.ffmpeg.org/ticket/7995</a><br><a href="https://www.debian.org/security/2021/dsa-4990">https://www.debian.org/security/2021/dsa-4990</a><br><a href="https://www.debian.org/security/2021/dsa-4998">https://www.debian.org/security/2021/dsa-4998</a><br></details>  |
| libavformat58         |    CVE-2020-20450   |   LOW  |  7:4.2.4-1ubuntu0.1 |  | <details><summary>Expand...</summary><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2020-20450">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2020-20450</a><br><a href="https://git.videolan.org/?p=ffmpeg.git;a=commitdiff;h=3865b1952e5cf993b016d83ba78fe1deb63bbfad (4.3)">https://git.videolan.org/?p=ffmpeg.git;a=commitdiff;h=3865b1952e5cf993b016d83ba78fe1deb63bbfad (4.3)</a><br><a href="https://git.videolan.org/?p=ffmpeg.git;a=commitdiff;h=5400e4a50c61e53e1bc50b3e77201649bbe9c510">https://git.videolan.org/?p=ffmpeg.git;a=commitdiff;h=5400e4a50c61e53e1bc50b3e77201649bbe9c510</a><br><a href="https://trac.ffmpeg.org/ticket/7993">https://trac.ffmpeg.org/ticket/7993</a><br><a href="https://www.debian.org/security/2021/dsa-4998">https://www.debian.org/security/2021/dsa-4998</a><br></details>  |
| libavformat58         |    CVE-2020-20451   |   LOW  |  7:4.2.4-1ubuntu0.1 |  | <details><summary>Expand...</summary><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2020-20451">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2020-20451</a><br><a href="https://git.videolan.org/?p=ffmpeg.git;a=commitdiff;h=21265f42ecb265debe9fec1dbfd0cb7de5a8aefb">https://git.videolan.org/?p=ffmpeg.git;a=commitdiff;h=21265f42ecb265debe9fec1dbfd0cb7de5a8aefb</a><br><a href="https://lists.debian.org/debian-lts-announce/2021/11/msg00012.html">https://lists.debian.org/debian-lts-announce/2021/11/msg00012.html</a><br><a href="https://trac.ffmpeg.org/ticket/8094">https://trac.ffmpeg.org/ticket/8094</a><br></details>  |
| libavformat58         |    CVE-2020-20453   |   LOW  |  7:4.2.4-1ubuntu0.1 |  | <details><summary>Expand...</summary><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2020-20453">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2020-20453</a><br><a href="https://lists.debian.org/debian-lts-announce/2021/11/msg00012.html">https://lists.debian.org/debian-lts-announce/2021/11/msg00012.html</a><br><a href="https://trac.ffmpeg.org/ticket/8003">https://trac.ffmpeg.org/ticket/8003</a><br><a href="https://www.debian.org/security/2021/dsa-4990">https://www.debian.org/security/2021/dsa-4990</a><br><a href="https://www.debian.org/security/2021/dsa-4998">https://www.debian.org/security/2021/dsa-4998</a><br></details>  |
| libavutil56         |    CVE-2020-14212   |   MEDIUM  |  7:4.2.4-1ubuntu0.1 |  | <details><summary>Expand...</summary><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2020-14212">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2020-14212</a><br><a href="https://patchwork.ffmpeg.org/project/ffmpeg/list/?series=1463">https://patchwork.ffmpeg.org/project/ffmpeg/list/?series=1463</a><br><a href="https://security.gentoo.org/glsa/202007-58">https://security.gentoo.org/glsa/202007-58</a><br><a href="https://trac.ffmpeg.org/ticket/8716">https://trac.ffmpeg.org/ticket/8716</a><br></details>  |
| libavutil56         |    CVE-2020-20891   |   MEDIUM  |  7:4.2.4-1ubuntu0.1 |  | <details><summary>Expand...</summary><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2020-20891">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2020-20891</a><br><a href="https://git.ffmpeg.org/gitweb/ffmpeg.git/commit/64a805883d7223c868a683f0030837d859edd2ab">https://git.ffmpeg.org/gitweb/ffmpeg.git/commit/64a805883d7223c868a683f0030837d859edd2ab</a><br><a href="https://trac.ffmpeg.org/ticket/8282">https://trac.ffmpeg.org/ticket/8282</a><br></details>  |
| libavutil56         |    CVE-2020-20892   |   MEDIUM  |  7:4.2.4-1ubuntu0.1 |  | <details><summary>Expand...</summary><a href="http://git.videolan.org/?p=ffmpeg.git;a=commit;h=19587c9332f5be4f6bc6d7b2b8ef3fd21dfeaa01">http://git.videolan.org/?p=ffmpeg.git;a=commit;h=19587c9332f5be4f6bc6d7b2b8ef3fd21dfeaa01</a><br><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2020-20892">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2020-20892</a><br><a href="https://trac.ffmpeg.org/ticket/8265">https://trac.ffmpeg.org/ticket/8265</a><br></details>  |
| libavutil56         |    CVE-2020-20896   |   MEDIUM  |  7:4.2.4-1ubuntu0.1 |  | <details><summary>Expand...</summary><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2020-20896">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2020-20896</a><br><a href="https://git.ffmpeg.org/gitweb/ffmpeg.git/commit/dd01947397b98e94c3f2a79d5820aaf4594f4d3b">https://git.ffmpeg.org/gitweb/ffmpeg.git/commit/dd01947397b98e94c3f2a79d5820aaf4594f4d3b</a><br><a href="https://trac.ffmpeg.org/ticket/8273">https://trac.ffmpeg.org/ticket/8273</a><br></details>  |
| libavutil56         |    CVE-2020-20898   |   MEDIUM  |  7:4.2.4-1ubuntu0.1 |  | <details><summary>Expand...</summary><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2020-20898">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2020-20898</a><br><a href="https://git.ffmpeg.org/gitweb/ffmpeg.git/commit/99f8d32129dd233d4eb2efa44678a0bc44869f23">https://git.ffmpeg.org/gitweb/ffmpeg.git/commit/99f8d32129dd233d4eb2efa44678a0bc44869f23</a><br><a href="https://trac.ffmpeg.org/ticket/8263">https://trac.ffmpeg.org/ticket/8263</a><br></details>  |
| libavutil56         |    CVE-2020-21041   |   MEDIUM  |  7:4.2.4-1ubuntu0.1 |  | <details><summary>Expand...</summary><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2020-21041">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2020-21041</a><br><a href="https://git.videolan.org/?p=ffmpeg.git;a=commitdiff;h=5d9f44da460f781a1604d537d0555b78e29438ba">https://git.videolan.org/?p=ffmpeg.git;a=commitdiff;h=5d9f44da460f781a1604d537d0555b78e29438ba</a><br><a href="https://lists.debian.org/debian-lts-announce/2021/08/msg00018.html">https://lists.debian.org/debian-lts-announce/2021/08/msg00018.html</a><br><a href="https://trac.ffmpeg.org/ticket/7989">https://trac.ffmpeg.org/ticket/7989</a><br><a href="https://www.debian.org/security/2021/dsa-4990">https://www.debian.org/security/2021/dsa-4990</a><br></details>  |
| libavutil56         |    CVE-2020-21688   |   MEDIUM  |  7:4.2.4-1ubuntu0.1 |  | <details><summary>Expand...</summary><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2020-21688">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2020-21688</a><br><a href="https://trac.ffmpeg.org/ticket/8186">https://trac.ffmpeg.org/ticket/8186</a><br><a href="https://www.debian.org/security/2021/dsa-4998">https://www.debian.org/security/2021/dsa-4998</a><br></details>  |
| libavutil56         |    CVE-2020-21697   |   MEDIUM  |  7:4.2.4-1ubuntu0.1 |  | <details><summary>Expand...</summary><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2020-21697">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2020-21697</a><br><a href="https://trac.ffmpeg.org/ticket/8188">https://trac.ffmpeg.org/ticket/8188</a><br><a href="https://www.debian.org/security/2021/dsa-4998">https://www.debian.org/security/2021/dsa-4998</a><br></details>  |
| libavutil56         |    CVE-2020-22015   |   MEDIUM  |  7:4.2.4-1ubuntu0.1 |  | <details><summary>Expand...</summary><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2020-22015">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2020-22015</a><br><a href="https://lists.debian.org/debian-lts-announce/2021/08/msg00018.html">https://lists.debian.org/debian-lts-announce/2021/08/msg00018.html</a><br><a href="https://trac.ffmpeg.org/ticket/8190">https://trac.ffmpeg.org/ticket/8190</a><br><a href="https://www.debian.org/security/2021/dsa-4990">https://www.debian.org/security/2021/dsa-4990</a><br></details>  |
| libavutil56         |    CVE-2020-22017   |   MEDIUM  |  7:4.2.4-1ubuntu0.1 |  | <details><summary>Expand...</summary><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2020-22017">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2020-22017</a><br><a href="https://trac.ffmpeg.org/ticket/8309">https://trac.ffmpeg.org/ticket/8309</a><br><a href="https://www.debian.org/security/2021/dsa-4990">https://www.debian.org/security/2021/dsa-4990</a><br></details>  |
| libavutil56         |    CVE-2020-22019   |   MEDIUM  |  7:4.2.4-1ubuntu0.1 |  | <details><summary>Expand...</summary><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2020-22019">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2020-22019</a><br><a href="https://trac.ffmpeg.org/ticket/8241">https://trac.ffmpeg.org/ticket/8241</a><br><a href="https://www.debian.org/security/2021/dsa-4990">https://www.debian.org/security/2021/dsa-4990</a><br></details>  |
| libavutil56         |    CVE-2020-22020   |   MEDIUM  |  7:4.2.4-1ubuntu0.1 |  | <details><summary>Expand...</summary><a href="http://git.videolan.org/?p=ffmpeg.git;a=commitdiff;h=ce5274c1385d55892a692998923802023526b765">http://git.videolan.org/?p=ffmpeg.git;a=commitdiff;h=ce5274c1385d55892a692998923802023526b765</a><br><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2020-22020">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2020-22020</a><br><a href="https://lists.debian.org/debian-lts-announce/2021/08/msg00018.html">https://lists.debian.org/debian-lts-announce/2021/08/msg00018.html</a><br><a href="https://trac.ffmpeg.org/ticket/8239">https://trac.ffmpeg.org/ticket/8239</a><br><a href="https://www.debian.org/security/2021/dsa-4990">https://www.debian.org/security/2021/dsa-4990</a><br></details>  |
| libavutil56         |    CVE-2020-22021   |   MEDIUM  |  7:4.2.4-1ubuntu0.1 |  | <details><summary>Expand...</summary><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2020-22021">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2020-22021</a><br><a href="https://lists.debian.org/debian-lts-announce/2021/08/msg00018.html">https://lists.debian.org/debian-lts-announce/2021/08/msg00018.html</a><br><a href="https://trac.ffmpeg.org/ticket/8240">https://trac.ffmpeg.org/ticket/8240</a><br><a href="https://www.debian.org/security/2021/dsa-4990">https://www.debian.org/security/2021/dsa-4990</a><br></details>  |
| libavutil56         |    CVE-2020-22022   |   MEDIUM  |  7:4.2.4-1ubuntu0.1 |  | <details><summary>Expand...</summary><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2020-22022">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2020-22022</a><br><a href="https://lists.debian.org/debian-lts-announce/2021/08/msg00018.html">https://lists.debian.org/debian-lts-announce/2021/08/msg00018.html</a><br><a href="https://trac.ffmpeg.org/ticket/8264">https://trac.ffmpeg.org/ticket/8264</a><br><a href="https://www.debian.org/security/2021/dsa-4990">https://www.debian.org/security/2021/dsa-4990</a><br></details>  |
| libavutil56         |    CVE-2020-22023   |   MEDIUM  |  7:4.2.4-1ubuntu0.1 |  | <details><summary>Expand...</summary><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2020-22023">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2020-22023</a><br><a href="https://lists.debian.org/debian-lts-announce/2021/08/msg00018.html">https://lists.debian.org/debian-lts-announce/2021/08/msg00018.html</a><br><a href="https://trac.ffmpeg.org/ticket/8244">https://trac.ffmpeg.org/ticket/8244</a><br><a href="https://www.debian.org/security/2021/dsa-4990">https://www.debian.org/security/2021/dsa-4990</a><br></details>  |
| libavutil56         |    CVE-2020-22024   |   MEDIUM  |  7:4.2.4-1ubuntu0.1 |  | <details><summary>Expand...</summary><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2020-22024">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2020-22024</a><br><a href="https://trac.ffmpeg.org/ticket/8310">https://trac.ffmpeg.org/ticket/8310</a><br></details>  |
| libavutil56         |    CVE-2020-22025   |   MEDIUM  |  7:4.2.4-1ubuntu0.1 |  | <details><summary>Expand...</summary><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2020-22025">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2020-22025</a><br><a href="https://lists.debian.org/debian-lts-announce/2021/08/msg00018.html">https://lists.debian.org/debian-lts-announce/2021/08/msg00018.html</a><br><a href="https://trac.ffmpeg.org/ticket/8260">https://trac.ffmpeg.org/ticket/8260</a><br><a href="https://www.debian.org/security/2021/dsa-4990">https://www.debian.org/security/2021/dsa-4990</a><br></details>  |
| libavutil56         |    CVE-2020-22026   |   MEDIUM  |  7:4.2.4-1ubuntu0.1 |  | <details><summary>Expand...</summary><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2020-22026">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2020-22026</a><br><a href="https://lists.debian.org/debian-lts-announce/2021/08/msg00018.html">https://lists.debian.org/debian-lts-announce/2021/08/msg00018.html</a><br><a href="https://trac.ffmpeg.org/ticket/8317">https://trac.ffmpeg.org/ticket/8317</a><br><a href="https://www.debian.org/security/2021/dsa-4990">https://www.debian.org/security/2021/dsa-4990</a><br></details>  |
| libavutil56         |    CVE-2020-22027   |   MEDIUM  |  7:4.2.4-1ubuntu0.1 |  | <details><summary>Expand...</summary><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2020-22027">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2020-22027</a><br><a href="https://trac.ffmpeg.org/attachment/ticket/8242/gdb-vf_neighbor_191">https://trac.ffmpeg.org/attachment/ticket/8242/gdb-vf_neighbor_191</a><br><a href="https://trac.ffmpeg.org/ticket/8242">https://trac.ffmpeg.org/ticket/8242</a><br><a href="https://www.debian.org/security/2021/dsa-4990">https://www.debian.org/security/2021/dsa-4990</a><br></details>  |
| libavutil56         |    CVE-2020-22028   |   MEDIUM  |  7:4.2.4-1ubuntu0.1 |  | <details><summary>Expand...</summary><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2020-22028">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2020-22028</a><br><a href="https://lists.debian.org/debian-lts-announce/2021/08/msg00018.html">https://lists.debian.org/debian-lts-announce/2021/08/msg00018.html</a><br><a href="https://trac.ffmpeg.org/ticket/8274">https://trac.ffmpeg.org/ticket/8274</a><br><a href="https://www.debian.org/security/2021/dsa-4990">https://www.debian.org/security/2021/dsa-4990</a><br></details>  |
| libavutil56         |    CVE-2020-22029   |   MEDIUM  |  7:4.2.4-1ubuntu0.1 |  | <details><summary>Expand...</summary><a href="http://git.videolan.org/?p=ffmpeg.git;a=commitdiff;h=a7fd1279703683ebb548ef7baa2f1519994496ae">http://git.videolan.org/?p=ffmpeg.git;a=commitdiff;h=a7fd1279703683ebb548ef7baa2f1519994496ae</a><br><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2020-22029">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2020-22029</a><br><a href="https://trac.ffmpeg.org/ticket/8250">https://trac.ffmpeg.org/ticket/8250</a><br><a href="https://www.debian.org/security/2021/dsa-4990">https://www.debian.org/security/2021/dsa-4990</a><br></details>  |
| libavutil56         |    CVE-2020-22030   |   MEDIUM  |  7:4.2.4-1ubuntu0.1 |  | <details><summary>Expand...</summary><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2020-22030">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2020-22030</a><br><a href="https://trac.ffmpeg.org/ticket/8276">https://trac.ffmpeg.org/ticket/8276</a><br><a href="https://www.debian.org/security/2021/dsa-4990">https://www.debian.org/security/2021/dsa-4990</a><br></details>  |
| libavutil56         |    CVE-2020-22031   |   MEDIUM  |  7:4.2.4-1ubuntu0.1 |  | <details><summary>Expand...</summary><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2020-22031">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2020-22031</a><br><a href="https://lists.debian.org/debian-lts-announce/2021/08/msg00018.html">https://lists.debian.org/debian-lts-announce/2021/08/msg00018.html</a><br><a href="https://trac.ffmpeg.org/attachment/ticket/8243/gdb-vf_w3fdif_191">https://trac.ffmpeg.org/attachment/ticket/8243/gdb-vf_w3fdif_191</a><br><a href="https://trac.ffmpeg.org/ticket/8243">https://trac.ffmpeg.org/ticket/8243</a><br><a href="https://www.debian.org/security/2021/dsa-4990">https://www.debian.org/security/2021/dsa-4990</a><br></details>  |
| libavutil56         |    CVE-2020-22032   |   MEDIUM  |  7:4.2.4-1ubuntu0.1 |  | <details><summary>Expand...</summary><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2020-22032">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2020-22032</a><br><a href="https://lists.debian.org/debian-lts-announce/2021/08/msg00018.html">https://lists.debian.org/debian-lts-announce/2021/08/msg00018.html</a><br><a href="https://trac.ffmpeg.org/ticket/8275">https://trac.ffmpeg.org/ticket/8275</a><br><a href="https://www.debian.org/security/2021/dsa-4990">https://www.debian.org/security/2021/dsa-4990</a><br></details>  |
| libavutil56         |    CVE-2020-22033   |   MEDIUM  |  7:4.2.4-1ubuntu0.1 |  | <details><summary>Expand...</summary><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2020-22033">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2020-22033</a><br><a href="https://trac.ffmpeg.org/ticket/8246">https://trac.ffmpeg.org/ticket/8246</a><br><a href="https://www.debian.org/security/2021/dsa-4990">https://www.debian.org/security/2021/dsa-4990</a><br></details>  |
| libavutil56         |    CVE-2020-22034   |   MEDIUM  |  7:4.2.4-1ubuntu0.1 |  | <details><summary>Expand...</summary><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2020-22034">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2020-22034</a><br><a href="https://trac.ffmpeg.org/ticket/8236">https://trac.ffmpeg.org/ticket/8236</a><br><a href="https://www.debian.org/security/2021/dsa-4990">https://www.debian.org/security/2021/dsa-4990</a><br></details>  |
| libavutil56         |    CVE-2020-22035   |   MEDIUM  |  7:4.2.4-1ubuntu0.1 |  | <details><summary>Expand...</summary><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2020-22035">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2020-22035</a><br><a href="https://trac.ffmpeg.org/ticket/8262">https://trac.ffmpeg.org/ticket/8262</a><br><a href="https://www.debian.org/security/2021/dsa-4990">https://www.debian.org/security/2021/dsa-4990</a><br></details>  |
| libavutil56         |    CVE-2020-22036   |   MEDIUM  |  7:4.2.4-1ubuntu0.1 |  | <details><summary>Expand...</summary><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2020-22036">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2020-22036</a><br><a href="https://lists.debian.org/debian-lts-announce/2021/08/msg00018.html">https://lists.debian.org/debian-lts-announce/2021/08/msg00018.html</a><br><a href="https://trac.ffmpeg.org/ticket/8261">https://trac.ffmpeg.org/ticket/8261</a><br><a href="https://www.debian.org/security/2021/dsa-4990">https://www.debian.org/security/2021/dsa-4990</a><br></details>  |
| libavutil56         |    CVE-2020-22037   |   MEDIUM  |  7:4.2.4-1ubuntu0.1 |  | <details><summary>Expand...</summary><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2020-22037">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2020-22037</a><br><a href="https://lists.debian.org/debian-lts-announce/2021/11/msg00012.html">https://lists.debian.org/debian-lts-announce/2021/11/msg00012.html</a><br><a href="https://trac.ffmpeg.org/ticket/8281">https://trac.ffmpeg.org/ticket/8281</a><br><a href="https://www.debian.org/security/2021/dsa-4990">https://www.debian.org/security/2021/dsa-4990</a><br><a href="https://www.debian.org/security/2021/dsa-4998">https://www.debian.org/security/2021/dsa-4998</a><br></details>  |
| libavutil56         |    CVE-2020-22038   |   MEDIUM  |  7:4.2.4-1ubuntu0.1 |  | <details><summary>Expand...</summary><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2020-22038">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2020-22038</a><br><a href="https://git.videolan.org/?p=ffmpeg.git;a=commitdiff;h=7c32e9cf93b712f8463573a59ed4e98fd10fa013">https://git.videolan.org/?p=ffmpeg.git;a=commitdiff;h=7c32e9cf93b712f8463573a59ed4e98fd10fa013</a><br><a href="https://trac.ffmpeg.org/ticket/8285">https://trac.ffmpeg.org/ticket/8285</a><br></details>  |
| libavutil56         |    CVE-2020-22039   |   MEDIUM  |  7:4.2.4-1ubuntu0.1 |  | <details><summary>Expand...</summary><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2020-22039">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2020-22039</a><br><a href="https://git.videolan.org/?p=ffmpeg.git;a=commitdiff;h=a581bb66ea5eb981e2e498ca301df7d1ef15a6a3">https://git.videolan.org/?p=ffmpeg.git;a=commitdiff;h=a581bb66ea5eb981e2e498ca301df7d1ef15a6a3</a><br><a href="https://trac.ffmpeg.org/ticket/8302">https://trac.ffmpeg.org/ticket/8302</a><br></details>  |
| libavutil56         |    CVE-2020-22040   |   MEDIUM  |  7:4.2.4-1ubuntu0.1 |  | <details><summary>Expand...</summary><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2020-22040">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2020-22040</a><br><a href="https://git.videolan.org/?p=ffmpeg.git;a=commitdiff;h=1a0c584abc9709b1d11dbafef05d22e0937d7d19">https://git.videolan.org/?p=ffmpeg.git;a=commitdiff;h=1a0c584abc9709b1d11dbafef05d22e0937d7d19</a><br><a href="https://trac.ffmpeg.org/ticket/8283">https://trac.ffmpeg.org/ticket/8283</a><br></details>  |
| libavutil56         |    CVE-2020-22041   |   MEDIUM  |  7:4.2.4-1ubuntu0.1 |  | <details><summary>Expand...</summary><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2020-22041">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2020-22041</a><br><a href="https://git.videolan.org/?p=ffmpeg.git;a=commitdiff;h=3488e0977c671568731afa12b811adce9d4d807f">https://git.videolan.org/?p=ffmpeg.git;a=commitdiff;h=3488e0977c671568731afa12b811adce9d4d807f</a><br><a href="https://lists.debian.org/debian-lts-announce/2021/11/msg00012.html">https://lists.debian.org/debian-lts-announce/2021/11/msg00012.html</a><br><a href="https://trac.ffmpeg.org/ticket/8296">https://trac.ffmpeg.org/ticket/8296</a><br></details>  |
| libavutil56         |    CVE-2020-22042   |   MEDIUM  |  7:4.2.4-1ubuntu0.1 |  | <details><summary>Expand...</summary><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2020-22042">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2020-22042</a><br><a href="https://git.videolan.org/?p=ffmpeg.git;a=commitdiff;h=426c16d61a9b5056a157a1a2a057a4e4d13eef84">https://git.videolan.org/?p=ffmpeg.git;a=commitdiff;h=426c16d61a9b5056a157a1a2a057a4e4d13eef84</a><br><a href="https://trac.ffmpeg.org/ticket/8267">https://trac.ffmpeg.org/ticket/8267</a><br><a href="https://www.debian.org/security/2021/dsa-4998">https://www.debian.org/security/2021/dsa-4998</a><br></details>  |
| libavutil56         |    CVE-2020-22043   |   MEDIUM  |  7:4.2.4-1ubuntu0.1 |  | <details><summary>Expand...</summary><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2020-22043">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2020-22043</a><br><a href="https://git.videolan.org/?p=ffmpeg.git;a=commitdiff;h=b288a7eb3d963a175e177b6219c8271076ee8590">https://git.videolan.org/?p=ffmpeg.git;a=commitdiff;h=b288a7eb3d963a175e177b6219c8271076ee8590</a><br><a href="https://trac.ffmpeg.org/ticket/8284">https://trac.ffmpeg.org/ticket/8284</a><br></details>  |
| libavutil56         |    CVE-2020-22044   |   MEDIUM  |  7:4.2.4-1ubuntu0.1 |  | <details><summary>Expand...</summary><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2020-22044">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2020-22044</a><br><a href="https://git.videolan.org/?p=ffmpeg.git;a=commitdiff;h=1d479300cbe0522c233b7d51148aea2b29bd29ad">https://git.videolan.org/?p=ffmpeg.git;a=commitdiff;h=1d479300cbe0522c233b7d51148aea2b29bd29ad</a><br><a href="https://lists.debian.org/debian-lts-announce/2021/11/msg00012.html">https://lists.debian.org/debian-lts-announce/2021/11/msg00012.html</a><br><a href="https://trac.ffmpeg.org/ticket/8295">https://trac.ffmpeg.org/ticket/8295</a><br></details>  |
| libavutil56         |    CVE-2020-22048   |   MEDIUM  |  7:4.2.4-1ubuntu0.1 |  | <details><summary>Expand...</summary><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2020-22048">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2020-22048</a><br><a href="https://lists.debian.org/debian-lts-announce/2021/11/msg00012.html">https://lists.debian.org/debian-lts-announce/2021/11/msg00012.html</a><br><a href="https://trac.ffmpeg.org/ticket/8303">https://trac.ffmpeg.org/ticket/8303</a><br></details>  |
| libavutil56         |    CVE-2020-22051   |   MEDIUM  |  7:4.2.4-1ubuntu0.1 |  | <details><summary>Expand...</summary><a href="http://git.videolan.org/?p=ffmpeg.git;a=commitdiff;h=673fce6d40d9a594fb7a0ea17d296b7d3d9ea856">http://git.videolan.org/?p=ffmpeg.git;a=commitdiff;h=673fce6d40d9a594fb7a0ea17d296b7d3d9ea856</a><br><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2020-22051">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2020-22051</a><br><a href="https://trac.ffmpeg.org/ticket/8313">https://trac.ffmpeg.org/ticket/8313</a><br></details>  |
| libavutil56         |    CVE-2020-22056   |   MEDIUM  |  7:4.2.4-1ubuntu0.1 |  | <details><summary>Expand...</summary><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2020-22056">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2020-22056</a><br><a href="https://trac.ffmpeg.org/ticket/8304">https://trac.ffmpeg.org/ticket/8304</a><br></details>  |
| libavutil56         |    CVE-2020-35964   |   MEDIUM  |  7:4.2.4-1ubuntu0.1 |  | <details><summary>Expand...</summary><a href="https://bugs.chromium.org/p/oss-fuzz/issues/detail?id=26622">https://bugs.chromium.org/p/oss-fuzz/issues/detail?id=26622</a><br><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2020-35964">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2020-35964</a><br><a href="https://github.com/FFmpeg/FFmpeg/commit/27a99e2c7d450fef15594671eef4465c8a166bd7">https://github.com/FFmpeg/FFmpeg/commit/27a99e2c7d450fef15594671eef4465c8a166bd7</a><br><a href="https://security.gentoo.org/glsa/202105-24">https://security.gentoo.org/glsa/202105-24</a><br></details>  |
| libavutil56         |    CVE-2020-35965   |   MEDIUM  |  7:4.2.4-1ubuntu0.1 |  | <details><summary>Expand...</summary><a href="https://bugs.chromium.org/p/oss-fuzz/issues/detail?id=26532">https://bugs.chromium.org/p/oss-fuzz/issues/detail?id=26532</a><br><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2020-35965">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2020-35965</a><br><a href="https://github.com/FFmpeg/FFmpeg/commit/3e5959b3457f7f1856d997261e6ac672bba49e8b">https://github.com/FFmpeg/FFmpeg/commit/3e5959b3457f7f1856d997261e6ac672bba49e8b</a><br><a href="https://github.com/FFmpeg/FFmpeg/commit/b0a8b40294ea212c1938348ff112ef1b9bf16bb3">https://github.com/FFmpeg/FFmpeg/commit/b0a8b40294ea212c1938348ff112ef1b9bf16bb3</a><br><a href="https://lists.debian.org/debian-lts-announce/2021/01/msg00026.html">https://lists.debian.org/debian-lts-announce/2021/01/msg00026.html</a><br><a href="https://security.gentoo.org/glsa/202105-24">https://security.gentoo.org/glsa/202105-24</a><br><a href="https://www.debian.org/security/2021/dsa-4990">https://www.debian.org/security/2021/dsa-4990</a><br></details>  |
| libavutil56         |    CVE-2021-3566   |   MEDIUM  |  7:4.2.4-1ubuntu0.1 |  | <details><summary>Expand...</summary><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2021-3566">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2021-3566</a><br><a href="https://github.com/FFmpeg/FFmpeg/commit/3bce9e9b3ea35c54bacccc793d7da99ea5157532#diff-74f6b92a0541378ad15de9c29c0a2b0c69881ad9ffc71abe568b88b535e00a7f">https://github.com/FFmpeg/FFmpeg/commit/3bce9e9b3ea35c54bacccc793d7da99ea5157532#diff-74f6b92a0541378ad15de9c29c0a2b0c69881ad9ffc71abe568b88b535e00a7f</a><br><a href="https://lists.debian.org/debian-lts-announce/2021/08/msg00018.html">https://lists.debian.org/debian-lts-announce/2021/08/msg00018.html</a><br></details>  |
| libavutil56         |    CVE-2021-38090   |   MEDIUM  |  7:4.2.4-1ubuntu0.1 |  | <details><summary>Expand...</summary><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2021-38090">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2021-38090</a><br><a href="https://git.ffmpeg.org/gitweb/ffmpeg.git/commit/99f8d32129dd233d4eb2efa44678a0bc44869f23">https://git.ffmpeg.org/gitweb/ffmpeg.git/commit/99f8d32129dd233d4eb2efa44678a0bc44869f23</a><br><a href="https://trac.ffmpeg.org/ticket/8263">https://trac.ffmpeg.org/ticket/8263</a><br></details>  |
| libavutil56         |    CVE-2021-38091   |   MEDIUM  |  7:4.2.4-1ubuntu0.1 |  | <details><summary>Expand...</summary><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2021-38091">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2021-38091</a><br><a href="https://git.ffmpeg.org/gitweb/ffmpeg.git/commit/99f8d32129dd233d4eb2efa44678a0bc44869f23">https://git.ffmpeg.org/gitweb/ffmpeg.git/commit/99f8d32129dd233d4eb2efa44678a0bc44869f23</a><br><a href="https://trac.ffmpeg.org/ticket/8263">https://trac.ffmpeg.org/ticket/8263</a><br></details>  |
| libavutil56         |    CVE-2021-38092   |   MEDIUM  |  7:4.2.4-1ubuntu0.1 |  | <details><summary>Expand...</summary><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2021-38092">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2021-38092</a><br><a href="https://git.ffmpeg.org/gitweb/ffmpeg.git/commit/99f8d32129dd233d4eb2efa44678a0bc44869f23">https://git.ffmpeg.org/gitweb/ffmpeg.git/commit/99f8d32129dd233d4eb2efa44678a0bc44869f23</a><br><a href="https://trac.ffmpeg.org/ticket/8263">https://trac.ffmpeg.org/ticket/8263</a><br></details>  |
| libavutil56         |    CVE-2021-38093   |   MEDIUM  |  7:4.2.4-1ubuntu0.1 |  | <details><summary>Expand...</summary><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2021-38093">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2021-38093</a><br><a href="https://git.ffmpeg.org/gitweb/ffmpeg.git/commit/99f8d32129dd233d4eb2efa44678a0bc44869f23">https://git.ffmpeg.org/gitweb/ffmpeg.git/commit/99f8d32129dd233d4eb2efa44678a0bc44869f23</a><br><a href="https://trac.ffmpeg.org/ticket/8263">https://trac.ffmpeg.org/ticket/8263</a><br></details>  |
| libavutil56         |    CVE-2021-38094   |   MEDIUM  |  7:4.2.4-1ubuntu0.1 |  | <details><summary>Expand...</summary><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2021-38094">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2021-38094</a><br><a href="https://git.ffmpeg.org/gitweb/ffmpeg.git/commit/99f8d32129dd233d4eb2efa44678a0bc44869f23">https://git.ffmpeg.org/gitweb/ffmpeg.git/commit/99f8d32129dd233d4eb2efa44678a0bc44869f23</a><br><a href="https://trac.ffmpeg.org/ticket/8263">https://trac.ffmpeg.org/ticket/8263</a><br></details>  |
| libavutil56         |    CVE-2021-38114   |   MEDIUM  |  7:4.2.4-1ubuntu0.1 |  | <details><summary>Expand...</summary><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2021-38114">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2021-38114</a><br><a href="https://github.com/FFmpeg/FFmpeg/commit/7150f9575671f898382c370acae35f9087a30ba1">https://github.com/FFmpeg/FFmpeg/commit/7150f9575671f898382c370acae35f9087a30ba1</a><br><a href="https://lists.debian.org/debian-lts-announce/2021/08/msg00018.html">https://lists.debian.org/debian-lts-announce/2021/08/msg00018.html</a><br><a href="https://patchwork.ffmpeg.org/project/ffmpeg/patch/PAXP193MB12624C21AE412BE95BA4D4A4B6F09@PAXP193MB1262.EURP193.PROD.OUTLOOK.COM/">https://patchwork.ffmpeg.org/project/ffmpeg/patch/PAXP193MB12624C21AE412BE95BA4D4A4B6F09@PAXP193MB1262.EURP193.PROD.OUTLOOK.COM/</a><br><a href="https://www.debian.org/security/2021/dsa-4990">https://www.debian.org/security/2021/dsa-4990</a><br><a href="https://www.debian.org/security/2021/dsa-4998">https://www.debian.org/security/2021/dsa-4998</a><br></details>  |
| libavutil56         |    CVE-2021-38171   |   MEDIUM  |  7:4.2.4-1ubuntu0.1 |  | <details><summary>Expand...</summary><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2021-38171">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2021-38171</a><br><a href="https://github.com/FFmpeg/FFmpeg/commit/9ffa49496d1aae4cbbb387aac28a9e061a6ab0a6">https://github.com/FFmpeg/FFmpeg/commit/9ffa49496d1aae4cbbb387aac28a9e061a6ab0a6</a><br><a href="https://lists.debian.org/debian-lts-announce/2021/11/msg00012.html">https://lists.debian.org/debian-lts-announce/2021/11/msg00012.html</a><br><a href="https://patchwork.ffmpeg.org/project/ffmpeg/patch/AS8P193MB12542A86E22F8207EC971930B6F19@AS8P193MB1254.EURP193.PROD.OUTLOOK.COM/">https://patchwork.ffmpeg.org/project/ffmpeg/patch/AS8P193MB12542A86E22F8207EC971930B6F19@AS8P193MB1254.EURP193.PROD.OUTLOOK.COM/</a><br><a href="https://www.debian.org/security/2021/dsa-4990">https://www.debian.org/security/2021/dsa-4990</a><br><a href="https://www.debian.org/security/2021/dsa-4998">https://www.debian.org/security/2021/dsa-4998</a><br></details>  |
| libavutil56         |    CVE-2021-38291   |   MEDIUM  |  7:4.2.4-1ubuntu0.1 |  | <details><summary>Expand...</summary><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2021-38291">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2021-38291</a><br><a href="https://lists.debian.org/debian-lts-announce/2021/11/msg00012.html">https://lists.debian.org/debian-lts-announce/2021/11/msg00012.html</a><br><a href="https://trac.ffmpeg.org/ticket/9312">https://trac.ffmpeg.org/ticket/9312</a><br><a href="https://www.debian.org/security/2021/dsa-4990">https://www.debian.org/security/2021/dsa-4990</a><br><a href="https://www.debian.org/security/2021/dsa-4998">https://www.debian.org/security/2021/dsa-4998</a><br></details>  |
| libavutil56         |    CVE-2020-20445   |   LOW  |  7:4.2.4-1ubuntu0.1 |  | <details><summary>Expand...</summary><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2020-20445">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2020-20445</a><br><a href="https://lists.debian.org/debian-lts-announce/2021/11/msg00012.html">https://lists.debian.org/debian-lts-announce/2021/11/msg00012.html</a><br><a href="https://trac.ffmpeg.org/ticket/7996">https://trac.ffmpeg.org/ticket/7996</a><br><a href="https://www.debian.org/security/2021/dsa-4990">https://www.debian.org/security/2021/dsa-4990</a><br><a href="https://www.debian.org/security/2021/dsa-4998">https://www.debian.org/security/2021/dsa-4998</a><br></details>  |
| libavutil56         |    CVE-2020-20446   |   LOW  |  7:4.2.4-1ubuntu0.1 |  | <details><summary>Expand...</summary><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2020-20446">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2020-20446</a><br><a href="https://lists.debian.org/debian-lts-announce/2021/11/msg00012.html">https://lists.debian.org/debian-lts-announce/2021/11/msg00012.html</a><br><a href="https://trac.ffmpeg.org/ticket/7995">https://trac.ffmpeg.org/ticket/7995</a><br><a href="https://www.debian.org/security/2021/dsa-4990">https://www.debian.org/security/2021/dsa-4990</a><br><a href="https://www.debian.org/security/2021/dsa-4998">https://www.debian.org/security/2021/dsa-4998</a><br></details>  |
| libavutil56         |    CVE-2020-20450   |   LOW  |  7:4.2.4-1ubuntu0.1 |  | <details><summary>Expand...</summary><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2020-20450">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2020-20450</a><br><a href="https://git.videolan.org/?p=ffmpeg.git;a=commitdiff;h=3865b1952e5cf993b016d83ba78fe1deb63bbfad (4.3)">https://git.videolan.org/?p=ffmpeg.git;a=commitdiff;h=3865b1952e5cf993b016d83ba78fe1deb63bbfad (4.3)</a><br><a href="https://git.videolan.org/?p=ffmpeg.git;a=commitdiff;h=5400e4a50c61e53e1bc50b3e77201649bbe9c510">https://git.videolan.org/?p=ffmpeg.git;a=commitdiff;h=5400e4a50c61e53e1bc50b3e77201649bbe9c510</a><br><a href="https://trac.ffmpeg.org/ticket/7993">https://trac.ffmpeg.org/ticket/7993</a><br><a href="https://www.debian.org/security/2021/dsa-4998">https://www.debian.org/security/2021/dsa-4998</a><br></details>  |
| libavutil56         |    CVE-2020-20451   |   LOW  |  7:4.2.4-1ubuntu0.1 |  | <details><summary>Expand...</summary><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2020-20451">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2020-20451</a><br><a href="https://git.videolan.org/?p=ffmpeg.git;a=commitdiff;h=21265f42ecb265debe9fec1dbfd0cb7de5a8aefb">https://git.videolan.org/?p=ffmpeg.git;a=commitdiff;h=21265f42ecb265debe9fec1dbfd0cb7de5a8aefb</a><br><a href="https://lists.debian.org/debian-lts-announce/2021/11/msg00012.html">https://lists.debian.org/debian-lts-announce/2021/11/msg00012.html</a><br><a href="https://trac.ffmpeg.org/ticket/8094">https://trac.ffmpeg.org/ticket/8094</a><br></details>  |
| libavutil56         |    CVE-2020-20453   |   LOW  |  7:4.2.4-1ubuntu0.1 |  | <details><summary>Expand...</summary><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2020-20453">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2020-20453</a><br><a href="https://lists.debian.org/debian-lts-announce/2021/11/msg00012.html">https://lists.debian.org/debian-lts-announce/2021/11/msg00012.html</a><br><a href="https://trac.ffmpeg.org/ticket/8003">https://trac.ffmpeg.org/ticket/8003</a><br><a href="https://www.debian.org/security/2021/dsa-4990">https://www.debian.org/security/2021/dsa-4990</a><br><a href="https://www.debian.org/security/2021/dsa-4998">https://www.debian.org/security/2021/dsa-4998</a><br></details>  |
| libc-bin         |    CVE-2021-35942   |   MEDIUM  |  2.31-0ubuntu9.2 |  | <details><summary>Expand...</summary><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2021-35942">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2021-35942</a><br><a href="https://linux.oracle.com/cve/CVE-2021-35942.html">https://linux.oracle.com/cve/CVE-2021-35942.html</a><br><a href="https://linux.oracle.com/errata/ELSA-2021-9560.html">https://linux.oracle.com/errata/ELSA-2021-9560.html</a><br><a href="https://security.netapp.com/advisory/ntap-20210827-0005/">https://security.netapp.com/advisory/ntap-20210827-0005/</a><br><a href="https://sourceware.org/bugzilla/show_bug.cgi?id=28011">https://sourceware.org/bugzilla/show_bug.cgi?id=28011</a><br><a href="https://sourceware.org/git/?p=glibc.git;a=commit;h=5adda61f62b77384718b4c0d8336ade8f2b4b35c">https://sourceware.org/git/?p=glibc.git;a=commit;h=5adda61f62b77384718b4c0d8336ade8f2b4b35c</a><br><a href="https://sourceware.org/git/?p=glibc.git;a=commitdiff;h=5adda61f62b77384718b4c0d8336ade8f2b4b35c">https://sourceware.org/git/?p=glibc.git;a=commitdiff;h=5adda61f62b77384718b4c0d8336ade8f2b4b35c</a><br><a href="https://sourceware.org/glibc/wiki/Security%20Exceptions">https://sourceware.org/glibc/wiki/Security%20Exceptions</a><br></details>  |
| libc-bin         |    CVE-2021-38604   |   MEDIUM  |  2.31-0ubuntu9.2 |  | <details><summary>Expand...</summary><a href="https://blog.tuxcare.com/cve/tuxcare-team-identifies-cve-2021-38604-a-new-vulnerability-in-glibc">https://blog.tuxcare.com/cve/tuxcare-team-identifies-cve-2021-38604-a-new-vulnerability-in-glibc</a><br><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2021-38604">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2021-38604</a><br><a href="https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/GYEXYM37RCJWJ6B5KQUYQI4NZBDDYSXP/">https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/GYEXYM37RCJWJ6B5KQUYQI4NZBDDYSXP/</a><br><a href="https://security.netapp.com/advisory/ntap-20210909-0005/">https://security.netapp.com/advisory/ntap-20210909-0005/</a><br><a href="https://sourceware.org/bugzilla/show_bug.cgi?id=28213">https://sourceware.org/bugzilla/show_bug.cgi?id=28213</a><br><a href="https://sourceware.org/git/?p=glibc.git;a=commit;h=4cc79c217744743077bf7a0ec5e0a4318f1e6641">https://sourceware.org/git/?p=glibc.git;a=commit;h=4cc79c217744743077bf7a0ec5e0a4318f1e6641</a><br><a href="https://sourceware.org/git/?p=glibc.git;a=commit;h=b805aebd42364fe696e417808a700fdb9800c9e8">https://sourceware.org/git/?p=glibc.git;a=commit;h=b805aebd42364fe696e417808a700fdb9800c9e8</a><br></details>  |
| libc-bin         |    CVE-2016-10228   |   LOW  |  2.31-0ubuntu9.2 |  | <details><summary>Expand...</summary><a href="http://openwall.com/lists/oss-security/2017/03/01/10">http://openwall.com/lists/oss-security/2017/03/01/10</a><br><a href="http://www.securityfocus.com/bid/96525">http://www.securityfocus.com/bid/96525</a><br><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2016-10228">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2016-10228</a><br><a href="https://linux.oracle.com/cve/CVE-2016-10228.html">https://linux.oracle.com/cve/CVE-2016-10228.html</a><br><a href="https://linux.oracle.com/errata/ELSA-2021-9344.html">https://linux.oracle.com/errata/ELSA-2021-9344.html</a><br><a href="https://lists.apache.org/thread.html/rf9fa47ab66495c78bb4120b0754dd9531ca2ff0430f6685ac9b07772@%3Cdev.mina.apache.org%3E">https://lists.apache.org/thread.html/rf9fa47ab66495c78bb4120b0754dd9531ca2ff0430f6685ac9b07772@%3Cdev.mina.apache.org%3E</a><br><a href="https://security.gentoo.org/glsa/202101-20">https://security.gentoo.org/glsa/202101-20</a><br><a href="https://sourceware.org/bugzilla/show_bug.cgi?id=19519">https://sourceware.org/bugzilla/show_bug.cgi?id=19519</a><br><a href="https://sourceware.org/bugzilla/show_bug.cgi?id=19519#c21">https://sourceware.org/bugzilla/show_bug.cgi?id=19519#c21</a><br><a href="https://sourceware.org/bugzilla/show_bug.cgi?id=26224">https://sourceware.org/bugzilla/show_bug.cgi?id=26224</a><br></details>  |
| libc-bin         |    CVE-2019-25013   |   LOW  |  2.31-0ubuntu9.2 |  | <details><summary>Expand...</summary><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2019-25013">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2019-25013</a><br><a href="https://linux.oracle.com/cve/CVE-2019-25013.html">https://linux.oracle.com/cve/CVE-2019-25013.html</a><br><a href="https://linux.oracle.com/errata/ELSA-2021-9344.html">https://linux.oracle.com/errata/ELSA-2021-9344.html</a><br><a href="https://lists.apache.org/thread.html/r32d767ac804e9b8aad4355bb85960a6a1385eab7afff549a5e98660f@%3Cjira.kafka.apache.org%3E">https://lists.apache.org/thread.html/r32d767ac804e9b8aad4355bb85960a6a1385eab7afff549a5e98660f@%3Cjira.kafka.apache.org%3E</a><br><a href="https://lists.apache.org/thread.html/r448bb851cc8e6e3f93f3c28c70032b37062625d81214744474ac49e7@%3Cdev.kafka.apache.org%3E">https://lists.apache.org/thread.html/r448bb851cc8e6e3f93f3c28c70032b37062625d81214744474ac49e7@%3Cdev.kafka.apache.org%3E</a><br><a href="https://lists.apache.org/thread.html/r4806a391091e082bdea17266452ca656ebc176e51bb3932733b3a0a2@%3Cjira.kafka.apache.org%3E">https://lists.apache.org/thread.html/r4806a391091e082bdea17266452ca656ebc176e51bb3932733b3a0a2@%3Cjira.kafka.apache.org%3E</a><br><a href="https://lists.apache.org/thread.html/r499e4f96d0b5109ef083f2feccd33c51650c1b7d7068aa3bd47efca9@%3Cjira.kafka.apache.org%3E">https://lists.apache.org/thread.html/r499e4f96d0b5109ef083f2feccd33c51650c1b7d7068aa3bd47efca9@%3Cjira.kafka.apache.org%3E</a><br><a href="https://lists.apache.org/thread.html/r5af4430421bb6f9973294691a7904bbd260937e9eef96b20556f43ff@%3Cjira.kafka.apache.org%3E">https://lists.apache.org/thread.html/r5af4430421bb6f9973294691a7904bbd260937e9eef96b20556f43ff@%3Cjira.kafka.apache.org%3E</a><br><a href="https://lists.apache.org/thread.html/r750eee18542bc02bd8350861c424ee60a9b9b225568fa09436a37ece@%3Cissues.zookeeper.apache.org%3E">https://lists.apache.org/thread.html/r750eee18542bc02bd8350861c424ee60a9b9b225568fa09436a37ece@%3Cissues.zookeeper.apache.org%3E</a><br><a href="https://lists.apache.org/thread.html/r7a2e94adfe0a2f0a1d42e4927e8c32ecac97d37db9cb68095fe9ddbc@%3Cdev.zookeeper.apache.org%3E">https://lists.apache.org/thread.html/r7a2e94adfe0a2f0a1d42e4927e8c32ecac97d37db9cb68095fe9ddbc@%3Cdev.zookeeper.apache.org%3E</a><br><a href="https://lists.apache.org/thread.html/rd2354f9ccce41e494fbadcbc5ad87218de6ec0fff8a7b54c8462226c@%3Cissues.zookeeper.apache.org%3E">https://lists.apache.org/thread.html/rd2354f9ccce41e494fbadcbc5ad87218de6ec0fff8a7b54c8462226c@%3Cissues.zookeeper.apache.org%3E</a><br><a href="https://lists.apache.org/thread.html/rf9fa47ab66495c78bb4120b0754dd9531ca2ff0430f6685ac9b07772@%3Cdev.mina.apache.org%3E">https://lists.apache.org/thread.html/rf9fa47ab66495c78bb4120b0754dd9531ca2ff0430f6685ac9b07772@%3Cdev.mina.apache.org%3E</a><br><a href="https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/4Y6TX47P47KABSFOL26FLDNVCWXDKDEZ/">https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/4Y6TX47P47KABSFOL26FLDNVCWXDKDEZ/</a><br><a href="https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/TVCUNLQ3HXGS4VPUQKWTJGRAW2KTFGXS/">https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/TVCUNLQ3HXGS4VPUQKWTJGRAW2KTFGXS/</a><br><a href="https://security.netapp.com/advisory/ntap-20210205-0004/">https://security.netapp.com/advisory/ntap-20210205-0004/</a><br><a href="https://sourceware.org/bugzilla/show_bug.cgi?id=24973">https://sourceware.org/bugzilla/show_bug.cgi?id=24973</a><br><a href="https://sourceware.org/git/?p=glibc.git;a=commit;h=ee7a3144c9922808181009b7b3e50e852fb4999b">https://sourceware.org/git/?p=glibc.git;a=commit;h=ee7a3144c9922808181009b7b3e50e852fb4999b</a><br></details>  |
| libc-bin         |    CVE-2020-27618   |   LOW  |  2.31-0ubuntu9.2 |  | <details><summary>Expand...</summary><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2020-27618">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2020-27618</a><br><a href="https://linux.oracle.com/cve/CVE-2020-27618.html">https://linux.oracle.com/cve/CVE-2020-27618.html</a><br><a href="https://linux.oracle.com/errata/ELSA-2021-9344.html">https://linux.oracle.com/errata/ELSA-2021-9344.html</a><br><a href="https://security.netapp.com/advisory/ntap-20210401-0006/">https://security.netapp.com/advisory/ntap-20210401-0006/</a><br><a href="https://sourceware.org/bugzilla/show_bug.cgi?id=19519#c21">https://sourceware.org/bugzilla/show_bug.cgi?id=19519#c21</a><br><a href="https://sourceware.org/bugzilla/show_bug.cgi?id=26224">https://sourceware.org/bugzilla/show_bug.cgi?id=26224</a><br></details>  |
| libc-bin         |    CVE-2020-29562   |   LOW  |  2.31-0ubuntu9.2 |  | <details><summary>Expand...</summary><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2020-29562">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2020-29562</a><br><a href="https://lists.apache.org/thread.html/rf9fa47ab66495c78bb4120b0754dd9531ca2ff0430f6685ac9b07772@%3Cdev.mina.apache.org%3E">https://lists.apache.org/thread.html/rf9fa47ab66495c78bb4120b0754dd9531ca2ff0430f6685ac9b07772@%3Cdev.mina.apache.org%3E</a><br><a href="https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/TVCUNLQ3HXGS4VPUQKWTJGRAW2KTFGXS/">https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/TVCUNLQ3HXGS4VPUQKWTJGRAW2KTFGXS/</a><br><a href="https://security.gentoo.org/glsa/202101-20">https://security.gentoo.org/glsa/202101-20</a><br><a href="https://security.netapp.com/advisory/ntap-20210122-0004/">https://security.netapp.com/advisory/ntap-20210122-0004/</a><br><a href="https://sourceware.org/bugzilla/show_bug.cgi?id=26923">https://sourceware.org/bugzilla/show_bug.cgi?id=26923</a><br><a href="https://sourceware.org/pipermail/libc-alpha/2020-November/119822.html">https://sourceware.org/pipermail/libc-alpha/2020-November/119822.html</a><br></details>  |
| libc-bin         |    CVE-2020-6096   |   LOW  |  2.31-0ubuntu9.2 |  | <details><summary>Expand...</summary><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2020-6096">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2020-6096</a><br><a href="https://lists.apache.org/thread.html/rf9fa47ab66495c78bb4120b0754dd9531ca2ff0430f6685ac9b07772@%3Cdev.mina.apache.org%3E">https://lists.apache.org/thread.html/rf9fa47ab66495c78bb4120b0754dd9531ca2ff0430f6685ac9b07772@%3Cdev.mina.apache.org%3E</a><br><a href="https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/SPYXTDOOB4PQGTYAMZAZNJIB3FF6YQXI/">https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/SPYXTDOOB4PQGTYAMZAZNJIB3FF6YQXI/</a><br><a href="https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/URXOIA2LDUKHQXK4BE55BQBRI6ZZG3Y6/">https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/URXOIA2LDUKHQXK4BE55BQBRI6ZZG3Y6/</a><br><a href="https://security.gentoo.org/glsa/202101-20">https://security.gentoo.org/glsa/202101-20</a><br><a href="https://sourceware.org/bugzilla/attachment.cgi?id=12334">https://sourceware.org/bugzilla/attachment.cgi?id=12334</a><br><a href="https://sourceware.org/bugzilla/show_bug.cgi?id=25620">https://sourceware.org/bugzilla/show_bug.cgi?id=25620</a><br><a href="https://talosintelligence.com/vulnerability_reports/TALOS-2020-1019">https://talosintelligence.com/vulnerability_reports/TALOS-2020-1019</a><br><a href="https://ubuntu.com/security/notices/USN-4954-1">https://ubuntu.com/security/notices/USN-4954-1</a><br><a href="https://www.talosintelligence.com/vulnerability_reports/TALOS-2020-1019">https://www.talosintelligence.com/vulnerability_reports/TALOS-2020-1019</a><br></details>  |
| libc-bin         |    CVE-2021-27645   |   LOW  |  2.31-0ubuntu9.2 |  | <details><summary>Expand...</summary><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2021-27645">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2021-27645</a><br><a href="https://linux.oracle.com/cve/CVE-2021-27645.html">https://linux.oracle.com/cve/CVE-2021-27645.html</a><br><a href="https://linux.oracle.com/errata/ELSA-2021-9560.html">https://linux.oracle.com/errata/ELSA-2021-9560.html</a><br><a href="https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/7LZNT6KTMCCWPWXEOGSHD3YLYZKUGMH5/">https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/7LZNT6KTMCCWPWXEOGSHD3YLYZKUGMH5/</a><br><a href="https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/I7TS26LIZSOBLGJEZMJX4PXT5BQDE2WS/">https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/I7TS26LIZSOBLGJEZMJX4PXT5BQDE2WS/</a><br><a href="https://sourceware.org/bugzilla/show_bug.cgi?id=27462">https://sourceware.org/bugzilla/show_bug.cgi?id=27462</a><br></details>  |
| libc-bin         |    CVE-2021-3326   |   LOW  |  2.31-0ubuntu9.2 |  | <details><summary>Expand...</summary><a href="http://www.openwall.com/lists/oss-security/2021/01/28/2">http://www.openwall.com/lists/oss-security/2021/01/28/2</a><br><a href="https://bugs.chromium.org/p/project-zero/issues/detail?id=2146">https://bugs.chromium.org/p/project-zero/issues/detail?id=2146</a><br><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2021-3326">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2021-3326</a><br><a href="https://linux.oracle.com/cve/CVE-2021-3326.html">https://linux.oracle.com/cve/CVE-2021-3326.html</a><br><a href="https://linux.oracle.com/errata/ELSA-2021-9344.html">https://linux.oracle.com/errata/ELSA-2021-9344.html</a><br><a href="https://security.netapp.com/advisory/ntap-20210304-0007/">https://security.netapp.com/advisory/ntap-20210304-0007/</a><br><a href="https://sourceware.org/bugzilla/show_bug.cgi?id=27256">https://sourceware.org/bugzilla/show_bug.cgi?id=27256</a><br><a href="https://sourceware.org/git/?p=glibc.git;a=commit;h=7d88c6142c6efc160c0ee5e4f85cde382c072888">https://sourceware.org/git/?p=glibc.git;a=commit;h=7d88c6142c6efc160c0ee5e4f85cde382c072888</a><br><a href="https://sourceware.org/pipermail/libc-alpha/2021-January/122058.html">https://sourceware.org/pipermail/libc-alpha/2021-January/122058.html</a><br></details>  |
| libc-bin         |    CVE-2021-33574   |   LOW  |  2.31-0ubuntu9.2 |  | <details><summary>Expand...</summary><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2021-33574">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2021-33574</a><br><a href="https://linux.oracle.com/cve/CVE-2021-33574.html">https://linux.oracle.com/cve/CVE-2021-33574.html</a><br><a href="https://linux.oracle.com/errata/ELSA-2021-9560.html">https://linux.oracle.com/errata/ELSA-2021-9560.html</a><br><a href="https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/RBUUWUGXVILQXVWEOU7N42ICHPJNAEUP/">https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/RBUUWUGXVILQXVWEOU7N42ICHPJNAEUP/</a><br><a href="https://security.gentoo.org/glsa/202107-07">https://security.gentoo.org/glsa/202107-07</a><br><a href="https://security.netapp.com/advisory/ntap-20210629-0005/">https://security.netapp.com/advisory/ntap-20210629-0005/</a><br><a href="https://sourceware.org/bugzilla/show_bug.cgi?id=27896">https://sourceware.org/bugzilla/show_bug.cgi?id=27896</a><br><a href="https://sourceware.org/bugzilla/show_bug.cgi?id=27896#c1">https://sourceware.org/bugzilla/show_bug.cgi?id=27896#c1</a><br></details>  |
| libc6         |    CVE-2021-35942   |   MEDIUM  |  2.31-0ubuntu9.2 |  | <details><summary>Expand...</summary><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2021-35942">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2021-35942</a><br><a href="https://linux.oracle.com/cve/CVE-2021-35942.html">https://linux.oracle.com/cve/CVE-2021-35942.html</a><br><a href="https://linux.oracle.com/errata/ELSA-2021-9560.html">https://linux.oracle.com/errata/ELSA-2021-9560.html</a><br><a href="https://security.netapp.com/advisory/ntap-20210827-0005/">https://security.netapp.com/advisory/ntap-20210827-0005/</a><br><a href="https://sourceware.org/bugzilla/show_bug.cgi?id=28011">https://sourceware.org/bugzilla/show_bug.cgi?id=28011</a><br><a href="https://sourceware.org/git/?p=glibc.git;a=commit;h=5adda61f62b77384718b4c0d8336ade8f2b4b35c">https://sourceware.org/git/?p=glibc.git;a=commit;h=5adda61f62b77384718b4c0d8336ade8f2b4b35c</a><br><a href="https://sourceware.org/git/?p=glibc.git;a=commitdiff;h=5adda61f62b77384718b4c0d8336ade8f2b4b35c">https://sourceware.org/git/?p=glibc.git;a=commitdiff;h=5adda61f62b77384718b4c0d8336ade8f2b4b35c</a><br><a href="https://sourceware.org/glibc/wiki/Security%20Exceptions">https://sourceware.org/glibc/wiki/Security%20Exceptions</a><br></details>  |
| libc6         |    CVE-2021-38604   |   MEDIUM  |  2.31-0ubuntu9.2 |  | <details><summary>Expand...</summary><a href="https://blog.tuxcare.com/cve/tuxcare-team-identifies-cve-2021-38604-a-new-vulnerability-in-glibc">https://blog.tuxcare.com/cve/tuxcare-team-identifies-cve-2021-38604-a-new-vulnerability-in-glibc</a><br><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2021-38604">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2021-38604</a><br><a href="https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/GYEXYM37RCJWJ6B5KQUYQI4NZBDDYSXP/">https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/GYEXYM37RCJWJ6B5KQUYQI4NZBDDYSXP/</a><br><a href="https://security.netapp.com/advisory/ntap-20210909-0005/">https://security.netapp.com/advisory/ntap-20210909-0005/</a><br><a href="https://sourceware.org/bugzilla/show_bug.cgi?id=28213">https://sourceware.org/bugzilla/show_bug.cgi?id=28213</a><br><a href="https://sourceware.org/git/?p=glibc.git;a=commit;h=4cc79c217744743077bf7a0ec5e0a4318f1e6641">https://sourceware.org/git/?p=glibc.git;a=commit;h=4cc79c217744743077bf7a0ec5e0a4318f1e6641</a><br><a href="https://sourceware.org/git/?p=glibc.git;a=commit;h=b805aebd42364fe696e417808a700fdb9800c9e8">https://sourceware.org/git/?p=glibc.git;a=commit;h=b805aebd42364fe696e417808a700fdb9800c9e8</a><br></details>  |
| libc6         |    CVE-2016-10228   |   LOW  |  2.31-0ubuntu9.2 |  | <details><summary>Expand...</summary><a href="http://openwall.com/lists/oss-security/2017/03/01/10">http://openwall.com/lists/oss-security/2017/03/01/10</a><br><a href="http://www.securityfocus.com/bid/96525">http://www.securityfocus.com/bid/96525</a><br><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2016-10228">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2016-10228</a><br><a href="https://linux.oracle.com/cve/CVE-2016-10228.html">https://linux.oracle.com/cve/CVE-2016-10228.html</a><br><a href="https://linux.oracle.com/errata/ELSA-2021-9344.html">https://linux.oracle.com/errata/ELSA-2021-9344.html</a><br><a href="https://lists.apache.org/thread.html/rf9fa47ab66495c78bb4120b0754dd9531ca2ff0430f6685ac9b07772@%3Cdev.mina.apache.org%3E">https://lists.apache.org/thread.html/rf9fa47ab66495c78bb4120b0754dd9531ca2ff0430f6685ac9b07772@%3Cdev.mina.apache.org%3E</a><br><a href="https://security.gentoo.org/glsa/202101-20">https://security.gentoo.org/glsa/202101-20</a><br><a href="https://sourceware.org/bugzilla/show_bug.cgi?id=19519">https://sourceware.org/bugzilla/show_bug.cgi?id=19519</a><br><a href="https://sourceware.org/bugzilla/show_bug.cgi?id=19519#c21">https://sourceware.org/bugzilla/show_bug.cgi?id=19519#c21</a><br><a href="https://sourceware.org/bugzilla/show_bug.cgi?id=26224">https://sourceware.org/bugzilla/show_bug.cgi?id=26224</a><br></details>  |
| libc6         |    CVE-2019-25013   |   LOW  |  2.31-0ubuntu9.2 |  | <details><summary>Expand...</summary><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2019-25013">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2019-25013</a><br><a href="https://linux.oracle.com/cve/CVE-2019-25013.html">https://linux.oracle.com/cve/CVE-2019-25013.html</a><br><a href="https://linux.oracle.com/errata/ELSA-2021-9344.html">https://linux.oracle.com/errata/ELSA-2021-9344.html</a><br><a href="https://lists.apache.org/thread.html/r32d767ac804e9b8aad4355bb85960a6a1385eab7afff549a5e98660f@%3Cjira.kafka.apache.org%3E">https://lists.apache.org/thread.html/r32d767ac804e9b8aad4355bb85960a6a1385eab7afff549a5e98660f@%3Cjira.kafka.apache.org%3E</a><br><a href="https://lists.apache.org/thread.html/r448bb851cc8e6e3f93f3c28c70032b37062625d81214744474ac49e7@%3Cdev.kafka.apache.org%3E">https://lists.apache.org/thread.html/r448bb851cc8e6e3f93f3c28c70032b37062625d81214744474ac49e7@%3Cdev.kafka.apache.org%3E</a><br><a href="https://lists.apache.org/thread.html/r4806a391091e082bdea17266452ca656ebc176e51bb3932733b3a0a2@%3Cjira.kafka.apache.org%3E">https://lists.apache.org/thread.html/r4806a391091e082bdea17266452ca656ebc176e51bb3932733b3a0a2@%3Cjira.kafka.apache.org%3E</a><br><a href="https://lists.apache.org/thread.html/r499e4f96d0b5109ef083f2feccd33c51650c1b7d7068aa3bd47efca9@%3Cjira.kafka.apache.org%3E">https://lists.apache.org/thread.html/r499e4f96d0b5109ef083f2feccd33c51650c1b7d7068aa3bd47efca9@%3Cjira.kafka.apache.org%3E</a><br><a href="https://lists.apache.org/thread.html/r5af4430421bb6f9973294691a7904bbd260937e9eef96b20556f43ff@%3Cjira.kafka.apache.org%3E">https://lists.apache.org/thread.html/r5af4430421bb6f9973294691a7904bbd260937e9eef96b20556f43ff@%3Cjira.kafka.apache.org%3E</a><br><a href="https://lists.apache.org/thread.html/r750eee18542bc02bd8350861c424ee60a9b9b225568fa09436a37ece@%3Cissues.zookeeper.apache.org%3E">https://lists.apache.org/thread.html/r750eee18542bc02bd8350861c424ee60a9b9b225568fa09436a37ece@%3Cissues.zookeeper.apache.org%3E</a><br><a href="https://lists.apache.org/thread.html/r7a2e94adfe0a2f0a1d42e4927e8c32ecac97d37db9cb68095fe9ddbc@%3Cdev.zookeeper.apache.org%3E">https://lists.apache.org/thread.html/r7a2e94adfe0a2f0a1d42e4927e8c32ecac97d37db9cb68095fe9ddbc@%3Cdev.zookeeper.apache.org%3E</a><br><a href="https://lists.apache.org/thread.html/rd2354f9ccce41e494fbadcbc5ad87218de6ec0fff8a7b54c8462226c@%3Cissues.zookeeper.apache.org%3E">https://lists.apache.org/thread.html/rd2354f9ccce41e494fbadcbc5ad87218de6ec0fff8a7b54c8462226c@%3Cissues.zookeeper.apache.org%3E</a><br><a href="https://lists.apache.org/thread.html/rf9fa47ab66495c78bb4120b0754dd9531ca2ff0430f6685ac9b07772@%3Cdev.mina.apache.org%3E">https://lists.apache.org/thread.html/rf9fa47ab66495c78bb4120b0754dd9531ca2ff0430f6685ac9b07772@%3Cdev.mina.apache.org%3E</a><br><a href="https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/4Y6TX47P47KABSFOL26FLDNVCWXDKDEZ/">https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/4Y6TX47P47KABSFOL26FLDNVCWXDKDEZ/</a><br><a href="https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/TVCUNLQ3HXGS4VPUQKWTJGRAW2KTFGXS/">https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/TVCUNLQ3HXGS4VPUQKWTJGRAW2KTFGXS/</a><br><a href="https://security.netapp.com/advisory/ntap-20210205-0004/">https://security.netapp.com/advisory/ntap-20210205-0004/</a><br><a href="https://sourceware.org/bugzilla/show_bug.cgi?id=24973">https://sourceware.org/bugzilla/show_bug.cgi?id=24973</a><br><a href="https://sourceware.org/git/?p=glibc.git;a=commit;h=ee7a3144c9922808181009b7b3e50e852fb4999b">https://sourceware.org/git/?p=glibc.git;a=commit;h=ee7a3144c9922808181009b7b3e50e852fb4999b</a><br></details>  |
| libc6         |    CVE-2020-27618   |   LOW  |  2.31-0ubuntu9.2 |  | <details><summary>Expand...</summary><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2020-27618">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2020-27618</a><br><a href="https://linux.oracle.com/cve/CVE-2020-27618.html">https://linux.oracle.com/cve/CVE-2020-27618.html</a><br><a href="https://linux.oracle.com/errata/ELSA-2021-9344.html">https://linux.oracle.com/errata/ELSA-2021-9344.html</a><br><a href="https://security.netapp.com/advisory/ntap-20210401-0006/">https://security.netapp.com/advisory/ntap-20210401-0006/</a><br><a href="https://sourceware.org/bugzilla/show_bug.cgi?id=19519#c21">https://sourceware.org/bugzilla/show_bug.cgi?id=19519#c21</a><br><a href="https://sourceware.org/bugzilla/show_bug.cgi?id=26224">https://sourceware.org/bugzilla/show_bug.cgi?id=26224</a><br></details>  |
| libc6         |    CVE-2020-29562   |   LOW  |  2.31-0ubuntu9.2 |  | <details><summary>Expand...</summary><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2020-29562">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2020-29562</a><br><a href="https://lists.apache.org/thread.html/rf9fa47ab66495c78bb4120b0754dd9531ca2ff0430f6685ac9b07772@%3Cdev.mina.apache.org%3E">https://lists.apache.org/thread.html/rf9fa47ab66495c78bb4120b0754dd9531ca2ff0430f6685ac9b07772@%3Cdev.mina.apache.org%3E</a><br><a href="https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/TVCUNLQ3HXGS4VPUQKWTJGRAW2KTFGXS/">https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/TVCUNLQ3HXGS4VPUQKWTJGRAW2KTFGXS/</a><br><a href="https://security.gentoo.org/glsa/202101-20">https://security.gentoo.org/glsa/202101-20</a><br><a href="https://security.netapp.com/advisory/ntap-20210122-0004/">https://security.netapp.com/advisory/ntap-20210122-0004/</a><br><a href="https://sourceware.org/bugzilla/show_bug.cgi?id=26923">https://sourceware.org/bugzilla/show_bug.cgi?id=26923</a><br><a href="https://sourceware.org/pipermail/libc-alpha/2020-November/119822.html">https://sourceware.org/pipermail/libc-alpha/2020-November/119822.html</a><br></details>  |
| libc6         |    CVE-2020-6096   |   LOW  |  2.31-0ubuntu9.2 |  | <details><summary>Expand...</summary><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2020-6096">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2020-6096</a><br><a href="https://lists.apache.org/thread.html/rf9fa47ab66495c78bb4120b0754dd9531ca2ff0430f6685ac9b07772@%3Cdev.mina.apache.org%3E">https://lists.apache.org/thread.html/rf9fa47ab66495c78bb4120b0754dd9531ca2ff0430f6685ac9b07772@%3Cdev.mina.apache.org%3E</a><br><a href="https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/SPYXTDOOB4PQGTYAMZAZNJIB3FF6YQXI/">https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/SPYXTDOOB4PQGTYAMZAZNJIB3FF6YQXI/</a><br><a href="https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/URXOIA2LDUKHQXK4BE55BQBRI6ZZG3Y6/">https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/URXOIA2LDUKHQXK4BE55BQBRI6ZZG3Y6/</a><br><a href="https://security.gentoo.org/glsa/202101-20">https://security.gentoo.org/glsa/202101-20</a><br><a href="https://sourceware.org/bugzilla/attachment.cgi?id=12334">https://sourceware.org/bugzilla/attachment.cgi?id=12334</a><br><a href="https://sourceware.org/bugzilla/show_bug.cgi?id=25620">https://sourceware.org/bugzilla/show_bug.cgi?id=25620</a><br><a href="https://talosintelligence.com/vulnerability_reports/TALOS-2020-1019">https://talosintelligence.com/vulnerability_reports/TALOS-2020-1019</a><br><a href="https://ubuntu.com/security/notices/USN-4954-1">https://ubuntu.com/security/notices/USN-4954-1</a><br><a href="https://www.talosintelligence.com/vulnerability_reports/TALOS-2020-1019">https://www.talosintelligence.com/vulnerability_reports/TALOS-2020-1019</a><br></details>  |
| libc6         |    CVE-2021-27645   |   LOW  |  2.31-0ubuntu9.2 |  | <details><summary>Expand...</summary><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2021-27645">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2021-27645</a><br><a href="https://linux.oracle.com/cve/CVE-2021-27645.html">https://linux.oracle.com/cve/CVE-2021-27645.html</a><br><a href="https://linux.oracle.com/errata/ELSA-2021-9560.html">https://linux.oracle.com/errata/ELSA-2021-9560.html</a><br><a href="https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/7LZNT6KTMCCWPWXEOGSHD3YLYZKUGMH5/">https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/7LZNT6KTMCCWPWXEOGSHD3YLYZKUGMH5/</a><br><a href="https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/I7TS26LIZSOBLGJEZMJX4PXT5BQDE2WS/">https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/I7TS26LIZSOBLGJEZMJX4PXT5BQDE2WS/</a><br><a href="https://sourceware.org/bugzilla/show_bug.cgi?id=27462">https://sourceware.org/bugzilla/show_bug.cgi?id=27462</a><br></details>  |
| libc6         |    CVE-2021-3326   |   LOW  |  2.31-0ubuntu9.2 |  | <details><summary>Expand...</summary><a href="http://www.openwall.com/lists/oss-security/2021/01/28/2">http://www.openwall.com/lists/oss-security/2021/01/28/2</a><br><a href="https://bugs.chromium.org/p/project-zero/issues/detail?id=2146">https://bugs.chromium.org/p/project-zero/issues/detail?id=2146</a><br><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2021-3326">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2021-3326</a><br><a href="https://linux.oracle.com/cve/CVE-2021-3326.html">https://linux.oracle.com/cve/CVE-2021-3326.html</a><br><a href="https://linux.oracle.com/errata/ELSA-2021-9344.html">https://linux.oracle.com/errata/ELSA-2021-9344.html</a><br><a href="https://security.netapp.com/advisory/ntap-20210304-0007/">https://security.netapp.com/advisory/ntap-20210304-0007/</a><br><a href="https://sourceware.org/bugzilla/show_bug.cgi?id=27256">https://sourceware.org/bugzilla/show_bug.cgi?id=27256</a><br><a href="https://sourceware.org/git/?p=glibc.git;a=commit;h=7d88c6142c6efc160c0ee5e4f85cde382c072888">https://sourceware.org/git/?p=glibc.git;a=commit;h=7d88c6142c6efc160c0ee5e4f85cde382c072888</a><br><a href="https://sourceware.org/pipermail/libc-alpha/2021-January/122058.html">https://sourceware.org/pipermail/libc-alpha/2021-January/122058.html</a><br></details>  |
| libc6         |    CVE-2021-33574   |   LOW  |  2.31-0ubuntu9.2 |  | <details><summary>Expand...</summary><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2021-33574">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2021-33574</a><br><a href="https://linux.oracle.com/cve/CVE-2021-33574.html">https://linux.oracle.com/cve/CVE-2021-33574.html</a><br><a href="https://linux.oracle.com/errata/ELSA-2021-9560.html">https://linux.oracle.com/errata/ELSA-2021-9560.html</a><br><a href="https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/RBUUWUGXVILQXVWEOU7N42ICHPJNAEUP/">https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/RBUUWUGXVILQXVWEOU7N42ICHPJNAEUP/</a><br><a href="https://security.gentoo.org/glsa/202107-07">https://security.gentoo.org/glsa/202107-07</a><br><a href="https://security.netapp.com/advisory/ntap-20210629-0005/">https://security.netapp.com/advisory/ntap-20210629-0005/</a><br><a href="https://sourceware.org/bugzilla/show_bug.cgi?id=27896">https://sourceware.org/bugzilla/show_bug.cgi?id=27896</a><br><a href="https://sourceware.org/bugzilla/show_bug.cgi?id=27896#c1">https://sourceware.org/bugzilla/show_bug.cgi?id=27896#c1</a><br></details>  |
| libcairo-gobject2         |    CVE-2017-7475   |   LOW  |  1.16.0-4ubuntu1 |  | <details><summary>Expand...</summary><a href="http://seclists.org/oss-sec/2017/q2/151">http://seclists.org/oss-sec/2017/q2/151</a><br><a href="https://bugs.freedesktop.org/show_bug.cgi?id=100763">https://bugs.freedesktop.org/show_bug.cgi?id=100763</a><br><a href="https://bugzilla.redhat.com/show_bug.cgi?id=CVE-2017-7475">https://bugzilla.redhat.com/show_bug.cgi?id=CVE-2017-7475</a><br><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2017-7475">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2017-7475</a><br><a href="https://github.com/advisories/GHSA-5v3f-73gv-x7x5">https://github.com/advisories/GHSA-5v3f-73gv-x7x5</a><br><a href="https://lists.apache.org/thread.html/rf9fa47ab66495c78bb4120b0754dd9531ca2ff0430f6685ac9b07772@%3Cdev.mina.apache.org%3E">https://lists.apache.org/thread.html/rf9fa47ab66495c78bb4120b0754dd9531ca2ff0430f6685ac9b07772@%3Cdev.mina.apache.org%3E</a><br><a href="https://nvd.nist.gov/vuln/detail/CVE-2017-7475">https://nvd.nist.gov/vuln/detail/CVE-2017-7475</a><br></details>  |
| libcairo-gobject2         |    CVE-2017-9814   |   LOW  |  1.16.0-4ubuntu1 |  | <details><summary>Expand...</summary><a href="http://lists.opensuse.org/opensuse-security-announce/2020-07/msg00042.html">http://lists.opensuse.org/opensuse-security-announce/2020-07/msg00042.html</a><br><a href="https://bugs.freedesktop.org/show_bug.cgi?id=101547">https://bugs.freedesktop.org/show_bug.cgi?id=101547</a><br><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2017-9814">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2017-9814</a><br><a href="https://lists.apache.org/thread.html/rf9fa47ab66495c78bb4120b0754dd9531ca2ff0430f6685ac9b07772@%3Cdev.mina.apache.org%3E">https://lists.apache.org/thread.html/rf9fa47ab66495c78bb4120b0754dd9531ca2ff0430f6685ac9b07772@%3Cdev.mina.apache.org%3E</a><br><a href="https://security.gentoo.org/glsa/201904-01">https://security.gentoo.org/glsa/201904-01</a><br></details>  |
| libcairo-gobject2         |    CVE-2018-18064   |   LOW  |  1.16.0-4ubuntu1 |  | <details><summary>Expand...</summary><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2018-18064">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2018-18064</a><br><a href="https://gitlab.freedesktop.org/cairo/cairo/issues/341">https://gitlab.freedesktop.org/cairo/cairo/issues/341</a><br><a href="https://lists.apache.org/thread.html/rf9fa47ab66495c78bb4120b0754dd9531ca2ff0430f6685ac9b07772@%3Cdev.mina.apache.org%3E">https://lists.apache.org/thread.html/rf9fa47ab66495c78bb4120b0754dd9531ca2ff0430f6685ac9b07772@%3Cdev.mina.apache.org%3E</a><br></details>  |
| libcairo-gobject2         |    CVE-2019-6461   |   LOW  |  1.16.0-4ubuntu1 |  | <details><summary>Expand...</summary><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2019-6461">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2019-6461</a><br><a href="https://github.com/TeamSeri0us/pocs/tree/master/gerbv">https://github.com/TeamSeri0us/pocs/tree/master/gerbv</a><br><a href="https://gitlab.freedesktop.org/cairo/cairo/issues/352">https://gitlab.freedesktop.org/cairo/cairo/issues/352</a><br><a href="https://lists.apache.org/thread.html/rf9fa47ab66495c78bb4120b0754dd9531ca2ff0430f6685ac9b07772@%3Cdev.mina.apache.org%3E">https://lists.apache.org/thread.html/rf9fa47ab66495c78bb4120b0754dd9531ca2ff0430f6685ac9b07772@%3Cdev.mina.apache.org%3E</a><br></details>  |
| libcairo-gobject2         |    CVE-2019-6462   |   LOW  |  1.16.0-4ubuntu1 |  | <details><summary>Expand...</summary><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2019-6462">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2019-6462</a><br><a href="https://github.com/TeamSeri0us/pocs/tree/master/gerbv">https://github.com/TeamSeri0us/pocs/tree/master/gerbv</a><br><a href="https://gitlab.freedesktop.org/cairo/cairo/issues/353">https://gitlab.freedesktop.org/cairo/cairo/issues/353</a><br><a href="https://lists.apache.org/thread.html/rf9fa47ab66495c78bb4120b0754dd9531ca2ff0430f6685ac9b07772@%3Cdev.mina.apache.org%3E">https://lists.apache.org/thread.html/rf9fa47ab66495c78bb4120b0754dd9531ca2ff0430f6685ac9b07772@%3Cdev.mina.apache.org%3E</a><br></details>  |
| libcairo2         |    CVE-2017-7475   |   LOW  |  1.16.0-4ubuntu1 |  | <details><summary>Expand...</summary><a href="http://seclists.org/oss-sec/2017/q2/151">http://seclists.org/oss-sec/2017/q2/151</a><br><a href="https://bugs.freedesktop.org/show_bug.cgi?id=100763">https://bugs.freedesktop.org/show_bug.cgi?id=100763</a><br><a href="https://bugzilla.redhat.com/show_bug.cgi?id=CVE-2017-7475">https://bugzilla.redhat.com/show_bug.cgi?id=CVE-2017-7475</a><br><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2017-7475">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2017-7475</a><br><a href="https://github.com/advisories/GHSA-5v3f-73gv-x7x5">https://github.com/advisories/GHSA-5v3f-73gv-x7x5</a><br><a href="https://lists.apache.org/thread.html/rf9fa47ab66495c78bb4120b0754dd9531ca2ff0430f6685ac9b07772@%3Cdev.mina.apache.org%3E">https://lists.apache.org/thread.html/rf9fa47ab66495c78bb4120b0754dd9531ca2ff0430f6685ac9b07772@%3Cdev.mina.apache.org%3E</a><br><a href="https://nvd.nist.gov/vuln/detail/CVE-2017-7475">https://nvd.nist.gov/vuln/detail/CVE-2017-7475</a><br></details>  |
| libcairo2         |    CVE-2017-9814   |   LOW  |  1.16.0-4ubuntu1 |  | <details><summary>Expand...</summary><a href="http://lists.opensuse.org/opensuse-security-announce/2020-07/msg00042.html">http://lists.opensuse.org/opensuse-security-announce/2020-07/msg00042.html</a><br><a href="https://bugs.freedesktop.org/show_bug.cgi?id=101547">https://bugs.freedesktop.org/show_bug.cgi?id=101547</a><br><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2017-9814">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2017-9814</a><br><a href="https://lists.apache.org/thread.html/rf9fa47ab66495c78bb4120b0754dd9531ca2ff0430f6685ac9b07772@%3Cdev.mina.apache.org%3E">https://lists.apache.org/thread.html/rf9fa47ab66495c78bb4120b0754dd9531ca2ff0430f6685ac9b07772@%3Cdev.mina.apache.org%3E</a><br><a href="https://security.gentoo.org/glsa/201904-01">https://security.gentoo.org/glsa/201904-01</a><br></details>  |
| libcairo2         |    CVE-2018-18064   |   LOW  |  1.16.0-4ubuntu1 |  | <details><summary>Expand...</summary><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2018-18064">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2018-18064</a><br><a href="https://gitlab.freedesktop.org/cairo/cairo/issues/341">https://gitlab.freedesktop.org/cairo/cairo/issues/341</a><br><a href="https://lists.apache.org/thread.html/rf9fa47ab66495c78bb4120b0754dd9531ca2ff0430f6685ac9b07772@%3Cdev.mina.apache.org%3E">https://lists.apache.org/thread.html/rf9fa47ab66495c78bb4120b0754dd9531ca2ff0430f6685ac9b07772@%3Cdev.mina.apache.org%3E</a><br></details>  |
| libcairo2         |    CVE-2019-6461   |   LOW  |  1.16.0-4ubuntu1 |  | <details><summary>Expand...</summary><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2019-6461">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2019-6461</a><br><a href="https://github.com/TeamSeri0us/pocs/tree/master/gerbv">https://github.com/TeamSeri0us/pocs/tree/master/gerbv</a><br><a href="https://gitlab.freedesktop.org/cairo/cairo/issues/352">https://gitlab.freedesktop.org/cairo/cairo/issues/352</a><br><a href="https://lists.apache.org/thread.html/rf9fa47ab66495c78bb4120b0754dd9531ca2ff0430f6685ac9b07772@%3Cdev.mina.apache.org%3E">https://lists.apache.org/thread.html/rf9fa47ab66495c78bb4120b0754dd9531ca2ff0430f6685ac9b07772@%3Cdev.mina.apache.org%3E</a><br></details>  |
| libcairo2         |    CVE-2019-6462   |   LOW  |  1.16.0-4ubuntu1 |  | <details><summary>Expand...</summary><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2019-6462">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2019-6462</a><br><a href="https://github.com/TeamSeri0us/pocs/tree/master/gerbv">https://github.com/TeamSeri0us/pocs/tree/master/gerbv</a><br><a href="https://gitlab.freedesktop.org/cairo/cairo/issues/353">https://gitlab.freedesktop.org/cairo/cairo/issues/353</a><br><a href="https://lists.apache.org/thread.html/rf9fa47ab66495c78bb4120b0754dd9531ca2ff0430f6685ac9b07772@%3Cdev.mina.apache.org%3E">https://lists.apache.org/thread.html/rf9fa47ab66495c78bb4120b0754dd9531ca2ff0430f6685ac9b07772@%3Cdev.mina.apache.org%3E</a><br></details>  |
| libgmp10         |    CVE-2021-43618   |   LOW  |  2:6.2.0+dfsg-4 |  | <details><summary>Expand...</summary><a href="https://bugs.debian.org/994405">https://bugs.debian.org/994405</a><br><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2021-43618">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2021-43618</a><br><a href="https://gmplib.org/list-archives/gmp-bugs/2021-September/005077.html">https://gmplib.org/list-archives/gmp-bugs/2021-September/005077.html</a><br><a href="https://gmplib.org/repo/gmp-6.2/rev/561a9c25298e">https://gmplib.org/repo/gmp-6.2/rev/561a9c25298e</a><br><a href="https://lists.debian.org/debian-lts-announce/2021/12/msg00001.html">https://lists.debian.org/debian-lts-announce/2021/12/msg00001.html</a><br></details>  |
| libgssapi-krb5-2         |    CVE-2021-36222   |   MEDIUM  |  1.17-6ubuntu4.1 |  | <details><summary>Expand...</summary><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2021-36222">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2021-36222</a><br><a href="https://github.com/krb5/krb5/commit/fc98f520caefff2e5ee9a0026fdf5109944b3562">https://github.com/krb5/krb5/commit/fc98f520caefff2e5ee9a0026fdf5109944b3562</a><br><a href="https://github.com/krb5/krb5/releases">https://github.com/krb5/krb5/releases</a><br><a href="https://linux.oracle.com/cve/CVE-2021-36222.html">https://linux.oracle.com/cve/CVE-2021-36222.html</a><br><a href="https://linux.oracle.com/errata/ELSA-2021-3576.html">https://linux.oracle.com/errata/ELSA-2021-3576.html</a><br><a href="https://security.netapp.com/advisory/ntap-20211022-0003/">https://security.netapp.com/advisory/ntap-20211022-0003/</a><br><a href="https://security.netapp.com/advisory/ntap-20211104-0007/">https://security.netapp.com/advisory/ntap-20211104-0007/</a><br><a href="https://web.mit.edu/kerberos/advisories/">https://web.mit.edu/kerberos/advisories/</a><br><a href="https://www.debian.org/security/2021/dsa-4944">https://www.debian.org/security/2021/dsa-4944</a><br><a href="https://www.oracle.com/security-alerts/cpuoct2021.html">https://www.oracle.com/security-alerts/cpuoct2021.html</a><br></details>  |
| libgssapi-krb5-2         |    CVE-2018-5709   |   LOW  |  1.17-6ubuntu4.1 |  | <details><summary>Expand...</summary><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2018-5709">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2018-5709</a><br><a href="https://github.com/poojamnit/Kerberos-V5-1.16-Vulnerabilities/tree/master/Integer%20Overflow">https://github.com/poojamnit/Kerberos-V5-1.16-Vulnerabilities/tree/master/Integer%20Overflow</a><br><a href="https://lists.apache.org/thread.html/rf9fa47ab66495c78bb4120b0754dd9531ca2ff0430f6685ac9b07772@%3Cdev.mina.apache.org%3E">https://lists.apache.org/thread.html/rf9fa47ab66495c78bb4120b0754dd9531ca2ff0430f6685ac9b07772@%3Cdev.mina.apache.org%3E</a><br></details>  |
| libgssapi3-heimdal         |    CVE-2021-3671   |   LOW  |  7.7.0+dfsg-1ubuntu1 |  | <details><summary>Expand...</summary><a href="https://bugzilla.redhat.com/show_bug.cgi?id=2013080,">https://bugzilla.redhat.com/show_bug.cgi?id=2013080,</a><br><a href="https://bugzilla.samba.org/show_bug.cgi?id=14770,">https://bugzilla.samba.org/show_bug.cgi?id=14770,</a><br><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2021-3671">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2021-3671</a><br><a href="https://github.com/heimdal/heimdal/commit/04171147948d0a3636bc6374181926f0fb2ec83a">https://github.com/heimdal/heimdal/commit/04171147948d0a3636bc6374181926f0fb2ec83a</a><br><a href="https://ubuntu.com/security/notices/USN-5142-1">https://ubuntu.com/security/notices/USN-5142-1</a><br><a href="https://ubuntu.com/security/notices/USN-5174-1">https://ubuntu.com/security/notices/USN-5174-1</a><br></details>  |
| libhcrypto4-heimdal         |    CVE-2021-3671   |   LOW  |  7.7.0+dfsg-1ubuntu1 |  | <details><summary>Expand...</summary><a href="https://bugzilla.redhat.com/show_bug.cgi?id=2013080,">https://bugzilla.redhat.com/show_bug.cgi?id=2013080,</a><br><a href="https://bugzilla.samba.org/show_bug.cgi?id=14770,">https://bugzilla.samba.org/show_bug.cgi?id=14770,</a><br><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2021-3671">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2021-3671</a><br><a href="https://github.com/heimdal/heimdal/commit/04171147948d0a3636bc6374181926f0fb2ec83a">https://github.com/heimdal/heimdal/commit/04171147948d0a3636bc6374181926f0fb2ec83a</a><br><a href="https://ubuntu.com/security/notices/USN-5142-1">https://ubuntu.com/security/notices/USN-5142-1</a><br><a href="https://ubuntu.com/security/notices/USN-5174-1">https://ubuntu.com/security/notices/USN-5174-1</a><br></details>  |
| libheimbase1-heimdal         |    CVE-2021-3671   |   LOW  |  7.7.0+dfsg-1ubuntu1 |  | <details><summary>Expand...</summary><a href="https://bugzilla.redhat.com/show_bug.cgi?id=2013080,">https://bugzilla.redhat.com/show_bug.cgi?id=2013080,</a><br><a href="https://bugzilla.samba.org/show_bug.cgi?id=14770,">https://bugzilla.samba.org/show_bug.cgi?id=14770,</a><br><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2021-3671">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2021-3671</a><br><a href="https://github.com/heimdal/heimdal/commit/04171147948d0a3636bc6374181926f0fb2ec83a">https://github.com/heimdal/heimdal/commit/04171147948d0a3636bc6374181926f0fb2ec83a</a><br><a href="https://ubuntu.com/security/notices/USN-5142-1">https://ubuntu.com/security/notices/USN-5142-1</a><br><a href="https://ubuntu.com/security/notices/USN-5174-1">https://ubuntu.com/security/notices/USN-5174-1</a><br></details>  |
| libheimntlm0-heimdal         |    CVE-2021-3671   |   LOW  |  7.7.0+dfsg-1ubuntu1 |  | <details><summary>Expand...</summary><a href="https://bugzilla.redhat.com/show_bug.cgi?id=2013080,">https://bugzilla.redhat.com/show_bug.cgi?id=2013080,</a><br><a href="https://bugzilla.samba.org/show_bug.cgi?id=14770,">https://bugzilla.samba.org/show_bug.cgi?id=14770,</a><br><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2021-3671">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2021-3671</a><br><a href="https://github.com/heimdal/heimdal/commit/04171147948d0a3636bc6374181926f0fb2ec83a">https://github.com/heimdal/heimdal/commit/04171147948d0a3636bc6374181926f0fb2ec83a</a><br><a href="https://ubuntu.com/security/notices/USN-5142-1">https://ubuntu.com/security/notices/USN-5142-1</a><br><a href="https://ubuntu.com/security/notices/USN-5174-1">https://ubuntu.com/security/notices/USN-5174-1</a><br></details>  |
| libhx509-5-heimdal         |    CVE-2021-3671   |   LOW  |  7.7.0+dfsg-1ubuntu1 |  | <details><summary>Expand...</summary><a href="https://bugzilla.redhat.com/show_bug.cgi?id=2013080,">https://bugzilla.redhat.com/show_bug.cgi?id=2013080,</a><br><a href="https://bugzilla.samba.org/show_bug.cgi?id=14770,">https://bugzilla.samba.org/show_bug.cgi?id=14770,</a><br><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2021-3671">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2021-3671</a><br><a href="https://github.com/heimdal/heimdal/commit/04171147948d0a3636bc6374181926f0fb2ec83a">https://github.com/heimdal/heimdal/commit/04171147948d0a3636bc6374181926f0fb2ec83a</a><br><a href="https://ubuntu.com/security/notices/USN-5142-1">https://ubuntu.com/security/notices/USN-5142-1</a><br><a href="https://ubuntu.com/security/notices/USN-5174-1">https://ubuntu.com/security/notices/USN-5174-1</a><br></details>  |
| libjbig0         |    CVE-2017-9937   |   LOW  |  2.1-3.1build1 |  | <details><summary>Expand...</summary><a href="http://bugzilla.maptools.org/show_bug.cgi?id=2707">http://bugzilla.maptools.org/show_bug.cgi?id=2707</a><br><a href="http://www.securityfocus.com/bid/99304">http://www.securityfocus.com/bid/99304</a><br><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2017-9937">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2017-9937</a><br><a href="https://lists.apache.org/thread.html/rf9fa47ab66495c78bb4120b0754dd9531ca2ff0430f6685ac9b07772@%3Cdev.mina.apache.org%3E">https://lists.apache.org/thread.html/rf9fa47ab66495c78bb4120b0754dd9531ca2ff0430f6685ac9b07772@%3Cdev.mina.apache.org%3E</a><br></details>  |
| libjpeg-turbo8         |    CVE-2020-17541   |   LOW  |  2.0.3-0ubuntu1.20.04.1 |  | <details><summary>Expand...</summary><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2020-17541">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2020-17541</a><br><a href="https://github.com/libjpeg-turbo/libjpeg-turbo/issues/392">https://github.com/libjpeg-turbo/libjpeg-turbo/issues/392</a><br><a href="https://linux.oracle.com/cve/CVE-2020-17541.html">https://linux.oracle.com/cve/CVE-2020-17541.html</a><br><a href="https://linux.oracle.com/errata/ELSA-2021-4288.html">https://linux.oracle.com/errata/ELSA-2021-4288.html</a><br></details>  |
| libk5crypto3         |    CVE-2021-36222   |   MEDIUM  |  1.17-6ubuntu4.1 |  | <details><summary>Expand...</summary><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2021-36222">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2021-36222</a><br><a href="https://github.com/krb5/krb5/commit/fc98f520caefff2e5ee9a0026fdf5109944b3562">https://github.com/krb5/krb5/commit/fc98f520caefff2e5ee9a0026fdf5109944b3562</a><br><a href="https://github.com/krb5/krb5/releases">https://github.com/krb5/krb5/releases</a><br><a href="https://linux.oracle.com/cve/CVE-2021-36222.html">https://linux.oracle.com/cve/CVE-2021-36222.html</a><br><a href="https://linux.oracle.com/errata/ELSA-2021-3576.html">https://linux.oracle.com/errata/ELSA-2021-3576.html</a><br><a href="https://security.netapp.com/advisory/ntap-20211022-0003/">https://security.netapp.com/advisory/ntap-20211022-0003/</a><br><a href="https://security.netapp.com/advisory/ntap-20211104-0007/">https://security.netapp.com/advisory/ntap-20211104-0007/</a><br><a href="https://web.mit.edu/kerberos/advisories/">https://web.mit.edu/kerberos/advisories/</a><br><a href="https://www.debian.org/security/2021/dsa-4944">https://www.debian.org/security/2021/dsa-4944</a><br><a href="https://www.oracle.com/security-alerts/cpuoct2021.html">https://www.oracle.com/security-alerts/cpuoct2021.html</a><br></details>  |
| libk5crypto3         |    CVE-2018-5709   |   LOW  |  1.17-6ubuntu4.1 |  | <details><summary>Expand...</summary><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2018-5709">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2018-5709</a><br><a href="https://github.com/poojamnit/Kerberos-V5-1.16-Vulnerabilities/tree/master/Integer%20Overflow">https://github.com/poojamnit/Kerberos-V5-1.16-Vulnerabilities/tree/master/Integer%20Overflow</a><br><a href="https://lists.apache.org/thread.html/rf9fa47ab66495c78bb4120b0754dd9531ca2ff0430f6685ac9b07772@%3Cdev.mina.apache.org%3E">https://lists.apache.org/thread.html/rf9fa47ab66495c78bb4120b0754dd9531ca2ff0430f6685ac9b07772@%3Cdev.mina.apache.org%3E</a><br></details>  |
| libkrb5-26-heimdal         |    CVE-2021-3671   |   LOW  |  7.7.0+dfsg-1ubuntu1 |  | <details><summary>Expand...</summary><a href="https://bugzilla.redhat.com/show_bug.cgi?id=2013080,">https://bugzilla.redhat.com/show_bug.cgi?id=2013080,</a><br><a href="https://bugzilla.samba.org/show_bug.cgi?id=14770,">https://bugzilla.samba.org/show_bug.cgi?id=14770,</a><br><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2021-3671">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2021-3671</a><br><a href="https://github.com/heimdal/heimdal/commit/04171147948d0a3636bc6374181926f0fb2ec83a">https://github.com/heimdal/heimdal/commit/04171147948d0a3636bc6374181926f0fb2ec83a</a><br><a href="https://ubuntu.com/security/notices/USN-5142-1">https://ubuntu.com/security/notices/USN-5142-1</a><br><a href="https://ubuntu.com/security/notices/USN-5174-1">https://ubuntu.com/security/notices/USN-5174-1</a><br></details>  |
| libkrb5-3         |    CVE-2021-36222   |   MEDIUM  |  1.17-6ubuntu4.1 |  | <details><summary>Expand...</summary><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2021-36222">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2021-36222</a><br><a href="https://github.com/krb5/krb5/commit/fc98f520caefff2e5ee9a0026fdf5109944b3562">https://github.com/krb5/krb5/commit/fc98f520caefff2e5ee9a0026fdf5109944b3562</a><br><a href="https://github.com/krb5/krb5/releases">https://github.com/krb5/krb5/releases</a><br><a href="https://linux.oracle.com/cve/CVE-2021-36222.html">https://linux.oracle.com/cve/CVE-2021-36222.html</a><br><a href="https://linux.oracle.com/errata/ELSA-2021-3576.html">https://linux.oracle.com/errata/ELSA-2021-3576.html</a><br><a href="https://security.netapp.com/advisory/ntap-20211022-0003/">https://security.netapp.com/advisory/ntap-20211022-0003/</a><br><a href="https://security.netapp.com/advisory/ntap-20211104-0007/">https://security.netapp.com/advisory/ntap-20211104-0007/</a><br><a href="https://web.mit.edu/kerberos/advisories/">https://web.mit.edu/kerberos/advisories/</a><br><a href="https://www.debian.org/security/2021/dsa-4944">https://www.debian.org/security/2021/dsa-4944</a><br><a href="https://www.oracle.com/security-alerts/cpuoct2021.html">https://www.oracle.com/security-alerts/cpuoct2021.html</a><br></details>  |
| libkrb5-3         |    CVE-2018-5709   |   LOW  |  1.17-6ubuntu4.1 |  | <details><summary>Expand...</summary><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2018-5709">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2018-5709</a><br><a href="https://github.com/poojamnit/Kerberos-V5-1.16-Vulnerabilities/tree/master/Integer%20Overflow">https://github.com/poojamnit/Kerberos-V5-1.16-Vulnerabilities/tree/master/Integer%20Overflow</a><br><a href="https://lists.apache.org/thread.html/rf9fa47ab66495c78bb4120b0754dd9531ca2ff0430f6685ac9b07772@%3Cdev.mina.apache.org%3E">https://lists.apache.org/thread.html/rf9fa47ab66495c78bb4120b0754dd9531ca2ff0430f6685ac9b07772@%3Cdev.mina.apache.org%3E</a><br></details>  |
| libkrb5support0         |    CVE-2021-36222   |   MEDIUM  |  1.17-6ubuntu4.1 |  | <details><summary>Expand...</summary><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2021-36222">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2021-36222</a><br><a href="https://github.com/krb5/krb5/commit/fc98f520caefff2e5ee9a0026fdf5109944b3562">https://github.com/krb5/krb5/commit/fc98f520caefff2e5ee9a0026fdf5109944b3562</a><br><a href="https://github.com/krb5/krb5/releases">https://github.com/krb5/krb5/releases</a><br><a href="https://linux.oracle.com/cve/CVE-2021-36222.html">https://linux.oracle.com/cve/CVE-2021-36222.html</a><br><a href="https://linux.oracle.com/errata/ELSA-2021-3576.html">https://linux.oracle.com/errata/ELSA-2021-3576.html</a><br><a href="https://security.netapp.com/advisory/ntap-20211022-0003/">https://security.netapp.com/advisory/ntap-20211022-0003/</a><br><a href="https://security.netapp.com/advisory/ntap-20211104-0007/">https://security.netapp.com/advisory/ntap-20211104-0007/</a><br><a href="https://web.mit.edu/kerberos/advisories/">https://web.mit.edu/kerberos/advisories/</a><br><a href="https://www.debian.org/security/2021/dsa-4944">https://www.debian.org/security/2021/dsa-4944</a><br><a href="https://www.oracle.com/security-alerts/cpuoct2021.html">https://www.oracle.com/security-alerts/cpuoct2021.html</a><br></details>  |
| libkrb5support0         |    CVE-2018-5709   |   LOW  |  1.17-6ubuntu4.1 |  | <details><summary>Expand...</summary><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2018-5709">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2018-5709</a><br><a href="https://github.com/poojamnit/Kerberos-V5-1.16-Vulnerabilities/tree/master/Integer%20Overflow">https://github.com/poojamnit/Kerberos-V5-1.16-Vulnerabilities/tree/master/Integer%20Overflow</a><br><a href="https://lists.apache.org/thread.html/rf9fa47ab66495c78bb4120b0754dd9531ca2ff0430f6685ac9b07772@%3Cdev.mina.apache.org%3E">https://lists.apache.org/thread.html/rf9fa47ab66495c78bb4120b0754dd9531ca2ff0430f6685ac9b07772@%3Cdev.mina.apache.org%3E</a><br></details>  |
| libopenjp2-7         |    CVE-2019-6988   |   LOW  |  2.3.1-1ubuntu4.20.04.1 |  | <details><summary>Expand...</summary><a href="http://www.securityfocus.com/bid/106785">http://www.securityfocus.com/bid/106785</a><br><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2019-6988">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2019-6988</a><br><a href="https://github.com/uclouvain/openjpeg/issues/1178">https://github.com/uclouvain/openjpeg/issues/1178</a><br></details>  |
| libopenjp2-7         |    CVE-2021-29338   |   LOW  |  2.3.1-1ubuntu4.20.04.1 |  | <details><summary>Expand...</summary><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2021-29338">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2021-29338</a><br><a href="https://github.com/uclouvain/openjpeg/issues/1338">https://github.com/uclouvain/openjpeg/issues/1338</a><br><a href="https://github.com/uclouvain/openjpeg/pull/1346">https://github.com/uclouvain/openjpeg/pull/1346</a><br><a href="https://linux.oracle.com/cve/CVE-2021-29338.html">https://linux.oracle.com/cve/CVE-2021-29338.html</a><br><a href="https://linux.oracle.com/errata/ELSA-2021-4251.html">https://linux.oracle.com/errata/ELSA-2021-4251.html</a><br><a href="https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/EZ54FGM2IGAP4AWSJ22JKHOPHCR3FGYU/">https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/EZ54FGM2IGAP4AWSJ22JKHOPHCR3FGYU/</a><br><a href="https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/QB6AI7CWXWMEDZIQY4LQ6DMIEXMDOHUP/">https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/QB6AI7CWXWMEDZIQY4LQ6DMIEXMDOHUP/</a><br></details>  |
| libopenmpt0         |    CVE-2019-17113   |   MEDIUM  |  0.4.11-1build1 |  | <details><summary>Expand...</summary><a href="http://lists.opensuse.org/opensuse-security-announce/2019-10/msg00035.html">http://lists.opensuse.org/opensuse-security-announce/2019-10/msg00035.html</a><br><a href="http://lists.opensuse.org/opensuse-security-announce/2019-10/msg00044.html">http://lists.opensuse.org/opensuse-security-announce/2019-10/msg00044.html</a><br><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2019-17113">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2019-17113</a><br><a href="https://github.com/OpenMPT/openmpt/commit/927688ddab43c2b203569de79407a899e734fabe">https://github.com/OpenMPT/openmpt/commit/927688ddab43c2b203569de79407a899e734fabe</a><br><a href="https://github.com/OpenMPT/openmpt/compare/libopenmpt-0.3.18...libopenmpt-0.3.19">https://github.com/OpenMPT/openmpt/compare/libopenmpt-0.3.18...libopenmpt-0.3.19</a><br><a href="https://github.com/OpenMPT/openmpt/compare/libopenmpt-0.4.8...libopenmpt-0.4.9">https://github.com/OpenMPT/openmpt/compare/libopenmpt-0.4.8...libopenmpt-0.4.9</a><br><a href="https://lists.debian.org/debian-lts-announce/2020/08/msg00003.html">https://lists.debian.org/debian-lts-announce/2020/08/msg00003.html</a><br><a href="https://source.openmpt.org/browse/openmpt/trunk/OpenMPT/?op=revision&amp;rev=12127&amp;peg=12127">https://source.openmpt.org/browse/openmpt/trunk/OpenMPT/?op=revision&amp;rev=12127&amp;peg=12127</a><br><a href="https://www.debian.org/security/2020/dsa-4729">https://www.debian.org/security/2020/dsa-4729</a><br></details>  |
| libpcre3         |    CVE-2017-11164   |   LOW  |  2:8.39-12build1 |  | <details><summary>Expand...</summary><a href="http://openwall.com/lists/oss-security/2017/07/11/3">http://openwall.com/lists/oss-security/2017/07/11/3</a><br><a href="http://www.securityfocus.com/bid/99575">http://www.securityfocus.com/bid/99575</a><br><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2017-11164">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2017-11164</a><br><a href="https://lists.apache.org/thread.html/rf9fa47ab66495c78bb4120b0754dd9531ca2ff0430f6685ac9b07772@%3Cdev.mina.apache.org%3E">https://lists.apache.org/thread.html/rf9fa47ab66495c78bb4120b0754dd9531ca2ff0430f6685ac9b07772@%3Cdev.mina.apache.org%3E</a><br></details>  |
| libpcre3         |    CVE-2019-20838   |   LOW  |  2:8.39-12build1 |  | <details><summary>Expand...</summary><a href="http://seclists.org/fulldisclosure/2020/Dec/32">http://seclists.org/fulldisclosure/2020/Dec/32</a><br><a href="http://seclists.org/fulldisclosure/2021/Feb/14">http://seclists.org/fulldisclosure/2021/Feb/14</a><br><a href="https://bugs.gentoo.org/717920">https://bugs.gentoo.org/717920</a><br><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2019-20838">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2019-20838</a><br><a href="https://linux.oracle.com/cve/CVE-2019-20838.html">https://linux.oracle.com/cve/CVE-2019-20838.html</a><br><a href="https://linux.oracle.com/errata/ELSA-2021-4373.html">https://linux.oracle.com/errata/ELSA-2021-4373.html</a><br><a href="https://lists.apache.org/thread.html/rf9fa47ab66495c78bb4120b0754dd9531ca2ff0430f6685ac9b07772@%3Cdev.mina.apache.org%3E">https://lists.apache.org/thread.html/rf9fa47ab66495c78bb4120b0754dd9531ca2ff0430f6685ac9b07772@%3Cdev.mina.apache.org%3E</a><br><a href="https://support.apple.com/kb/HT211931">https://support.apple.com/kb/HT211931</a><br><a href="https://support.apple.com/kb/HT212147">https://support.apple.com/kb/HT212147</a><br><a href="https://www.pcre.org/original/changelog.txt">https://www.pcre.org/original/changelog.txt</a><br></details>  |
| libpcre3         |    CVE-2020-14155   |   LOW  |  2:8.39-12build1 |  | <details><summary>Expand...</summary><a href="http://seclists.org/fulldisclosure/2020/Dec/32">http://seclists.org/fulldisclosure/2020/Dec/32</a><br><a href="http://seclists.org/fulldisclosure/2021/Feb/14">http://seclists.org/fulldisclosure/2021/Feb/14</a><br><a href="https://about.gitlab.com/releases/2020/07/01/security-release-13-1-2-release/">https://about.gitlab.com/releases/2020/07/01/security-release-13-1-2-release/</a><br><a href="https://bugs.gentoo.org/717920">https://bugs.gentoo.org/717920</a><br><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2020-14155">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2020-14155</a><br><a href="https://linux.oracle.com/cve/CVE-2020-14155.html">https://linux.oracle.com/cve/CVE-2020-14155.html</a><br><a href="https://linux.oracle.com/errata/ELSA-2021-4373.html">https://linux.oracle.com/errata/ELSA-2021-4373.html</a><br><a href="https://lists.apache.org/thread.html/rf9fa47ab66495c78bb4120b0754dd9531ca2ff0430f6685ac9b07772@%3Cdev.mina.apache.org%3E">https://lists.apache.org/thread.html/rf9fa47ab66495c78bb4120b0754dd9531ca2ff0430f6685ac9b07772@%3Cdev.mina.apache.org%3E</a><br><a href="https://support.apple.com/kb/HT211931">https://support.apple.com/kb/HT211931</a><br><a href="https://support.apple.com/kb/HT212147">https://support.apple.com/kb/HT212147</a><br><a href="https://www.pcre.org/original/changelog.txt">https://www.pcre.org/original/changelog.txt</a><br></details>  |
| libpython3.8-minimal         |    CVE-2021-3737   |   MEDIUM  |  3.8.10-0ubuntu1~20.04.2 |  | <details><summary>Expand...</summary><a href="https://bugs.python.org/issue44022">https://bugs.python.org/issue44022</a><br><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2021-3737">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2021-3737</a><br><a href="https://github.com/python/cpython/commit/0389426fa4af4dfc8b1d7f3f291932d928392d8b (3.8 branch)">https://github.com/python/cpython/commit/0389426fa4af4dfc8b1d7f3f291932d928392d8b (3.8 branch)</a><br><a href="https://github.com/python/cpython/commit/078b146f062d212919d0ba25e34e658a8234aa63 (v3.7.11)">https://github.com/python/cpython/commit/078b146f062d212919d0ba25e34e658a8234aa63 (v3.7.11)</a><br><a href="https://github.com/python/cpython/commit/1b6f4e5e13ebd1f957b47f7415b53d0869bdbac6 (v3.6.14">https://github.com/python/cpython/commit/1b6f4e5e13ebd1f957b47f7415b53d0869bdbac6 (v3.6.14</a><br><a href="https://github.com/python/cpython/commit/5df4abd6b033a5f1e48945c6988b45e35e76f647 (v3.9.6)">https://github.com/python/cpython/commit/5df4abd6b033a5f1e48945c6988b45e35e76f647 (v3.9.6)</a><br><a href="https://github.com/python/cpython/commit/60ba0b68470a584103e28958d91e93a6db37ec92 (v3.10.0b2)">https://github.com/python/cpython/commit/60ba0b68470a584103e28958d91e93a6db37ec92 (v3.10.0b2)</a><br><a href="https://github.com/python/cpython/commit/98e5a7975d99b58d511f171816ecdfb13d5cca18 (v3.10.0b3)">https://github.com/python/cpython/commit/98e5a7975d99b58d511f171816ecdfb13d5cca18 (v3.10.0b3)</a><br><a href="https://github.com/python/cpython/commit/ea9327036680acc92d9f89eaf6f6a54d2f8d78d9 (v3.9.6)">https://github.com/python/cpython/commit/ea9327036680acc92d9f89eaf6f6a54d2f8d78d9 (v3.9.6)</a><br><a href="https://github.com/python/cpython/commit/f396864ddfe914531b5856d7bf852808ebfc01ae (v3.8.11)">https://github.com/python/cpython/commit/f396864ddfe914531b5856d7bf852808ebfc01ae (v3.8.11)</a><br><a href="https://github.com/python/cpython/commit/f68d2d69f1da56c2aea1293ecf93ab69a6010ad7 (v3.6.14)">https://github.com/python/cpython/commit/f68d2d69f1da56c2aea1293ecf93ab69a6010ad7 (v3.6.14)</a><br><a href="https://github.com/python/cpython/commit/fee96422e6f0056561cf74fef2012cc066c9db86 (v3.7.11)">https://github.com/python/cpython/commit/fee96422e6f0056561cf74fef2012cc066c9db86 (v3.7.11)</a><br><a href="https://github.com/python/cpython/pull/25916">https://github.com/python/cpython/pull/25916</a><br><a href="https://github.com/python/cpython/pull/26503">https://github.com/python/cpython/pull/26503</a><br><a href="https://linux.oracle.com/cve/CVE-2021-3737.html">https://linux.oracle.com/cve/CVE-2021-3737.html</a><br><a href="https://linux.oracle.com/errata/ELSA-2021-4160.html">https://linux.oracle.com/errata/ELSA-2021-4160.html</a><br><a href="https://ubuntu.com/security/notices/USN-5083-1">https://ubuntu.com/security/notices/USN-5083-1</a><br></details>  |
| libpython3.8-minimal         |    CVE-2021-23336   |   LOW  |  3.8.10-0ubuntu1~20.04.2 |  | <details><summary>Expand...</summary><a href="http://www.openwall.com/lists/oss-security/2021/02/19/4">http://www.openwall.com/lists/oss-security/2021/02/19/4</a><br><a href="http://www.openwall.com/lists/oss-security/2021/05/01/2">http://www.openwall.com/lists/oss-security/2021/05/01/2</a><br><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2021-23336">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2021-23336</a><br><a href="https://github.com/python/cpython/commit/fcbe0cb04d35189401c0c880ebfb4311e952d776 (master)">https://github.com/python/cpython/commit/fcbe0cb04d35189401c0c880ebfb4311e952d776 (master)</a><br><a href="https://github.com/python/cpython/pull/24297">https://github.com/python/cpython/pull/24297</a><br><a href="https://linux.oracle.com/cve/CVE-2021-23336.html">https://linux.oracle.com/cve/CVE-2021-23336.html</a><br><a href="https://linux.oracle.com/errata/ELSA-2021-4162.html">https://linux.oracle.com/errata/ELSA-2021-4162.html</a><br><a href="https://lists.apache.org/thread.html/ra8ce70088ba291f358e077cafdb14d174b7a1ce9a9d86d1b332d6367@%3Cusers.airflow.apache.org%3E">https://lists.apache.org/thread.html/ra8ce70088ba291f358e077cafdb14d174b7a1ce9a9d86d1b332d6367@%3Cusers.airflow.apache.org%3E</a><br><a href="https://lists.apache.org/thread.html/rc005f4de9d9b0ba943ceb8ff5a21a5c6ff8a9df52632476698d99432@%3Cannounce.apache.org%3E">https://lists.apache.org/thread.html/rc005f4de9d9b0ba943ceb8ff5a21a5c6ff8a9df52632476698d99432@%3Cannounce.apache.org%3E</a><br><a href="https://lists.apache.org/thread.html/rf9fa47ab66495c78bb4120b0754dd9531ca2ff0430f6685ac9b07772@%3Cdev.mina.apache.org%3E">https://lists.apache.org/thread.html/rf9fa47ab66495c78bb4120b0754dd9531ca2ff0430f6685ac9b07772@%3Cdev.mina.apache.org%3E</a><br><a href="https://lists.debian.org/debian-lts-announce/2021/02/msg00030.html">https://lists.debian.org/debian-lts-announce/2021/02/msg00030.html</a><br><a href="https://lists.debian.org/debian-lts-announce/2021/04/msg00005.html">https://lists.debian.org/debian-lts-announce/2021/04/msg00005.html</a><br><a href="https://lists.debian.org/debian-lts-announce/2021/04/msg00015.html">https://lists.debian.org/debian-lts-announce/2021/04/msg00015.html</a><br><a href="https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/3EPYWWFDV22CJ5AOH5VCE72DOASZZ255/">https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/3EPYWWFDV22CJ5AOH5VCE72DOASZZ255/</a><br><a href="https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/3YKKDLXL3UEZ3J426C2XTBS63AHE46SM/">https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/3YKKDLXL3UEZ3J426C2XTBS63AHE46SM/</a><br><a href="https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/46N6A52EGSXHJYCZWVMBJJIH4NWIV2B5/">https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/46N6A52EGSXHJYCZWVMBJJIH4NWIV2B5/</a><br><a href="https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/FONHJIOZOFD7CD35KZL6SVBUTMBPGZGA/">https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/FONHJIOZOFD7CD35KZL6SVBUTMBPGZGA/</a><br><a href="https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/HCQTCSP6SCVIYNIRUJC5X7YBVUHPLSC4/">https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/HCQTCSP6SCVIYNIRUJC5X7YBVUHPLSC4/</a><br><a href="https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/HZTM7KLHFCE3LWSEVO2NAFLUHMGYMCRY/">https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/HZTM7KLHFCE3LWSEVO2NAFLUHMGYMCRY/</a><br><a href="https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/IHQDU7NXA7EWAE4W7VO6MURVJIULEPPR/">https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/IHQDU7NXA7EWAE4W7VO6MURVJIULEPPR/</a><br><a href="https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/KJXCMHLY7H3FIYLE4OKDYUILU2CCRUCZ/">https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/KJXCMHLY7H3FIYLE4OKDYUILU2CCRUCZ/</a><br><a href="https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/LVNH6Z24IG3E67ZCQGGJ46FZB4XFLQNZ/">https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/LVNH6Z24IG3E67ZCQGGJ46FZB4XFLQNZ/</a><br><a href="https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/MNUN5SOMFL2BBKP6ZAICIIUPQKZDMGYO/">https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/MNUN5SOMFL2BBKP6ZAICIIUPQKZDMGYO/</a><br><a href="https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/MP572OLHMS7MZO4KUPSCIMSZIA5IZZ62/">https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/MP572OLHMS7MZO4KUPSCIMSZIA5IZZ62/</a><br><a href="https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/N6VXJZSZ6N64AILJX4CTMACYGQGHHD5C/">https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/N6VXJZSZ6N64AILJX4CTMACYGQGHHD5C/</a><br><a href="https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/NJSCSN722JO2E2AGPWD4NTGVELVRPB4R/">https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/NJSCSN722JO2E2AGPWD4NTGVELVRPB4R/</a><br><a href="https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/NODWHDIFBQE5RU5PUWUVE47JOT5VCMJ2/">https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/NODWHDIFBQE5RU5PUWUVE47JOT5VCMJ2/</a><br><a href="https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/OAGSWNGZJ6HQ5ISA67SNMK3CJRKICET7/">https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/OAGSWNGZJ6HQ5ISA67SNMK3CJRKICET7/</a><br><a href="https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/RSLQD5CCM75IZGAMBDGUZEATYU5YSGJ7/">https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/RSLQD5CCM75IZGAMBDGUZEATYU5YSGJ7/</a><br><a href="https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/SGIY6I4YS3WOXAK4SXKIEOC2G4VZKIR7/">https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/SGIY6I4YS3WOXAK4SXKIEOC2G4VZKIR7/</a><br><a href="https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/TFTELUMWZE3KV3JB2H5EE6VFRZFRD5MV/">https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/TFTELUMWZE3KV3JB2H5EE6VFRZFRD5MV/</a><br><a href="https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/W2LSKBEFI5SYEY5FM6ICZVZM5WRQUCS4/">https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/W2LSKBEFI5SYEY5FM6ICZVZM5WRQUCS4/</a><br><a href="https://security.gentoo.org/glsa/202104-04">https://security.gentoo.org/glsa/202104-04</a><br><a href="https://security.netapp.com/advisory/ntap-20210326-0004/">https://security.netapp.com/advisory/ntap-20210326-0004/</a><br><a href="https://snyk.io/blog/cache-poisoning-in-popular-open-source-packages/">https://snyk.io/blog/cache-poisoning-in-popular-open-source-packages/</a><br><a href="https://snyk.io/vuln/SNYK-UPSTREAM-PYTHONCPYTHON-1074933">https://snyk.io/vuln/SNYK-UPSTREAM-PYTHONCPYTHON-1074933</a><br><a href="https://ubuntu.com/security/notices/USN-4742-1">https://ubuntu.com/security/notices/USN-4742-1</a><br><a href="https://www.djangoproject.com/weblog/2021/feb/19/security-releases/">https://www.djangoproject.com/weblog/2021/feb/19/security-releases/</a><br><a href="https://www.oracle.com//security-alerts/cpujul2021.html">https://www.oracle.com//security-alerts/cpujul2021.html</a><br><a href="https://www.oracle.com/security-alerts/cpuApr2021.html">https://www.oracle.com/security-alerts/cpuApr2021.html</a><br><a href="https://www.oracle.com/security-alerts/cpuoct2021.html">https://www.oracle.com/security-alerts/cpuoct2021.html</a><br></details>  |
| libpython3.8-stdlib         |    CVE-2021-3737   |   MEDIUM  |  3.8.10-0ubuntu1~20.04.2 |  | <details><summary>Expand...</summary><a href="https://bugs.python.org/issue44022">https://bugs.python.org/issue44022</a><br><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2021-3737">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2021-3737</a><br><a href="https://github.com/python/cpython/commit/0389426fa4af4dfc8b1d7f3f291932d928392d8b (3.8 branch)">https://github.com/python/cpython/commit/0389426fa4af4dfc8b1d7f3f291932d928392d8b (3.8 branch)</a><br><a href="https://github.com/python/cpython/commit/078b146f062d212919d0ba25e34e658a8234aa63 (v3.7.11)">https://github.com/python/cpython/commit/078b146f062d212919d0ba25e34e658a8234aa63 (v3.7.11)</a><br><a href="https://github.com/python/cpython/commit/1b6f4e5e13ebd1f957b47f7415b53d0869bdbac6 (v3.6.14">https://github.com/python/cpython/commit/1b6f4e5e13ebd1f957b47f7415b53d0869bdbac6 (v3.6.14</a><br><a href="https://github.com/python/cpython/commit/5df4abd6b033a5f1e48945c6988b45e35e76f647 (v3.9.6)">https://github.com/python/cpython/commit/5df4abd6b033a5f1e48945c6988b45e35e76f647 (v3.9.6)</a><br><a href="https://github.com/python/cpython/commit/60ba0b68470a584103e28958d91e93a6db37ec92 (v3.10.0b2)">https://github.com/python/cpython/commit/60ba0b68470a584103e28958d91e93a6db37ec92 (v3.10.0b2)</a><br><a href="https://github.com/python/cpython/commit/98e5a7975d99b58d511f171816ecdfb13d5cca18 (v3.10.0b3)">https://github.com/python/cpython/commit/98e5a7975d99b58d511f171816ecdfb13d5cca18 (v3.10.0b3)</a><br><a href="https://github.com/python/cpython/commit/ea9327036680acc92d9f89eaf6f6a54d2f8d78d9 (v3.9.6)">https://github.com/python/cpython/commit/ea9327036680acc92d9f89eaf6f6a54d2f8d78d9 (v3.9.6)</a><br><a href="https://github.com/python/cpython/commit/f396864ddfe914531b5856d7bf852808ebfc01ae (v3.8.11)">https://github.com/python/cpython/commit/f396864ddfe914531b5856d7bf852808ebfc01ae (v3.8.11)</a><br><a href="https://github.com/python/cpython/commit/f68d2d69f1da56c2aea1293ecf93ab69a6010ad7 (v3.6.14)">https://github.com/python/cpython/commit/f68d2d69f1da56c2aea1293ecf93ab69a6010ad7 (v3.6.14)</a><br><a href="https://github.com/python/cpython/commit/fee96422e6f0056561cf74fef2012cc066c9db86 (v3.7.11)">https://github.com/python/cpython/commit/fee96422e6f0056561cf74fef2012cc066c9db86 (v3.7.11)</a><br><a href="https://github.com/python/cpython/pull/25916">https://github.com/python/cpython/pull/25916</a><br><a href="https://github.com/python/cpython/pull/26503">https://github.com/python/cpython/pull/26503</a><br><a href="https://linux.oracle.com/cve/CVE-2021-3737.html">https://linux.oracle.com/cve/CVE-2021-3737.html</a><br><a href="https://linux.oracle.com/errata/ELSA-2021-4160.html">https://linux.oracle.com/errata/ELSA-2021-4160.html</a><br><a href="https://ubuntu.com/security/notices/USN-5083-1">https://ubuntu.com/security/notices/USN-5083-1</a><br></details>  |
| libpython3.8-stdlib         |    CVE-2021-23336   |   LOW  |  3.8.10-0ubuntu1~20.04.2 |  | <details><summary>Expand...</summary><a href="http://www.openwall.com/lists/oss-security/2021/02/19/4">http://www.openwall.com/lists/oss-security/2021/02/19/4</a><br><a href="http://www.openwall.com/lists/oss-security/2021/05/01/2">http://www.openwall.com/lists/oss-security/2021/05/01/2</a><br><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2021-23336">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2021-23336</a><br><a href="https://github.com/python/cpython/commit/fcbe0cb04d35189401c0c880ebfb4311e952d776 (master)">https://github.com/python/cpython/commit/fcbe0cb04d35189401c0c880ebfb4311e952d776 (master)</a><br><a href="https://github.com/python/cpython/pull/24297">https://github.com/python/cpython/pull/24297</a><br><a href="https://linux.oracle.com/cve/CVE-2021-23336.html">https://linux.oracle.com/cve/CVE-2021-23336.html</a><br><a href="https://linux.oracle.com/errata/ELSA-2021-4162.html">https://linux.oracle.com/errata/ELSA-2021-4162.html</a><br><a href="https://lists.apache.org/thread.html/ra8ce70088ba291f358e077cafdb14d174b7a1ce9a9d86d1b332d6367@%3Cusers.airflow.apache.org%3E">https://lists.apache.org/thread.html/ra8ce70088ba291f358e077cafdb14d174b7a1ce9a9d86d1b332d6367@%3Cusers.airflow.apache.org%3E</a><br><a href="https://lists.apache.org/thread.html/rc005f4de9d9b0ba943ceb8ff5a21a5c6ff8a9df52632476698d99432@%3Cannounce.apache.org%3E">https://lists.apache.org/thread.html/rc005f4de9d9b0ba943ceb8ff5a21a5c6ff8a9df52632476698d99432@%3Cannounce.apache.org%3E</a><br><a href="https://lists.apache.org/thread.html/rf9fa47ab66495c78bb4120b0754dd9531ca2ff0430f6685ac9b07772@%3Cdev.mina.apache.org%3E">https://lists.apache.org/thread.html/rf9fa47ab66495c78bb4120b0754dd9531ca2ff0430f6685ac9b07772@%3Cdev.mina.apache.org%3E</a><br><a href="https://lists.debian.org/debian-lts-announce/2021/02/msg00030.html">https://lists.debian.org/debian-lts-announce/2021/02/msg00030.html</a><br><a href="https://lists.debian.org/debian-lts-announce/2021/04/msg00005.html">https://lists.debian.org/debian-lts-announce/2021/04/msg00005.html</a><br><a href="https://lists.debian.org/debian-lts-announce/2021/04/msg00015.html">https://lists.debian.org/debian-lts-announce/2021/04/msg00015.html</a><br><a href="https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/3EPYWWFDV22CJ5AOH5VCE72DOASZZ255/">https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/3EPYWWFDV22CJ5AOH5VCE72DOASZZ255/</a><br><a href="https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/3YKKDLXL3UEZ3J426C2XTBS63AHE46SM/">https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/3YKKDLXL3UEZ3J426C2XTBS63AHE46SM/</a><br><a href="https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/46N6A52EGSXHJYCZWVMBJJIH4NWIV2B5/">https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/46N6A52EGSXHJYCZWVMBJJIH4NWIV2B5/</a><br><a href="https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/FONHJIOZOFD7CD35KZL6SVBUTMBPGZGA/">https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/FONHJIOZOFD7CD35KZL6SVBUTMBPGZGA/</a><br><a href="https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/HCQTCSP6SCVIYNIRUJC5X7YBVUHPLSC4/">https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/HCQTCSP6SCVIYNIRUJC5X7YBVUHPLSC4/</a><br><a href="https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/HZTM7KLHFCE3LWSEVO2NAFLUHMGYMCRY/">https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/HZTM7KLHFCE3LWSEVO2NAFLUHMGYMCRY/</a><br><a href="https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/IHQDU7NXA7EWAE4W7VO6MURVJIULEPPR/">https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/IHQDU7NXA7EWAE4W7VO6MURVJIULEPPR/</a><br><a href="https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/KJXCMHLY7H3FIYLE4OKDYUILU2CCRUCZ/">https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/KJXCMHLY7H3FIYLE4OKDYUILU2CCRUCZ/</a><br><a href="https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/LVNH6Z24IG3E67ZCQGGJ46FZB4XFLQNZ/">https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/LVNH6Z24IG3E67ZCQGGJ46FZB4XFLQNZ/</a><br><a href="https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/MNUN5SOMFL2BBKP6ZAICIIUPQKZDMGYO/">https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/MNUN5SOMFL2BBKP6ZAICIIUPQKZDMGYO/</a><br><a href="https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/MP572OLHMS7MZO4KUPSCIMSZIA5IZZ62/">https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/MP572OLHMS7MZO4KUPSCIMSZIA5IZZ62/</a><br><a href="https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/N6VXJZSZ6N64AILJX4CTMACYGQGHHD5C/">https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/N6VXJZSZ6N64AILJX4CTMACYGQGHHD5C/</a><br><a href="https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/NJSCSN722JO2E2AGPWD4NTGVELVRPB4R/">https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/NJSCSN722JO2E2AGPWD4NTGVELVRPB4R/</a><br><a href="https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/NODWHDIFBQE5RU5PUWUVE47JOT5VCMJ2/">https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/NODWHDIFBQE5RU5PUWUVE47JOT5VCMJ2/</a><br><a href="https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/OAGSWNGZJ6HQ5ISA67SNMK3CJRKICET7/">https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/OAGSWNGZJ6HQ5ISA67SNMK3CJRKICET7/</a><br><a href="https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/RSLQD5CCM75IZGAMBDGUZEATYU5YSGJ7/">https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/RSLQD5CCM75IZGAMBDGUZEATYU5YSGJ7/</a><br><a href="https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/SGIY6I4YS3WOXAK4SXKIEOC2G4VZKIR7/">https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/SGIY6I4YS3WOXAK4SXKIEOC2G4VZKIR7/</a><br><a href="https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/TFTELUMWZE3KV3JB2H5EE6VFRZFRD5MV/">https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/TFTELUMWZE3KV3JB2H5EE6VFRZFRD5MV/</a><br><a href="https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/W2LSKBEFI5SYEY5FM6ICZVZM5WRQUCS4/">https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/W2LSKBEFI5SYEY5FM6ICZVZM5WRQUCS4/</a><br><a href="https://security.gentoo.org/glsa/202104-04">https://security.gentoo.org/glsa/202104-04</a><br><a href="https://security.netapp.com/advisory/ntap-20210326-0004/">https://security.netapp.com/advisory/ntap-20210326-0004/</a><br><a href="https://snyk.io/blog/cache-poisoning-in-popular-open-source-packages/">https://snyk.io/blog/cache-poisoning-in-popular-open-source-packages/</a><br><a href="https://snyk.io/vuln/SNYK-UPSTREAM-PYTHONCPYTHON-1074933">https://snyk.io/vuln/SNYK-UPSTREAM-PYTHONCPYTHON-1074933</a><br><a href="https://ubuntu.com/security/notices/USN-4742-1">https://ubuntu.com/security/notices/USN-4742-1</a><br><a href="https://www.djangoproject.com/weblog/2021/feb/19/security-releases/">https://www.djangoproject.com/weblog/2021/feb/19/security-releases/</a><br><a href="https://www.oracle.com//security-alerts/cpujul2021.html">https://www.oracle.com//security-alerts/cpujul2021.html</a><br><a href="https://www.oracle.com/security-alerts/cpuApr2021.html">https://www.oracle.com/security-alerts/cpuApr2021.html</a><br><a href="https://www.oracle.com/security-alerts/cpuoct2021.html">https://www.oracle.com/security-alerts/cpuoct2021.html</a><br></details>  |
| libroken18-heimdal         |    CVE-2021-3671   |   LOW  |  7.7.0+dfsg-1ubuntu1 |  | <details><summary>Expand...</summary><a href="https://bugzilla.redhat.com/show_bug.cgi?id=2013080,">https://bugzilla.redhat.com/show_bug.cgi?id=2013080,</a><br><a href="https://bugzilla.samba.org/show_bug.cgi?id=14770,">https://bugzilla.samba.org/show_bug.cgi?id=14770,</a><br><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2021-3671">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2021-3671</a><br><a href="https://github.com/heimdal/heimdal/commit/04171147948d0a3636bc6374181926f0fb2ec83a">https://github.com/heimdal/heimdal/commit/04171147948d0a3636bc6374181926f0fb2ec83a</a><br><a href="https://ubuntu.com/security/notices/USN-5142-1">https://ubuntu.com/security/notices/USN-5142-1</a><br><a href="https://ubuntu.com/security/notices/USN-5174-1">https://ubuntu.com/security/notices/USN-5174-1</a><br></details>  |
| libsqlite3-0         |    CVE-2020-9794   |   MEDIUM  |  3.31.1-4ubuntu0.2 |  | <details><summary>Expand...</summary><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2020-9794">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2020-9794</a><br><a href="https://lists.apache.org/thread.html/rf9fa47ab66495c78bb4120b0754dd9531ca2ff0430f6685ac9b07772@%3Cdev.mina.apache.org%3E">https://lists.apache.org/thread.html/rf9fa47ab66495c78bb4120b0754dd9531ca2ff0430f6685ac9b07772@%3Cdev.mina.apache.org%3E</a><br><a href="https://support.apple.com/HT211168">https://support.apple.com/HT211168</a><br><a href="https://support.apple.com/HT211170">https://support.apple.com/HT211170</a><br><a href="https://support.apple.com/HT211171">https://support.apple.com/HT211171</a><br><a href="https://support.apple.com/HT211175">https://support.apple.com/HT211175</a><br><a href="https://support.apple.com/HT211178">https://support.apple.com/HT211178</a><br><a href="https://support.apple.com/HT211179">https://support.apple.com/HT211179</a><br><a href="https://support.apple.com/HT211181">https://support.apple.com/HT211181</a><br><a href="https://vuldb.com/?id.155768">https://vuldb.com/?id.155768</a><br></details>  |
| libsqlite3-0         |    CVE-2020-9849   |   LOW  |  3.31.1-4ubuntu0.2 |  | <details><summary>Expand...</summary><a href="http://seclists.org/fulldisclosure/2020/Dec/32">http://seclists.org/fulldisclosure/2020/Dec/32</a><br><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2020-9849">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2020-9849</a><br><a href="https://lists.apache.org/thread.html/rf9fa47ab66495c78bb4120b0754dd9531ca2ff0430f6685ac9b07772@%3Cdev.mina.apache.org%3E">https://lists.apache.org/thread.html/rf9fa47ab66495c78bb4120b0754dd9531ca2ff0430f6685ac9b07772@%3Cdev.mina.apache.org%3E</a><br><a href="https://support.apple.com/en-us/HT211843">https://support.apple.com/en-us/HT211843</a><br><a href="https://support.apple.com/en-us/HT211844">https://support.apple.com/en-us/HT211844</a><br><a href="https://support.apple.com/en-us/HT211850">https://support.apple.com/en-us/HT211850</a><br><a href="https://support.apple.com/en-us/HT211931">https://support.apple.com/en-us/HT211931</a><br><a href="https://support.apple.com/en-us/HT211935">https://support.apple.com/en-us/HT211935</a><br><a href="https://support.apple.com/en-us/HT211952">https://support.apple.com/en-us/HT211952</a><br><a href="https://www.rapid7.com/db/vulnerabilities/apple-osx-sqlite-cve-2020-9849/">https://www.rapid7.com/db/vulnerabilities/apple-osx-sqlite-cve-2020-9849/</a><br></details>  |
| libsqlite3-0         |    CVE-2020-9991   |   LOW  |  3.31.1-4ubuntu0.2 |  | <details><summary>Expand...</summary><a href="http://seclists.org/fulldisclosure/2020/Dec/32">http://seclists.org/fulldisclosure/2020/Dec/32</a><br><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2020-9991">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2020-9991</a><br><a href="https://lists.apache.org/thread.html/rf9fa47ab66495c78bb4120b0754dd9531ca2ff0430f6685ac9b07772@%3Cdev.mina.apache.org%3E">https://lists.apache.org/thread.html/rf9fa47ab66495c78bb4120b0754dd9531ca2ff0430f6685ac9b07772@%3Cdev.mina.apache.org%3E</a><br><a href="https://support.apple.com/en-us/HT211843">https://support.apple.com/en-us/HT211843</a><br><a href="https://support.apple.com/en-us/HT211844">https://support.apple.com/en-us/HT211844</a><br><a href="https://support.apple.com/en-us/HT211847">https://support.apple.com/en-us/HT211847</a><br><a href="https://support.apple.com/en-us/HT211850">https://support.apple.com/en-us/HT211850</a><br><a href="https://support.apple.com/en-us/HT211931">https://support.apple.com/en-us/HT211931</a><br><a href="https://support.apple.com/kb/HT211846">https://support.apple.com/kb/HT211846</a><br><a href="https://www.rapid7.com/db/vulnerabilities/apple-osx-sqlite-cve-2020-9991/">https://www.rapid7.com/db/vulnerabilities/apple-osx-sqlite-cve-2020-9991/</a><br></details>  |
| libswresample3         |    CVE-2020-14212   |   MEDIUM  |  7:4.2.4-1ubuntu0.1 |  | <details><summary>Expand...</summary><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2020-14212">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2020-14212</a><br><a href="https://patchwork.ffmpeg.org/project/ffmpeg/list/?series=1463">https://patchwork.ffmpeg.org/project/ffmpeg/list/?series=1463</a><br><a href="https://security.gentoo.org/glsa/202007-58">https://security.gentoo.org/glsa/202007-58</a><br><a href="https://trac.ffmpeg.org/ticket/8716">https://trac.ffmpeg.org/ticket/8716</a><br></details>  |
| libswresample3         |    CVE-2020-20891   |   MEDIUM  |  7:4.2.4-1ubuntu0.1 |  | <details><summary>Expand...</summary><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2020-20891">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2020-20891</a><br><a href="https://git.ffmpeg.org/gitweb/ffmpeg.git/commit/64a805883d7223c868a683f0030837d859edd2ab">https://git.ffmpeg.org/gitweb/ffmpeg.git/commit/64a805883d7223c868a683f0030837d859edd2ab</a><br><a href="https://trac.ffmpeg.org/ticket/8282">https://trac.ffmpeg.org/ticket/8282</a><br></details>  |
| libswresample3         |    CVE-2020-20892   |   MEDIUM  |  7:4.2.4-1ubuntu0.1 |  | <details><summary>Expand...</summary><a href="http://git.videolan.org/?p=ffmpeg.git;a=commit;h=19587c9332f5be4f6bc6d7b2b8ef3fd21dfeaa01">http://git.videolan.org/?p=ffmpeg.git;a=commit;h=19587c9332f5be4f6bc6d7b2b8ef3fd21dfeaa01</a><br><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2020-20892">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2020-20892</a><br><a href="https://trac.ffmpeg.org/ticket/8265">https://trac.ffmpeg.org/ticket/8265</a><br></details>  |
| libswresample3         |    CVE-2020-20896   |   MEDIUM  |  7:4.2.4-1ubuntu0.1 |  | <details><summary>Expand...</summary><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2020-20896">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2020-20896</a><br><a href="https://git.ffmpeg.org/gitweb/ffmpeg.git/commit/dd01947397b98e94c3f2a79d5820aaf4594f4d3b">https://git.ffmpeg.org/gitweb/ffmpeg.git/commit/dd01947397b98e94c3f2a79d5820aaf4594f4d3b</a><br><a href="https://trac.ffmpeg.org/ticket/8273">https://trac.ffmpeg.org/ticket/8273</a><br></details>  |
| libswresample3         |    CVE-2020-20898   |   MEDIUM  |  7:4.2.4-1ubuntu0.1 |  | <details><summary>Expand...</summary><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2020-20898">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2020-20898</a><br><a href="https://git.ffmpeg.org/gitweb/ffmpeg.git/commit/99f8d32129dd233d4eb2efa44678a0bc44869f23">https://git.ffmpeg.org/gitweb/ffmpeg.git/commit/99f8d32129dd233d4eb2efa44678a0bc44869f23</a><br><a href="https://trac.ffmpeg.org/ticket/8263">https://trac.ffmpeg.org/ticket/8263</a><br></details>  |
| libswresample3         |    CVE-2020-21041   |   MEDIUM  |  7:4.2.4-1ubuntu0.1 |  | <details><summary>Expand...</summary><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2020-21041">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2020-21041</a><br><a href="https://git.videolan.org/?p=ffmpeg.git;a=commitdiff;h=5d9f44da460f781a1604d537d0555b78e29438ba">https://git.videolan.org/?p=ffmpeg.git;a=commitdiff;h=5d9f44da460f781a1604d537d0555b78e29438ba</a><br><a href="https://lists.debian.org/debian-lts-announce/2021/08/msg00018.html">https://lists.debian.org/debian-lts-announce/2021/08/msg00018.html</a><br><a href="https://trac.ffmpeg.org/ticket/7989">https://trac.ffmpeg.org/ticket/7989</a><br><a href="https://www.debian.org/security/2021/dsa-4990">https://www.debian.org/security/2021/dsa-4990</a><br></details>  |
| libswresample3         |    CVE-2020-21688   |   MEDIUM  |  7:4.2.4-1ubuntu0.1 |  | <details><summary>Expand...</summary><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2020-21688">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2020-21688</a><br><a href="https://trac.ffmpeg.org/ticket/8186">https://trac.ffmpeg.org/ticket/8186</a><br><a href="https://www.debian.org/security/2021/dsa-4998">https://www.debian.org/security/2021/dsa-4998</a><br></details>  |
| libswresample3         |    CVE-2020-21697   |   MEDIUM  |  7:4.2.4-1ubuntu0.1 |  | <details><summary>Expand...</summary><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2020-21697">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2020-21697</a><br><a href="https://trac.ffmpeg.org/ticket/8188">https://trac.ffmpeg.org/ticket/8188</a><br><a href="https://www.debian.org/security/2021/dsa-4998">https://www.debian.org/security/2021/dsa-4998</a><br></details>  |
| libswresample3         |    CVE-2020-22015   |   MEDIUM  |  7:4.2.4-1ubuntu0.1 |  | <details><summary>Expand...</summary><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2020-22015">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2020-22015</a><br><a href="https://lists.debian.org/debian-lts-announce/2021/08/msg00018.html">https://lists.debian.org/debian-lts-announce/2021/08/msg00018.html</a><br><a href="https://trac.ffmpeg.org/ticket/8190">https://trac.ffmpeg.org/ticket/8190</a><br><a href="https://www.debian.org/security/2021/dsa-4990">https://www.debian.org/security/2021/dsa-4990</a><br></details>  |
| libswresample3         |    CVE-2020-22017   |   MEDIUM  |  7:4.2.4-1ubuntu0.1 |  | <details><summary>Expand...</summary><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2020-22017">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2020-22017</a><br><a href="https://trac.ffmpeg.org/ticket/8309">https://trac.ffmpeg.org/ticket/8309</a><br><a href="https://www.debian.org/security/2021/dsa-4990">https://www.debian.org/security/2021/dsa-4990</a><br></details>  |
| libswresample3         |    CVE-2020-22019   |   MEDIUM  |  7:4.2.4-1ubuntu0.1 |  | <details><summary>Expand...</summary><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2020-22019">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2020-22019</a><br><a href="https://trac.ffmpeg.org/ticket/8241">https://trac.ffmpeg.org/ticket/8241</a><br><a href="https://www.debian.org/security/2021/dsa-4990">https://www.debian.org/security/2021/dsa-4990</a><br></details>  |
| libswresample3         |    CVE-2020-22020   |   MEDIUM  |  7:4.2.4-1ubuntu0.1 |  | <details><summary>Expand...</summary><a href="http://git.videolan.org/?p=ffmpeg.git;a=commitdiff;h=ce5274c1385d55892a692998923802023526b765">http://git.videolan.org/?p=ffmpeg.git;a=commitdiff;h=ce5274c1385d55892a692998923802023526b765</a><br><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2020-22020">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2020-22020</a><br><a href="https://lists.debian.org/debian-lts-announce/2021/08/msg00018.html">https://lists.debian.org/debian-lts-announce/2021/08/msg00018.html</a><br><a href="https://trac.ffmpeg.org/ticket/8239">https://trac.ffmpeg.org/ticket/8239</a><br><a href="https://www.debian.org/security/2021/dsa-4990">https://www.debian.org/security/2021/dsa-4990</a><br></details>  |
| libswresample3         |    CVE-2020-22021   |   MEDIUM  |  7:4.2.4-1ubuntu0.1 |  | <details><summary>Expand...</summary><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2020-22021">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2020-22021</a><br><a href="https://lists.debian.org/debian-lts-announce/2021/08/msg00018.html">https://lists.debian.org/debian-lts-announce/2021/08/msg00018.html</a><br><a href="https://trac.ffmpeg.org/ticket/8240">https://trac.ffmpeg.org/ticket/8240</a><br><a href="https://www.debian.org/security/2021/dsa-4990">https://www.debian.org/security/2021/dsa-4990</a><br></details>  |
| libswresample3         |    CVE-2020-22022   |   MEDIUM  |  7:4.2.4-1ubuntu0.1 |  | <details><summary>Expand...</summary><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2020-22022">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2020-22022</a><br><a href="https://lists.debian.org/debian-lts-announce/2021/08/msg00018.html">https://lists.debian.org/debian-lts-announce/2021/08/msg00018.html</a><br><a href="https://trac.ffmpeg.org/ticket/8264">https://trac.ffmpeg.org/ticket/8264</a><br><a href="https://www.debian.org/security/2021/dsa-4990">https://www.debian.org/security/2021/dsa-4990</a><br></details>  |
| libswresample3         |    CVE-2020-22023   |   MEDIUM  |  7:4.2.4-1ubuntu0.1 |  | <details><summary>Expand...</summary><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2020-22023">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2020-22023</a><br><a href="https://lists.debian.org/debian-lts-announce/2021/08/msg00018.html">https://lists.debian.org/debian-lts-announce/2021/08/msg00018.html</a><br><a href="https://trac.ffmpeg.org/ticket/8244">https://trac.ffmpeg.org/ticket/8244</a><br><a href="https://www.debian.org/security/2021/dsa-4990">https://www.debian.org/security/2021/dsa-4990</a><br></details>  |
| libswresample3         |    CVE-2020-22024   |   MEDIUM  |  7:4.2.4-1ubuntu0.1 |  | <details><summary>Expand...</summary><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2020-22024">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2020-22024</a><br><a href="https://trac.ffmpeg.org/ticket/8310">https://trac.ffmpeg.org/ticket/8310</a><br></details>  |
| libswresample3         |    CVE-2020-22025   |   MEDIUM  |  7:4.2.4-1ubuntu0.1 |  | <details><summary>Expand...</summary><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2020-22025">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2020-22025</a><br><a href="https://lists.debian.org/debian-lts-announce/2021/08/msg00018.html">https://lists.debian.org/debian-lts-announce/2021/08/msg00018.html</a><br><a href="https://trac.ffmpeg.org/ticket/8260">https://trac.ffmpeg.org/ticket/8260</a><br><a href="https://www.debian.org/security/2021/dsa-4990">https://www.debian.org/security/2021/dsa-4990</a><br></details>  |
| libswresample3         |    CVE-2020-22026   |   MEDIUM  |  7:4.2.4-1ubuntu0.1 |  | <details><summary>Expand...</summary><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2020-22026">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2020-22026</a><br><a href="https://lists.debian.org/debian-lts-announce/2021/08/msg00018.html">https://lists.debian.org/debian-lts-announce/2021/08/msg00018.html</a><br><a href="https://trac.ffmpeg.org/ticket/8317">https://trac.ffmpeg.org/ticket/8317</a><br><a href="https://www.debian.org/security/2021/dsa-4990">https://www.debian.org/security/2021/dsa-4990</a><br></details>  |
| libswresample3         |    CVE-2020-22027   |   MEDIUM  |  7:4.2.4-1ubuntu0.1 |  | <details><summary>Expand...</summary><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2020-22027">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2020-22027</a><br><a href="https://trac.ffmpeg.org/attachment/ticket/8242/gdb-vf_neighbor_191">https://trac.ffmpeg.org/attachment/ticket/8242/gdb-vf_neighbor_191</a><br><a href="https://trac.ffmpeg.org/ticket/8242">https://trac.ffmpeg.org/ticket/8242</a><br><a href="https://www.debian.org/security/2021/dsa-4990">https://www.debian.org/security/2021/dsa-4990</a><br></details>  |
| libswresample3         |    CVE-2020-22028   |   MEDIUM  |  7:4.2.4-1ubuntu0.1 |  | <details><summary>Expand...</summary><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2020-22028">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2020-22028</a><br><a href="https://lists.debian.org/debian-lts-announce/2021/08/msg00018.html">https://lists.debian.org/debian-lts-announce/2021/08/msg00018.html</a><br><a href="https://trac.ffmpeg.org/ticket/8274">https://trac.ffmpeg.org/ticket/8274</a><br><a href="https://www.debian.org/security/2021/dsa-4990">https://www.debian.org/security/2021/dsa-4990</a><br></details>  |
| libswresample3         |    CVE-2020-22029   |   MEDIUM  |  7:4.2.4-1ubuntu0.1 |  | <details><summary>Expand...</summary><a href="http://git.videolan.org/?p=ffmpeg.git;a=commitdiff;h=a7fd1279703683ebb548ef7baa2f1519994496ae">http://git.videolan.org/?p=ffmpeg.git;a=commitdiff;h=a7fd1279703683ebb548ef7baa2f1519994496ae</a><br><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2020-22029">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2020-22029</a><br><a href="https://trac.ffmpeg.org/ticket/8250">https://trac.ffmpeg.org/ticket/8250</a><br><a href="https://www.debian.org/security/2021/dsa-4990">https://www.debian.org/security/2021/dsa-4990</a><br></details>  |
| libswresample3         |    CVE-2020-22030   |   MEDIUM  |  7:4.2.4-1ubuntu0.1 |  | <details><summary>Expand...</summary><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2020-22030">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2020-22030</a><br><a href="https://trac.ffmpeg.org/ticket/8276">https://trac.ffmpeg.org/ticket/8276</a><br><a href="https://www.debian.org/security/2021/dsa-4990">https://www.debian.org/security/2021/dsa-4990</a><br></details>  |
| libswresample3         |    CVE-2020-22031   |   MEDIUM  |  7:4.2.4-1ubuntu0.1 |  | <details><summary>Expand...</summary><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2020-22031">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2020-22031</a><br><a href="https://lists.debian.org/debian-lts-announce/2021/08/msg00018.html">https://lists.debian.org/debian-lts-announce/2021/08/msg00018.html</a><br><a href="https://trac.ffmpeg.org/attachment/ticket/8243/gdb-vf_w3fdif_191">https://trac.ffmpeg.org/attachment/ticket/8243/gdb-vf_w3fdif_191</a><br><a href="https://trac.ffmpeg.org/ticket/8243">https://trac.ffmpeg.org/ticket/8243</a><br><a href="https://www.debian.org/security/2021/dsa-4990">https://www.debian.org/security/2021/dsa-4990</a><br></details>  |
| libswresample3         |    CVE-2020-22032   |   MEDIUM  |  7:4.2.4-1ubuntu0.1 |  | <details><summary>Expand...</summary><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2020-22032">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2020-22032</a><br><a href="https://lists.debian.org/debian-lts-announce/2021/08/msg00018.html">https://lists.debian.org/debian-lts-announce/2021/08/msg00018.html</a><br><a href="https://trac.ffmpeg.org/ticket/8275">https://trac.ffmpeg.org/ticket/8275</a><br><a href="https://www.debian.org/security/2021/dsa-4990">https://www.debian.org/security/2021/dsa-4990</a><br></details>  |
| libswresample3         |    CVE-2020-22033   |   MEDIUM  |  7:4.2.4-1ubuntu0.1 |  | <details><summary>Expand...</summary><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2020-22033">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2020-22033</a><br><a href="https://trac.ffmpeg.org/ticket/8246">https://trac.ffmpeg.org/ticket/8246</a><br><a href="https://www.debian.org/security/2021/dsa-4990">https://www.debian.org/security/2021/dsa-4990</a><br></details>  |
| libswresample3         |    CVE-2020-22034   |   MEDIUM  |  7:4.2.4-1ubuntu0.1 |  | <details><summary>Expand...</summary><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2020-22034">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2020-22034</a><br><a href="https://trac.ffmpeg.org/ticket/8236">https://trac.ffmpeg.org/ticket/8236</a><br><a href="https://www.debian.org/security/2021/dsa-4990">https://www.debian.org/security/2021/dsa-4990</a><br></details>  |
| libswresample3         |    CVE-2020-22035   |   MEDIUM  |  7:4.2.4-1ubuntu0.1 |  | <details><summary>Expand...</summary><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2020-22035">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2020-22035</a><br><a href="https://trac.ffmpeg.org/ticket/8262">https://trac.ffmpeg.org/ticket/8262</a><br><a href="https://www.debian.org/security/2021/dsa-4990">https://www.debian.org/security/2021/dsa-4990</a><br></details>  |
| libswresample3         |    CVE-2020-22036   |   MEDIUM  |  7:4.2.4-1ubuntu0.1 |  | <details><summary>Expand...</summary><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2020-22036">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2020-22036</a><br><a href="https://lists.debian.org/debian-lts-announce/2021/08/msg00018.html">https://lists.debian.org/debian-lts-announce/2021/08/msg00018.html</a><br><a href="https://trac.ffmpeg.org/ticket/8261">https://trac.ffmpeg.org/ticket/8261</a><br><a href="https://www.debian.org/security/2021/dsa-4990">https://www.debian.org/security/2021/dsa-4990</a><br></details>  |
| libswresample3         |    CVE-2020-22037   |   MEDIUM  |  7:4.2.4-1ubuntu0.1 |  | <details><summary>Expand...</summary><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2020-22037">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2020-22037</a><br><a href="https://lists.debian.org/debian-lts-announce/2021/11/msg00012.html">https://lists.debian.org/debian-lts-announce/2021/11/msg00012.html</a><br><a href="https://trac.ffmpeg.org/ticket/8281">https://trac.ffmpeg.org/ticket/8281</a><br><a href="https://www.debian.org/security/2021/dsa-4990">https://www.debian.org/security/2021/dsa-4990</a><br><a href="https://www.debian.org/security/2021/dsa-4998">https://www.debian.org/security/2021/dsa-4998</a><br></details>  |
| libswresample3         |    CVE-2020-22038   |   MEDIUM  |  7:4.2.4-1ubuntu0.1 |  | <details><summary>Expand...</summary><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2020-22038">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2020-22038</a><br><a href="https://git.videolan.org/?p=ffmpeg.git;a=commitdiff;h=7c32e9cf93b712f8463573a59ed4e98fd10fa013">https://git.videolan.org/?p=ffmpeg.git;a=commitdiff;h=7c32e9cf93b712f8463573a59ed4e98fd10fa013</a><br><a href="https://trac.ffmpeg.org/ticket/8285">https://trac.ffmpeg.org/ticket/8285</a><br></details>  |
| libswresample3         |    CVE-2020-22039   |   MEDIUM  |  7:4.2.4-1ubuntu0.1 |  | <details><summary>Expand...</summary><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2020-22039">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2020-22039</a><br><a href="https://git.videolan.org/?p=ffmpeg.git;a=commitdiff;h=a581bb66ea5eb981e2e498ca301df7d1ef15a6a3">https://git.videolan.org/?p=ffmpeg.git;a=commitdiff;h=a581bb66ea5eb981e2e498ca301df7d1ef15a6a3</a><br><a href="https://trac.ffmpeg.org/ticket/8302">https://trac.ffmpeg.org/ticket/8302</a><br></details>  |
| libswresample3         |    CVE-2020-22040   |   MEDIUM  |  7:4.2.4-1ubuntu0.1 |  | <details><summary>Expand...</summary><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2020-22040">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2020-22040</a><br><a href="https://git.videolan.org/?p=ffmpeg.git;a=commitdiff;h=1a0c584abc9709b1d11dbafef05d22e0937d7d19">https://git.videolan.org/?p=ffmpeg.git;a=commitdiff;h=1a0c584abc9709b1d11dbafef05d22e0937d7d19</a><br><a href="https://trac.ffmpeg.org/ticket/8283">https://trac.ffmpeg.org/ticket/8283</a><br></details>  |
| libswresample3         |    CVE-2020-22041   |   MEDIUM  |  7:4.2.4-1ubuntu0.1 |  | <details><summary>Expand...</summary><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2020-22041">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2020-22041</a><br><a href="https://git.videolan.org/?p=ffmpeg.git;a=commitdiff;h=3488e0977c671568731afa12b811adce9d4d807f">https://git.videolan.org/?p=ffmpeg.git;a=commitdiff;h=3488e0977c671568731afa12b811adce9d4d807f</a><br><a href="https://lists.debian.org/debian-lts-announce/2021/11/msg00012.html">https://lists.debian.org/debian-lts-announce/2021/11/msg00012.html</a><br><a href="https://trac.ffmpeg.org/ticket/8296">https://trac.ffmpeg.org/ticket/8296</a><br></details>  |
| libswresample3         |    CVE-2020-22042   |   MEDIUM  |  7:4.2.4-1ubuntu0.1 |  | <details><summary>Expand...</summary><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2020-22042">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2020-22042</a><br><a href="https://git.videolan.org/?p=ffmpeg.git;a=commitdiff;h=426c16d61a9b5056a157a1a2a057a4e4d13eef84">https://git.videolan.org/?p=ffmpeg.git;a=commitdiff;h=426c16d61a9b5056a157a1a2a057a4e4d13eef84</a><br><a href="https://trac.ffmpeg.org/ticket/8267">https://trac.ffmpeg.org/ticket/8267</a><br><a href="https://www.debian.org/security/2021/dsa-4998">https://www.debian.org/security/2021/dsa-4998</a><br></details>  |
| libswresample3         |    CVE-2020-22043   |   MEDIUM  |  7:4.2.4-1ubuntu0.1 |  | <details><summary>Expand...</summary><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2020-22043">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2020-22043</a><br><a href="https://git.videolan.org/?p=ffmpeg.git;a=commitdiff;h=b288a7eb3d963a175e177b6219c8271076ee8590">https://git.videolan.org/?p=ffmpeg.git;a=commitdiff;h=b288a7eb3d963a175e177b6219c8271076ee8590</a><br><a href="https://trac.ffmpeg.org/ticket/8284">https://trac.ffmpeg.org/ticket/8284</a><br></details>  |
| libswresample3         |    CVE-2020-22044   |   MEDIUM  |  7:4.2.4-1ubuntu0.1 |  | <details><summary>Expand...</summary><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2020-22044">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2020-22044</a><br><a href="https://git.videolan.org/?p=ffmpeg.git;a=commitdiff;h=1d479300cbe0522c233b7d51148aea2b29bd29ad">https://git.videolan.org/?p=ffmpeg.git;a=commitdiff;h=1d479300cbe0522c233b7d51148aea2b29bd29ad</a><br><a href="https://lists.debian.org/debian-lts-announce/2021/11/msg00012.html">https://lists.debian.org/debian-lts-announce/2021/11/msg00012.html</a><br><a href="https://trac.ffmpeg.org/ticket/8295">https://trac.ffmpeg.org/ticket/8295</a><br></details>  |
| libswresample3         |    CVE-2020-22048   |   MEDIUM  |  7:4.2.4-1ubuntu0.1 |  | <details><summary>Expand...</summary><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2020-22048">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2020-22048</a><br><a href="https://lists.debian.org/debian-lts-announce/2021/11/msg00012.html">https://lists.debian.org/debian-lts-announce/2021/11/msg00012.html</a><br><a href="https://trac.ffmpeg.org/ticket/8303">https://trac.ffmpeg.org/ticket/8303</a><br></details>  |
| libswresample3         |    CVE-2020-22051   |   MEDIUM  |  7:4.2.4-1ubuntu0.1 |  | <details><summary>Expand...</summary><a href="http://git.videolan.org/?p=ffmpeg.git;a=commitdiff;h=673fce6d40d9a594fb7a0ea17d296b7d3d9ea856">http://git.videolan.org/?p=ffmpeg.git;a=commitdiff;h=673fce6d40d9a594fb7a0ea17d296b7d3d9ea856</a><br><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2020-22051">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2020-22051</a><br><a href="https://trac.ffmpeg.org/ticket/8313">https://trac.ffmpeg.org/ticket/8313</a><br></details>  |
| libswresample3         |    CVE-2020-22056   |   MEDIUM  |  7:4.2.4-1ubuntu0.1 |  | <details><summary>Expand...</summary><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2020-22056">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2020-22056</a><br><a href="https://trac.ffmpeg.org/ticket/8304">https://trac.ffmpeg.org/ticket/8304</a><br></details>  |
| libswresample3         |    CVE-2020-35964   |   MEDIUM  |  7:4.2.4-1ubuntu0.1 |  | <details><summary>Expand...</summary><a href="https://bugs.chromium.org/p/oss-fuzz/issues/detail?id=26622">https://bugs.chromium.org/p/oss-fuzz/issues/detail?id=26622</a><br><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2020-35964">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2020-35964</a><br><a href="https://github.com/FFmpeg/FFmpeg/commit/27a99e2c7d450fef15594671eef4465c8a166bd7">https://github.com/FFmpeg/FFmpeg/commit/27a99e2c7d450fef15594671eef4465c8a166bd7</a><br><a href="https://security.gentoo.org/glsa/202105-24">https://security.gentoo.org/glsa/202105-24</a><br></details>  |
| libswresample3         |    CVE-2020-35965   |   MEDIUM  |  7:4.2.4-1ubuntu0.1 |  | <details><summary>Expand...</summary><a href="https://bugs.chromium.org/p/oss-fuzz/issues/detail?id=26532">https://bugs.chromium.org/p/oss-fuzz/issues/detail?id=26532</a><br><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2020-35965">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2020-35965</a><br><a href="https://github.com/FFmpeg/FFmpeg/commit/3e5959b3457f7f1856d997261e6ac672bba49e8b">https://github.com/FFmpeg/FFmpeg/commit/3e5959b3457f7f1856d997261e6ac672bba49e8b</a><br><a href="https://github.com/FFmpeg/FFmpeg/commit/b0a8b40294ea212c1938348ff112ef1b9bf16bb3">https://github.com/FFmpeg/FFmpeg/commit/b0a8b40294ea212c1938348ff112ef1b9bf16bb3</a><br><a href="https://lists.debian.org/debian-lts-announce/2021/01/msg00026.html">https://lists.debian.org/debian-lts-announce/2021/01/msg00026.html</a><br><a href="https://security.gentoo.org/glsa/202105-24">https://security.gentoo.org/glsa/202105-24</a><br><a href="https://www.debian.org/security/2021/dsa-4990">https://www.debian.org/security/2021/dsa-4990</a><br></details>  |
| libswresample3         |    CVE-2021-3566   |   MEDIUM  |  7:4.2.4-1ubuntu0.1 |  | <details><summary>Expand...</summary><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2021-3566">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2021-3566</a><br><a href="https://github.com/FFmpeg/FFmpeg/commit/3bce9e9b3ea35c54bacccc793d7da99ea5157532#diff-74f6b92a0541378ad15de9c29c0a2b0c69881ad9ffc71abe568b88b535e00a7f">https://github.com/FFmpeg/FFmpeg/commit/3bce9e9b3ea35c54bacccc793d7da99ea5157532#diff-74f6b92a0541378ad15de9c29c0a2b0c69881ad9ffc71abe568b88b535e00a7f</a><br><a href="https://lists.debian.org/debian-lts-announce/2021/08/msg00018.html">https://lists.debian.org/debian-lts-announce/2021/08/msg00018.html</a><br></details>  |
| libswresample3         |    CVE-2021-38090   |   MEDIUM  |  7:4.2.4-1ubuntu0.1 |  | <details><summary>Expand...</summary><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2021-38090">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2021-38090</a><br><a href="https://git.ffmpeg.org/gitweb/ffmpeg.git/commit/99f8d32129dd233d4eb2efa44678a0bc44869f23">https://git.ffmpeg.org/gitweb/ffmpeg.git/commit/99f8d32129dd233d4eb2efa44678a0bc44869f23</a><br><a href="https://trac.ffmpeg.org/ticket/8263">https://trac.ffmpeg.org/ticket/8263</a><br></details>  |
| libswresample3         |    CVE-2021-38091   |   MEDIUM  |  7:4.2.4-1ubuntu0.1 |  | <details><summary>Expand...</summary><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2021-38091">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2021-38091</a><br><a href="https://git.ffmpeg.org/gitweb/ffmpeg.git/commit/99f8d32129dd233d4eb2efa44678a0bc44869f23">https://git.ffmpeg.org/gitweb/ffmpeg.git/commit/99f8d32129dd233d4eb2efa44678a0bc44869f23</a><br><a href="https://trac.ffmpeg.org/ticket/8263">https://trac.ffmpeg.org/ticket/8263</a><br></details>  |
| libswresample3         |    CVE-2021-38092   |   MEDIUM  |  7:4.2.4-1ubuntu0.1 |  | <details><summary>Expand...</summary><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2021-38092">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2021-38092</a><br><a href="https://git.ffmpeg.org/gitweb/ffmpeg.git/commit/99f8d32129dd233d4eb2efa44678a0bc44869f23">https://git.ffmpeg.org/gitweb/ffmpeg.git/commit/99f8d32129dd233d4eb2efa44678a0bc44869f23</a><br><a href="https://trac.ffmpeg.org/ticket/8263">https://trac.ffmpeg.org/ticket/8263</a><br></details>  |
| libswresample3         |    CVE-2021-38093   |   MEDIUM  |  7:4.2.4-1ubuntu0.1 |  | <details><summary>Expand...</summary><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2021-38093">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2021-38093</a><br><a href="https://git.ffmpeg.org/gitweb/ffmpeg.git/commit/99f8d32129dd233d4eb2efa44678a0bc44869f23">https://git.ffmpeg.org/gitweb/ffmpeg.git/commit/99f8d32129dd233d4eb2efa44678a0bc44869f23</a><br><a href="https://trac.ffmpeg.org/ticket/8263">https://trac.ffmpeg.org/ticket/8263</a><br></details>  |
| libswresample3         |    CVE-2021-38094   |   MEDIUM  |  7:4.2.4-1ubuntu0.1 |  | <details><summary>Expand...</summary><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2021-38094">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2021-38094</a><br><a href="https://git.ffmpeg.org/gitweb/ffmpeg.git/commit/99f8d32129dd233d4eb2efa44678a0bc44869f23">https://git.ffmpeg.org/gitweb/ffmpeg.git/commit/99f8d32129dd233d4eb2efa44678a0bc44869f23</a><br><a href="https://trac.ffmpeg.org/ticket/8263">https://trac.ffmpeg.org/ticket/8263</a><br></details>  |
| libswresample3         |    CVE-2021-38114   |   MEDIUM  |  7:4.2.4-1ubuntu0.1 |  | <details><summary>Expand...</summary><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2021-38114">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2021-38114</a><br><a href="https://github.com/FFmpeg/FFmpeg/commit/7150f9575671f898382c370acae35f9087a30ba1">https://github.com/FFmpeg/FFmpeg/commit/7150f9575671f898382c370acae35f9087a30ba1</a><br><a href="https://lists.debian.org/debian-lts-announce/2021/08/msg00018.html">https://lists.debian.org/debian-lts-announce/2021/08/msg00018.html</a><br><a href="https://patchwork.ffmpeg.org/project/ffmpeg/patch/PAXP193MB12624C21AE412BE95BA4D4A4B6F09@PAXP193MB1262.EURP193.PROD.OUTLOOK.COM/">https://patchwork.ffmpeg.org/project/ffmpeg/patch/PAXP193MB12624C21AE412BE95BA4D4A4B6F09@PAXP193MB1262.EURP193.PROD.OUTLOOK.COM/</a><br><a href="https://www.debian.org/security/2021/dsa-4990">https://www.debian.org/security/2021/dsa-4990</a><br><a href="https://www.debian.org/security/2021/dsa-4998">https://www.debian.org/security/2021/dsa-4998</a><br></details>  |
| libswresample3         |    CVE-2021-38171   |   MEDIUM  |  7:4.2.4-1ubuntu0.1 |  | <details><summary>Expand...</summary><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2021-38171">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2021-38171</a><br><a href="https://github.com/FFmpeg/FFmpeg/commit/9ffa49496d1aae4cbbb387aac28a9e061a6ab0a6">https://github.com/FFmpeg/FFmpeg/commit/9ffa49496d1aae4cbbb387aac28a9e061a6ab0a6</a><br><a href="https://lists.debian.org/debian-lts-announce/2021/11/msg00012.html">https://lists.debian.org/debian-lts-announce/2021/11/msg00012.html</a><br><a href="https://patchwork.ffmpeg.org/project/ffmpeg/patch/AS8P193MB12542A86E22F8207EC971930B6F19@AS8P193MB1254.EURP193.PROD.OUTLOOK.COM/">https://patchwork.ffmpeg.org/project/ffmpeg/patch/AS8P193MB12542A86E22F8207EC971930B6F19@AS8P193MB1254.EURP193.PROD.OUTLOOK.COM/</a><br><a href="https://www.debian.org/security/2021/dsa-4990">https://www.debian.org/security/2021/dsa-4990</a><br><a href="https://www.debian.org/security/2021/dsa-4998">https://www.debian.org/security/2021/dsa-4998</a><br></details>  |
| libswresample3         |    CVE-2021-38291   |   MEDIUM  |  7:4.2.4-1ubuntu0.1 |  | <details><summary>Expand...</summary><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2021-38291">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2021-38291</a><br><a href="https://lists.debian.org/debian-lts-announce/2021/11/msg00012.html">https://lists.debian.org/debian-lts-announce/2021/11/msg00012.html</a><br><a href="https://trac.ffmpeg.org/ticket/9312">https://trac.ffmpeg.org/ticket/9312</a><br><a href="https://www.debian.org/security/2021/dsa-4990">https://www.debian.org/security/2021/dsa-4990</a><br><a href="https://www.debian.org/security/2021/dsa-4998">https://www.debian.org/security/2021/dsa-4998</a><br></details>  |
| libswresample3         |    CVE-2020-20445   |   LOW  |  7:4.2.4-1ubuntu0.1 |  | <details><summary>Expand...</summary><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2020-20445">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2020-20445</a><br><a href="https://lists.debian.org/debian-lts-announce/2021/11/msg00012.html">https://lists.debian.org/debian-lts-announce/2021/11/msg00012.html</a><br><a href="https://trac.ffmpeg.org/ticket/7996">https://trac.ffmpeg.org/ticket/7996</a><br><a href="https://www.debian.org/security/2021/dsa-4990">https://www.debian.org/security/2021/dsa-4990</a><br><a href="https://www.debian.org/security/2021/dsa-4998">https://www.debian.org/security/2021/dsa-4998</a><br></details>  |
| libswresample3         |    CVE-2020-20446   |   LOW  |  7:4.2.4-1ubuntu0.1 |  | <details><summary>Expand...</summary><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2020-20446">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2020-20446</a><br><a href="https://lists.debian.org/debian-lts-announce/2021/11/msg00012.html">https://lists.debian.org/debian-lts-announce/2021/11/msg00012.html</a><br><a href="https://trac.ffmpeg.org/ticket/7995">https://trac.ffmpeg.org/ticket/7995</a><br><a href="https://www.debian.org/security/2021/dsa-4990">https://www.debian.org/security/2021/dsa-4990</a><br><a href="https://www.debian.org/security/2021/dsa-4998">https://www.debian.org/security/2021/dsa-4998</a><br></details>  |
| libswresample3         |    CVE-2020-20450   |   LOW  |  7:4.2.4-1ubuntu0.1 |  | <details><summary>Expand...</summary><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2020-20450">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2020-20450</a><br><a href="https://git.videolan.org/?p=ffmpeg.git;a=commitdiff;h=3865b1952e5cf993b016d83ba78fe1deb63bbfad (4.3)">https://git.videolan.org/?p=ffmpeg.git;a=commitdiff;h=3865b1952e5cf993b016d83ba78fe1deb63bbfad (4.3)</a><br><a href="https://git.videolan.org/?p=ffmpeg.git;a=commitdiff;h=5400e4a50c61e53e1bc50b3e77201649bbe9c510">https://git.videolan.org/?p=ffmpeg.git;a=commitdiff;h=5400e4a50c61e53e1bc50b3e77201649bbe9c510</a><br><a href="https://trac.ffmpeg.org/ticket/7993">https://trac.ffmpeg.org/ticket/7993</a><br><a href="https://www.debian.org/security/2021/dsa-4998">https://www.debian.org/security/2021/dsa-4998</a><br></details>  |
| libswresample3         |    CVE-2020-20451   |   LOW  |  7:4.2.4-1ubuntu0.1 |  | <details><summary>Expand...</summary><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2020-20451">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2020-20451</a><br><a href="https://git.videolan.org/?p=ffmpeg.git;a=commitdiff;h=21265f42ecb265debe9fec1dbfd0cb7de5a8aefb">https://git.videolan.org/?p=ffmpeg.git;a=commitdiff;h=21265f42ecb265debe9fec1dbfd0cb7de5a8aefb</a><br><a href="https://lists.debian.org/debian-lts-announce/2021/11/msg00012.html">https://lists.debian.org/debian-lts-announce/2021/11/msg00012.html</a><br><a href="https://trac.ffmpeg.org/ticket/8094">https://trac.ffmpeg.org/ticket/8094</a><br></details>  |
| libswresample3         |    CVE-2020-20453   |   LOW  |  7:4.2.4-1ubuntu0.1 |  | <details><summary>Expand...</summary><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2020-20453">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2020-20453</a><br><a href="https://lists.debian.org/debian-lts-announce/2021/11/msg00012.html">https://lists.debian.org/debian-lts-announce/2021/11/msg00012.html</a><br><a href="https://trac.ffmpeg.org/ticket/8003">https://trac.ffmpeg.org/ticket/8003</a><br><a href="https://www.debian.org/security/2021/dsa-4990">https://www.debian.org/security/2021/dsa-4990</a><br><a href="https://www.debian.org/security/2021/dsa-4998">https://www.debian.org/security/2021/dsa-4998</a><br></details>  |
| libtasn1-6         |    CVE-2018-1000654   |   LOW  |  4.16.0-2 |  | <details><summary>Expand...</summary><a href="http://lists.opensuse.org/opensuse-security-announce/2019-06/msg00009.html">http://lists.opensuse.org/opensuse-security-announce/2019-06/msg00009.html</a><br><a href="http://lists.opensuse.org/opensuse-security-announce/2019-06/msg00018.html">http://lists.opensuse.org/opensuse-security-announce/2019-06/msg00018.html</a><br><a href="http://www.securityfocus.com/bid/105151">http://www.securityfocus.com/bid/105151</a><br><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2018-1000654">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2018-1000654</a><br><a href="https://gitlab.com/gnutls/libtasn1/issues/4">https://gitlab.com/gnutls/libtasn1/issues/4</a><br><a href="https://lists.apache.org/thread.html/rf9fa47ab66495c78bb4120b0754dd9531ca2ff0430f6685ac9b07772@%3Cdev.mina.apache.org%3E">https://lists.apache.org/thread.html/rf9fa47ab66495c78bb4120b0754dd9531ca2ff0430f6685ac9b07772@%3Cdev.mina.apache.org%3E</a><br></details>  |
| libtiff5         |    CVE-2018-10126   |   LOW  |  4.1.0+git191117-2ubuntu0.20.04.2 |  | <details><summary>Expand...</summary><a href="http://bugzilla.maptools.org/show_bug.cgi?id=2786">http://bugzilla.maptools.org/show_bug.cgi?id=2786</a><br><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2018-10126">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2018-10126</a><br><a href="https://lists.apache.org/thread.html/rf9fa47ab66495c78bb4120b0754dd9531ca2ff0430f6685ac9b07772@%3Cdev.mina.apache.org%3E">https://lists.apache.org/thread.html/rf9fa47ab66495c78bb4120b0754dd9531ca2ff0430f6685ac9b07772@%3Cdev.mina.apache.org%3E</a><br></details>  |
| libwind0-heimdal         |    CVE-2021-3671   |   LOW  |  7.7.0+dfsg-1ubuntu1 |  | <details><summary>Expand...</summary><a href="https://bugzilla.redhat.com/show_bug.cgi?id=2013080,">https://bugzilla.redhat.com/show_bug.cgi?id=2013080,</a><br><a href="https://bugzilla.samba.org/show_bug.cgi?id=14770,">https://bugzilla.samba.org/show_bug.cgi?id=14770,</a><br><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2021-3671">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2021-3671</a><br><a href="https://github.com/heimdal/heimdal/commit/04171147948d0a3636bc6374181926f0fb2ec83a">https://github.com/heimdal/heimdal/commit/04171147948d0a3636bc6374181926f0fb2ec83a</a><br><a href="https://ubuntu.com/security/notices/USN-5142-1">https://ubuntu.com/security/notices/USN-5142-1</a><br><a href="https://ubuntu.com/security/notices/USN-5174-1">https://ubuntu.com/security/notices/USN-5174-1</a><br></details>  |
| locales         |    CVE-2021-35942   |   MEDIUM  |  2.31-0ubuntu9.2 |  | <details><summary>Expand...</summary><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2021-35942">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2021-35942</a><br><a href="https://linux.oracle.com/cve/CVE-2021-35942.html">https://linux.oracle.com/cve/CVE-2021-35942.html</a><br><a href="https://linux.oracle.com/errata/ELSA-2021-9560.html">https://linux.oracle.com/errata/ELSA-2021-9560.html</a><br><a href="https://security.netapp.com/advisory/ntap-20210827-0005/">https://security.netapp.com/advisory/ntap-20210827-0005/</a><br><a href="https://sourceware.org/bugzilla/show_bug.cgi?id=28011">https://sourceware.org/bugzilla/show_bug.cgi?id=28011</a><br><a href="https://sourceware.org/git/?p=glibc.git;a=commit;h=5adda61f62b77384718b4c0d8336ade8f2b4b35c">https://sourceware.org/git/?p=glibc.git;a=commit;h=5adda61f62b77384718b4c0d8336ade8f2b4b35c</a><br><a href="https://sourceware.org/git/?p=glibc.git;a=commitdiff;h=5adda61f62b77384718b4c0d8336ade8f2b4b35c">https://sourceware.org/git/?p=glibc.git;a=commitdiff;h=5adda61f62b77384718b4c0d8336ade8f2b4b35c</a><br><a href="https://sourceware.org/glibc/wiki/Security%20Exceptions">https://sourceware.org/glibc/wiki/Security%20Exceptions</a><br></details>  |
| locales         |    CVE-2021-38604   |   MEDIUM  |  2.31-0ubuntu9.2 |  | <details><summary>Expand...</summary><a href="https://blog.tuxcare.com/cve/tuxcare-team-identifies-cve-2021-38604-a-new-vulnerability-in-glibc">https://blog.tuxcare.com/cve/tuxcare-team-identifies-cve-2021-38604-a-new-vulnerability-in-glibc</a><br><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2021-38604">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2021-38604</a><br><a href="https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/GYEXYM37RCJWJ6B5KQUYQI4NZBDDYSXP/">https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/GYEXYM37RCJWJ6B5KQUYQI4NZBDDYSXP/</a><br><a href="https://security.netapp.com/advisory/ntap-20210909-0005/">https://security.netapp.com/advisory/ntap-20210909-0005/</a><br><a href="https://sourceware.org/bugzilla/show_bug.cgi?id=28213">https://sourceware.org/bugzilla/show_bug.cgi?id=28213</a><br><a href="https://sourceware.org/git/?p=glibc.git;a=commit;h=4cc79c217744743077bf7a0ec5e0a4318f1e6641">https://sourceware.org/git/?p=glibc.git;a=commit;h=4cc79c217744743077bf7a0ec5e0a4318f1e6641</a><br><a href="https://sourceware.org/git/?p=glibc.git;a=commit;h=b805aebd42364fe696e417808a700fdb9800c9e8">https://sourceware.org/git/?p=glibc.git;a=commit;h=b805aebd42364fe696e417808a700fdb9800c9e8</a><br></details>  |
| locales         |    CVE-2016-10228   |   LOW  |  2.31-0ubuntu9.2 |  | <details><summary>Expand...</summary><a href="http://openwall.com/lists/oss-security/2017/03/01/10">http://openwall.com/lists/oss-security/2017/03/01/10</a><br><a href="http://www.securityfocus.com/bid/96525">http://www.securityfocus.com/bid/96525</a><br><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2016-10228">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2016-10228</a><br><a href="https://linux.oracle.com/cve/CVE-2016-10228.html">https://linux.oracle.com/cve/CVE-2016-10228.html</a><br><a href="https://linux.oracle.com/errata/ELSA-2021-9344.html">https://linux.oracle.com/errata/ELSA-2021-9344.html</a><br><a href="https://lists.apache.org/thread.html/rf9fa47ab66495c78bb4120b0754dd9531ca2ff0430f6685ac9b07772@%3Cdev.mina.apache.org%3E">https://lists.apache.org/thread.html/rf9fa47ab66495c78bb4120b0754dd9531ca2ff0430f6685ac9b07772@%3Cdev.mina.apache.org%3E</a><br><a href="https://security.gentoo.org/glsa/202101-20">https://security.gentoo.org/glsa/202101-20</a><br><a href="https://sourceware.org/bugzilla/show_bug.cgi?id=19519">https://sourceware.org/bugzilla/show_bug.cgi?id=19519</a><br><a href="https://sourceware.org/bugzilla/show_bug.cgi?id=19519#c21">https://sourceware.org/bugzilla/show_bug.cgi?id=19519#c21</a><br><a href="https://sourceware.org/bugzilla/show_bug.cgi?id=26224">https://sourceware.org/bugzilla/show_bug.cgi?id=26224</a><br></details>  |
| locales         |    CVE-2019-25013   |   LOW  |  2.31-0ubuntu9.2 |  | <details><summary>Expand...</summary><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2019-25013">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2019-25013</a><br><a href="https://linux.oracle.com/cve/CVE-2019-25013.html">https://linux.oracle.com/cve/CVE-2019-25013.html</a><br><a href="https://linux.oracle.com/errata/ELSA-2021-9344.html">https://linux.oracle.com/errata/ELSA-2021-9344.html</a><br><a href="https://lists.apache.org/thread.html/r32d767ac804e9b8aad4355bb85960a6a1385eab7afff549a5e98660f@%3Cjira.kafka.apache.org%3E">https://lists.apache.org/thread.html/r32d767ac804e9b8aad4355bb85960a6a1385eab7afff549a5e98660f@%3Cjira.kafka.apache.org%3E</a><br><a href="https://lists.apache.org/thread.html/r448bb851cc8e6e3f93f3c28c70032b37062625d81214744474ac49e7@%3Cdev.kafka.apache.org%3E">https://lists.apache.org/thread.html/r448bb851cc8e6e3f93f3c28c70032b37062625d81214744474ac49e7@%3Cdev.kafka.apache.org%3E</a><br><a href="https://lists.apache.org/thread.html/r4806a391091e082bdea17266452ca656ebc176e51bb3932733b3a0a2@%3Cjira.kafka.apache.org%3E">https://lists.apache.org/thread.html/r4806a391091e082bdea17266452ca656ebc176e51bb3932733b3a0a2@%3Cjira.kafka.apache.org%3E</a><br><a href="https://lists.apache.org/thread.html/r499e4f96d0b5109ef083f2feccd33c51650c1b7d7068aa3bd47efca9@%3Cjira.kafka.apache.org%3E">https://lists.apache.org/thread.html/r499e4f96d0b5109ef083f2feccd33c51650c1b7d7068aa3bd47efca9@%3Cjira.kafka.apache.org%3E</a><br><a href="https://lists.apache.org/thread.html/r5af4430421bb6f9973294691a7904bbd260937e9eef96b20556f43ff@%3Cjira.kafka.apache.org%3E">https://lists.apache.org/thread.html/r5af4430421bb6f9973294691a7904bbd260937e9eef96b20556f43ff@%3Cjira.kafka.apache.org%3E</a><br><a href="https://lists.apache.org/thread.html/r750eee18542bc02bd8350861c424ee60a9b9b225568fa09436a37ece@%3Cissues.zookeeper.apache.org%3E">https://lists.apache.org/thread.html/r750eee18542bc02bd8350861c424ee60a9b9b225568fa09436a37ece@%3Cissues.zookeeper.apache.org%3E</a><br><a href="https://lists.apache.org/thread.html/r7a2e94adfe0a2f0a1d42e4927e8c32ecac97d37db9cb68095fe9ddbc@%3Cdev.zookeeper.apache.org%3E">https://lists.apache.org/thread.html/r7a2e94adfe0a2f0a1d42e4927e8c32ecac97d37db9cb68095fe9ddbc@%3Cdev.zookeeper.apache.org%3E</a><br><a href="https://lists.apache.org/thread.html/rd2354f9ccce41e494fbadcbc5ad87218de6ec0fff8a7b54c8462226c@%3Cissues.zookeeper.apache.org%3E">https://lists.apache.org/thread.html/rd2354f9ccce41e494fbadcbc5ad87218de6ec0fff8a7b54c8462226c@%3Cissues.zookeeper.apache.org%3E</a><br><a href="https://lists.apache.org/thread.html/rf9fa47ab66495c78bb4120b0754dd9531ca2ff0430f6685ac9b07772@%3Cdev.mina.apache.org%3E">https://lists.apache.org/thread.html/rf9fa47ab66495c78bb4120b0754dd9531ca2ff0430f6685ac9b07772@%3Cdev.mina.apache.org%3E</a><br><a href="https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/4Y6TX47P47KABSFOL26FLDNVCWXDKDEZ/">https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/4Y6TX47P47KABSFOL26FLDNVCWXDKDEZ/</a><br><a href="https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/TVCUNLQ3HXGS4VPUQKWTJGRAW2KTFGXS/">https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/TVCUNLQ3HXGS4VPUQKWTJGRAW2KTFGXS/</a><br><a href="https://security.netapp.com/advisory/ntap-20210205-0004/">https://security.netapp.com/advisory/ntap-20210205-0004/</a><br><a href="https://sourceware.org/bugzilla/show_bug.cgi?id=24973">https://sourceware.org/bugzilla/show_bug.cgi?id=24973</a><br><a href="https://sourceware.org/git/?p=glibc.git;a=commit;h=ee7a3144c9922808181009b7b3e50e852fb4999b">https://sourceware.org/git/?p=glibc.git;a=commit;h=ee7a3144c9922808181009b7b3e50e852fb4999b</a><br></details>  |
| locales         |    CVE-2020-27618   |   LOW  |  2.31-0ubuntu9.2 |  | <details><summary>Expand...</summary><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2020-27618">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2020-27618</a><br><a href="https://linux.oracle.com/cve/CVE-2020-27618.html">https://linux.oracle.com/cve/CVE-2020-27618.html</a><br><a href="https://linux.oracle.com/errata/ELSA-2021-9344.html">https://linux.oracle.com/errata/ELSA-2021-9344.html</a><br><a href="https://security.netapp.com/advisory/ntap-20210401-0006/">https://security.netapp.com/advisory/ntap-20210401-0006/</a><br><a href="https://sourceware.org/bugzilla/show_bug.cgi?id=19519#c21">https://sourceware.org/bugzilla/show_bug.cgi?id=19519#c21</a><br><a href="https://sourceware.org/bugzilla/show_bug.cgi?id=26224">https://sourceware.org/bugzilla/show_bug.cgi?id=26224</a><br></details>  |
| locales         |    CVE-2020-29562   |   LOW  |  2.31-0ubuntu9.2 |  | <details><summary>Expand...</summary><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2020-29562">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2020-29562</a><br><a href="https://lists.apache.org/thread.html/rf9fa47ab66495c78bb4120b0754dd9531ca2ff0430f6685ac9b07772@%3Cdev.mina.apache.org%3E">https://lists.apache.org/thread.html/rf9fa47ab66495c78bb4120b0754dd9531ca2ff0430f6685ac9b07772@%3Cdev.mina.apache.org%3E</a><br><a href="https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/TVCUNLQ3HXGS4VPUQKWTJGRAW2KTFGXS/">https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/TVCUNLQ3HXGS4VPUQKWTJGRAW2KTFGXS/</a><br><a href="https://security.gentoo.org/glsa/202101-20">https://security.gentoo.org/glsa/202101-20</a><br><a href="https://security.netapp.com/advisory/ntap-20210122-0004/">https://security.netapp.com/advisory/ntap-20210122-0004/</a><br><a href="https://sourceware.org/bugzilla/show_bug.cgi?id=26923">https://sourceware.org/bugzilla/show_bug.cgi?id=26923</a><br><a href="https://sourceware.org/pipermail/libc-alpha/2020-November/119822.html">https://sourceware.org/pipermail/libc-alpha/2020-November/119822.html</a><br></details>  |
| locales         |    CVE-2020-6096   |   LOW  |  2.31-0ubuntu9.2 |  | <details><summary>Expand...</summary><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2020-6096">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2020-6096</a><br><a href="https://lists.apache.org/thread.html/rf9fa47ab66495c78bb4120b0754dd9531ca2ff0430f6685ac9b07772@%3Cdev.mina.apache.org%3E">https://lists.apache.org/thread.html/rf9fa47ab66495c78bb4120b0754dd9531ca2ff0430f6685ac9b07772@%3Cdev.mina.apache.org%3E</a><br><a href="https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/SPYXTDOOB4PQGTYAMZAZNJIB3FF6YQXI/">https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/SPYXTDOOB4PQGTYAMZAZNJIB3FF6YQXI/</a><br><a href="https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/URXOIA2LDUKHQXK4BE55BQBRI6ZZG3Y6/">https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/URXOIA2LDUKHQXK4BE55BQBRI6ZZG3Y6/</a><br><a href="https://security.gentoo.org/glsa/202101-20">https://security.gentoo.org/glsa/202101-20</a><br><a href="https://sourceware.org/bugzilla/attachment.cgi?id=12334">https://sourceware.org/bugzilla/attachment.cgi?id=12334</a><br><a href="https://sourceware.org/bugzilla/show_bug.cgi?id=25620">https://sourceware.org/bugzilla/show_bug.cgi?id=25620</a><br><a href="https://talosintelligence.com/vulnerability_reports/TALOS-2020-1019">https://talosintelligence.com/vulnerability_reports/TALOS-2020-1019</a><br><a href="https://ubuntu.com/security/notices/USN-4954-1">https://ubuntu.com/security/notices/USN-4954-1</a><br><a href="https://www.talosintelligence.com/vulnerability_reports/TALOS-2020-1019">https://www.talosintelligence.com/vulnerability_reports/TALOS-2020-1019</a><br></details>  |
| locales         |    CVE-2021-27645   |   LOW  |  2.31-0ubuntu9.2 |  | <details><summary>Expand...</summary><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2021-27645">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2021-27645</a><br><a href="https://linux.oracle.com/cve/CVE-2021-27645.html">https://linux.oracle.com/cve/CVE-2021-27645.html</a><br><a href="https://linux.oracle.com/errata/ELSA-2021-9560.html">https://linux.oracle.com/errata/ELSA-2021-9560.html</a><br><a href="https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/7LZNT6KTMCCWPWXEOGSHD3YLYZKUGMH5/">https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/7LZNT6KTMCCWPWXEOGSHD3YLYZKUGMH5/</a><br><a href="https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/I7TS26LIZSOBLGJEZMJX4PXT5BQDE2WS/">https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/I7TS26LIZSOBLGJEZMJX4PXT5BQDE2WS/</a><br><a href="https://sourceware.org/bugzilla/show_bug.cgi?id=27462">https://sourceware.org/bugzilla/show_bug.cgi?id=27462</a><br></details>  |
| locales         |    CVE-2021-3326   |   LOW  |  2.31-0ubuntu9.2 |  | <details><summary>Expand...</summary><a href="http://www.openwall.com/lists/oss-security/2021/01/28/2">http://www.openwall.com/lists/oss-security/2021/01/28/2</a><br><a href="https://bugs.chromium.org/p/project-zero/issues/detail?id=2146">https://bugs.chromium.org/p/project-zero/issues/detail?id=2146</a><br><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2021-3326">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2021-3326</a><br><a href="https://linux.oracle.com/cve/CVE-2021-3326.html">https://linux.oracle.com/cve/CVE-2021-3326.html</a><br><a href="https://linux.oracle.com/errata/ELSA-2021-9344.html">https://linux.oracle.com/errata/ELSA-2021-9344.html</a><br><a href="https://security.netapp.com/advisory/ntap-20210304-0007/">https://security.netapp.com/advisory/ntap-20210304-0007/</a><br><a href="https://sourceware.org/bugzilla/show_bug.cgi?id=27256">https://sourceware.org/bugzilla/show_bug.cgi?id=27256</a><br><a href="https://sourceware.org/git/?p=glibc.git;a=commit;h=7d88c6142c6efc160c0ee5e4f85cde382c072888">https://sourceware.org/git/?p=glibc.git;a=commit;h=7d88c6142c6efc160c0ee5e4f85cde382c072888</a><br><a href="https://sourceware.org/pipermail/libc-alpha/2021-January/122058.html">https://sourceware.org/pipermail/libc-alpha/2021-January/122058.html</a><br></details>  |
| locales         |    CVE-2021-33574   |   LOW  |  2.31-0ubuntu9.2 |  | <details><summary>Expand...</summary><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2021-33574">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2021-33574</a><br><a href="https://linux.oracle.com/cve/CVE-2021-33574.html">https://linux.oracle.com/cve/CVE-2021-33574.html</a><br><a href="https://linux.oracle.com/errata/ELSA-2021-9560.html">https://linux.oracle.com/errata/ELSA-2021-9560.html</a><br><a href="https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/RBUUWUGXVILQXVWEOU7N42ICHPJNAEUP/">https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/RBUUWUGXVILQXVWEOU7N42ICHPJNAEUP/</a><br><a href="https://security.gentoo.org/glsa/202107-07">https://security.gentoo.org/glsa/202107-07</a><br><a href="https://security.netapp.com/advisory/ntap-20210629-0005/">https://security.netapp.com/advisory/ntap-20210629-0005/</a><br><a href="https://sourceware.org/bugzilla/show_bug.cgi?id=27896">https://sourceware.org/bugzilla/show_bug.cgi?id=27896</a><br><a href="https://sourceware.org/bugzilla/show_bug.cgi?id=27896#c1">https://sourceware.org/bugzilla/show_bug.cgi?id=27896#c1</a><br></details>  |
| login         |    CVE-2013-4235   |   LOW  |  1:4.8.1-1ubuntu5.20.04.1 |  | <details><summary>Expand...</summary><a href="https://access.redhat.com/security/cve/cve-2013-4235">https://access.redhat.com/security/cve/cve-2013-4235</a><br><a href="https://bugzilla.redhat.com/show_bug.cgi?id=CVE-2013-4235">https://bugzilla.redhat.com/show_bug.cgi?id=CVE-2013-4235</a><br><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2013-4235">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2013-4235</a><br><a href="https://lists.apache.org/thread.html/rf9fa47ab66495c78bb4120b0754dd9531ca2ff0430f6685ac9b07772@%3Cdev.mina.apache.org%3E">https://lists.apache.org/thread.html/rf9fa47ab66495c78bb4120b0754dd9531ca2ff0430f6685ac9b07772@%3Cdev.mina.apache.org%3E</a><br><a href="https://security-tracker.debian.org/tracker/CVE-2013-4235">https://security-tracker.debian.org/tracker/CVE-2013-4235</a><br></details>  |
| passwd         |    CVE-2013-4235   |   LOW  |  1:4.8.1-1ubuntu5.20.04.1 |  | <details><summary>Expand...</summary><a href="https://access.redhat.com/security/cve/cve-2013-4235">https://access.redhat.com/security/cve/cve-2013-4235</a><br><a href="https://bugzilla.redhat.com/show_bug.cgi?id=CVE-2013-4235">https://bugzilla.redhat.com/show_bug.cgi?id=CVE-2013-4235</a><br><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2013-4235">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2013-4235</a><br><a href="https://lists.apache.org/thread.html/rf9fa47ab66495c78bb4120b0754dd9531ca2ff0430f6685ac9b07772@%3Cdev.mina.apache.org%3E">https://lists.apache.org/thread.html/rf9fa47ab66495c78bb4120b0754dd9531ca2ff0430f6685ac9b07772@%3Cdev.mina.apache.org%3E</a><br><a href="https://security-tracker.debian.org/tracker/CVE-2013-4235">https://security-tracker.debian.org/tracker/CVE-2013-4235</a><br></details>  |
| perl-base         |    CVE-2020-16156   |   MEDIUM  |  5.30.0-9ubuntu0.2 |  | <details><summary>Expand...</summary><a href="http://blogs.perl.org/users/neilb/2021/11/addressing-cpan-vulnerabilities-related-to-checksums.html">http://blogs.perl.org/users/neilb/2021/11/addressing-cpan-vulnerabilities-related-to-checksums.html</a><br><a href="https://blog.hackeriet.no/cpan-signature-verification-vulnerabilities/">https://blog.hackeriet.no/cpan-signature-verification-vulnerabilities/</a><br><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2020-16156">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2020-16156</a><br><a href="https://github.com/andk/cpanpm/commit/b27c51adf0fda25dee84cb72cb2b1bf7d832148c">https://github.com/andk/cpanpm/commit/b27c51adf0fda25dee84cb72cb2b1bf7d832148c</a><br><a href="https://metacpan.org/pod/distribution/CPAN/scripts/cpan">https://metacpan.org/pod/distribution/CPAN/scripts/cpan</a><br></details>  |
| python3.8         |    CVE-2021-3737   |   MEDIUM  |  3.8.10-0ubuntu1~20.04.2 |  | <details><summary>Expand...</summary><a href="https://bugs.python.org/issue44022">https://bugs.python.org/issue44022</a><br><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2021-3737">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2021-3737</a><br><a href="https://github.com/python/cpython/commit/0389426fa4af4dfc8b1d7f3f291932d928392d8b (3.8 branch)">https://github.com/python/cpython/commit/0389426fa4af4dfc8b1d7f3f291932d928392d8b (3.8 branch)</a><br><a href="https://github.com/python/cpython/commit/078b146f062d212919d0ba25e34e658a8234aa63 (v3.7.11)">https://github.com/python/cpython/commit/078b146f062d212919d0ba25e34e658a8234aa63 (v3.7.11)</a><br><a href="https://github.com/python/cpython/commit/1b6f4e5e13ebd1f957b47f7415b53d0869bdbac6 (v3.6.14">https://github.com/python/cpython/commit/1b6f4e5e13ebd1f957b47f7415b53d0869bdbac6 (v3.6.14</a><br><a href="https://github.com/python/cpython/commit/5df4abd6b033a5f1e48945c6988b45e35e76f647 (v3.9.6)">https://github.com/python/cpython/commit/5df4abd6b033a5f1e48945c6988b45e35e76f647 (v3.9.6)</a><br><a href="https://github.com/python/cpython/commit/60ba0b68470a584103e28958d91e93a6db37ec92 (v3.10.0b2)">https://github.com/python/cpython/commit/60ba0b68470a584103e28958d91e93a6db37ec92 (v3.10.0b2)</a><br><a href="https://github.com/python/cpython/commit/98e5a7975d99b58d511f171816ecdfb13d5cca18 (v3.10.0b3)">https://github.com/python/cpython/commit/98e5a7975d99b58d511f171816ecdfb13d5cca18 (v3.10.0b3)</a><br><a href="https://github.com/python/cpython/commit/ea9327036680acc92d9f89eaf6f6a54d2f8d78d9 (v3.9.6)">https://github.com/python/cpython/commit/ea9327036680acc92d9f89eaf6f6a54d2f8d78d9 (v3.9.6)</a><br><a href="https://github.com/python/cpython/commit/f396864ddfe914531b5856d7bf852808ebfc01ae (v3.8.11)">https://github.com/python/cpython/commit/f396864ddfe914531b5856d7bf852808ebfc01ae (v3.8.11)</a><br><a href="https://github.com/python/cpython/commit/f68d2d69f1da56c2aea1293ecf93ab69a6010ad7 (v3.6.14)">https://github.com/python/cpython/commit/f68d2d69f1da56c2aea1293ecf93ab69a6010ad7 (v3.6.14)</a><br><a href="https://github.com/python/cpython/commit/fee96422e6f0056561cf74fef2012cc066c9db86 (v3.7.11)">https://github.com/python/cpython/commit/fee96422e6f0056561cf74fef2012cc066c9db86 (v3.7.11)</a><br><a href="https://github.com/python/cpython/pull/25916">https://github.com/python/cpython/pull/25916</a><br><a href="https://github.com/python/cpython/pull/26503">https://github.com/python/cpython/pull/26503</a><br><a href="https://linux.oracle.com/cve/CVE-2021-3737.html">https://linux.oracle.com/cve/CVE-2021-3737.html</a><br><a href="https://linux.oracle.com/errata/ELSA-2021-4160.html">https://linux.oracle.com/errata/ELSA-2021-4160.html</a><br><a href="https://ubuntu.com/security/notices/USN-5083-1">https://ubuntu.com/security/notices/USN-5083-1</a><br></details>  |
| python3.8         |    CVE-2021-23336   |   LOW  |  3.8.10-0ubuntu1~20.04.2 |  | <details><summary>Expand...</summary><a href="http://www.openwall.com/lists/oss-security/2021/02/19/4">http://www.openwall.com/lists/oss-security/2021/02/19/4</a><br><a href="http://www.openwall.com/lists/oss-security/2021/05/01/2">http://www.openwall.com/lists/oss-security/2021/05/01/2</a><br><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2021-23336">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2021-23336</a><br><a href="https://github.com/python/cpython/commit/fcbe0cb04d35189401c0c880ebfb4311e952d776 (master)">https://github.com/python/cpython/commit/fcbe0cb04d35189401c0c880ebfb4311e952d776 (master)</a><br><a href="https://github.com/python/cpython/pull/24297">https://github.com/python/cpython/pull/24297</a><br><a href="https://linux.oracle.com/cve/CVE-2021-23336.html">https://linux.oracle.com/cve/CVE-2021-23336.html</a><br><a href="https://linux.oracle.com/errata/ELSA-2021-4162.html">https://linux.oracle.com/errata/ELSA-2021-4162.html</a><br><a href="https://lists.apache.org/thread.html/ra8ce70088ba291f358e077cafdb14d174b7a1ce9a9d86d1b332d6367@%3Cusers.airflow.apache.org%3E">https://lists.apache.org/thread.html/ra8ce70088ba291f358e077cafdb14d174b7a1ce9a9d86d1b332d6367@%3Cusers.airflow.apache.org%3E</a><br><a href="https://lists.apache.org/thread.html/rc005f4de9d9b0ba943ceb8ff5a21a5c6ff8a9df52632476698d99432@%3Cannounce.apache.org%3E">https://lists.apache.org/thread.html/rc005f4de9d9b0ba943ceb8ff5a21a5c6ff8a9df52632476698d99432@%3Cannounce.apache.org%3E</a><br><a href="https://lists.apache.org/thread.html/rf9fa47ab66495c78bb4120b0754dd9531ca2ff0430f6685ac9b07772@%3Cdev.mina.apache.org%3E">https://lists.apache.org/thread.html/rf9fa47ab66495c78bb4120b0754dd9531ca2ff0430f6685ac9b07772@%3Cdev.mina.apache.org%3E</a><br><a href="https://lists.debian.org/debian-lts-announce/2021/02/msg00030.html">https://lists.debian.org/debian-lts-announce/2021/02/msg00030.html</a><br><a href="https://lists.debian.org/debian-lts-announce/2021/04/msg00005.html">https://lists.debian.org/debian-lts-announce/2021/04/msg00005.html</a><br><a href="https://lists.debian.org/debian-lts-announce/2021/04/msg00015.html">https://lists.debian.org/debian-lts-announce/2021/04/msg00015.html</a><br><a href="https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/3EPYWWFDV22CJ5AOH5VCE72DOASZZ255/">https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/3EPYWWFDV22CJ5AOH5VCE72DOASZZ255/</a><br><a href="https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/3YKKDLXL3UEZ3J426C2XTBS63AHE46SM/">https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/3YKKDLXL3UEZ3J426C2XTBS63AHE46SM/</a><br><a href="https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/46N6A52EGSXHJYCZWVMBJJIH4NWIV2B5/">https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/46N6A52EGSXHJYCZWVMBJJIH4NWIV2B5/</a><br><a href="https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/FONHJIOZOFD7CD35KZL6SVBUTMBPGZGA/">https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/FONHJIOZOFD7CD35KZL6SVBUTMBPGZGA/</a><br><a href="https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/HCQTCSP6SCVIYNIRUJC5X7YBVUHPLSC4/">https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/HCQTCSP6SCVIYNIRUJC5X7YBVUHPLSC4/</a><br><a href="https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/HZTM7KLHFCE3LWSEVO2NAFLUHMGYMCRY/">https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/HZTM7KLHFCE3LWSEVO2NAFLUHMGYMCRY/</a><br><a href="https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/IHQDU7NXA7EWAE4W7VO6MURVJIULEPPR/">https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/IHQDU7NXA7EWAE4W7VO6MURVJIULEPPR/</a><br><a href="https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/KJXCMHLY7H3FIYLE4OKDYUILU2CCRUCZ/">https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/KJXCMHLY7H3FIYLE4OKDYUILU2CCRUCZ/</a><br><a href="https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/LVNH6Z24IG3E67ZCQGGJ46FZB4XFLQNZ/">https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/LVNH6Z24IG3E67ZCQGGJ46FZB4XFLQNZ/</a><br><a href="https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/MNUN5SOMFL2BBKP6ZAICIIUPQKZDMGYO/">https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/MNUN5SOMFL2BBKP6ZAICIIUPQKZDMGYO/</a><br><a href="https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/MP572OLHMS7MZO4KUPSCIMSZIA5IZZ62/">https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/MP572OLHMS7MZO4KUPSCIMSZIA5IZZ62/</a><br><a href="https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/N6VXJZSZ6N64AILJX4CTMACYGQGHHD5C/">https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/N6VXJZSZ6N64AILJX4CTMACYGQGHHD5C/</a><br><a href="https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/NJSCSN722JO2E2AGPWD4NTGVELVRPB4R/">https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/NJSCSN722JO2E2AGPWD4NTGVELVRPB4R/</a><br><a href="https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/NODWHDIFBQE5RU5PUWUVE47JOT5VCMJ2/">https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/NODWHDIFBQE5RU5PUWUVE47JOT5VCMJ2/</a><br><a href="https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/OAGSWNGZJ6HQ5ISA67SNMK3CJRKICET7/">https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/OAGSWNGZJ6HQ5ISA67SNMK3CJRKICET7/</a><br><a href="https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/RSLQD5CCM75IZGAMBDGUZEATYU5YSGJ7/">https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/RSLQD5CCM75IZGAMBDGUZEATYU5YSGJ7/</a><br><a href="https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/SGIY6I4YS3WOXAK4SXKIEOC2G4VZKIR7/">https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/SGIY6I4YS3WOXAK4SXKIEOC2G4VZKIR7/</a><br><a href="https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/TFTELUMWZE3KV3JB2H5EE6VFRZFRD5MV/">https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/TFTELUMWZE3KV3JB2H5EE6VFRZFRD5MV/</a><br><a href="https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/W2LSKBEFI5SYEY5FM6ICZVZM5WRQUCS4/">https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/W2LSKBEFI5SYEY5FM6ICZVZM5WRQUCS4/</a><br><a href="https://security.gentoo.org/glsa/202104-04">https://security.gentoo.org/glsa/202104-04</a><br><a href="https://security.netapp.com/advisory/ntap-20210326-0004/">https://security.netapp.com/advisory/ntap-20210326-0004/</a><br><a href="https://snyk.io/blog/cache-poisoning-in-popular-open-source-packages/">https://snyk.io/blog/cache-poisoning-in-popular-open-source-packages/</a><br><a href="https://snyk.io/vuln/SNYK-UPSTREAM-PYTHONCPYTHON-1074933">https://snyk.io/vuln/SNYK-UPSTREAM-PYTHONCPYTHON-1074933</a><br><a href="https://ubuntu.com/security/notices/USN-4742-1">https://ubuntu.com/security/notices/USN-4742-1</a><br><a href="https://www.djangoproject.com/weblog/2021/feb/19/security-releases/">https://www.djangoproject.com/weblog/2021/feb/19/security-releases/</a><br><a href="https://www.oracle.com//security-alerts/cpujul2021.html">https://www.oracle.com//security-alerts/cpujul2021.html</a><br><a href="https://www.oracle.com/security-alerts/cpuApr2021.html">https://www.oracle.com/security-alerts/cpuApr2021.html</a><br><a href="https://www.oracle.com/security-alerts/cpuoct2021.html">https://www.oracle.com/security-alerts/cpuoct2021.html</a><br></details>  |
| python3.8-minimal         |    CVE-2021-3737   |   MEDIUM  |  3.8.10-0ubuntu1~20.04.2 |  | <details><summary>Expand...</summary><a href="https://bugs.python.org/issue44022">https://bugs.python.org/issue44022</a><br><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2021-3737">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2021-3737</a><br><a href="https://github.com/python/cpython/commit/0389426fa4af4dfc8b1d7f3f291932d928392d8b (3.8 branch)">https://github.com/python/cpython/commit/0389426fa4af4dfc8b1d7f3f291932d928392d8b (3.8 branch)</a><br><a href="https://github.com/python/cpython/commit/078b146f062d212919d0ba25e34e658a8234aa63 (v3.7.11)">https://github.com/python/cpython/commit/078b146f062d212919d0ba25e34e658a8234aa63 (v3.7.11)</a><br><a href="https://github.com/python/cpython/commit/1b6f4e5e13ebd1f957b47f7415b53d0869bdbac6 (v3.6.14">https://github.com/python/cpython/commit/1b6f4e5e13ebd1f957b47f7415b53d0869bdbac6 (v3.6.14</a><br><a href="https://github.com/python/cpython/commit/5df4abd6b033a5f1e48945c6988b45e35e76f647 (v3.9.6)">https://github.com/python/cpython/commit/5df4abd6b033a5f1e48945c6988b45e35e76f647 (v3.9.6)</a><br><a href="https://github.com/python/cpython/commit/60ba0b68470a584103e28958d91e93a6db37ec92 (v3.10.0b2)">https://github.com/python/cpython/commit/60ba0b68470a584103e28958d91e93a6db37ec92 (v3.10.0b2)</a><br><a href="https://github.com/python/cpython/commit/98e5a7975d99b58d511f171816ecdfb13d5cca18 (v3.10.0b3)">https://github.com/python/cpython/commit/98e5a7975d99b58d511f171816ecdfb13d5cca18 (v3.10.0b3)</a><br><a href="https://github.com/python/cpython/commit/ea9327036680acc92d9f89eaf6f6a54d2f8d78d9 (v3.9.6)">https://github.com/python/cpython/commit/ea9327036680acc92d9f89eaf6f6a54d2f8d78d9 (v3.9.6)</a><br><a href="https://github.com/python/cpython/commit/f396864ddfe914531b5856d7bf852808ebfc01ae (v3.8.11)">https://github.com/python/cpython/commit/f396864ddfe914531b5856d7bf852808ebfc01ae (v3.8.11)</a><br><a href="https://github.com/python/cpython/commit/f68d2d69f1da56c2aea1293ecf93ab69a6010ad7 (v3.6.14)">https://github.com/python/cpython/commit/f68d2d69f1da56c2aea1293ecf93ab69a6010ad7 (v3.6.14)</a><br><a href="https://github.com/python/cpython/commit/fee96422e6f0056561cf74fef2012cc066c9db86 (v3.7.11)">https://github.com/python/cpython/commit/fee96422e6f0056561cf74fef2012cc066c9db86 (v3.7.11)</a><br><a href="https://github.com/python/cpython/pull/25916">https://github.com/python/cpython/pull/25916</a><br><a href="https://github.com/python/cpython/pull/26503">https://github.com/python/cpython/pull/26503</a><br><a href="https://linux.oracle.com/cve/CVE-2021-3737.html">https://linux.oracle.com/cve/CVE-2021-3737.html</a><br><a href="https://linux.oracle.com/errata/ELSA-2021-4160.html">https://linux.oracle.com/errata/ELSA-2021-4160.html</a><br><a href="https://ubuntu.com/security/notices/USN-5083-1">https://ubuntu.com/security/notices/USN-5083-1</a><br></details>  |
| python3.8-minimal         |    CVE-2021-23336   |   LOW  |  3.8.10-0ubuntu1~20.04.2 |  | <details><summary>Expand...</summary><a href="http://www.openwall.com/lists/oss-security/2021/02/19/4">http://www.openwall.com/lists/oss-security/2021/02/19/4</a><br><a href="http://www.openwall.com/lists/oss-security/2021/05/01/2">http://www.openwall.com/lists/oss-security/2021/05/01/2</a><br><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2021-23336">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2021-23336</a><br><a href="https://github.com/python/cpython/commit/fcbe0cb04d35189401c0c880ebfb4311e952d776 (master)">https://github.com/python/cpython/commit/fcbe0cb04d35189401c0c880ebfb4311e952d776 (master)</a><br><a href="https://github.com/python/cpython/pull/24297">https://github.com/python/cpython/pull/24297</a><br><a href="https://linux.oracle.com/cve/CVE-2021-23336.html">https://linux.oracle.com/cve/CVE-2021-23336.html</a><br><a href="https://linux.oracle.com/errata/ELSA-2021-4162.html">https://linux.oracle.com/errata/ELSA-2021-4162.html</a><br><a href="https://lists.apache.org/thread.html/ra8ce70088ba291f358e077cafdb14d174b7a1ce9a9d86d1b332d6367@%3Cusers.airflow.apache.org%3E">https://lists.apache.org/thread.html/ra8ce70088ba291f358e077cafdb14d174b7a1ce9a9d86d1b332d6367@%3Cusers.airflow.apache.org%3E</a><br><a href="https://lists.apache.org/thread.html/rc005f4de9d9b0ba943ceb8ff5a21a5c6ff8a9df52632476698d99432@%3Cannounce.apache.org%3E">https://lists.apache.org/thread.html/rc005f4de9d9b0ba943ceb8ff5a21a5c6ff8a9df52632476698d99432@%3Cannounce.apache.org%3E</a><br><a href="https://lists.apache.org/thread.html/rf9fa47ab66495c78bb4120b0754dd9531ca2ff0430f6685ac9b07772@%3Cdev.mina.apache.org%3E">https://lists.apache.org/thread.html/rf9fa47ab66495c78bb4120b0754dd9531ca2ff0430f6685ac9b07772@%3Cdev.mina.apache.org%3E</a><br><a href="https://lists.debian.org/debian-lts-announce/2021/02/msg00030.html">https://lists.debian.org/debian-lts-announce/2021/02/msg00030.html</a><br><a href="https://lists.debian.org/debian-lts-announce/2021/04/msg00005.html">https://lists.debian.org/debian-lts-announce/2021/04/msg00005.html</a><br><a href="https://lists.debian.org/debian-lts-announce/2021/04/msg00015.html">https://lists.debian.org/debian-lts-announce/2021/04/msg00015.html</a><br><a href="https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/3EPYWWFDV22CJ5AOH5VCE72DOASZZ255/">https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/3EPYWWFDV22CJ5AOH5VCE72DOASZZ255/</a><br><a href="https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/3YKKDLXL3UEZ3J426C2XTBS63AHE46SM/">https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/3YKKDLXL3UEZ3J426C2XTBS63AHE46SM/</a><br><a href="https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/46N6A52EGSXHJYCZWVMBJJIH4NWIV2B5/">https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/46N6A52EGSXHJYCZWVMBJJIH4NWIV2B5/</a><br><a href="https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/FONHJIOZOFD7CD35KZL6SVBUTMBPGZGA/">https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/FONHJIOZOFD7CD35KZL6SVBUTMBPGZGA/</a><br><a href="https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/HCQTCSP6SCVIYNIRUJC5X7YBVUHPLSC4/">https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/HCQTCSP6SCVIYNIRUJC5X7YBVUHPLSC4/</a><br><a href="https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/HZTM7KLHFCE3LWSEVO2NAFLUHMGYMCRY/">https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/HZTM7KLHFCE3LWSEVO2NAFLUHMGYMCRY/</a><br><a href="https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/IHQDU7NXA7EWAE4W7VO6MURVJIULEPPR/">https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/IHQDU7NXA7EWAE4W7VO6MURVJIULEPPR/</a><br><a href="https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/KJXCMHLY7H3FIYLE4OKDYUILU2CCRUCZ/">https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/KJXCMHLY7H3FIYLE4OKDYUILU2CCRUCZ/</a><br><a href="https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/LVNH6Z24IG3E67ZCQGGJ46FZB4XFLQNZ/">https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/LVNH6Z24IG3E67ZCQGGJ46FZB4XFLQNZ/</a><br><a href="https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/MNUN5SOMFL2BBKP6ZAICIIUPQKZDMGYO/">https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/MNUN5SOMFL2BBKP6ZAICIIUPQKZDMGYO/</a><br><a href="https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/MP572OLHMS7MZO4KUPSCIMSZIA5IZZ62/">https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/MP572OLHMS7MZO4KUPSCIMSZIA5IZZ62/</a><br><a href="https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/N6VXJZSZ6N64AILJX4CTMACYGQGHHD5C/">https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/N6VXJZSZ6N64AILJX4CTMACYGQGHHD5C/</a><br><a href="https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/NJSCSN722JO2E2AGPWD4NTGVELVRPB4R/">https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/NJSCSN722JO2E2AGPWD4NTGVELVRPB4R/</a><br><a href="https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/NODWHDIFBQE5RU5PUWUVE47JOT5VCMJ2/">https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/NODWHDIFBQE5RU5PUWUVE47JOT5VCMJ2/</a><br><a href="https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/OAGSWNGZJ6HQ5ISA67SNMK3CJRKICET7/">https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/OAGSWNGZJ6HQ5ISA67SNMK3CJRKICET7/</a><br><a href="https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/RSLQD5CCM75IZGAMBDGUZEATYU5YSGJ7/">https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/RSLQD5CCM75IZGAMBDGUZEATYU5YSGJ7/</a><br><a href="https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/SGIY6I4YS3WOXAK4SXKIEOC2G4VZKIR7/">https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/SGIY6I4YS3WOXAK4SXKIEOC2G4VZKIR7/</a><br><a href="https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/TFTELUMWZE3KV3JB2H5EE6VFRZFRD5MV/">https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/TFTELUMWZE3KV3JB2H5EE6VFRZFRD5MV/</a><br><a href="https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/W2LSKBEFI5SYEY5FM6ICZVZM5WRQUCS4/">https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/W2LSKBEFI5SYEY5FM6ICZVZM5WRQUCS4/</a><br><a href="https://security.gentoo.org/glsa/202104-04">https://security.gentoo.org/glsa/202104-04</a><br><a href="https://security.netapp.com/advisory/ntap-20210326-0004/">https://security.netapp.com/advisory/ntap-20210326-0004/</a><br><a href="https://snyk.io/blog/cache-poisoning-in-popular-open-source-packages/">https://snyk.io/blog/cache-poisoning-in-popular-open-source-packages/</a><br><a href="https://snyk.io/vuln/SNYK-UPSTREAM-PYTHONCPYTHON-1074933">https://snyk.io/vuln/SNYK-UPSTREAM-PYTHONCPYTHON-1074933</a><br><a href="https://ubuntu.com/security/notices/USN-4742-1">https://ubuntu.com/security/notices/USN-4742-1</a><br><a href="https://www.djangoproject.com/weblog/2021/feb/19/security-releases/">https://www.djangoproject.com/weblog/2021/feb/19/security-releases/</a><br><a href="https://www.oracle.com//security-alerts/cpujul2021.html">https://www.oracle.com//security-alerts/cpujul2021.html</a><br><a href="https://www.oracle.com/security-alerts/cpuApr2021.html">https://www.oracle.com/security-alerts/cpuApr2021.html</a><br><a href="https://www.oracle.com/security-alerts/cpuoct2021.html">https://www.oracle.com/security-alerts/cpuoct2021.html</a><br></details>  |

**gobinary**

      
| Package         |    Vulnerability   |   Severity  |  Installed Version | Fixed Version |                   Links                   |
|:----------------|:------------------:|:-----------:|:------------------:|:-------------:|-----------------------------------------|
| golang.org/x/text         |    CVE-2020-14040   |   HIGH  |  v0.3.2 | 0.3.3 | <details><summary>Expand...</summary><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2020-14040">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2020-14040</a><br><a href="https://github.com/golang/go/issues/39491">https://github.com/golang/go/issues/39491</a><br><a href="https://groups.google.com/forum/#!topic/golang-announce/bXVeAmGOqz0">https://groups.google.com/forum/#!topic/golang-announce/bXVeAmGOqz0</a><br><a href="https://linux.oracle.com/cve/CVE-2020-14040.html">https://linux.oracle.com/cve/CVE-2020-14040.html</a><br><a href="https://linux.oracle.com/errata/ELSA-2020-4694.html">https://linux.oracle.com/errata/ELSA-2020-4694.html</a><br><a href="https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/TACQFZDPA7AUR6TRZBCX2RGRFSDYLI7O/">https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/TACQFZDPA7AUR6TRZBCX2RGRFSDYLI7O/</a><br><a href="https://nvd.nist.gov/vuln/detail/CVE-2020-14040">https://nvd.nist.gov/vuln/detail/CVE-2020-14040</a><br></details>  |
| golang.org/x/text         |    CVE-2021-38561   |   UNKNOWN  |  v0.3.2 | 0.3.7 | <details><summary>Expand...</summary></details>  |
| gopkg.in/yaml.v2         |    CVE-2019-11254   |   MEDIUM  |  v2.2.7 | 2.2.8 | <details><summary>Expand...</summary><a href="https://github.com/kubernetes/kubernetes/issues/89535">https://github.com/kubernetes/kubernetes/issues/89535</a><br><a href="https://groups.google.com/d/msg/kubernetes-announce/ALL9s73E5ck/4yHe8J-PBAAJ">https://groups.google.com/d/msg/kubernetes-announce/ALL9s73E5ck/4yHe8J-PBAAJ</a><br><a href="https://groups.google.com/forum/#!topic/kubernetes-security-announce/wuwEwZigXBc">https://groups.google.com/forum/#!topic/kubernetes-security-announce/wuwEwZigXBc</a><br><a href="https://linux.oracle.com/cve/CVE-2019-11254.html">https://linux.oracle.com/cve/CVE-2019-11254.html</a><br><a href="https://linux.oracle.com/errata/ELSA-2020-5653.html">https://linux.oracle.com/errata/ELSA-2020-5653.html</a><br><a href="https://security.netapp.com/advisory/ntap-20200413-0003/">https://security.netapp.com/advisory/ntap-20200413-0003/</a><br></details>  |

