---
hide:
  - toc
---

# Security Overview

<link href="https://truecharts.org/_static/trivy.css" type="text/css" rel="stylesheet" />

## Helm-Chart

##### Scan Results

#### Chart Object: webgrabplus/templates/common.yaml
    

      
| Type         |    Misconfiguration ID   |   Check  |  Severity |                   Explaination                   | Links  |
|:----------------|:------------------:|:-----------:|:------------------:|-----------------------------------------|-----------------------------------------|
| Kubernetes Security Check         |    KSV003   |   Default capabilities not dropped  |  LOW | <details><summary>Expand...</summary> The container should drop all default capabilities and add only those that are needed for its execution. <br> <hr> <br> Container &#39;RELEASE-NAME-webgrabplus&#39; of Deployment &#39;RELEASE-NAME-webgrabplus&#39; should add &#39;ALL&#39; to &#39;securityContext.capabilities.drop&#39; </details>| <details><summary>Expand...</summary><a href="https://kubesec.io/basics/containers-securitycontext-capabilities-drop-index-all/">https://kubesec.io/basics/containers-securitycontext-capabilities-drop-index-all/</a><br><a href="https://avd.aquasec.com/appshield/ksv003">https://avd.aquasec.com/appshield/ksv003</a><br></details>  |
| Kubernetes Security Check         |    KSV012   |   Runs as root user  |  MEDIUM | <details><summary>Expand...</summary> &#39;runAsNonRoot&#39; forces the running image to run as a non-root user to ensure least privileges. <br> <hr> <br> Container &#39;RELEASE-NAME-webgrabplus&#39; of Deployment &#39;RELEASE-NAME-webgrabplus&#39; should set &#39;securityContext.runAsNonRoot&#39; to true </details>| <details><summary>Expand...</summary><a href="https://kubernetes.io/docs/concepts/security/pod-security-standards/#restricted">https://kubernetes.io/docs/concepts/security/pod-security-standards/#restricted</a><br><a href="https://avd.aquasec.com/appshield/ksv012">https://avd.aquasec.com/appshield/ksv012</a><br></details>  |
| Kubernetes Security Check         |    KSV012   |   Runs as root user  |  MEDIUM | <details><summary>Expand...</summary> &#39;runAsNonRoot&#39; forces the running image to run as a non-root user to ensure least privileges. <br> <hr> <br> Container &#39;autopermissions&#39; of Deployment &#39;RELEASE-NAME-webgrabplus&#39; should set &#39;securityContext.runAsNonRoot&#39; to true </details>| <details><summary>Expand...</summary><a href="https://kubernetes.io/docs/concepts/security/pod-security-standards/#restricted">https://kubernetes.io/docs/concepts/security/pod-security-standards/#restricted</a><br><a href="https://avd.aquasec.com/appshield/ksv012">https://avd.aquasec.com/appshield/ksv012</a><br></details>  |
| Kubernetes Security Check         |    KSV014   |   Root file system is not read-only  |  LOW | <details><summary>Expand...</summary> An immutable root file system prevents applications from writing to their local disk. This can limit intrusions, as attackers will not be able to tamper with the file system or write foreign executables to disk. <br> <hr> <br> Container &#39;autopermissions&#39; of Deployment &#39;RELEASE-NAME-webgrabplus&#39; should set &#39;securityContext.readOnlyRootFilesystem&#39; to true </details>| <details><summary>Expand...</summary><a href="https://kubesec.io/basics/containers-securitycontext-readonlyrootfilesystem-true/">https://kubesec.io/basics/containers-securitycontext-readonlyrootfilesystem-true/</a><br><a href="https://avd.aquasec.com/appshield/ksv014">https://avd.aquasec.com/appshield/ksv014</a><br></details>  |
| Kubernetes Security Check         |    KSV020   |   Runs with low user ID  |  MEDIUM | <details><summary>Expand...</summary> Force the container to run with user ID &gt; 10000 to avoid conflicts with the host’s user table. <br> <hr> <br> Container &#39;RELEASE-NAME-webgrabplus&#39; of Deployment &#39;RELEASE-NAME-webgrabplus&#39; should set &#39;securityContext.runAsUser&#39; &gt; 10000 </details>| <details><summary>Expand...</summary><a href="https://kubesec.io/basics/containers-securitycontext-runasuser/">https://kubesec.io/basics/containers-securitycontext-runasuser/</a><br><a href="https://avd.aquasec.com/appshield/ksv020">https://avd.aquasec.com/appshield/ksv020</a><br></details>  |
| Kubernetes Security Check         |    KSV020   |   Runs with low user ID  |  MEDIUM | <details><summary>Expand...</summary> Force the container to run with user ID &gt; 10000 to avoid conflicts with the host’s user table. <br> <hr> <br> Container &#39;autopermissions&#39; of Deployment &#39;RELEASE-NAME-webgrabplus&#39; should set &#39;securityContext.runAsUser&#39; &gt; 10000 </details>| <details><summary>Expand...</summary><a href="https://kubesec.io/basics/containers-securitycontext-runasuser/">https://kubesec.io/basics/containers-securitycontext-runasuser/</a><br><a href="https://avd.aquasec.com/appshield/ksv020">https://avd.aquasec.com/appshield/ksv020</a><br></details>  |
| Kubernetes Security Check         |    KSV021   |   Runs with low group ID  |  MEDIUM | <details><summary>Expand...</summary> Force the container to run with group ID &gt; 10000 to avoid conflicts with the host’s user table. <br> <hr> <br> Container &#39;RELEASE-NAME-webgrabplus&#39; of Deployment &#39;RELEASE-NAME-webgrabplus&#39; should set &#39;securityContext.runAsGroup&#39; &gt; 10000 </details>| <details><summary>Expand...</summary><a href="https://kubesec.io/basics/containers-securitycontext-runasuser/">https://kubesec.io/basics/containers-securitycontext-runasuser/</a><br><a href="https://avd.aquasec.com/appshield/ksv021">https://avd.aquasec.com/appshield/ksv021</a><br></details>  |
| Kubernetes Security Check         |    KSV021   |   Runs with low group ID  |  MEDIUM | <details><summary>Expand...</summary> Force the container to run with group ID &gt; 10000 to avoid conflicts with the host’s user table. <br> <hr> <br> Container &#39;autopermissions&#39; of Deployment &#39;RELEASE-NAME-webgrabplus&#39; should set &#39;securityContext.runAsGroup&#39; &gt; 10000 </details>| <details><summary>Expand...</summary><a href="https://kubesec.io/basics/containers-securitycontext-runasuser/">https://kubesec.io/basics/containers-securitycontext-runasuser/</a><br><a href="https://avd.aquasec.com/appshield/ksv021">https://avd.aquasec.com/appshield/ksv021</a><br></details>  |
| Kubernetes Security Check         |    KSV029   |   A root primary or supplementary GID set  |  LOW | <details><summary>Expand...</summary> Containers should be forbidden from running with a root primary or supplementary GID. <br> <hr> <br> Deployment &#39;RELEASE-NAME-webgrabplus&#39; should set &#39;spec.securityContext.runAsGroup&#39;, &#39;spec.securityContext.supplementalGroups[*]&#39; and &#39;spec.securityContext.fsGroup&#39; to integer greater than 0 </details>| <details><summary>Expand...</summary><a href="https://kubernetes.io/docs/concepts/security/pod-security-standards/#restricted">https://kubernetes.io/docs/concepts/security/pod-security-standards/#restricted</a><br><a href="https://avd.aquasec.com/appshield/ksv029">https://avd.aquasec.com/appshield/ksv029</a><br></details>  |

## Containers

##### Detected Containers

          tccr.io/truecharts/alpine:v3.14.2@sha256:4095394abbae907e94b1f2fd2e2de6c4f201a5b9704573243ca8eb16db8cdb7c
          tccr.io/truecharts/webgrabplus:v3.2.2

##### Scan Results


#### Container: tccr.io/truecharts/alpine:v3.14.2@sha256:4095394abbae907e94b1f2fd2e2de6c4f201a5b9704573243ca8eb16db8cdb7c (alpine 3.14.2)
    

**alpine**

      
| Package         |    Vulnerability   |   Severity  |  Installed Version | Fixed Version |                   Links                   |
|:----------------|:------------------:|:-----------:|:------------------:|:-------------:|-----------------------------------------|
| busybox         |    CVE-2021-42378   |   HIGH  |  1.33.1-r3 | 1.33.1-r6 | <details><summary>Expand...</summary><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2021-42378">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2021-42378</a><br><a href="https://jfrog.com/blog/unboxing-busybox-14-new-vulnerabilities-uncovered-by-claroty-and-jfrog/">https://jfrog.com/blog/unboxing-busybox-14-new-vulnerabilities-uncovered-by-claroty-and-jfrog/</a><br><a href="https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/6T2TURBYYJGBMQTTN2DSOAIQGP7WCPGV/">https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/6T2TURBYYJGBMQTTN2DSOAIQGP7WCPGV/</a><br><a href="https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/UQXGOGWBIYWOIVXJVRKHZR34UMEHQBXS/">https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/UQXGOGWBIYWOIVXJVRKHZR34UMEHQBXS/</a><br><a href="https://ubuntu.com/security/notices/USN-5179-1">https://ubuntu.com/security/notices/USN-5179-1</a><br></details>  |
| busybox         |    CVE-2021-42379   |   HIGH  |  1.33.1-r3 | 1.33.1-r6 | <details><summary>Expand...</summary><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2021-42379">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2021-42379</a><br><a href="https://jfrog.com/blog/unboxing-busybox-14-new-vulnerabilities-uncovered-by-claroty-and-jfrog/">https://jfrog.com/blog/unboxing-busybox-14-new-vulnerabilities-uncovered-by-claroty-and-jfrog/</a><br><a href="https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/6T2TURBYYJGBMQTTN2DSOAIQGP7WCPGV/">https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/6T2TURBYYJGBMQTTN2DSOAIQGP7WCPGV/</a><br><a href="https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/UQXGOGWBIYWOIVXJVRKHZR34UMEHQBXS/">https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/UQXGOGWBIYWOIVXJVRKHZR34UMEHQBXS/</a><br><a href="https://ubuntu.com/security/notices/USN-5179-1">https://ubuntu.com/security/notices/USN-5179-1</a><br></details>  |
| busybox         |    CVE-2021-42380   |   HIGH  |  1.33.1-r3 | 1.33.1-r6 | <details><summary>Expand...</summary><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2021-42380">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2021-42380</a><br><a href="https://jfrog.com/blog/unboxing-busybox-14-new-vulnerabilities-uncovered-by-claroty-and-jfrog/">https://jfrog.com/blog/unboxing-busybox-14-new-vulnerabilities-uncovered-by-claroty-and-jfrog/</a><br><a href="https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/6T2TURBYYJGBMQTTN2DSOAIQGP7WCPGV/">https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/6T2TURBYYJGBMQTTN2DSOAIQGP7WCPGV/</a><br><a href="https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/UQXGOGWBIYWOIVXJVRKHZR34UMEHQBXS/">https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/UQXGOGWBIYWOIVXJVRKHZR34UMEHQBXS/</a><br><a href="https://ubuntu.com/security/notices/USN-5179-1">https://ubuntu.com/security/notices/USN-5179-1</a><br></details>  |
| busybox         |    CVE-2021-42381   |   HIGH  |  1.33.1-r3 | 1.33.1-r6 | <details><summary>Expand...</summary><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2021-42381">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2021-42381</a><br><a href="https://jfrog.com/blog/unboxing-busybox-14-new-vulnerabilities-uncovered-by-claroty-and-jfrog/">https://jfrog.com/blog/unboxing-busybox-14-new-vulnerabilities-uncovered-by-claroty-and-jfrog/</a><br><a href="https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/6T2TURBYYJGBMQTTN2DSOAIQGP7WCPGV/">https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/6T2TURBYYJGBMQTTN2DSOAIQGP7WCPGV/</a><br><a href="https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/UQXGOGWBIYWOIVXJVRKHZR34UMEHQBXS/">https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/UQXGOGWBIYWOIVXJVRKHZR34UMEHQBXS/</a><br><a href="https://ubuntu.com/security/notices/USN-5179-1">https://ubuntu.com/security/notices/USN-5179-1</a><br></details>  |
| busybox         |    CVE-2021-42382   |   HIGH  |  1.33.1-r3 | 1.33.1-r6 | <details><summary>Expand...</summary><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2021-42382">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2021-42382</a><br><a href="https://jfrog.com/blog/unboxing-busybox-14-new-vulnerabilities-uncovered-by-claroty-and-jfrog/">https://jfrog.com/blog/unboxing-busybox-14-new-vulnerabilities-uncovered-by-claroty-and-jfrog/</a><br><a href="https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/6T2TURBYYJGBMQTTN2DSOAIQGP7WCPGV/">https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/6T2TURBYYJGBMQTTN2DSOAIQGP7WCPGV/</a><br><a href="https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/UQXGOGWBIYWOIVXJVRKHZR34UMEHQBXS/">https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/UQXGOGWBIYWOIVXJVRKHZR34UMEHQBXS/</a><br><a href="https://ubuntu.com/security/notices/USN-5179-1">https://ubuntu.com/security/notices/USN-5179-1</a><br></details>  |
| busybox         |    CVE-2021-42383   |   HIGH  |  1.33.1-r3 | 1.33.1-r6 | <details><summary>Expand...</summary><a href="https://jfrog.com/blog/unboxing-busybox-14-new-vulnerabilities-uncovered-by-claroty-and-jfrog/">https://jfrog.com/blog/unboxing-busybox-14-new-vulnerabilities-uncovered-by-claroty-and-jfrog/</a><br><a href="https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/6T2TURBYYJGBMQTTN2DSOAIQGP7WCPGV/">https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/6T2TURBYYJGBMQTTN2DSOAIQGP7WCPGV/</a><br><a href="https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/UQXGOGWBIYWOIVXJVRKHZR34UMEHQBXS/">https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/UQXGOGWBIYWOIVXJVRKHZR34UMEHQBXS/</a><br></details>  |
| busybox         |    CVE-2021-42384   |   HIGH  |  1.33.1-r3 | 1.33.1-r6 | <details><summary>Expand...</summary><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2021-42384">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2021-42384</a><br><a href="https://jfrog.com/blog/unboxing-busybox-14-new-vulnerabilities-uncovered-by-claroty-and-jfrog/">https://jfrog.com/blog/unboxing-busybox-14-new-vulnerabilities-uncovered-by-claroty-and-jfrog/</a><br><a href="https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/6T2TURBYYJGBMQTTN2DSOAIQGP7WCPGV/">https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/6T2TURBYYJGBMQTTN2DSOAIQGP7WCPGV/</a><br><a href="https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/UQXGOGWBIYWOIVXJVRKHZR34UMEHQBXS/">https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/UQXGOGWBIYWOIVXJVRKHZR34UMEHQBXS/</a><br><a href="https://ubuntu.com/security/notices/USN-5179-1">https://ubuntu.com/security/notices/USN-5179-1</a><br></details>  |
| busybox         |    CVE-2021-42385   |   HIGH  |  1.33.1-r3 | 1.33.1-r6 | <details><summary>Expand...</summary><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2021-42385">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2021-42385</a><br><a href="https://jfrog.com/blog/unboxing-busybox-14-new-vulnerabilities-uncovered-by-claroty-and-jfrog/">https://jfrog.com/blog/unboxing-busybox-14-new-vulnerabilities-uncovered-by-claroty-and-jfrog/</a><br><a href="https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/6T2TURBYYJGBMQTTN2DSOAIQGP7WCPGV/">https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/6T2TURBYYJGBMQTTN2DSOAIQGP7WCPGV/</a><br><a href="https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/UQXGOGWBIYWOIVXJVRKHZR34UMEHQBXS/">https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/UQXGOGWBIYWOIVXJVRKHZR34UMEHQBXS/</a><br><a href="https://ubuntu.com/security/notices/USN-5179-1">https://ubuntu.com/security/notices/USN-5179-1</a><br></details>  |
| busybox         |    CVE-2021-42386   |   HIGH  |  1.33.1-r3 | 1.33.1-r6 | <details><summary>Expand...</summary><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2021-42386">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2021-42386</a><br><a href="https://jfrog.com/blog/unboxing-busybox-14-new-vulnerabilities-uncovered-by-claroty-and-jfrog/">https://jfrog.com/blog/unboxing-busybox-14-new-vulnerabilities-uncovered-by-claroty-and-jfrog/</a><br><a href="https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/6T2TURBYYJGBMQTTN2DSOAIQGP7WCPGV/">https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/6T2TURBYYJGBMQTTN2DSOAIQGP7WCPGV/</a><br><a href="https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/UQXGOGWBIYWOIVXJVRKHZR34UMEHQBXS/">https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/UQXGOGWBIYWOIVXJVRKHZR34UMEHQBXS/</a><br><a href="https://ubuntu.com/security/notices/USN-5179-1">https://ubuntu.com/security/notices/USN-5179-1</a><br></details>  |
| busybox         |    CVE-2021-42374   |   MEDIUM  |  1.33.1-r3 | 1.33.1-r4 | <details><summary>Expand...</summary><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2021-42374">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2021-42374</a><br><a href="https://jfrog.com/blog/unboxing-busybox-14-new-vulnerabilities-uncovered-by-claroty-and-jfrog/">https://jfrog.com/blog/unboxing-busybox-14-new-vulnerabilities-uncovered-by-claroty-and-jfrog/</a><br><a href="https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/6T2TURBYYJGBMQTTN2DSOAIQGP7WCPGV/">https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/6T2TURBYYJGBMQTTN2DSOAIQGP7WCPGV/</a><br><a href="https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/UQXGOGWBIYWOIVXJVRKHZR34UMEHQBXS/">https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/UQXGOGWBIYWOIVXJVRKHZR34UMEHQBXS/</a><br><a href="https://ubuntu.com/security/notices/USN-5179-1">https://ubuntu.com/security/notices/USN-5179-1</a><br></details>  |
| busybox         |    CVE-2021-42375   |   MEDIUM  |  1.33.1-r3 | 1.33.1-r5 | <details><summary>Expand...</summary><a href="https://jfrog.com/blog/unboxing-busybox-14-new-vulnerabilities-uncovered-by-claroty-and-jfrog/">https://jfrog.com/blog/unboxing-busybox-14-new-vulnerabilities-uncovered-by-claroty-and-jfrog/</a><br><a href="https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/6T2TURBYYJGBMQTTN2DSOAIQGP7WCPGV/">https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/6T2TURBYYJGBMQTTN2DSOAIQGP7WCPGV/</a><br><a href="https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/UQXGOGWBIYWOIVXJVRKHZR34UMEHQBXS/">https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/UQXGOGWBIYWOIVXJVRKHZR34UMEHQBXS/</a><br></details>  |
| ssl_client         |    CVE-2021-42378   |   HIGH  |  1.33.1-r3 | 1.33.1-r6 | <details><summary>Expand...</summary><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2021-42378">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2021-42378</a><br><a href="https://jfrog.com/blog/unboxing-busybox-14-new-vulnerabilities-uncovered-by-claroty-and-jfrog/">https://jfrog.com/blog/unboxing-busybox-14-new-vulnerabilities-uncovered-by-claroty-and-jfrog/</a><br><a href="https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/6T2TURBYYJGBMQTTN2DSOAIQGP7WCPGV/">https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/6T2TURBYYJGBMQTTN2DSOAIQGP7WCPGV/</a><br><a href="https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/UQXGOGWBIYWOIVXJVRKHZR34UMEHQBXS/">https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/UQXGOGWBIYWOIVXJVRKHZR34UMEHQBXS/</a><br><a href="https://ubuntu.com/security/notices/USN-5179-1">https://ubuntu.com/security/notices/USN-5179-1</a><br></details>  |
| ssl_client         |    CVE-2021-42379   |   HIGH  |  1.33.1-r3 | 1.33.1-r6 | <details><summary>Expand...</summary><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2021-42379">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2021-42379</a><br><a href="https://jfrog.com/blog/unboxing-busybox-14-new-vulnerabilities-uncovered-by-claroty-and-jfrog/">https://jfrog.com/blog/unboxing-busybox-14-new-vulnerabilities-uncovered-by-claroty-and-jfrog/</a><br><a href="https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/6T2TURBYYJGBMQTTN2DSOAIQGP7WCPGV/">https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/6T2TURBYYJGBMQTTN2DSOAIQGP7WCPGV/</a><br><a href="https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/UQXGOGWBIYWOIVXJVRKHZR34UMEHQBXS/">https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/UQXGOGWBIYWOIVXJVRKHZR34UMEHQBXS/</a><br><a href="https://ubuntu.com/security/notices/USN-5179-1">https://ubuntu.com/security/notices/USN-5179-1</a><br></details>  |
| ssl_client         |    CVE-2021-42380   |   HIGH  |  1.33.1-r3 | 1.33.1-r6 | <details><summary>Expand...</summary><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2021-42380">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2021-42380</a><br><a href="https://jfrog.com/blog/unboxing-busybox-14-new-vulnerabilities-uncovered-by-claroty-and-jfrog/">https://jfrog.com/blog/unboxing-busybox-14-new-vulnerabilities-uncovered-by-claroty-and-jfrog/</a><br><a href="https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/6T2TURBYYJGBMQTTN2DSOAIQGP7WCPGV/">https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/6T2TURBYYJGBMQTTN2DSOAIQGP7WCPGV/</a><br><a href="https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/UQXGOGWBIYWOIVXJVRKHZR34UMEHQBXS/">https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/UQXGOGWBIYWOIVXJVRKHZR34UMEHQBXS/</a><br><a href="https://ubuntu.com/security/notices/USN-5179-1">https://ubuntu.com/security/notices/USN-5179-1</a><br></details>  |
| ssl_client         |    CVE-2021-42381   |   HIGH  |  1.33.1-r3 | 1.33.1-r6 | <details><summary>Expand...</summary><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2021-42381">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2021-42381</a><br><a href="https://jfrog.com/blog/unboxing-busybox-14-new-vulnerabilities-uncovered-by-claroty-and-jfrog/">https://jfrog.com/blog/unboxing-busybox-14-new-vulnerabilities-uncovered-by-claroty-and-jfrog/</a><br><a href="https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/6T2TURBYYJGBMQTTN2DSOAIQGP7WCPGV/">https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/6T2TURBYYJGBMQTTN2DSOAIQGP7WCPGV/</a><br><a href="https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/UQXGOGWBIYWOIVXJVRKHZR34UMEHQBXS/">https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/UQXGOGWBIYWOIVXJVRKHZR34UMEHQBXS/</a><br><a href="https://ubuntu.com/security/notices/USN-5179-1">https://ubuntu.com/security/notices/USN-5179-1</a><br></details>  |
| ssl_client         |    CVE-2021-42382   |   HIGH  |  1.33.1-r3 | 1.33.1-r6 | <details><summary>Expand...</summary><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2021-42382">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2021-42382</a><br><a href="https://jfrog.com/blog/unboxing-busybox-14-new-vulnerabilities-uncovered-by-claroty-and-jfrog/">https://jfrog.com/blog/unboxing-busybox-14-new-vulnerabilities-uncovered-by-claroty-and-jfrog/</a><br><a href="https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/6T2TURBYYJGBMQTTN2DSOAIQGP7WCPGV/">https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/6T2TURBYYJGBMQTTN2DSOAIQGP7WCPGV/</a><br><a href="https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/UQXGOGWBIYWOIVXJVRKHZR34UMEHQBXS/">https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/UQXGOGWBIYWOIVXJVRKHZR34UMEHQBXS/</a><br><a href="https://ubuntu.com/security/notices/USN-5179-1">https://ubuntu.com/security/notices/USN-5179-1</a><br></details>  |
| ssl_client         |    CVE-2021-42383   |   HIGH  |  1.33.1-r3 | 1.33.1-r6 | <details><summary>Expand...</summary><a href="https://jfrog.com/blog/unboxing-busybox-14-new-vulnerabilities-uncovered-by-claroty-and-jfrog/">https://jfrog.com/blog/unboxing-busybox-14-new-vulnerabilities-uncovered-by-claroty-and-jfrog/</a><br><a href="https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/6T2TURBYYJGBMQTTN2DSOAIQGP7WCPGV/">https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/6T2TURBYYJGBMQTTN2DSOAIQGP7WCPGV/</a><br><a href="https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/UQXGOGWBIYWOIVXJVRKHZR34UMEHQBXS/">https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/UQXGOGWBIYWOIVXJVRKHZR34UMEHQBXS/</a><br></details>  |
| ssl_client         |    CVE-2021-42384   |   HIGH  |  1.33.1-r3 | 1.33.1-r6 | <details><summary>Expand...</summary><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2021-42384">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2021-42384</a><br><a href="https://jfrog.com/blog/unboxing-busybox-14-new-vulnerabilities-uncovered-by-claroty-and-jfrog/">https://jfrog.com/blog/unboxing-busybox-14-new-vulnerabilities-uncovered-by-claroty-and-jfrog/</a><br><a href="https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/6T2TURBYYJGBMQTTN2DSOAIQGP7WCPGV/">https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/6T2TURBYYJGBMQTTN2DSOAIQGP7WCPGV/</a><br><a href="https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/UQXGOGWBIYWOIVXJVRKHZR34UMEHQBXS/">https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/UQXGOGWBIYWOIVXJVRKHZR34UMEHQBXS/</a><br><a href="https://ubuntu.com/security/notices/USN-5179-1">https://ubuntu.com/security/notices/USN-5179-1</a><br></details>  |
| ssl_client         |    CVE-2021-42385   |   HIGH  |  1.33.1-r3 | 1.33.1-r6 | <details><summary>Expand...</summary><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2021-42385">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2021-42385</a><br><a href="https://jfrog.com/blog/unboxing-busybox-14-new-vulnerabilities-uncovered-by-claroty-and-jfrog/">https://jfrog.com/blog/unboxing-busybox-14-new-vulnerabilities-uncovered-by-claroty-and-jfrog/</a><br><a href="https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/6T2TURBYYJGBMQTTN2DSOAIQGP7WCPGV/">https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/6T2TURBYYJGBMQTTN2DSOAIQGP7WCPGV/</a><br><a href="https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/UQXGOGWBIYWOIVXJVRKHZR34UMEHQBXS/">https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/UQXGOGWBIYWOIVXJVRKHZR34UMEHQBXS/</a><br><a href="https://ubuntu.com/security/notices/USN-5179-1">https://ubuntu.com/security/notices/USN-5179-1</a><br></details>  |
| ssl_client         |    CVE-2021-42386   |   HIGH  |  1.33.1-r3 | 1.33.1-r6 | <details><summary>Expand...</summary><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2021-42386">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2021-42386</a><br><a href="https://jfrog.com/blog/unboxing-busybox-14-new-vulnerabilities-uncovered-by-claroty-and-jfrog/">https://jfrog.com/blog/unboxing-busybox-14-new-vulnerabilities-uncovered-by-claroty-and-jfrog/</a><br><a href="https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/6T2TURBYYJGBMQTTN2DSOAIQGP7WCPGV/">https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/6T2TURBYYJGBMQTTN2DSOAIQGP7WCPGV/</a><br><a href="https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/UQXGOGWBIYWOIVXJVRKHZR34UMEHQBXS/">https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/UQXGOGWBIYWOIVXJVRKHZR34UMEHQBXS/</a><br><a href="https://ubuntu.com/security/notices/USN-5179-1">https://ubuntu.com/security/notices/USN-5179-1</a><br></details>  |
| ssl_client         |    CVE-2021-42374   |   MEDIUM  |  1.33.1-r3 | 1.33.1-r4 | <details><summary>Expand...</summary><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2021-42374">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2021-42374</a><br><a href="https://jfrog.com/blog/unboxing-busybox-14-new-vulnerabilities-uncovered-by-claroty-and-jfrog/">https://jfrog.com/blog/unboxing-busybox-14-new-vulnerabilities-uncovered-by-claroty-and-jfrog/</a><br><a href="https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/6T2TURBYYJGBMQTTN2DSOAIQGP7WCPGV/">https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/6T2TURBYYJGBMQTTN2DSOAIQGP7WCPGV/</a><br><a href="https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/UQXGOGWBIYWOIVXJVRKHZR34UMEHQBXS/">https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/UQXGOGWBIYWOIVXJVRKHZR34UMEHQBXS/</a><br><a href="https://ubuntu.com/security/notices/USN-5179-1">https://ubuntu.com/security/notices/USN-5179-1</a><br></details>  |
| ssl_client         |    CVE-2021-42375   |   MEDIUM  |  1.33.1-r3 | 1.33.1-r5 | <details><summary>Expand...</summary><a href="https://jfrog.com/blog/unboxing-busybox-14-new-vulnerabilities-uncovered-by-claroty-and-jfrog/">https://jfrog.com/blog/unboxing-busybox-14-new-vulnerabilities-uncovered-by-claroty-and-jfrog/</a><br><a href="https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/6T2TURBYYJGBMQTTN2DSOAIQGP7WCPGV/">https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/6T2TURBYYJGBMQTTN2DSOAIQGP7WCPGV/</a><br><a href="https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/UQXGOGWBIYWOIVXJVRKHZR34UMEHQBXS/">https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/UQXGOGWBIYWOIVXJVRKHZR34UMEHQBXS/</a><br></details>  |


#### Container: tccr.io/truecharts/webgrabplus:v3.2.2 (ubuntu 18.04)
    

**ubuntu**

      
| Package         |    Vulnerability   |   Severity  |  Installed Version | Fixed Version |                   Links                   |
|:----------------|:------------------:|:-----------:|:------------------:|:-------------:|-----------------------------------------|
| bash         |    CVE-2019-18276   |   LOW  |  4.4.18-2ubuntu1.2 |  | <details><summary>Expand...</summary><a href="http://packetstormsecurity.com/files/155498/Bash-5.0-Patch-11-Privilege-Escalation.html">http://packetstormsecurity.com/files/155498/Bash-5.0-Patch-11-Privilege-Escalation.html</a><br><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2019-18276">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2019-18276</a><br><a href="https://github.com/bminor/bash/commit/951bdaad7a18cc0dc1036bba86b18b90874d39ff">https://github.com/bminor/bash/commit/951bdaad7a18cc0dc1036bba86b18b90874d39ff</a><br><a href="https://linux.oracle.com/cve/CVE-2019-18276.html">https://linux.oracle.com/cve/CVE-2019-18276.html</a><br><a href="https://linux.oracle.com/errata/ELSA-2021-1679.html">https://linux.oracle.com/errata/ELSA-2021-1679.html</a><br><a href="https://lists.apache.org/thread.html/rf9fa47ab66495c78bb4120b0754dd9531ca2ff0430f6685ac9b07772@%3Cdev.mina.apache.org%3E">https://lists.apache.org/thread.html/rf9fa47ab66495c78bb4120b0754dd9531ca2ff0430f6685ac9b07772@%3Cdev.mina.apache.org%3E</a><br><a href="https://security.gentoo.org/glsa/202105-34">https://security.gentoo.org/glsa/202105-34</a><br><a href="https://security.netapp.com/advisory/ntap-20200430-0003/">https://security.netapp.com/advisory/ntap-20200430-0003/</a><br><a href="https://www.youtube.com/watch?v=-wGtxJ8opa8">https://www.youtube.com/watch?v=-wGtxJ8opa8</a><br></details>  |
| binutils         |    CVE-2017-13716   |   LOW  |  2.30-21ubuntu1~18.04.7 |  | <details><summary>Expand...</summary><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2017-13716">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2017-13716</a><br><a href="https://sourceware.org/bugzilla/show_bug.cgi?id=22009">https://sourceware.org/bugzilla/show_bug.cgi?id=22009</a><br></details>  |
| binutils         |    CVE-2018-20657   |   LOW  |  2.30-21ubuntu1~18.04.7 |  | <details><summary>Expand...</summary><a href="http://www.securityfocus.com/bid/106444">http://www.securityfocus.com/bid/106444</a><br><a href="https://access.redhat.com/errata/RHSA-2019:3352">https://access.redhat.com/errata/RHSA-2019:3352</a><br><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2018-20657">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2018-20657</a><br><a href="https://gcc.gnu.org/bugzilla/show_bug.cgi?id=88539">https://gcc.gnu.org/bugzilla/show_bug.cgi?id=88539</a><br><a href="https://linux.oracle.com/cve/CVE-2018-20657.html">https://linux.oracle.com/cve/CVE-2018-20657.html</a><br><a href="https://linux.oracle.com/errata/ELSA-2019-3352.html">https://linux.oracle.com/errata/ELSA-2019-3352.html</a><br><a href="https://support.f5.com/csp/article/K62602089">https://support.f5.com/csp/article/K62602089</a><br></details>  |
| binutils         |    CVE-2018-20673   |   LOW  |  2.30-21ubuntu1~18.04.7 |  | <details><summary>Expand...</summary><a href="http://www.securityfocus.com/bid/106454">http://www.securityfocus.com/bid/106454</a><br><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2018-20673">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2018-20673</a><br><a href="https://linux.oracle.com/cve/CVE-2018-20673.html">https://linux.oracle.com/cve/CVE-2018-20673.html</a><br><a href="https://linux.oracle.com/errata/ELSA-2021-4386.html">https://linux.oracle.com/errata/ELSA-2021-4386.html</a><br><a href="https://sourceware.org/bugzilla/show_bug.cgi?id=24039">https://sourceware.org/bugzilla/show_bug.cgi?id=24039</a><br></details>  |
| binutils         |    CVE-2019-1010204   |   LOW  |  2.30-21ubuntu1~18.04.7 |  | <details><summary>Expand...</summary><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2019-1010204">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2019-1010204</a><br><a href="https://linux.oracle.com/cve/CVE-2019-1010204.html">https://linux.oracle.com/cve/CVE-2019-1010204.html</a><br><a href="https://linux.oracle.com/errata/ELSA-2020-1797.html">https://linux.oracle.com/errata/ELSA-2020-1797.html</a><br><a href="https://security.netapp.com/advisory/ntap-20190822-0001/">https://security.netapp.com/advisory/ntap-20190822-0001/</a><br><a href="https://sourceware.org/bugzilla/show_bug.cgi?id=23765">https://sourceware.org/bugzilla/show_bug.cgi?id=23765</a><br><a href="https://support.f5.com/csp/article/K05032915?utm_source=f5support&amp;amp;utm_medium=RSS">https://support.f5.com/csp/article/K05032915?utm_source=f5support&amp;amp;utm_medium=RSS</a><br></details>  |
| binutils-common         |    CVE-2017-13716   |   LOW  |  2.30-21ubuntu1~18.04.7 |  | <details><summary>Expand...</summary><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2017-13716">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2017-13716</a><br><a href="https://sourceware.org/bugzilla/show_bug.cgi?id=22009">https://sourceware.org/bugzilla/show_bug.cgi?id=22009</a><br></details>  |
| binutils-common         |    CVE-2018-20657   |   LOW  |  2.30-21ubuntu1~18.04.7 |  | <details><summary>Expand...</summary><a href="http://www.securityfocus.com/bid/106444">http://www.securityfocus.com/bid/106444</a><br><a href="https://access.redhat.com/errata/RHSA-2019:3352">https://access.redhat.com/errata/RHSA-2019:3352</a><br><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2018-20657">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2018-20657</a><br><a href="https://gcc.gnu.org/bugzilla/show_bug.cgi?id=88539">https://gcc.gnu.org/bugzilla/show_bug.cgi?id=88539</a><br><a href="https://linux.oracle.com/cve/CVE-2018-20657.html">https://linux.oracle.com/cve/CVE-2018-20657.html</a><br><a href="https://linux.oracle.com/errata/ELSA-2019-3352.html">https://linux.oracle.com/errata/ELSA-2019-3352.html</a><br><a href="https://support.f5.com/csp/article/K62602089">https://support.f5.com/csp/article/K62602089</a><br></details>  |
| binutils-common         |    CVE-2018-20673   |   LOW  |  2.30-21ubuntu1~18.04.7 |  | <details><summary>Expand...</summary><a href="http://www.securityfocus.com/bid/106454">http://www.securityfocus.com/bid/106454</a><br><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2018-20673">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2018-20673</a><br><a href="https://linux.oracle.com/cve/CVE-2018-20673.html">https://linux.oracle.com/cve/CVE-2018-20673.html</a><br><a href="https://linux.oracle.com/errata/ELSA-2021-4386.html">https://linux.oracle.com/errata/ELSA-2021-4386.html</a><br><a href="https://sourceware.org/bugzilla/show_bug.cgi?id=24039">https://sourceware.org/bugzilla/show_bug.cgi?id=24039</a><br></details>  |
| binutils-common         |    CVE-2019-1010204   |   LOW  |  2.30-21ubuntu1~18.04.7 |  | <details><summary>Expand...</summary><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2019-1010204">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2019-1010204</a><br><a href="https://linux.oracle.com/cve/CVE-2019-1010204.html">https://linux.oracle.com/cve/CVE-2019-1010204.html</a><br><a href="https://linux.oracle.com/errata/ELSA-2020-1797.html">https://linux.oracle.com/errata/ELSA-2020-1797.html</a><br><a href="https://security.netapp.com/advisory/ntap-20190822-0001/">https://security.netapp.com/advisory/ntap-20190822-0001/</a><br><a href="https://sourceware.org/bugzilla/show_bug.cgi?id=23765">https://sourceware.org/bugzilla/show_bug.cgi?id=23765</a><br><a href="https://support.f5.com/csp/article/K05032915?utm_source=f5support&amp;amp;utm_medium=RSS">https://support.f5.com/csp/article/K05032915?utm_source=f5support&amp;amp;utm_medium=RSS</a><br></details>  |
| binutils-x86-64-linux-gnu         |    CVE-2017-13716   |   LOW  |  2.30-21ubuntu1~18.04.7 |  | <details><summary>Expand...</summary><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2017-13716">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2017-13716</a><br><a href="https://sourceware.org/bugzilla/show_bug.cgi?id=22009">https://sourceware.org/bugzilla/show_bug.cgi?id=22009</a><br></details>  |
| binutils-x86-64-linux-gnu         |    CVE-2018-20657   |   LOW  |  2.30-21ubuntu1~18.04.7 |  | <details><summary>Expand...</summary><a href="http://www.securityfocus.com/bid/106444">http://www.securityfocus.com/bid/106444</a><br><a href="https://access.redhat.com/errata/RHSA-2019:3352">https://access.redhat.com/errata/RHSA-2019:3352</a><br><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2018-20657">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2018-20657</a><br><a href="https://gcc.gnu.org/bugzilla/show_bug.cgi?id=88539">https://gcc.gnu.org/bugzilla/show_bug.cgi?id=88539</a><br><a href="https://linux.oracle.com/cve/CVE-2018-20657.html">https://linux.oracle.com/cve/CVE-2018-20657.html</a><br><a href="https://linux.oracle.com/errata/ELSA-2019-3352.html">https://linux.oracle.com/errata/ELSA-2019-3352.html</a><br><a href="https://support.f5.com/csp/article/K62602089">https://support.f5.com/csp/article/K62602089</a><br></details>  |
| binutils-x86-64-linux-gnu         |    CVE-2018-20673   |   LOW  |  2.30-21ubuntu1~18.04.7 |  | <details><summary>Expand...</summary><a href="http://www.securityfocus.com/bid/106454">http://www.securityfocus.com/bid/106454</a><br><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2018-20673">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2018-20673</a><br><a href="https://linux.oracle.com/cve/CVE-2018-20673.html">https://linux.oracle.com/cve/CVE-2018-20673.html</a><br><a href="https://linux.oracle.com/errata/ELSA-2021-4386.html">https://linux.oracle.com/errata/ELSA-2021-4386.html</a><br><a href="https://sourceware.org/bugzilla/show_bug.cgi?id=24039">https://sourceware.org/bugzilla/show_bug.cgi?id=24039</a><br></details>  |
| binutils-x86-64-linux-gnu         |    CVE-2019-1010204   |   LOW  |  2.30-21ubuntu1~18.04.7 |  | <details><summary>Expand...</summary><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2019-1010204">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2019-1010204</a><br><a href="https://linux.oracle.com/cve/CVE-2019-1010204.html">https://linux.oracle.com/cve/CVE-2019-1010204.html</a><br><a href="https://linux.oracle.com/errata/ELSA-2020-1797.html">https://linux.oracle.com/errata/ELSA-2020-1797.html</a><br><a href="https://security.netapp.com/advisory/ntap-20190822-0001/">https://security.netapp.com/advisory/ntap-20190822-0001/</a><br><a href="https://sourceware.org/bugzilla/show_bug.cgi?id=23765">https://sourceware.org/bugzilla/show_bug.cgi?id=23765</a><br><a href="https://support.f5.com/csp/article/K05032915?utm_source=f5support&amp;amp;utm_medium=RSS">https://support.f5.com/csp/article/K05032915?utm_source=f5support&amp;amp;utm_medium=RSS</a><br></details>  |
| ca-certificates-mono         |    CVE-2018-1002208   |   LOW  |  6.12.0.122-0xamarin1+ubuntu1804b1 |  | <details><summary>Expand...</summary><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2018-1002208">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2018-1002208</a><br><a href="https://github.com/icsharpcode/SharpZipLib/issues/232">https://github.com/icsharpcode/SharpZipLib/issues/232</a><br><a href="https://github.com/icsharpcode/SharpZipLib/wiki/Release-1.0">https://github.com/icsharpcode/SharpZipLib/wiki/Release-1.0</a><br><a href="https://github.com/snyk/zip-slip-vulnerability">https://github.com/snyk/zip-slip-vulnerability</a><br><a href="https://snyk.io/research/zip-slip-vulnerability">https://snyk.io/research/zip-slip-vulnerability</a><br><a href="https://snyk.io/vuln/SNYK-DOTNET-SHARPZIPLIB-60247">https://snyk.io/vuln/SNYK-DOTNET-SHARPZIPLIB-60247</a><br></details>  |
| coreutils         |    CVE-2016-2781   |   LOW  |  8.28-1ubuntu1 |  | <details><summary>Expand...</summary><a href="http://seclists.org/oss-sec/2016/q1/452">http://seclists.org/oss-sec/2016/q1/452</a><br><a href="http://www.openwall.com/lists/oss-security/2016/02/28/2">http://www.openwall.com/lists/oss-security/2016/02/28/2</a><br><a href="http://www.openwall.com/lists/oss-security/2016/02/28/3">http://www.openwall.com/lists/oss-security/2016/02/28/3</a><br><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2016-2781">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2016-2781</a><br><a href="https://lists.apache.org/thread.html/rf9fa47ab66495c78bb4120b0754dd9531ca2ff0430f6685ac9b07772@%3Cdev.mina.apache.org%3E">https://lists.apache.org/thread.html/rf9fa47ab66495c78bb4120b0754dd9531ca2ff0430f6685ac9b07772@%3Cdev.mina.apache.org%3E</a><br><a href="https://lore.kernel.org/patchwork/patch/793178/">https://lore.kernel.org/patchwork/patch/793178/</a><br></details>  |
| cpp         |    CVE-2020-13844   |   MEDIUM  |  1.176ubuntu2.3 |  | <details><summary>Expand...</summary><a href="http://lists.llvm.org/pipermail/llvm-dev/2020-June/142109.html">http://lists.llvm.org/pipermail/llvm-dev/2020-June/142109.html</a><br><a href="http://lists.opensuse.org/opensuse-security-announce/2020-10/msg00039.html">http://lists.opensuse.org/opensuse-security-announce/2020-10/msg00039.html</a><br><a href="http://lists.opensuse.org/opensuse-security-announce/2020-10/msg00040.html">http://lists.opensuse.org/opensuse-security-announce/2020-10/msg00040.html</a><br><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2020-13844">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2020-13844</a><br><a href="https://developer.arm.com/support/arm-security-updates/speculative-processor-vulnerability">https://developer.arm.com/support/arm-security-updates/speculative-processor-vulnerability</a><br><a href="https://developer.arm.com/support/arm-security-updates/speculative-processor-vulnerability/downloads/straight-line-speculation">https://developer.arm.com/support/arm-security-updates/speculative-processor-vulnerability/downloads/straight-line-speculation</a><br><a href="https://developer.arm.com/support/arm-security-updates/speculative-processor-vulnerability/frequently-asked-questions">https://developer.arm.com/support/arm-security-updates/speculative-processor-vulnerability/frequently-asked-questions</a><br><a href="https://gcc.gnu.org/pipermail/gcc-patches/2020-June/547520.html">https://gcc.gnu.org/pipermail/gcc-patches/2020-June/547520.html</a><br><a href="https://git.kernel.org/pub/scm/linux/kernel/git/torvalds/linux.git/commit/?id=679db70801da9fda91d26caf13bf5b5ccc74e8e8">https://git.kernel.org/pub/scm/linux/kernel/git/torvalds/linux.git/commit/?id=679db70801da9fda91d26caf13bf5b5ccc74e8e8</a><br></details>  |
| cpp-7         |    CVE-2020-13844   |   MEDIUM  |  7.5.0-3ubuntu1~18.04 |  | <details><summary>Expand...</summary><a href="http://lists.llvm.org/pipermail/llvm-dev/2020-June/142109.html">http://lists.llvm.org/pipermail/llvm-dev/2020-June/142109.html</a><br><a href="http://lists.opensuse.org/opensuse-security-announce/2020-10/msg00039.html">http://lists.opensuse.org/opensuse-security-announce/2020-10/msg00039.html</a><br><a href="http://lists.opensuse.org/opensuse-security-announce/2020-10/msg00040.html">http://lists.opensuse.org/opensuse-security-announce/2020-10/msg00040.html</a><br><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2020-13844">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2020-13844</a><br><a href="https://developer.arm.com/support/arm-security-updates/speculative-processor-vulnerability">https://developer.arm.com/support/arm-security-updates/speculative-processor-vulnerability</a><br><a href="https://developer.arm.com/support/arm-security-updates/speculative-processor-vulnerability/downloads/straight-line-speculation">https://developer.arm.com/support/arm-security-updates/speculative-processor-vulnerability/downloads/straight-line-speculation</a><br><a href="https://developer.arm.com/support/arm-security-updates/speculative-processor-vulnerability/frequently-asked-questions">https://developer.arm.com/support/arm-security-updates/speculative-processor-vulnerability/frequently-asked-questions</a><br><a href="https://gcc.gnu.org/pipermail/gcc-patches/2020-June/547520.html">https://gcc.gnu.org/pipermail/gcc-patches/2020-June/547520.html</a><br><a href="https://git.kernel.org/pub/scm/linux/kernel/git/torvalds/linux.git/commit/?id=679db70801da9fda91d26caf13bf5b5ccc74e8e8">https://git.kernel.org/pub/scm/linux/kernel/git/torvalds/linux.git/commit/?id=679db70801da9fda91d26caf13bf5b5ccc74e8e8</a><br></details>  |
| cron         |    CVE-2017-9525   |   LOW  |  3.0pl1-128.1ubuntu1 |  | <details><summary>Expand...</summary><a href="http://bugs.debian.org/864466">http://bugs.debian.org/864466</a><br><a href="http://www.openwall.com/lists/oss-security/2017/06/08/3">http://www.openwall.com/lists/oss-security/2017/06/08/3</a><br><a href="http://www.securitytracker.com/id/1038651">http://www.securitytracker.com/id/1038651</a><br><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2017-9525">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2017-9525</a><br><a href="https://lists.debian.org/debian-lts-announce/2019/03/msg00025.html">https://lists.debian.org/debian-lts-announce/2019/03/msg00025.html</a><br><a href="https://lists.debian.org/debian-lts-announce/2021/10/msg00029.html">https://lists.debian.org/debian-lts-announce/2021/10/msg00029.html</a><br></details>  |
| dirmngr         |    CVE-2019-13050   |   LOW  |  2.2.4-1ubuntu1.4 |  | <details><summary>Expand...</summary><a href="http://lists.opensuse.org/opensuse-security-announce/2019-08/msg00039.html">http://lists.opensuse.org/opensuse-security-announce/2019-08/msg00039.html</a><br><a href="https://access.redhat.com/articles/4264021">https://access.redhat.com/articles/4264021</a><br><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2019-13050">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2019-13050</a><br><a href="https://gist.github.com/rjhansen/67ab921ffb4084c865b3618d6955275f">https://gist.github.com/rjhansen/67ab921ffb4084c865b3618d6955275f</a><br><a href="https://linux.oracle.com/cve/CVE-2019-13050.html">https://linux.oracle.com/cve/CVE-2019-13050.html</a><br><a href="https://linux.oracle.com/errata/ELSA-2020-4490.html">https://linux.oracle.com/errata/ELSA-2020-4490.html</a><br><a href="https://lists.apache.org/thread.html/r58af02e294bd07f487e2c64ffc0a29b837db5600e33b6e698b9d696b@%3Cissues.bookkeeper.apache.org%3E">https://lists.apache.org/thread.html/r58af02e294bd07f487e2c64ffc0a29b837db5600e33b6e698b9d696b@%3Cissues.bookkeeper.apache.org%3E</a><br><a href="https://lists.apache.org/thread.html/rf4c02775860db415b4955778a131c2795223f61cb8c6a450893651e4@%3Cissues.bookkeeper.apache.org%3E">https://lists.apache.org/thread.html/rf4c02775860db415b4955778a131c2795223f61cb8c6a450893651e4@%3Cissues.bookkeeper.apache.org%3E</a><br><a href="https://lists.apache.org/thread.html/rf9fa47ab66495c78bb4120b0754dd9531ca2ff0430f6685ac9b07772@%3Cdev.mina.apache.org%3E">https://lists.apache.org/thread.html/rf9fa47ab66495c78bb4120b0754dd9531ca2ff0430f6685ac9b07772@%3Cdev.mina.apache.org%3E</a><br><a href="https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/AUK2YRO6QIH64WP2LRA5D4LACTXQPPU4/">https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/AUK2YRO6QIH64WP2LRA5D4LACTXQPPU4/</a><br><a href="https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/CP4ON34YEXEZDZOXXWV43KVGGO6WZLJ5/">https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/CP4ON34YEXEZDZOXXWV43KVGGO6WZLJ5/</a><br><a href="https://lists.gnupg.org/pipermail/gnupg-announce/2019q3/000439.html">https://lists.gnupg.org/pipermail/gnupg-announce/2019q3/000439.html</a><br><a href="https://support.f5.com/csp/article/K08654551">https://support.f5.com/csp/article/K08654551</a><br><a href="https://support.f5.com/csp/article/K08654551?utm_source=f5support&amp;amp;utm_medium=RSS">https://support.f5.com/csp/article/K08654551?utm_source=f5support&amp;amp;utm_medium=RSS</a><br><a href="https://twitter.com/lambdafu/status/1147162583969009664">https://twitter.com/lambdafu/status/1147162583969009664</a><br></details>  |
| g++         |    CVE-2020-13844   |   MEDIUM  |  1.176ubuntu2.3 |  | <details><summary>Expand...</summary><a href="http://lists.llvm.org/pipermail/llvm-dev/2020-June/142109.html">http://lists.llvm.org/pipermail/llvm-dev/2020-June/142109.html</a><br><a href="http://lists.opensuse.org/opensuse-security-announce/2020-10/msg00039.html">http://lists.opensuse.org/opensuse-security-announce/2020-10/msg00039.html</a><br><a href="http://lists.opensuse.org/opensuse-security-announce/2020-10/msg00040.html">http://lists.opensuse.org/opensuse-security-announce/2020-10/msg00040.html</a><br><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2020-13844">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2020-13844</a><br><a href="https://developer.arm.com/support/arm-security-updates/speculative-processor-vulnerability">https://developer.arm.com/support/arm-security-updates/speculative-processor-vulnerability</a><br><a href="https://developer.arm.com/support/arm-security-updates/speculative-processor-vulnerability/downloads/straight-line-speculation">https://developer.arm.com/support/arm-security-updates/speculative-processor-vulnerability/downloads/straight-line-speculation</a><br><a href="https://developer.arm.com/support/arm-security-updates/speculative-processor-vulnerability/frequently-asked-questions">https://developer.arm.com/support/arm-security-updates/speculative-processor-vulnerability/frequently-asked-questions</a><br><a href="https://gcc.gnu.org/pipermail/gcc-patches/2020-June/547520.html">https://gcc.gnu.org/pipermail/gcc-patches/2020-June/547520.html</a><br><a href="https://git.kernel.org/pub/scm/linux/kernel/git/torvalds/linux.git/commit/?id=679db70801da9fda91d26caf13bf5b5ccc74e8e8">https://git.kernel.org/pub/scm/linux/kernel/git/torvalds/linux.git/commit/?id=679db70801da9fda91d26caf13bf5b5ccc74e8e8</a><br></details>  |
| g++-7         |    CVE-2020-13844   |   MEDIUM  |  7.5.0-3ubuntu1~18.04 |  | <details><summary>Expand...</summary><a href="http://lists.llvm.org/pipermail/llvm-dev/2020-June/142109.html">http://lists.llvm.org/pipermail/llvm-dev/2020-June/142109.html</a><br><a href="http://lists.opensuse.org/opensuse-security-announce/2020-10/msg00039.html">http://lists.opensuse.org/opensuse-security-announce/2020-10/msg00039.html</a><br><a href="http://lists.opensuse.org/opensuse-security-announce/2020-10/msg00040.html">http://lists.opensuse.org/opensuse-security-announce/2020-10/msg00040.html</a><br><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2020-13844">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2020-13844</a><br><a href="https://developer.arm.com/support/arm-security-updates/speculative-processor-vulnerability">https://developer.arm.com/support/arm-security-updates/speculative-processor-vulnerability</a><br><a href="https://developer.arm.com/support/arm-security-updates/speculative-processor-vulnerability/downloads/straight-line-speculation">https://developer.arm.com/support/arm-security-updates/speculative-processor-vulnerability/downloads/straight-line-speculation</a><br><a href="https://developer.arm.com/support/arm-security-updates/speculative-processor-vulnerability/frequently-asked-questions">https://developer.arm.com/support/arm-security-updates/speculative-processor-vulnerability/frequently-asked-questions</a><br><a href="https://gcc.gnu.org/pipermail/gcc-patches/2020-June/547520.html">https://gcc.gnu.org/pipermail/gcc-patches/2020-June/547520.html</a><br><a href="https://git.kernel.org/pub/scm/linux/kernel/git/torvalds/linux.git/commit/?id=679db70801da9fda91d26caf13bf5b5ccc74e8e8">https://git.kernel.org/pub/scm/linux/kernel/git/torvalds/linux.git/commit/?id=679db70801da9fda91d26caf13bf5b5ccc74e8e8</a><br></details>  |
| gcc         |    CVE-2020-13844   |   MEDIUM  |  1.176ubuntu2.3 |  | <details><summary>Expand...</summary><a href="http://lists.llvm.org/pipermail/llvm-dev/2020-June/142109.html">http://lists.llvm.org/pipermail/llvm-dev/2020-June/142109.html</a><br><a href="http://lists.opensuse.org/opensuse-security-announce/2020-10/msg00039.html">http://lists.opensuse.org/opensuse-security-announce/2020-10/msg00039.html</a><br><a href="http://lists.opensuse.org/opensuse-security-announce/2020-10/msg00040.html">http://lists.opensuse.org/opensuse-security-announce/2020-10/msg00040.html</a><br><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2020-13844">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2020-13844</a><br><a href="https://developer.arm.com/support/arm-security-updates/speculative-processor-vulnerability">https://developer.arm.com/support/arm-security-updates/speculative-processor-vulnerability</a><br><a href="https://developer.arm.com/support/arm-security-updates/speculative-processor-vulnerability/downloads/straight-line-speculation">https://developer.arm.com/support/arm-security-updates/speculative-processor-vulnerability/downloads/straight-line-speculation</a><br><a href="https://developer.arm.com/support/arm-security-updates/speculative-processor-vulnerability/frequently-asked-questions">https://developer.arm.com/support/arm-security-updates/speculative-processor-vulnerability/frequently-asked-questions</a><br><a href="https://gcc.gnu.org/pipermail/gcc-patches/2020-June/547520.html">https://gcc.gnu.org/pipermail/gcc-patches/2020-June/547520.html</a><br><a href="https://git.kernel.org/pub/scm/linux/kernel/git/torvalds/linux.git/commit/?id=679db70801da9fda91d26caf13bf5b5ccc74e8e8">https://git.kernel.org/pub/scm/linux/kernel/git/torvalds/linux.git/commit/?id=679db70801da9fda91d26caf13bf5b5ccc74e8e8</a><br></details>  |
| gcc-7         |    CVE-2020-13844   |   MEDIUM  |  7.5.0-3ubuntu1~18.04 |  | <details><summary>Expand...</summary><a href="http://lists.llvm.org/pipermail/llvm-dev/2020-June/142109.html">http://lists.llvm.org/pipermail/llvm-dev/2020-June/142109.html</a><br><a href="http://lists.opensuse.org/opensuse-security-announce/2020-10/msg00039.html">http://lists.opensuse.org/opensuse-security-announce/2020-10/msg00039.html</a><br><a href="http://lists.opensuse.org/opensuse-security-announce/2020-10/msg00040.html">http://lists.opensuse.org/opensuse-security-announce/2020-10/msg00040.html</a><br><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2020-13844">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2020-13844</a><br><a href="https://developer.arm.com/support/arm-security-updates/speculative-processor-vulnerability">https://developer.arm.com/support/arm-security-updates/speculative-processor-vulnerability</a><br><a href="https://developer.arm.com/support/arm-security-updates/speculative-processor-vulnerability/downloads/straight-line-speculation">https://developer.arm.com/support/arm-security-updates/speculative-processor-vulnerability/downloads/straight-line-speculation</a><br><a href="https://developer.arm.com/support/arm-security-updates/speculative-processor-vulnerability/frequently-asked-questions">https://developer.arm.com/support/arm-security-updates/speculative-processor-vulnerability/frequently-asked-questions</a><br><a href="https://gcc.gnu.org/pipermail/gcc-patches/2020-June/547520.html">https://gcc.gnu.org/pipermail/gcc-patches/2020-June/547520.html</a><br><a href="https://git.kernel.org/pub/scm/linux/kernel/git/torvalds/linux.git/commit/?id=679db70801da9fda91d26caf13bf5b5ccc74e8e8">https://git.kernel.org/pub/scm/linux/kernel/git/torvalds/linux.git/commit/?id=679db70801da9fda91d26caf13bf5b5ccc74e8e8</a><br></details>  |
| gcc-7-base         |    CVE-2020-13844   |   MEDIUM  |  7.5.0-3ubuntu1~18.04 |  | <details><summary>Expand...</summary><a href="http://lists.llvm.org/pipermail/llvm-dev/2020-June/142109.html">http://lists.llvm.org/pipermail/llvm-dev/2020-June/142109.html</a><br><a href="http://lists.opensuse.org/opensuse-security-announce/2020-10/msg00039.html">http://lists.opensuse.org/opensuse-security-announce/2020-10/msg00039.html</a><br><a href="http://lists.opensuse.org/opensuse-security-announce/2020-10/msg00040.html">http://lists.opensuse.org/opensuse-security-announce/2020-10/msg00040.html</a><br><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2020-13844">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2020-13844</a><br><a href="https://developer.arm.com/support/arm-security-updates/speculative-processor-vulnerability">https://developer.arm.com/support/arm-security-updates/speculative-processor-vulnerability</a><br><a href="https://developer.arm.com/support/arm-security-updates/speculative-processor-vulnerability/downloads/straight-line-speculation">https://developer.arm.com/support/arm-security-updates/speculative-processor-vulnerability/downloads/straight-line-speculation</a><br><a href="https://developer.arm.com/support/arm-security-updates/speculative-processor-vulnerability/frequently-asked-questions">https://developer.arm.com/support/arm-security-updates/speculative-processor-vulnerability/frequently-asked-questions</a><br><a href="https://gcc.gnu.org/pipermail/gcc-patches/2020-June/547520.html">https://gcc.gnu.org/pipermail/gcc-patches/2020-June/547520.html</a><br><a href="https://git.kernel.org/pub/scm/linux/kernel/git/torvalds/linux.git/commit/?id=679db70801da9fda91d26caf13bf5b5ccc74e8e8">https://git.kernel.org/pub/scm/linux/kernel/git/torvalds/linux.git/commit/?id=679db70801da9fda91d26caf13bf5b5ccc74e8e8</a><br></details>  |
| gcc-8-base         |    CVE-2020-13844   |   MEDIUM  |  8.4.0-1ubuntu1~18.04 |  | <details><summary>Expand...</summary><a href="http://lists.llvm.org/pipermail/llvm-dev/2020-June/142109.html">http://lists.llvm.org/pipermail/llvm-dev/2020-June/142109.html</a><br><a href="http://lists.opensuse.org/opensuse-security-announce/2020-10/msg00039.html">http://lists.opensuse.org/opensuse-security-announce/2020-10/msg00039.html</a><br><a href="http://lists.opensuse.org/opensuse-security-announce/2020-10/msg00040.html">http://lists.opensuse.org/opensuse-security-announce/2020-10/msg00040.html</a><br><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2020-13844">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2020-13844</a><br><a href="https://developer.arm.com/support/arm-security-updates/speculative-processor-vulnerability">https://developer.arm.com/support/arm-security-updates/speculative-processor-vulnerability</a><br><a href="https://developer.arm.com/support/arm-security-updates/speculative-processor-vulnerability/downloads/straight-line-speculation">https://developer.arm.com/support/arm-security-updates/speculative-processor-vulnerability/downloads/straight-line-speculation</a><br><a href="https://developer.arm.com/support/arm-security-updates/speculative-processor-vulnerability/frequently-asked-questions">https://developer.arm.com/support/arm-security-updates/speculative-processor-vulnerability/frequently-asked-questions</a><br><a href="https://gcc.gnu.org/pipermail/gcc-patches/2020-June/547520.html">https://gcc.gnu.org/pipermail/gcc-patches/2020-June/547520.html</a><br><a href="https://git.kernel.org/pub/scm/linux/kernel/git/torvalds/linux.git/commit/?id=679db70801da9fda91d26caf13bf5b5ccc74e8e8">https://git.kernel.org/pub/scm/linux/kernel/git/torvalds/linux.git/commit/?id=679db70801da9fda91d26caf13bf5b5ccc74e8e8</a><br></details>  |
| gnupg         |    CVE-2019-13050   |   LOW  |  2.2.4-1ubuntu1.4 |  | <details><summary>Expand...</summary><a href="http://lists.opensuse.org/opensuse-security-announce/2019-08/msg00039.html">http://lists.opensuse.org/opensuse-security-announce/2019-08/msg00039.html</a><br><a href="https://access.redhat.com/articles/4264021">https://access.redhat.com/articles/4264021</a><br><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2019-13050">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2019-13050</a><br><a href="https://gist.github.com/rjhansen/67ab921ffb4084c865b3618d6955275f">https://gist.github.com/rjhansen/67ab921ffb4084c865b3618d6955275f</a><br><a href="https://linux.oracle.com/cve/CVE-2019-13050.html">https://linux.oracle.com/cve/CVE-2019-13050.html</a><br><a href="https://linux.oracle.com/errata/ELSA-2020-4490.html">https://linux.oracle.com/errata/ELSA-2020-4490.html</a><br><a href="https://lists.apache.org/thread.html/r58af02e294bd07f487e2c64ffc0a29b837db5600e33b6e698b9d696b@%3Cissues.bookkeeper.apache.org%3E">https://lists.apache.org/thread.html/r58af02e294bd07f487e2c64ffc0a29b837db5600e33b6e698b9d696b@%3Cissues.bookkeeper.apache.org%3E</a><br><a href="https://lists.apache.org/thread.html/rf4c02775860db415b4955778a131c2795223f61cb8c6a450893651e4@%3Cissues.bookkeeper.apache.org%3E">https://lists.apache.org/thread.html/rf4c02775860db415b4955778a131c2795223f61cb8c6a450893651e4@%3Cissues.bookkeeper.apache.org%3E</a><br><a href="https://lists.apache.org/thread.html/rf9fa47ab66495c78bb4120b0754dd9531ca2ff0430f6685ac9b07772@%3Cdev.mina.apache.org%3E">https://lists.apache.org/thread.html/rf9fa47ab66495c78bb4120b0754dd9531ca2ff0430f6685ac9b07772@%3Cdev.mina.apache.org%3E</a><br><a href="https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/AUK2YRO6QIH64WP2LRA5D4LACTXQPPU4/">https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/AUK2YRO6QIH64WP2LRA5D4LACTXQPPU4/</a><br><a href="https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/CP4ON34YEXEZDZOXXWV43KVGGO6WZLJ5/">https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/CP4ON34YEXEZDZOXXWV43KVGGO6WZLJ5/</a><br><a href="https://lists.gnupg.org/pipermail/gnupg-announce/2019q3/000439.html">https://lists.gnupg.org/pipermail/gnupg-announce/2019q3/000439.html</a><br><a href="https://support.f5.com/csp/article/K08654551">https://support.f5.com/csp/article/K08654551</a><br><a href="https://support.f5.com/csp/article/K08654551?utm_source=f5support&amp;amp;utm_medium=RSS">https://support.f5.com/csp/article/K08654551?utm_source=f5support&amp;amp;utm_medium=RSS</a><br><a href="https://twitter.com/lambdafu/status/1147162583969009664">https://twitter.com/lambdafu/status/1147162583969009664</a><br></details>  |
| gnupg-l10n         |    CVE-2019-13050   |   LOW  |  2.2.4-1ubuntu1.4 |  | <details><summary>Expand...</summary><a href="http://lists.opensuse.org/opensuse-security-announce/2019-08/msg00039.html">http://lists.opensuse.org/opensuse-security-announce/2019-08/msg00039.html</a><br><a href="https://access.redhat.com/articles/4264021">https://access.redhat.com/articles/4264021</a><br><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2019-13050">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2019-13050</a><br><a href="https://gist.github.com/rjhansen/67ab921ffb4084c865b3618d6955275f">https://gist.github.com/rjhansen/67ab921ffb4084c865b3618d6955275f</a><br><a href="https://linux.oracle.com/cve/CVE-2019-13050.html">https://linux.oracle.com/cve/CVE-2019-13050.html</a><br><a href="https://linux.oracle.com/errata/ELSA-2020-4490.html">https://linux.oracle.com/errata/ELSA-2020-4490.html</a><br><a href="https://lists.apache.org/thread.html/r58af02e294bd07f487e2c64ffc0a29b837db5600e33b6e698b9d696b@%3Cissues.bookkeeper.apache.org%3E">https://lists.apache.org/thread.html/r58af02e294bd07f487e2c64ffc0a29b837db5600e33b6e698b9d696b@%3Cissues.bookkeeper.apache.org%3E</a><br><a href="https://lists.apache.org/thread.html/rf4c02775860db415b4955778a131c2795223f61cb8c6a450893651e4@%3Cissues.bookkeeper.apache.org%3E">https://lists.apache.org/thread.html/rf4c02775860db415b4955778a131c2795223f61cb8c6a450893651e4@%3Cissues.bookkeeper.apache.org%3E</a><br><a href="https://lists.apache.org/thread.html/rf9fa47ab66495c78bb4120b0754dd9531ca2ff0430f6685ac9b07772@%3Cdev.mina.apache.org%3E">https://lists.apache.org/thread.html/rf9fa47ab66495c78bb4120b0754dd9531ca2ff0430f6685ac9b07772@%3Cdev.mina.apache.org%3E</a><br><a href="https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/AUK2YRO6QIH64WP2LRA5D4LACTXQPPU4/">https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/AUK2YRO6QIH64WP2LRA5D4LACTXQPPU4/</a><br><a href="https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/CP4ON34YEXEZDZOXXWV43KVGGO6WZLJ5/">https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/CP4ON34YEXEZDZOXXWV43KVGGO6WZLJ5/</a><br><a href="https://lists.gnupg.org/pipermail/gnupg-announce/2019q3/000439.html">https://lists.gnupg.org/pipermail/gnupg-announce/2019q3/000439.html</a><br><a href="https://support.f5.com/csp/article/K08654551">https://support.f5.com/csp/article/K08654551</a><br><a href="https://support.f5.com/csp/article/K08654551?utm_source=f5support&amp;amp;utm_medium=RSS">https://support.f5.com/csp/article/K08654551?utm_source=f5support&amp;amp;utm_medium=RSS</a><br><a href="https://twitter.com/lambdafu/status/1147162583969009664">https://twitter.com/lambdafu/status/1147162583969009664</a><br></details>  |
| gnupg-utils         |    CVE-2019-13050   |   LOW  |  2.2.4-1ubuntu1.4 |  | <details><summary>Expand...</summary><a href="http://lists.opensuse.org/opensuse-security-announce/2019-08/msg00039.html">http://lists.opensuse.org/opensuse-security-announce/2019-08/msg00039.html</a><br><a href="https://access.redhat.com/articles/4264021">https://access.redhat.com/articles/4264021</a><br><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2019-13050">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2019-13050</a><br><a href="https://gist.github.com/rjhansen/67ab921ffb4084c865b3618d6955275f">https://gist.github.com/rjhansen/67ab921ffb4084c865b3618d6955275f</a><br><a href="https://linux.oracle.com/cve/CVE-2019-13050.html">https://linux.oracle.com/cve/CVE-2019-13050.html</a><br><a href="https://linux.oracle.com/errata/ELSA-2020-4490.html">https://linux.oracle.com/errata/ELSA-2020-4490.html</a><br><a href="https://lists.apache.org/thread.html/r58af02e294bd07f487e2c64ffc0a29b837db5600e33b6e698b9d696b@%3Cissues.bookkeeper.apache.org%3E">https://lists.apache.org/thread.html/r58af02e294bd07f487e2c64ffc0a29b837db5600e33b6e698b9d696b@%3Cissues.bookkeeper.apache.org%3E</a><br><a href="https://lists.apache.org/thread.html/rf4c02775860db415b4955778a131c2795223f61cb8c6a450893651e4@%3Cissues.bookkeeper.apache.org%3E">https://lists.apache.org/thread.html/rf4c02775860db415b4955778a131c2795223f61cb8c6a450893651e4@%3Cissues.bookkeeper.apache.org%3E</a><br><a href="https://lists.apache.org/thread.html/rf9fa47ab66495c78bb4120b0754dd9531ca2ff0430f6685ac9b07772@%3Cdev.mina.apache.org%3E">https://lists.apache.org/thread.html/rf9fa47ab66495c78bb4120b0754dd9531ca2ff0430f6685ac9b07772@%3Cdev.mina.apache.org%3E</a><br><a href="https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/AUK2YRO6QIH64WP2LRA5D4LACTXQPPU4/">https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/AUK2YRO6QIH64WP2LRA5D4LACTXQPPU4/</a><br><a href="https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/CP4ON34YEXEZDZOXXWV43KVGGO6WZLJ5/">https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/CP4ON34YEXEZDZOXXWV43KVGGO6WZLJ5/</a><br><a href="https://lists.gnupg.org/pipermail/gnupg-announce/2019q3/000439.html">https://lists.gnupg.org/pipermail/gnupg-announce/2019q3/000439.html</a><br><a href="https://support.f5.com/csp/article/K08654551">https://support.f5.com/csp/article/K08654551</a><br><a href="https://support.f5.com/csp/article/K08654551?utm_source=f5support&amp;amp;utm_medium=RSS">https://support.f5.com/csp/article/K08654551?utm_source=f5support&amp;amp;utm_medium=RSS</a><br><a href="https://twitter.com/lambdafu/status/1147162583969009664">https://twitter.com/lambdafu/status/1147162583969009664</a><br></details>  |
| gpg         |    CVE-2019-13050   |   LOW  |  2.2.4-1ubuntu1.4 |  | <details><summary>Expand...</summary><a href="http://lists.opensuse.org/opensuse-security-announce/2019-08/msg00039.html">http://lists.opensuse.org/opensuse-security-announce/2019-08/msg00039.html</a><br><a href="https://access.redhat.com/articles/4264021">https://access.redhat.com/articles/4264021</a><br><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2019-13050">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2019-13050</a><br><a href="https://gist.github.com/rjhansen/67ab921ffb4084c865b3618d6955275f">https://gist.github.com/rjhansen/67ab921ffb4084c865b3618d6955275f</a><br><a href="https://linux.oracle.com/cve/CVE-2019-13050.html">https://linux.oracle.com/cve/CVE-2019-13050.html</a><br><a href="https://linux.oracle.com/errata/ELSA-2020-4490.html">https://linux.oracle.com/errata/ELSA-2020-4490.html</a><br><a href="https://lists.apache.org/thread.html/r58af02e294bd07f487e2c64ffc0a29b837db5600e33b6e698b9d696b@%3Cissues.bookkeeper.apache.org%3E">https://lists.apache.org/thread.html/r58af02e294bd07f487e2c64ffc0a29b837db5600e33b6e698b9d696b@%3Cissues.bookkeeper.apache.org%3E</a><br><a href="https://lists.apache.org/thread.html/rf4c02775860db415b4955778a131c2795223f61cb8c6a450893651e4@%3Cissues.bookkeeper.apache.org%3E">https://lists.apache.org/thread.html/rf4c02775860db415b4955778a131c2795223f61cb8c6a450893651e4@%3Cissues.bookkeeper.apache.org%3E</a><br><a href="https://lists.apache.org/thread.html/rf9fa47ab66495c78bb4120b0754dd9531ca2ff0430f6685ac9b07772@%3Cdev.mina.apache.org%3E">https://lists.apache.org/thread.html/rf9fa47ab66495c78bb4120b0754dd9531ca2ff0430f6685ac9b07772@%3Cdev.mina.apache.org%3E</a><br><a href="https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/AUK2YRO6QIH64WP2LRA5D4LACTXQPPU4/">https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/AUK2YRO6QIH64WP2LRA5D4LACTXQPPU4/</a><br><a href="https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/CP4ON34YEXEZDZOXXWV43KVGGO6WZLJ5/">https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/CP4ON34YEXEZDZOXXWV43KVGGO6WZLJ5/</a><br><a href="https://lists.gnupg.org/pipermail/gnupg-announce/2019q3/000439.html">https://lists.gnupg.org/pipermail/gnupg-announce/2019q3/000439.html</a><br><a href="https://support.f5.com/csp/article/K08654551">https://support.f5.com/csp/article/K08654551</a><br><a href="https://support.f5.com/csp/article/K08654551?utm_source=f5support&amp;amp;utm_medium=RSS">https://support.f5.com/csp/article/K08654551?utm_source=f5support&amp;amp;utm_medium=RSS</a><br><a href="https://twitter.com/lambdafu/status/1147162583969009664">https://twitter.com/lambdafu/status/1147162583969009664</a><br></details>  |
| gpg-agent         |    CVE-2019-13050   |   LOW  |  2.2.4-1ubuntu1.4 |  | <details><summary>Expand...</summary><a href="http://lists.opensuse.org/opensuse-security-announce/2019-08/msg00039.html">http://lists.opensuse.org/opensuse-security-announce/2019-08/msg00039.html</a><br><a href="https://access.redhat.com/articles/4264021">https://access.redhat.com/articles/4264021</a><br><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2019-13050">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2019-13050</a><br><a href="https://gist.github.com/rjhansen/67ab921ffb4084c865b3618d6955275f">https://gist.github.com/rjhansen/67ab921ffb4084c865b3618d6955275f</a><br><a href="https://linux.oracle.com/cve/CVE-2019-13050.html">https://linux.oracle.com/cve/CVE-2019-13050.html</a><br><a href="https://linux.oracle.com/errata/ELSA-2020-4490.html">https://linux.oracle.com/errata/ELSA-2020-4490.html</a><br><a href="https://lists.apache.org/thread.html/r58af02e294bd07f487e2c64ffc0a29b837db5600e33b6e698b9d696b@%3Cissues.bookkeeper.apache.org%3E">https://lists.apache.org/thread.html/r58af02e294bd07f487e2c64ffc0a29b837db5600e33b6e698b9d696b@%3Cissues.bookkeeper.apache.org%3E</a><br><a href="https://lists.apache.org/thread.html/rf4c02775860db415b4955778a131c2795223f61cb8c6a450893651e4@%3Cissues.bookkeeper.apache.org%3E">https://lists.apache.org/thread.html/rf4c02775860db415b4955778a131c2795223f61cb8c6a450893651e4@%3Cissues.bookkeeper.apache.org%3E</a><br><a href="https://lists.apache.org/thread.html/rf9fa47ab66495c78bb4120b0754dd9531ca2ff0430f6685ac9b07772@%3Cdev.mina.apache.org%3E">https://lists.apache.org/thread.html/rf9fa47ab66495c78bb4120b0754dd9531ca2ff0430f6685ac9b07772@%3Cdev.mina.apache.org%3E</a><br><a href="https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/AUK2YRO6QIH64WP2LRA5D4LACTXQPPU4/">https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/AUK2YRO6QIH64WP2LRA5D4LACTXQPPU4/</a><br><a href="https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/CP4ON34YEXEZDZOXXWV43KVGGO6WZLJ5/">https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/CP4ON34YEXEZDZOXXWV43KVGGO6WZLJ5/</a><br><a href="https://lists.gnupg.org/pipermail/gnupg-announce/2019q3/000439.html">https://lists.gnupg.org/pipermail/gnupg-announce/2019q3/000439.html</a><br><a href="https://support.f5.com/csp/article/K08654551">https://support.f5.com/csp/article/K08654551</a><br><a href="https://support.f5.com/csp/article/K08654551?utm_source=f5support&amp;amp;utm_medium=RSS">https://support.f5.com/csp/article/K08654551?utm_source=f5support&amp;amp;utm_medium=RSS</a><br><a href="https://twitter.com/lambdafu/status/1147162583969009664">https://twitter.com/lambdafu/status/1147162583969009664</a><br></details>  |
| gpg-wks-client         |    CVE-2019-13050   |   LOW  |  2.2.4-1ubuntu1.4 |  | <details><summary>Expand...</summary><a href="http://lists.opensuse.org/opensuse-security-announce/2019-08/msg00039.html">http://lists.opensuse.org/opensuse-security-announce/2019-08/msg00039.html</a><br><a href="https://access.redhat.com/articles/4264021">https://access.redhat.com/articles/4264021</a><br><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2019-13050">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2019-13050</a><br><a href="https://gist.github.com/rjhansen/67ab921ffb4084c865b3618d6955275f">https://gist.github.com/rjhansen/67ab921ffb4084c865b3618d6955275f</a><br><a href="https://linux.oracle.com/cve/CVE-2019-13050.html">https://linux.oracle.com/cve/CVE-2019-13050.html</a><br><a href="https://linux.oracle.com/errata/ELSA-2020-4490.html">https://linux.oracle.com/errata/ELSA-2020-4490.html</a><br><a href="https://lists.apache.org/thread.html/r58af02e294bd07f487e2c64ffc0a29b837db5600e33b6e698b9d696b@%3Cissues.bookkeeper.apache.org%3E">https://lists.apache.org/thread.html/r58af02e294bd07f487e2c64ffc0a29b837db5600e33b6e698b9d696b@%3Cissues.bookkeeper.apache.org%3E</a><br><a href="https://lists.apache.org/thread.html/rf4c02775860db415b4955778a131c2795223f61cb8c6a450893651e4@%3Cissues.bookkeeper.apache.org%3E">https://lists.apache.org/thread.html/rf4c02775860db415b4955778a131c2795223f61cb8c6a450893651e4@%3Cissues.bookkeeper.apache.org%3E</a><br><a href="https://lists.apache.org/thread.html/rf9fa47ab66495c78bb4120b0754dd9531ca2ff0430f6685ac9b07772@%3Cdev.mina.apache.org%3E">https://lists.apache.org/thread.html/rf9fa47ab66495c78bb4120b0754dd9531ca2ff0430f6685ac9b07772@%3Cdev.mina.apache.org%3E</a><br><a href="https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/AUK2YRO6QIH64WP2LRA5D4LACTXQPPU4/">https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/AUK2YRO6QIH64WP2LRA5D4LACTXQPPU4/</a><br><a href="https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/CP4ON34YEXEZDZOXXWV43KVGGO6WZLJ5/">https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/CP4ON34YEXEZDZOXXWV43KVGGO6WZLJ5/</a><br><a href="https://lists.gnupg.org/pipermail/gnupg-announce/2019q3/000439.html">https://lists.gnupg.org/pipermail/gnupg-announce/2019q3/000439.html</a><br><a href="https://support.f5.com/csp/article/K08654551">https://support.f5.com/csp/article/K08654551</a><br><a href="https://support.f5.com/csp/article/K08654551?utm_source=f5support&amp;amp;utm_medium=RSS">https://support.f5.com/csp/article/K08654551?utm_source=f5support&amp;amp;utm_medium=RSS</a><br><a href="https://twitter.com/lambdafu/status/1147162583969009664">https://twitter.com/lambdafu/status/1147162583969009664</a><br></details>  |
| gpg-wks-server         |    CVE-2019-13050   |   LOW  |  2.2.4-1ubuntu1.4 |  | <details><summary>Expand...</summary><a href="http://lists.opensuse.org/opensuse-security-announce/2019-08/msg00039.html">http://lists.opensuse.org/opensuse-security-announce/2019-08/msg00039.html</a><br><a href="https://access.redhat.com/articles/4264021">https://access.redhat.com/articles/4264021</a><br><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2019-13050">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2019-13050</a><br><a href="https://gist.github.com/rjhansen/67ab921ffb4084c865b3618d6955275f">https://gist.github.com/rjhansen/67ab921ffb4084c865b3618d6955275f</a><br><a href="https://linux.oracle.com/cve/CVE-2019-13050.html">https://linux.oracle.com/cve/CVE-2019-13050.html</a><br><a href="https://linux.oracle.com/errata/ELSA-2020-4490.html">https://linux.oracle.com/errata/ELSA-2020-4490.html</a><br><a href="https://lists.apache.org/thread.html/r58af02e294bd07f487e2c64ffc0a29b837db5600e33b6e698b9d696b@%3Cissues.bookkeeper.apache.org%3E">https://lists.apache.org/thread.html/r58af02e294bd07f487e2c64ffc0a29b837db5600e33b6e698b9d696b@%3Cissues.bookkeeper.apache.org%3E</a><br><a href="https://lists.apache.org/thread.html/rf4c02775860db415b4955778a131c2795223f61cb8c6a450893651e4@%3Cissues.bookkeeper.apache.org%3E">https://lists.apache.org/thread.html/rf4c02775860db415b4955778a131c2795223f61cb8c6a450893651e4@%3Cissues.bookkeeper.apache.org%3E</a><br><a href="https://lists.apache.org/thread.html/rf9fa47ab66495c78bb4120b0754dd9531ca2ff0430f6685ac9b07772@%3Cdev.mina.apache.org%3E">https://lists.apache.org/thread.html/rf9fa47ab66495c78bb4120b0754dd9531ca2ff0430f6685ac9b07772@%3Cdev.mina.apache.org%3E</a><br><a href="https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/AUK2YRO6QIH64WP2LRA5D4LACTXQPPU4/">https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/AUK2YRO6QIH64WP2LRA5D4LACTXQPPU4/</a><br><a href="https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/CP4ON34YEXEZDZOXXWV43KVGGO6WZLJ5/">https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/CP4ON34YEXEZDZOXXWV43KVGGO6WZLJ5/</a><br><a href="https://lists.gnupg.org/pipermail/gnupg-announce/2019q3/000439.html">https://lists.gnupg.org/pipermail/gnupg-announce/2019q3/000439.html</a><br><a href="https://support.f5.com/csp/article/K08654551">https://support.f5.com/csp/article/K08654551</a><br><a href="https://support.f5.com/csp/article/K08654551?utm_source=f5support&amp;amp;utm_medium=RSS">https://support.f5.com/csp/article/K08654551?utm_source=f5support&amp;amp;utm_medium=RSS</a><br><a href="https://twitter.com/lambdafu/status/1147162583969009664">https://twitter.com/lambdafu/status/1147162583969009664</a><br></details>  |
| gpgconf         |    CVE-2019-13050   |   LOW  |  2.2.4-1ubuntu1.4 |  | <details><summary>Expand...</summary><a href="http://lists.opensuse.org/opensuse-security-announce/2019-08/msg00039.html">http://lists.opensuse.org/opensuse-security-announce/2019-08/msg00039.html</a><br><a href="https://access.redhat.com/articles/4264021">https://access.redhat.com/articles/4264021</a><br><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2019-13050">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2019-13050</a><br><a href="https://gist.github.com/rjhansen/67ab921ffb4084c865b3618d6955275f">https://gist.github.com/rjhansen/67ab921ffb4084c865b3618d6955275f</a><br><a href="https://linux.oracle.com/cve/CVE-2019-13050.html">https://linux.oracle.com/cve/CVE-2019-13050.html</a><br><a href="https://linux.oracle.com/errata/ELSA-2020-4490.html">https://linux.oracle.com/errata/ELSA-2020-4490.html</a><br><a href="https://lists.apache.org/thread.html/r58af02e294bd07f487e2c64ffc0a29b837db5600e33b6e698b9d696b@%3Cissues.bookkeeper.apache.org%3E">https://lists.apache.org/thread.html/r58af02e294bd07f487e2c64ffc0a29b837db5600e33b6e698b9d696b@%3Cissues.bookkeeper.apache.org%3E</a><br><a href="https://lists.apache.org/thread.html/rf4c02775860db415b4955778a131c2795223f61cb8c6a450893651e4@%3Cissues.bookkeeper.apache.org%3E">https://lists.apache.org/thread.html/rf4c02775860db415b4955778a131c2795223f61cb8c6a450893651e4@%3Cissues.bookkeeper.apache.org%3E</a><br><a href="https://lists.apache.org/thread.html/rf9fa47ab66495c78bb4120b0754dd9531ca2ff0430f6685ac9b07772@%3Cdev.mina.apache.org%3E">https://lists.apache.org/thread.html/rf9fa47ab66495c78bb4120b0754dd9531ca2ff0430f6685ac9b07772@%3Cdev.mina.apache.org%3E</a><br><a href="https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/AUK2YRO6QIH64WP2LRA5D4LACTXQPPU4/">https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/AUK2YRO6QIH64WP2LRA5D4LACTXQPPU4/</a><br><a href="https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/CP4ON34YEXEZDZOXXWV43KVGGO6WZLJ5/">https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/CP4ON34YEXEZDZOXXWV43KVGGO6WZLJ5/</a><br><a href="https://lists.gnupg.org/pipermail/gnupg-announce/2019q3/000439.html">https://lists.gnupg.org/pipermail/gnupg-announce/2019q3/000439.html</a><br><a href="https://support.f5.com/csp/article/K08654551">https://support.f5.com/csp/article/K08654551</a><br><a href="https://support.f5.com/csp/article/K08654551?utm_source=f5support&amp;amp;utm_medium=RSS">https://support.f5.com/csp/article/K08654551?utm_source=f5support&amp;amp;utm_medium=RSS</a><br><a href="https://twitter.com/lambdafu/status/1147162583969009664">https://twitter.com/lambdafu/status/1147162583969009664</a><br></details>  |
| gpgsm         |    CVE-2019-13050   |   LOW  |  2.2.4-1ubuntu1.4 |  | <details><summary>Expand...</summary><a href="http://lists.opensuse.org/opensuse-security-announce/2019-08/msg00039.html">http://lists.opensuse.org/opensuse-security-announce/2019-08/msg00039.html</a><br><a href="https://access.redhat.com/articles/4264021">https://access.redhat.com/articles/4264021</a><br><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2019-13050">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2019-13050</a><br><a href="https://gist.github.com/rjhansen/67ab921ffb4084c865b3618d6955275f">https://gist.github.com/rjhansen/67ab921ffb4084c865b3618d6955275f</a><br><a href="https://linux.oracle.com/cve/CVE-2019-13050.html">https://linux.oracle.com/cve/CVE-2019-13050.html</a><br><a href="https://linux.oracle.com/errata/ELSA-2020-4490.html">https://linux.oracle.com/errata/ELSA-2020-4490.html</a><br><a href="https://lists.apache.org/thread.html/r58af02e294bd07f487e2c64ffc0a29b837db5600e33b6e698b9d696b@%3Cissues.bookkeeper.apache.org%3E">https://lists.apache.org/thread.html/r58af02e294bd07f487e2c64ffc0a29b837db5600e33b6e698b9d696b@%3Cissues.bookkeeper.apache.org%3E</a><br><a href="https://lists.apache.org/thread.html/rf4c02775860db415b4955778a131c2795223f61cb8c6a450893651e4@%3Cissues.bookkeeper.apache.org%3E">https://lists.apache.org/thread.html/rf4c02775860db415b4955778a131c2795223f61cb8c6a450893651e4@%3Cissues.bookkeeper.apache.org%3E</a><br><a href="https://lists.apache.org/thread.html/rf9fa47ab66495c78bb4120b0754dd9531ca2ff0430f6685ac9b07772@%3Cdev.mina.apache.org%3E">https://lists.apache.org/thread.html/rf9fa47ab66495c78bb4120b0754dd9531ca2ff0430f6685ac9b07772@%3Cdev.mina.apache.org%3E</a><br><a href="https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/AUK2YRO6QIH64WP2LRA5D4LACTXQPPU4/">https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/AUK2YRO6QIH64WP2LRA5D4LACTXQPPU4/</a><br><a href="https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/CP4ON34YEXEZDZOXXWV43KVGGO6WZLJ5/">https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/CP4ON34YEXEZDZOXXWV43KVGGO6WZLJ5/</a><br><a href="https://lists.gnupg.org/pipermail/gnupg-announce/2019q3/000439.html">https://lists.gnupg.org/pipermail/gnupg-announce/2019q3/000439.html</a><br><a href="https://support.f5.com/csp/article/K08654551">https://support.f5.com/csp/article/K08654551</a><br><a href="https://support.f5.com/csp/article/K08654551?utm_source=f5support&amp;amp;utm_medium=RSS">https://support.f5.com/csp/article/K08654551?utm_source=f5support&amp;amp;utm_medium=RSS</a><br><a href="https://twitter.com/lambdafu/status/1147162583969009664">https://twitter.com/lambdafu/status/1147162583969009664</a><br></details>  |
| gpgv         |    CVE-2019-13050   |   LOW  |  2.2.4-1ubuntu1.4 |  | <details><summary>Expand...</summary><a href="http://lists.opensuse.org/opensuse-security-announce/2019-08/msg00039.html">http://lists.opensuse.org/opensuse-security-announce/2019-08/msg00039.html</a><br><a href="https://access.redhat.com/articles/4264021">https://access.redhat.com/articles/4264021</a><br><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2019-13050">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2019-13050</a><br><a href="https://gist.github.com/rjhansen/67ab921ffb4084c865b3618d6955275f">https://gist.github.com/rjhansen/67ab921ffb4084c865b3618d6955275f</a><br><a href="https://linux.oracle.com/cve/CVE-2019-13050.html">https://linux.oracle.com/cve/CVE-2019-13050.html</a><br><a href="https://linux.oracle.com/errata/ELSA-2020-4490.html">https://linux.oracle.com/errata/ELSA-2020-4490.html</a><br><a href="https://lists.apache.org/thread.html/r58af02e294bd07f487e2c64ffc0a29b837db5600e33b6e698b9d696b@%3Cissues.bookkeeper.apache.org%3E">https://lists.apache.org/thread.html/r58af02e294bd07f487e2c64ffc0a29b837db5600e33b6e698b9d696b@%3Cissues.bookkeeper.apache.org%3E</a><br><a href="https://lists.apache.org/thread.html/rf4c02775860db415b4955778a131c2795223f61cb8c6a450893651e4@%3Cissues.bookkeeper.apache.org%3E">https://lists.apache.org/thread.html/rf4c02775860db415b4955778a131c2795223f61cb8c6a450893651e4@%3Cissues.bookkeeper.apache.org%3E</a><br><a href="https://lists.apache.org/thread.html/rf9fa47ab66495c78bb4120b0754dd9531ca2ff0430f6685ac9b07772@%3Cdev.mina.apache.org%3E">https://lists.apache.org/thread.html/rf9fa47ab66495c78bb4120b0754dd9531ca2ff0430f6685ac9b07772@%3Cdev.mina.apache.org%3E</a><br><a href="https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/AUK2YRO6QIH64WP2LRA5D4LACTXQPPU4/">https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/AUK2YRO6QIH64WP2LRA5D4LACTXQPPU4/</a><br><a href="https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/CP4ON34YEXEZDZOXXWV43KVGGO6WZLJ5/">https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/CP4ON34YEXEZDZOXXWV43KVGGO6WZLJ5/</a><br><a href="https://lists.gnupg.org/pipermail/gnupg-announce/2019q3/000439.html">https://lists.gnupg.org/pipermail/gnupg-announce/2019q3/000439.html</a><br><a href="https://support.f5.com/csp/article/K08654551">https://support.f5.com/csp/article/K08654551</a><br><a href="https://support.f5.com/csp/article/K08654551?utm_source=f5support&amp;amp;utm_medium=RSS">https://support.f5.com/csp/article/K08654551?utm_source=f5support&amp;amp;utm_medium=RSS</a><br><a href="https://twitter.com/lambdafu/status/1147162583969009664">https://twitter.com/lambdafu/status/1147162583969009664</a><br></details>  |
| krb5-locales         |    CVE-2018-20217   |   MEDIUM  |  1.16-2ubuntu0.2 |  | <details><summary>Expand...</summary><a href="http://krbdev.mit.edu/rt/Ticket/Display.html?id=8763">http://krbdev.mit.edu/rt/Ticket/Display.html?id=8763</a><br><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2018-20217">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2018-20217</a><br><a href="https://github.com/krb5/krb5/commit/5e6d1796106df8ba6bc1973ee0917c170d929086">https://github.com/krb5/krb5/commit/5e6d1796106df8ba6bc1973ee0917c170d929086</a><br><a href="https://lists.debian.org/debian-lts-announce/2019/01/msg00020.html">https://lists.debian.org/debian-lts-announce/2019/01/msg00020.html</a><br><a href="https://lists.debian.org/debian-lts-announce/2021/09/msg00019.html">https://lists.debian.org/debian-lts-announce/2021/09/msg00019.html</a><br><a href="https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/2KNHELH4YHNT6H2ESJWX2UIDXLBNGB2O/">https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/2KNHELH4YHNT6H2ESJWX2UIDXLBNGB2O/</a><br><a href="https://security.netapp.com/advisory/ntap-20190416-0006/">https://security.netapp.com/advisory/ntap-20190416-0006/</a><br></details>  |
| krb5-locales         |    CVE-2021-36222   |   MEDIUM  |  1.16-2ubuntu0.2 |  | <details><summary>Expand...</summary><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2021-36222">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2021-36222</a><br><a href="https://github.com/krb5/krb5/commit/fc98f520caefff2e5ee9a0026fdf5109944b3562">https://github.com/krb5/krb5/commit/fc98f520caefff2e5ee9a0026fdf5109944b3562</a><br><a href="https://github.com/krb5/krb5/releases">https://github.com/krb5/krb5/releases</a><br><a href="https://linux.oracle.com/cve/CVE-2021-36222.html">https://linux.oracle.com/cve/CVE-2021-36222.html</a><br><a href="https://linux.oracle.com/errata/ELSA-2021-3576.html">https://linux.oracle.com/errata/ELSA-2021-3576.html</a><br><a href="https://security.netapp.com/advisory/ntap-20211022-0003/">https://security.netapp.com/advisory/ntap-20211022-0003/</a><br><a href="https://security.netapp.com/advisory/ntap-20211104-0007/">https://security.netapp.com/advisory/ntap-20211104-0007/</a><br><a href="https://web.mit.edu/kerberos/advisories/">https://web.mit.edu/kerberos/advisories/</a><br><a href="https://www.debian.org/security/2021/dsa-4944">https://www.debian.org/security/2021/dsa-4944</a><br><a href="https://www.oracle.com/security-alerts/cpuoct2021.html">https://www.oracle.com/security-alerts/cpuoct2021.html</a><br></details>  |
| krb5-locales         |    CVE-2018-5709   |   LOW  |  1.16-2ubuntu0.2 |  | <details><summary>Expand...</summary><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2018-5709">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2018-5709</a><br><a href="https://github.com/poojamnit/Kerberos-V5-1.16-Vulnerabilities/tree/master/Integer%20Overflow">https://github.com/poojamnit/Kerberos-V5-1.16-Vulnerabilities/tree/master/Integer%20Overflow</a><br><a href="https://lists.apache.org/thread.html/rf9fa47ab66495c78bb4120b0754dd9531ca2ff0430f6685ac9b07772@%3Cdev.mina.apache.org%3E">https://lists.apache.org/thread.html/rf9fa47ab66495c78bb4120b0754dd9531ca2ff0430f6685ac9b07772@%3Cdev.mina.apache.org%3E</a><br></details>  |
| krb5-locales         |    CVE-2018-5710   |   LOW  |  1.16-2ubuntu0.2 |  | <details><summary>Expand...</summary><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2018-5710">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2018-5710</a><br><a href="https://github.com/poojamnit/Kerberos-V5-1.16-Vulnerabilities/tree/master/Denial%20Of%20Service(DoS)">https://github.com/poojamnit/Kerberos-V5-1.16-Vulnerabilities/tree/master/Denial%20Of%20Service(DoS)</a><br></details>  |
| libasan4         |    CVE-2020-13844   |   MEDIUM  |  7.5.0-3ubuntu1~18.04 |  | <details><summary>Expand...</summary><a href="http://lists.llvm.org/pipermail/llvm-dev/2020-June/142109.html">http://lists.llvm.org/pipermail/llvm-dev/2020-June/142109.html</a><br><a href="http://lists.opensuse.org/opensuse-security-announce/2020-10/msg00039.html">http://lists.opensuse.org/opensuse-security-announce/2020-10/msg00039.html</a><br><a href="http://lists.opensuse.org/opensuse-security-announce/2020-10/msg00040.html">http://lists.opensuse.org/opensuse-security-announce/2020-10/msg00040.html</a><br><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2020-13844">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2020-13844</a><br><a href="https://developer.arm.com/support/arm-security-updates/speculative-processor-vulnerability">https://developer.arm.com/support/arm-security-updates/speculative-processor-vulnerability</a><br><a href="https://developer.arm.com/support/arm-security-updates/speculative-processor-vulnerability/downloads/straight-line-speculation">https://developer.arm.com/support/arm-security-updates/speculative-processor-vulnerability/downloads/straight-line-speculation</a><br><a href="https://developer.arm.com/support/arm-security-updates/speculative-processor-vulnerability/frequently-asked-questions">https://developer.arm.com/support/arm-security-updates/speculative-processor-vulnerability/frequently-asked-questions</a><br><a href="https://gcc.gnu.org/pipermail/gcc-patches/2020-June/547520.html">https://gcc.gnu.org/pipermail/gcc-patches/2020-June/547520.html</a><br><a href="https://git.kernel.org/pub/scm/linux/kernel/git/torvalds/linux.git/commit/?id=679db70801da9fda91d26caf13bf5b5ccc74e8e8">https://git.kernel.org/pub/scm/linux/kernel/git/torvalds/linux.git/commit/?id=679db70801da9fda91d26caf13bf5b5ccc74e8e8</a><br></details>  |
| libasn1-8-heimdal         |    CVE-2019-12098   |   LOW  |  7.5.0+dfsg-1 |  | <details><summary>Expand...</summary><a href="http://lists.opensuse.org/opensuse-security-announce/2019-07/msg00002.html">http://lists.opensuse.org/opensuse-security-announce/2019-07/msg00002.html</a><br><a href="http://lists.opensuse.org/opensuse-security-announce/2019-07/msg00003.html">http://lists.opensuse.org/opensuse-security-announce/2019-07/msg00003.html</a><br><a href="http://lists.opensuse.org/opensuse-security-announce/2019-08/msg00026.html">http://lists.opensuse.org/opensuse-security-announce/2019-08/msg00026.html</a><br><a href="http://www.h5l.org/pipermail/heimdal-announce/2019-May/000009.html">http://www.h5l.org/pipermail/heimdal-announce/2019-May/000009.html</a><br><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2019-12098">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2019-12098</a><br><a href="https://github.com/heimdal/heimdal/commit/2f7f3d9960aa6ea21358bdf3687cee5149aa35cf">https://github.com/heimdal/heimdal/commit/2f7f3d9960aa6ea21358bdf3687cee5149aa35cf</a><br><a href="https://github.com/heimdal/heimdal/compare/3e58559...bbafe72">https://github.com/heimdal/heimdal/compare/3e58559...bbafe72</a><br><a href="https://github.com/heimdal/heimdal/releases/tag/heimdal-7.6.0">https://github.com/heimdal/heimdal/releases/tag/heimdal-7.6.0</a><br><a href="https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/GIXEDVVMPD6ZAJSMI2EZ7FNEIVNWE5PD/">https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/GIXEDVVMPD6ZAJSMI2EZ7FNEIVNWE5PD/</a><br><a href="https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/SLXXIF4LOQEAEDAF4UGP2AO6WDNTDFUB/">https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/SLXXIF4LOQEAEDAF4UGP2AO6WDNTDFUB/</a><br><a href="https://seclists.org/bugtraq/2019/Jun/1">https://seclists.org/bugtraq/2019/Jun/1</a><br><a href="https://www.debian.org/security/2019/dsa-4455">https://www.debian.org/security/2019/dsa-4455</a><br></details>  |
| libasn1-8-heimdal         |    CVE-2021-3671   |   LOW  |  7.5.0+dfsg-1 |  | <details><summary>Expand...</summary><a href="https://bugzilla.redhat.com/show_bug.cgi?id=2013080,">https://bugzilla.redhat.com/show_bug.cgi?id=2013080,</a><br><a href="https://bugzilla.samba.org/show_bug.cgi?id=14770,">https://bugzilla.samba.org/show_bug.cgi?id=14770,</a><br><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2021-3671">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2021-3671</a><br><a href="https://github.com/heimdal/heimdal/commit/04171147948d0a3636bc6374181926f0fb2ec83a">https://github.com/heimdal/heimdal/commit/04171147948d0a3636bc6374181926f0fb2ec83a</a><br><a href="https://ubuntu.com/security/notices/USN-5142-1">https://ubuntu.com/security/notices/USN-5142-1</a><br><a href="https://ubuntu.com/security/notices/USN-5174-1">https://ubuntu.com/security/notices/USN-5174-1</a><br></details>  |
| libatomic1         |    CVE-2020-13844   |   MEDIUM  |  8.4.0-1ubuntu1~18.04 |  | <details><summary>Expand...</summary><a href="http://lists.llvm.org/pipermail/llvm-dev/2020-June/142109.html">http://lists.llvm.org/pipermail/llvm-dev/2020-June/142109.html</a><br><a href="http://lists.opensuse.org/opensuse-security-announce/2020-10/msg00039.html">http://lists.opensuse.org/opensuse-security-announce/2020-10/msg00039.html</a><br><a href="http://lists.opensuse.org/opensuse-security-announce/2020-10/msg00040.html">http://lists.opensuse.org/opensuse-security-announce/2020-10/msg00040.html</a><br><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2020-13844">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2020-13844</a><br><a href="https://developer.arm.com/support/arm-security-updates/speculative-processor-vulnerability">https://developer.arm.com/support/arm-security-updates/speculative-processor-vulnerability</a><br><a href="https://developer.arm.com/support/arm-security-updates/speculative-processor-vulnerability/downloads/straight-line-speculation">https://developer.arm.com/support/arm-security-updates/speculative-processor-vulnerability/downloads/straight-line-speculation</a><br><a href="https://developer.arm.com/support/arm-security-updates/speculative-processor-vulnerability/frequently-asked-questions">https://developer.arm.com/support/arm-security-updates/speculative-processor-vulnerability/frequently-asked-questions</a><br><a href="https://gcc.gnu.org/pipermail/gcc-patches/2020-June/547520.html">https://gcc.gnu.org/pipermail/gcc-patches/2020-June/547520.html</a><br><a href="https://git.kernel.org/pub/scm/linux/kernel/git/torvalds/linux.git/commit/?id=679db70801da9fda91d26caf13bf5b5ccc74e8e8">https://git.kernel.org/pub/scm/linux/kernel/git/torvalds/linux.git/commit/?id=679db70801da9fda91d26caf13bf5b5ccc74e8e8</a><br></details>  |
| libbinutils         |    CVE-2017-13716   |   LOW  |  2.30-21ubuntu1~18.04.7 |  | <details><summary>Expand...</summary><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2017-13716">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2017-13716</a><br><a href="https://sourceware.org/bugzilla/show_bug.cgi?id=22009">https://sourceware.org/bugzilla/show_bug.cgi?id=22009</a><br></details>  |
| libbinutils         |    CVE-2018-20657   |   LOW  |  2.30-21ubuntu1~18.04.7 |  | <details><summary>Expand...</summary><a href="http://www.securityfocus.com/bid/106444">http://www.securityfocus.com/bid/106444</a><br><a href="https://access.redhat.com/errata/RHSA-2019:3352">https://access.redhat.com/errata/RHSA-2019:3352</a><br><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2018-20657">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2018-20657</a><br><a href="https://gcc.gnu.org/bugzilla/show_bug.cgi?id=88539">https://gcc.gnu.org/bugzilla/show_bug.cgi?id=88539</a><br><a href="https://linux.oracle.com/cve/CVE-2018-20657.html">https://linux.oracle.com/cve/CVE-2018-20657.html</a><br><a href="https://linux.oracle.com/errata/ELSA-2019-3352.html">https://linux.oracle.com/errata/ELSA-2019-3352.html</a><br><a href="https://support.f5.com/csp/article/K62602089">https://support.f5.com/csp/article/K62602089</a><br></details>  |
| libbinutils         |    CVE-2018-20673   |   LOW  |  2.30-21ubuntu1~18.04.7 |  | <details><summary>Expand...</summary><a href="http://www.securityfocus.com/bid/106454">http://www.securityfocus.com/bid/106454</a><br><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2018-20673">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2018-20673</a><br><a href="https://linux.oracle.com/cve/CVE-2018-20673.html">https://linux.oracle.com/cve/CVE-2018-20673.html</a><br><a href="https://linux.oracle.com/errata/ELSA-2021-4386.html">https://linux.oracle.com/errata/ELSA-2021-4386.html</a><br><a href="https://sourceware.org/bugzilla/show_bug.cgi?id=24039">https://sourceware.org/bugzilla/show_bug.cgi?id=24039</a><br></details>  |
| libbinutils         |    CVE-2019-1010204   |   LOW  |  2.30-21ubuntu1~18.04.7 |  | <details><summary>Expand...</summary><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2019-1010204">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2019-1010204</a><br><a href="https://linux.oracle.com/cve/CVE-2019-1010204.html">https://linux.oracle.com/cve/CVE-2019-1010204.html</a><br><a href="https://linux.oracle.com/errata/ELSA-2020-1797.html">https://linux.oracle.com/errata/ELSA-2020-1797.html</a><br><a href="https://security.netapp.com/advisory/ntap-20190822-0001/">https://security.netapp.com/advisory/ntap-20190822-0001/</a><br><a href="https://sourceware.org/bugzilla/show_bug.cgi?id=23765">https://sourceware.org/bugzilla/show_bug.cgi?id=23765</a><br><a href="https://support.f5.com/csp/article/K05032915?utm_source=f5support&amp;amp;utm_medium=RSS">https://support.f5.com/csp/article/K05032915?utm_source=f5support&amp;amp;utm_medium=RSS</a><br></details>  |
| libc-bin         |    CVE-2021-35942   |   MEDIUM  |  2.27-3ubuntu1.4 |  | <details><summary>Expand...</summary><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2021-35942">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2021-35942</a><br><a href="https://linux.oracle.com/cve/CVE-2021-35942.html">https://linux.oracle.com/cve/CVE-2021-35942.html</a><br><a href="https://linux.oracle.com/errata/ELSA-2021-9560.html">https://linux.oracle.com/errata/ELSA-2021-9560.html</a><br><a href="https://security.netapp.com/advisory/ntap-20210827-0005/">https://security.netapp.com/advisory/ntap-20210827-0005/</a><br><a href="https://sourceware.org/bugzilla/show_bug.cgi?id=28011">https://sourceware.org/bugzilla/show_bug.cgi?id=28011</a><br><a href="https://sourceware.org/git/?p=glibc.git;a=commit;h=5adda61f62b77384718b4c0d8336ade8f2b4b35c">https://sourceware.org/git/?p=glibc.git;a=commit;h=5adda61f62b77384718b4c0d8336ade8f2b4b35c</a><br><a href="https://sourceware.org/git/?p=glibc.git;a=commitdiff;h=5adda61f62b77384718b4c0d8336ade8f2b4b35c">https://sourceware.org/git/?p=glibc.git;a=commitdiff;h=5adda61f62b77384718b4c0d8336ade8f2b4b35c</a><br><a href="https://sourceware.org/glibc/wiki/Security%20Exceptions">https://sourceware.org/glibc/wiki/Security%20Exceptions</a><br></details>  |
| libc-bin         |    CVE-2021-38604   |   MEDIUM  |  2.27-3ubuntu1.4 |  | <details><summary>Expand...</summary><a href="https://blog.tuxcare.com/cve/tuxcare-team-identifies-cve-2021-38604-a-new-vulnerability-in-glibc">https://blog.tuxcare.com/cve/tuxcare-team-identifies-cve-2021-38604-a-new-vulnerability-in-glibc</a><br><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2021-38604">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2021-38604</a><br><a href="https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/GYEXYM37RCJWJ6B5KQUYQI4NZBDDYSXP/">https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/GYEXYM37RCJWJ6B5KQUYQI4NZBDDYSXP/</a><br><a href="https://security.netapp.com/advisory/ntap-20210909-0005/">https://security.netapp.com/advisory/ntap-20210909-0005/</a><br><a href="https://sourceware.org/bugzilla/show_bug.cgi?id=28213">https://sourceware.org/bugzilla/show_bug.cgi?id=28213</a><br><a href="https://sourceware.org/git/?p=glibc.git;a=commit;h=4cc79c217744743077bf7a0ec5e0a4318f1e6641">https://sourceware.org/git/?p=glibc.git;a=commit;h=4cc79c217744743077bf7a0ec5e0a4318f1e6641</a><br><a href="https://sourceware.org/git/?p=glibc.git;a=commit;h=b805aebd42364fe696e417808a700fdb9800c9e8">https://sourceware.org/git/?p=glibc.git;a=commit;h=b805aebd42364fe696e417808a700fdb9800c9e8</a><br></details>  |
| libc-bin         |    CVE-2009-5155   |   LOW  |  2.27-3ubuntu1.4 |  | <details><summary>Expand...</summary><a href="http://git.savannah.gnu.org/cgit/gnulib.git/commit/?id=5513b40999149090987a0341c018d05d3eea1272">http://git.savannah.gnu.org/cgit/gnulib.git/commit/?id=5513b40999149090987a0341c018d05d3eea1272</a><br><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2009-5155">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2009-5155</a><br><a href="https://debbugs.gnu.org/cgi/bugreport.cgi?bug=22793">https://debbugs.gnu.org/cgi/bugreport.cgi?bug=22793</a><br><a href="https://debbugs.gnu.org/cgi/bugreport.cgi?bug=32806">https://debbugs.gnu.org/cgi/bugreport.cgi?bug=32806</a><br><a href="https://debbugs.gnu.org/cgi/bugreport.cgi?bug=34238">https://debbugs.gnu.org/cgi/bugreport.cgi?bug=34238</a><br><a href="https://lists.apache.org/thread.html/r58af02e294bd07f487e2c64ffc0a29b837db5600e33b6e698b9d696b@%3Cissues.bookkeeper.apache.org%3E">https://lists.apache.org/thread.html/r58af02e294bd07f487e2c64ffc0a29b837db5600e33b6e698b9d696b@%3Cissues.bookkeeper.apache.org%3E</a><br><a href="https://lists.apache.org/thread.html/rf4c02775860db415b4955778a131c2795223f61cb8c6a450893651e4@%3Cissues.bookkeeper.apache.org%3E">https://lists.apache.org/thread.html/rf4c02775860db415b4955778a131c2795223f61cb8c6a450893651e4@%3Cissues.bookkeeper.apache.org%3E</a><br><a href="https://security.netapp.com/advisory/ntap-20190315-0002/">https://security.netapp.com/advisory/ntap-20190315-0002/</a><br><a href="https://sourceware.org/bugzilla/show_bug.cgi?id=11053">https://sourceware.org/bugzilla/show_bug.cgi?id=11053</a><br><a href="https://sourceware.org/bugzilla/show_bug.cgi?id=18986">https://sourceware.org/bugzilla/show_bug.cgi?id=18986</a><br><a href="https://sourceware.org/git/gitweb.cgi?p=glibc.git;h=eb04c21373e2a2885f3d52ff192b0499afe3c672">https://sourceware.org/git/gitweb.cgi?p=glibc.git;h=eb04c21373e2a2885f3d52ff192b0499afe3c672</a><br><a href="https://support.f5.com/csp/article/K64119434">https://support.f5.com/csp/article/K64119434</a><br><a href="https://support.f5.com/csp/article/K64119434?utm_source=f5support&amp;amp;utm_medium=RSS">https://support.f5.com/csp/article/K64119434?utm_source=f5support&amp;amp;utm_medium=RSS</a><br><a href="https://ubuntu.com/security/notices/USN-4954-1">https://ubuntu.com/security/notices/USN-4954-1</a><br></details>  |
| libc-bin         |    CVE-2015-8985   |   LOW  |  2.27-3ubuntu1.4 |  | <details><summary>Expand...</summary><a href="http://www.openwall.com/lists/oss-security/2017/02/14/9">http://www.openwall.com/lists/oss-security/2017/02/14/9</a><br><a href="http://www.securityfocus.com/bid/76916">http://www.securityfocus.com/bid/76916</a><br><a href="https://bugs.debian.org/cgi-bin/bugreport.cgi?bug=779392">https://bugs.debian.org/cgi-bin/bugreport.cgi?bug=779392</a><br><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2015-8985">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2015-8985</a><br><a href="https://security.gentoo.org/glsa/201908-06">https://security.gentoo.org/glsa/201908-06</a><br></details>  |
| libc-bin         |    CVE-2016-10228   |   LOW  |  2.27-3ubuntu1.4 |  | <details><summary>Expand...</summary><a href="http://openwall.com/lists/oss-security/2017/03/01/10">http://openwall.com/lists/oss-security/2017/03/01/10</a><br><a href="http://www.securityfocus.com/bid/96525">http://www.securityfocus.com/bid/96525</a><br><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2016-10228">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2016-10228</a><br><a href="https://linux.oracle.com/cve/CVE-2016-10228.html">https://linux.oracle.com/cve/CVE-2016-10228.html</a><br><a href="https://linux.oracle.com/errata/ELSA-2021-9344.html">https://linux.oracle.com/errata/ELSA-2021-9344.html</a><br><a href="https://lists.apache.org/thread.html/rf9fa47ab66495c78bb4120b0754dd9531ca2ff0430f6685ac9b07772@%3Cdev.mina.apache.org%3E">https://lists.apache.org/thread.html/rf9fa47ab66495c78bb4120b0754dd9531ca2ff0430f6685ac9b07772@%3Cdev.mina.apache.org%3E</a><br><a href="https://security.gentoo.org/glsa/202101-20">https://security.gentoo.org/glsa/202101-20</a><br><a href="https://sourceware.org/bugzilla/show_bug.cgi?id=19519">https://sourceware.org/bugzilla/show_bug.cgi?id=19519</a><br><a href="https://sourceware.org/bugzilla/show_bug.cgi?id=19519#c21">https://sourceware.org/bugzilla/show_bug.cgi?id=19519#c21</a><br><a href="https://sourceware.org/bugzilla/show_bug.cgi?id=26224">https://sourceware.org/bugzilla/show_bug.cgi?id=26224</a><br></details>  |
| libc-bin         |    CVE-2016-10739   |   LOW  |  2.27-3ubuntu1.4 |  | <details><summary>Expand...</summary><a href="http://lists.opensuse.org/opensuse-security-announce/2019-04/msg00082.html">http://lists.opensuse.org/opensuse-security-announce/2019-04/msg00082.html</a><br><a href="http://www.securityfocus.com/bid/106672">http://www.securityfocus.com/bid/106672</a><br><a href="https://access.redhat.com/errata/RHSA-2019:2118">https://access.redhat.com/errata/RHSA-2019:2118</a><br><a href="https://access.redhat.com/errata/RHSA-2019:3513">https://access.redhat.com/errata/RHSA-2019:3513</a><br><a href="https://bugzilla.redhat.com/show_bug.cgi?id=1347549">https://bugzilla.redhat.com/show_bug.cgi?id=1347549</a><br><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2016-10739">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2016-10739</a><br><a href="https://linux.oracle.com/cve/CVE-2016-10739.html">https://linux.oracle.com/cve/CVE-2016-10739.html</a><br><a href="https://linux.oracle.com/errata/ELSA-2019-3513.html">https://linux.oracle.com/errata/ELSA-2019-3513.html</a><br><a href="https://sourceware.org/bugzilla/show_bug.cgi?id=20018">https://sourceware.org/bugzilla/show_bug.cgi?id=20018</a><br></details>  |
| libc-bin         |    CVE-2019-25013   |   LOW  |  2.27-3ubuntu1.4 |  | <details><summary>Expand...</summary><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2019-25013">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2019-25013</a><br><a href="https://linux.oracle.com/cve/CVE-2019-25013.html">https://linux.oracle.com/cve/CVE-2019-25013.html</a><br><a href="https://linux.oracle.com/errata/ELSA-2021-9344.html">https://linux.oracle.com/errata/ELSA-2021-9344.html</a><br><a href="https://lists.apache.org/thread.html/r32d767ac804e9b8aad4355bb85960a6a1385eab7afff549a5e98660f@%3Cjira.kafka.apache.org%3E">https://lists.apache.org/thread.html/r32d767ac804e9b8aad4355bb85960a6a1385eab7afff549a5e98660f@%3Cjira.kafka.apache.org%3E</a><br><a href="https://lists.apache.org/thread.html/r448bb851cc8e6e3f93f3c28c70032b37062625d81214744474ac49e7@%3Cdev.kafka.apache.org%3E">https://lists.apache.org/thread.html/r448bb851cc8e6e3f93f3c28c70032b37062625d81214744474ac49e7@%3Cdev.kafka.apache.org%3E</a><br><a href="https://lists.apache.org/thread.html/r4806a391091e082bdea17266452ca656ebc176e51bb3932733b3a0a2@%3Cjira.kafka.apache.org%3E">https://lists.apache.org/thread.html/r4806a391091e082bdea17266452ca656ebc176e51bb3932733b3a0a2@%3Cjira.kafka.apache.org%3E</a><br><a href="https://lists.apache.org/thread.html/r499e4f96d0b5109ef083f2feccd33c51650c1b7d7068aa3bd47efca9@%3Cjira.kafka.apache.org%3E">https://lists.apache.org/thread.html/r499e4f96d0b5109ef083f2feccd33c51650c1b7d7068aa3bd47efca9@%3Cjira.kafka.apache.org%3E</a><br><a href="https://lists.apache.org/thread.html/r5af4430421bb6f9973294691a7904bbd260937e9eef96b20556f43ff@%3Cjira.kafka.apache.org%3E">https://lists.apache.org/thread.html/r5af4430421bb6f9973294691a7904bbd260937e9eef96b20556f43ff@%3Cjira.kafka.apache.org%3E</a><br><a href="https://lists.apache.org/thread.html/r750eee18542bc02bd8350861c424ee60a9b9b225568fa09436a37ece@%3Cissues.zookeeper.apache.org%3E">https://lists.apache.org/thread.html/r750eee18542bc02bd8350861c424ee60a9b9b225568fa09436a37ece@%3Cissues.zookeeper.apache.org%3E</a><br><a href="https://lists.apache.org/thread.html/r7a2e94adfe0a2f0a1d42e4927e8c32ecac97d37db9cb68095fe9ddbc@%3Cdev.zookeeper.apache.org%3E">https://lists.apache.org/thread.html/r7a2e94adfe0a2f0a1d42e4927e8c32ecac97d37db9cb68095fe9ddbc@%3Cdev.zookeeper.apache.org%3E</a><br><a href="https://lists.apache.org/thread.html/rd2354f9ccce41e494fbadcbc5ad87218de6ec0fff8a7b54c8462226c@%3Cissues.zookeeper.apache.org%3E">https://lists.apache.org/thread.html/rd2354f9ccce41e494fbadcbc5ad87218de6ec0fff8a7b54c8462226c@%3Cissues.zookeeper.apache.org%3E</a><br><a href="https://lists.apache.org/thread.html/rf9fa47ab66495c78bb4120b0754dd9531ca2ff0430f6685ac9b07772@%3Cdev.mina.apache.org%3E">https://lists.apache.org/thread.html/rf9fa47ab66495c78bb4120b0754dd9531ca2ff0430f6685ac9b07772@%3Cdev.mina.apache.org%3E</a><br><a href="https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/4Y6TX47P47KABSFOL26FLDNVCWXDKDEZ/">https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/4Y6TX47P47KABSFOL26FLDNVCWXDKDEZ/</a><br><a href="https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/TVCUNLQ3HXGS4VPUQKWTJGRAW2KTFGXS/">https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/TVCUNLQ3HXGS4VPUQKWTJGRAW2KTFGXS/</a><br><a href="https://security.netapp.com/advisory/ntap-20210205-0004/">https://security.netapp.com/advisory/ntap-20210205-0004/</a><br><a href="https://sourceware.org/bugzilla/show_bug.cgi?id=24973">https://sourceware.org/bugzilla/show_bug.cgi?id=24973</a><br><a href="https://sourceware.org/git/?p=glibc.git;a=commit;h=ee7a3144c9922808181009b7b3e50e852fb4999b">https://sourceware.org/git/?p=glibc.git;a=commit;h=ee7a3144c9922808181009b7b3e50e852fb4999b</a><br></details>  |
| libc-bin         |    CVE-2020-27618   |   LOW  |  2.27-3ubuntu1.4 |  | <details><summary>Expand...</summary><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2020-27618">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2020-27618</a><br><a href="https://linux.oracle.com/cve/CVE-2020-27618.html">https://linux.oracle.com/cve/CVE-2020-27618.html</a><br><a href="https://linux.oracle.com/errata/ELSA-2021-9344.html">https://linux.oracle.com/errata/ELSA-2021-9344.html</a><br><a href="https://security.netapp.com/advisory/ntap-20210401-0006/">https://security.netapp.com/advisory/ntap-20210401-0006/</a><br><a href="https://sourceware.org/bugzilla/show_bug.cgi?id=19519#c21">https://sourceware.org/bugzilla/show_bug.cgi?id=19519#c21</a><br><a href="https://sourceware.org/bugzilla/show_bug.cgi?id=26224">https://sourceware.org/bugzilla/show_bug.cgi?id=26224</a><br></details>  |
| libc-bin         |    CVE-2020-6096   |   LOW  |  2.27-3ubuntu1.4 |  | <details><summary>Expand...</summary><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2020-6096">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2020-6096</a><br><a href="https://lists.apache.org/thread.html/rf9fa47ab66495c78bb4120b0754dd9531ca2ff0430f6685ac9b07772@%3Cdev.mina.apache.org%3E">https://lists.apache.org/thread.html/rf9fa47ab66495c78bb4120b0754dd9531ca2ff0430f6685ac9b07772@%3Cdev.mina.apache.org%3E</a><br><a href="https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/SPYXTDOOB4PQGTYAMZAZNJIB3FF6YQXI/">https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/SPYXTDOOB4PQGTYAMZAZNJIB3FF6YQXI/</a><br><a href="https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/URXOIA2LDUKHQXK4BE55BQBRI6ZZG3Y6/">https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/URXOIA2LDUKHQXK4BE55BQBRI6ZZG3Y6/</a><br><a href="https://security.gentoo.org/glsa/202101-20">https://security.gentoo.org/glsa/202101-20</a><br><a href="https://sourceware.org/bugzilla/attachment.cgi?id=12334">https://sourceware.org/bugzilla/attachment.cgi?id=12334</a><br><a href="https://sourceware.org/bugzilla/show_bug.cgi?id=25620">https://sourceware.org/bugzilla/show_bug.cgi?id=25620</a><br><a href="https://talosintelligence.com/vulnerability_reports/TALOS-2020-1019">https://talosintelligence.com/vulnerability_reports/TALOS-2020-1019</a><br><a href="https://ubuntu.com/security/notices/USN-4954-1">https://ubuntu.com/security/notices/USN-4954-1</a><br><a href="https://www.talosintelligence.com/vulnerability_reports/TALOS-2020-1019">https://www.talosintelligence.com/vulnerability_reports/TALOS-2020-1019</a><br></details>  |
| libc-bin         |    CVE-2021-3326   |   LOW  |  2.27-3ubuntu1.4 |  | <details><summary>Expand...</summary><a href="http://www.openwall.com/lists/oss-security/2021/01/28/2">http://www.openwall.com/lists/oss-security/2021/01/28/2</a><br><a href="https://bugs.chromium.org/p/project-zero/issues/detail?id=2146">https://bugs.chromium.org/p/project-zero/issues/detail?id=2146</a><br><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2021-3326">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2021-3326</a><br><a href="https://linux.oracle.com/cve/CVE-2021-3326.html">https://linux.oracle.com/cve/CVE-2021-3326.html</a><br><a href="https://linux.oracle.com/errata/ELSA-2021-9344.html">https://linux.oracle.com/errata/ELSA-2021-9344.html</a><br><a href="https://security.netapp.com/advisory/ntap-20210304-0007/">https://security.netapp.com/advisory/ntap-20210304-0007/</a><br><a href="https://sourceware.org/bugzilla/show_bug.cgi?id=27256">https://sourceware.org/bugzilla/show_bug.cgi?id=27256</a><br><a href="https://sourceware.org/git/?p=glibc.git;a=commit;h=7d88c6142c6efc160c0ee5e4f85cde382c072888">https://sourceware.org/git/?p=glibc.git;a=commit;h=7d88c6142c6efc160c0ee5e4f85cde382c072888</a><br><a href="https://sourceware.org/pipermail/libc-alpha/2021-January/122058.html">https://sourceware.org/pipermail/libc-alpha/2021-January/122058.html</a><br></details>  |
| libc-bin         |    CVE-2021-33574   |   LOW  |  2.27-3ubuntu1.4 |  | <details><summary>Expand...</summary><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2021-33574">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2021-33574</a><br><a href="https://linux.oracle.com/cve/CVE-2021-33574.html">https://linux.oracle.com/cve/CVE-2021-33574.html</a><br><a href="https://linux.oracle.com/errata/ELSA-2021-9560.html">https://linux.oracle.com/errata/ELSA-2021-9560.html</a><br><a href="https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/RBUUWUGXVILQXVWEOU7N42ICHPJNAEUP/">https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/RBUUWUGXVILQXVWEOU7N42ICHPJNAEUP/</a><br><a href="https://security.gentoo.org/glsa/202107-07">https://security.gentoo.org/glsa/202107-07</a><br><a href="https://security.netapp.com/advisory/ntap-20210629-0005/">https://security.netapp.com/advisory/ntap-20210629-0005/</a><br><a href="https://sourceware.org/bugzilla/show_bug.cgi?id=27896">https://sourceware.org/bugzilla/show_bug.cgi?id=27896</a><br><a href="https://sourceware.org/bugzilla/show_bug.cgi?id=27896#c1">https://sourceware.org/bugzilla/show_bug.cgi?id=27896#c1</a><br></details>  |
| libc-dev-bin         |    CVE-2021-35942   |   MEDIUM  |  2.27-3ubuntu1.4 |  | <details><summary>Expand...</summary><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2021-35942">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2021-35942</a><br><a href="https://linux.oracle.com/cve/CVE-2021-35942.html">https://linux.oracle.com/cve/CVE-2021-35942.html</a><br><a href="https://linux.oracle.com/errata/ELSA-2021-9560.html">https://linux.oracle.com/errata/ELSA-2021-9560.html</a><br><a href="https://security.netapp.com/advisory/ntap-20210827-0005/">https://security.netapp.com/advisory/ntap-20210827-0005/</a><br><a href="https://sourceware.org/bugzilla/show_bug.cgi?id=28011">https://sourceware.org/bugzilla/show_bug.cgi?id=28011</a><br><a href="https://sourceware.org/git/?p=glibc.git;a=commit;h=5adda61f62b77384718b4c0d8336ade8f2b4b35c">https://sourceware.org/git/?p=glibc.git;a=commit;h=5adda61f62b77384718b4c0d8336ade8f2b4b35c</a><br><a href="https://sourceware.org/git/?p=glibc.git;a=commitdiff;h=5adda61f62b77384718b4c0d8336ade8f2b4b35c">https://sourceware.org/git/?p=glibc.git;a=commitdiff;h=5adda61f62b77384718b4c0d8336ade8f2b4b35c</a><br><a href="https://sourceware.org/glibc/wiki/Security%20Exceptions">https://sourceware.org/glibc/wiki/Security%20Exceptions</a><br></details>  |
| libc-dev-bin         |    CVE-2021-38604   |   MEDIUM  |  2.27-3ubuntu1.4 |  | <details><summary>Expand...</summary><a href="https://blog.tuxcare.com/cve/tuxcare-team-identifies-cve-2021-38604-a-new-vulnerability-in-glibc">https://blog.tuxcare.com/cve/tuxcare-team-identifies-cve-2021-38604-a-new-vulnerability-in-glibc</a><br><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2021-38604">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2021-38604</a><br><a href="https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/GYEXYM37RCJWJ6B5KQUYQI4NZBDDYSXP/">https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/GYEXYM37RCJWJ6B5KQUYQI4NZBDDYSXP/</a><br><a href="https://security.netapp.com/advisory/ntap-20210909-0005/">https://security.netapp.com/advisory/ntap-20210909-0005/</a><br><a href="https://sourceware.org/bugzilla/show_bug.cgi?id=28213">https://sourceware.org/bugzilla/show_bug.cgi?id=28213</a><br><a href="https://sourceware.org/git/?p=glibc.git;a=commit;h=4cc79c217744743077bf7a0ec5e0a4318f1e6641">https://sourceware.org/git/?p=glibc.git;a=commit;h=4cc79c217744743077bf7a0ec5e0a4318f1e6641</a><br><a href="https://sourceware.org/git/?p=glibc.git;a=commit;h=b805aebd42364fe696e417808a700fdb9800c9e8">https://sourceware.org/git/?p=glibc.git;a=commit;h=b805aebd42364fe696e417808a700fdb9800c9e8</a><br></details>  |
| libc-dev-bin         |    CVE-2009-5155   |   LOW  |  2.27-3ubuntu1.4 |  | <details><summary>Expand...</summary><a href="http://git.savannah.gnu.org/cgit/gnulib.git/commit/?id=5513b40999149090987a0341c018d05d3eea1272">http://git.savannah.gnu.org/cgit/gnulib.git/commit/?id=5513b40999149090987a0341c018d05d3eea1272</a><br><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2009-5155">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2009-5155</a><br><a href="https://debbugs.gnu.org/cgi/bugreport.cgi?bug=22793">https://debbugs.gnu.org/cgi/bugreport.cgi?bug=22793</a><br><a href="https://debbugs.gnu.org/cgi/bugreport.cgi?bug=32806">https://debbugs.gnu.org/cgi/bugreport.cgi?bug=32806</a><br><a href="https://debbugs.gnu.org/cgi/bugreport.cgi?bug=34238">https://debbugs.gnu.org/cgi/bugreport.cgi?bug=34238</a><br><a href="https://lists.apache.org/thread.html/r58af02e294bd07f487e2c64ffc0a29b837db5600e33b6e698b9d696b@%3Cissues.bookkeeper.apache.org%3E">https://lists.apache.org/thread.html/r58af02e294bd07f487e2c64ffc0a29b837db5600e33b6e698b9d696b@%3Cissues.bookkeeper.apache.org%3E</a><br><a href="https://lists.apache.org/thread.html/rf4c02775860db415b4955778a131c2795223f61cb8c6a450893651e4@%3Cissues.bookkeeper.apache.org%3E">https://lists.apache.org/thread.html/rf4c02775860db415b4955778a131c2795223f61cb8c6a450893651e4@%3Cissues.bookkeeper.apache.org%3E</a><br><a href="https://security.netapp.com/advisory/ntap-20190315-0002/">https://security.netapp.com/advisory/ntap-20190315-0002/</a><br><a href="https://sourceware.org/bugzilla/show_bug.cgi?id=11053">https://sourceware.org/bugzilla/show_bug.cgi?id=11053</a><br><a href="https://sourceware.org/bugzilla/show_bug.cgi?id=18986">https://sourceware.org/bugzilla/show_bug.cgi?id=18986</a><br><a href="https://sourceware.org/git/gitweb.cgi?p=glibc.git;h=eb04c21373e2a2885f3d52ff192b0499afe3c672">https://sourceware.org/git/gitweb.cgi?p=glibc.git;h=eb04c21373e2a2885f3d52ff192b0499afe3c672</a><br><a href="https://support.f5.com/csp/article/K64119434">https://support.f5.com/csp/article/K64119434</a><br><a href="https://support.f5.com/csp/article/K64119434?utm_source=f5support&amp;amp;utm_medium=RSS">https://support.f5.com/csp/article/K64119434?utm_source=f5support&amp;amp;utm_medium=RSS</a><br><a href="https://ubuntu.com/security/notices/USN-4954-1">https://ubuntu.com/security/notices/USN-4954-1</a><br></details>  |
| libc-dev-bin         |    CVE-2015-8985   |   LOW  |  2.27-3ubuntu1.4 |  | <details><summary>Expand...</summary><a href="http://www.openwall.com/lists/oss-security/2017/02/14/9">http://www.openwall.com/lists/oss-security/2017/02/14/9</a><br><a href="http://www.securityfocus.com/bid/76916">http://www.securityfocus.com/bid/76916</a><br><a href="https://bugs.debian.org/cgi-bin/bugreport.cgi?bug=779392">https://bugs.debian.org/cgi-bin/bugreport.cgi?bug=779392</a><br><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2015-8985">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2015-8985</a><br><a href="https://security.gentoo.org/glsa/201908-06">https://security.gentoo.org/glsa/201908-06</a><br></details>  |
| libc-dev-bin         |    CVE-2016-10228   |   LOW  |  2.27-3ubuntu1.4 |  | <details><summary>Expand...</summary><a href="http://openwall.com/lists/oss-security/2017/03/01/10">http://openwall.com/lists/oss-security/2017/03/01/10</a><br><a href="http://www.securityfocus.com/bid/96525">http://www.securityfocus.com/bid/96525</a><br><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2016-10228">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2016-10228</a><br><a href="https://linux.oracle.com/cve/CVE-2016-10228.html">https://linux.oracle.com/cve/CVE-2016-10228.html</a><br><a href="https://linux.oracle.com/errata/ELSA-2021-9344.html">https://linux.oracle.com/errata/ELSA-2021-9344.html</a><br><a href="https://lists.apache.org/thread.html/rf9fa47ab66495c78bb4120b0754dd9531ca2ff0430f6685ac9b07772@%3Cdev.mina.apache.org%3E">https://lists.apache.org/thread.html/rf9fa47ab66495c78bb4120b0754dd9531ca2ff0430f6685ac9b07772@%3Cdev.mina.apache.org%3E</a><br><a href="https://security.gentoo.org/glsa/202101-20">https://security.gentoo.org/glsa/202101-20</a><br><a href="https://sourceware.org/bugzilla/show_bug.cgi?id=19519">https://sourceware.org/bugzilla/show_bug.cgi?id=19519</a><br><a href="https://sourceware.org/bugzilla/show_bug.cgi?id=19519#c21">https://sourceware.org/bugzilla/show_bug.cgi?id=19519#c21</a><br><a href="https://sourceware.org/bugzilla/show_bug.cgi?id=26224">https://sourceware.org/bugzilla/show_bug.cgi?id=26224</a><br></details>  |
| libc-dev-bin         |    CVE-2016-10739   |   LOW  |  2.27-3ubuntu1.4 |  | <details><summary>Expand...</summary><a href="http://lists.opensuse.org/opensuse-security-announce/2019-04/msg00082.html">http://lists.opensuse.org/opensuse-security-announce/2019-04/msg00082.html</a><br><a href="http://www.securityfocus.com/bid/106672">http://www.securityfocus.com/bid/106672</a><br><a href="https://access.redhat.com/errata/RHSA-2019:2118">https://access.redhat.com/errata/RHSA-2019:2118</a><br><a href="https://access.redhat.com/errata/RHSA-2019:3513">https://access.redhat.com/errata/RHSA-2019:3513</a><br><a href="https://bugzilla.redhat.com/show_bug.cgi?id=1347549">https://bugzilla.redhat.com/show_bug.cgi?id=1347549</a><br><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2016-10739">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2016-10739</a><br><a href="https://linux.oracle.com/cve/CVE-2016-10739.html">https://linux.oracle.com/cve/CVE-2016-10739.html</a><br><a href="https://linux.oracle.com/errata/ELSA-2019-3513.html">https://linux.oracle.com/errata/ELSA-2019-3513.html</a><br><a href="https://sourceware.org/bugzilla/show_bug.cgi?id=20018">https://sourceware.org/bugzilla/show_bug.cgi?id=20018</a><br></details>  |
| libc-dev-bin         |    CVE-2019-25013   |   LOW  |  2.27-3ubuntu1.4 |  | <details><summary>Expand...</summary><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2019-25013">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2019-25013</a><br><a href="https://linux.oracle.com/cve/CVE-2019-25013.html">https://linux.oracle.com/cve/CVE-2019-25013.html</a><br><a href="https://linux.oracle.com/errata/ELSA-2021-9344.html">https://linux.oracle.com/errata/ELSA-2021-9344.html</a><br><a href="https://lists.apache.org/thread.html/r32d767ac804e9b8aad4355bb85960a6a1385eab7afff549a5e98660f@%3Cjira.kafka.apache.org%3E">https://lists.apache.org/thread.html/r32d767ac804e9b8aad4355bb85960a6a1385eab7afff549a5e98660f@%3Cjira.kafka.apache.org%3E</a><br><a href="https://lists.apache.org/thread.html/r448bb851cc8e6e3f93f3c28c70032b37062625d81214744474ac49e7@%3Cdev.kafka.apache.org%3E">https://lists.apache.org/thread.html/r448bb851cc8e6e3f93f3c28c70032b37062625d81214744474ac49e7@%3Cdev.kafka.apache.org%3E</a><br><a href="https://lists.apache.org/thread.html/r4806a391091e082bdea17266452ca656ebc176e51bb3932733b3a0a2@%3Cjira.kafka.apache.org%3E">https://lists.apache.org/thread.html/r4806a391091e082bdea17266452ca656ebc176e51bb3932733b3a0a2@%3Cjira.kafka.apache.org%3E</a><br><a href="https://lists.apache.org/thread.html/r499e4f96d0b5109ef083f2feccd33c51650c1b7d7068aa3bd47efca9@%3Cjira.kafka.apache.org%3E">https://lists.apache.org/thread.html/r499e4f96d0b5109ef083f2feccd33c51650c1b7d7068aa3bd47efca9@%3Cjira.kafka.apache.org%3E</a><br><a href="https://lists.apache.org/thread.html/r5af4430421bb6f9973294691a7904bbd260937e9eef96b20556f43ff@%3Cjira.kafka.apache.org%3E">https://lists.apache.org/thread.html/r5af4430421bb6f9973294691a7904bbd260937e9eef96b20556f43ff@%3Cjira.kafka.apache.org%3E</a><br><a href="https://lists.apache.org/thread.html/r750eee18542bc02bd8350861c424ee60a9b9b225568fa09436a37ece@%3Cissues.zookeeper.apache.org%3E">https://lists.apache.org/thread.html/r750eee18542bc02bd8350861c424ee60a9b9b225568fa09436a37ece@%3Cissues.zookeeper.apache.org%3E</a><br><a href="https://lists.apache.org/thread.html/r7a2e94adfe0a2f0a1d42e4927e8c32ecac97d37db9cb68095fe9ddbc@%3Cdev.zookeeper.apache.org%3E">https://lists.apache.org/thread.html/r7a2e94adfe0a2f0a1d42e4927e8c32ecac97d37db9cb68095fe9ddbc@%3Cdev.zookeeper.apache.org%3E</a><br><a href="https://lists.apache.org/thread.html/rd2354f9ccce41e494fbadcbc5ad87218de6ec0fff8a7b54c8462226c@%3Cissues.zookeeper.apache.org%3E">https://lists.apache.org/thread.html/rd2354f9ccce41e494fbadcbc5ad87218de6ec0fff8a7b54c8462226c@%3Cissues.zookeeper.apache.org%3E</a><br><a href="https://lists.apache.org/thread.html/rf9fa47ab66495c78bb4120b0754dd9531ca2ff0430f6685ac9b07772@%3Cdev.mina.apache.org%3E">https://lists.apache.org/thread.html/rf9fa47ab66495c78bb4120b0754dd9531ca2ff0430f6685ac9b07772@%3Cdev.mina.apache.org%3E</a><br><a href="https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/4Y6TX47P47KABSFOL26FLDNVCWXDKDEZ/">https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/4Y6TX47P47KABSFOL26FLDNVCWXDKDEZ/</a><br><a href="https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/TVCUNLQ3HXGS4VPUQKWTJGRAW2KTFGXS/">https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/TVCUNLQ3HXGS4VPUQKWTJGRAW2KTFGXS/</a><br><a href="https://security.netapp.com/advisory/ntap-20210205-0004/">https://security.netapp.com/advisory/ntap-20210205-0004/</a><br><a href="https://sourceware.org/bugzilla/show_bug.cgi?id=24973">https://sourceware.org/bugzilla/show_bug.cgi?id=24973</a><br><a href="https://sourceware.org/git/?p=glibc.git;a=commit;h=ee7a3144c9922808181009b7b3e50e852fb4999b">https://sourceware.org/git/?p=glibc.git;a=commit;h=ee7a3144c9922808181009b7b3e50e852fb4999b</a><br></details>  |
| libc-dev-bin         |    CVE-2020-27618   |   LOW  |  2.27-3ubuntu1.4 |  | <details><summary>Expand...</summary><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2020-27618">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2020-27618</a><br><a href="https://linux.oracle.com/cve/CVE-2020-27618.html">https://linux.oracle.com/cve/CVE-2020-27618.html</a><br><a href="https://linux.oracle.com/errata/ELSA-2021-9344.html">https://linux.oracle.com/errata/ELSA-2021-9344.html</a><br><a href="https://security.netapp.com/advisory/ntap-20210401-0006/">https://security.netapp.com/advisory/ntap-20210401-0006/</a><br><a href="https://sourceware.org/bugzilla/show_bug.cgi?id=19519#c21">https://sourceware.org/bugzilla/show_bug.cgi?id=19519#c21</a><br><a href="https://sourceware.org/bugzilla/show_bug.cgi?id=26224">https://sourceware.org/bugzilla/show_bug.cgi?id=26224</a><br></details>  |
| libc-dev-bin         |    CVE-2020-6096   |   LOW  |  2.27-3ubuntu1.4 |  | <details><summary>Expand...</summary><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2020-6096">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2020-6096</a><br><a href="https://lists.apache.org/thread.html/rf9fa47ab66495c78bb4120b0754dd9531ca2ff0430f6685ac9b07772@%3Cdev.mina.apache.org%3E">https://lists.apache.org/thread.html/rf9fa47ab66495c78bb4120b0754dd9531ca2ff0430f6685ac9b07772@%3Cdev.mina.apache.org%3E</a><br><a href="https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/SPYXTDOOB4PQGTYAMZAZNJIB3FF6YQXI/">https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/SPYXTDOOB4PQGTYAMZAZNJIB3FF6YQXI/</a><br><a href="https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/URXOIA2LDUKHQXK4BE55BQBRI6ZZG3Y6/">https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/URXOIA2LDUKHQXK4BE55BQBRI6ZZG3Y6/</a><br><a href="https://security.gentoo.org/glsa/202101-20">https://security.gentoo.org/glsa/202101-20</a><br><a href="https://sourceware.org/bugzilla/attachment.cgi?id=12334">https://sourceware.org/bugzilla/attachment.cgi?id=12334</a><br><a href="https://sourceware.org/bugzilla/show_bug.cgi?id=25620">https://sourceware.org/bugzilla/show_bug.cgi?id=25620</a><br><a href="https://talosintelligence.com/vulnerability_reports/TALOS-2020-1019">https://talosintelligence.com/vulnerability_reports/TALOS-2020-1019</a><br><a href="https://ubuntu.com/security/notices/USN-4954-1">https://ubuntu.com/security/notices/USN-4954-1</a><br><a href="https://www.talosintelligence.com/vulnerability_reports/TALOS-2020-1019">https://www.talosintelligence.com/vulnerability_reports/TALOS-2020-1019</a><br></details>  |
| libc-dev-bin         |    CVE-2021-3326   |   LOW  |  2.27-3ubuntu1.4 |  | <details><summary>Expand...</summary><a href="http://www.openwall.com/lists/oss-security/2021/01/28/2">http://www.openwall.com/lists/oss-security/2021/01/28/2</a><br><a href="https://bugs.chromium.org/p/project-zero/issues/detail?id=2146">https://bugs.chromium.org/p/project-zero/issues/detail?id=2146</a><br><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2021-3326">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2021-3326</a><br><a href="https://linux.oracle.com/cve/CVE-2021-3326.html">https://linux.oracle.com/cve/CVE-2021-3326.html</a><br><a href="https://linux.oracle.com/errata/ELSA-2021-9344.html">https://linux.oracle.com/errata/ELSA-2021-9344.html</a><br><a href="https://security.netapp.com/advisory/ntap-20210304-0007/">https://security.netapp.com/advisory/ntap-20210304-0007/</a><br><a href="https://sourceware.org/bugzilla/show_bug.cgi?id=27256">https://sourceware.org/bugzilla/show_bug.cgi?id=27256</a><br><a href="https://sourceware.org/git/?p=glibc.git;a=commit;h=7d88c6142c6efc160c0ee5e4f85cde382c072888">https://sourceware.org/git/?p=glibc.git;a=commit;h=7d88c6142c6efc160c0ee5e4f85cde382c072888</a><br><a href="https://sourceware.org/pipermail/libc-alpha/2021-January/122058.html">https://sourceware.org/pipermail/libc-alpha/2021-January/122058.html</a><br></details>  |
| libc-dev-bin         |    CVE-2021-33574   |   LOW  |  2.27-3ubuntu1.4 |  | <details><summary>Expand...</summary><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2021-33574">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2021-33574</a><br><a href="https://linux.oracle.com/cve/CVE-2021-33574.html">https://linux.oracle.com/cve/CVE-2021-33574.html</a><br><a href="https://linux.oracle.com/errata/ELSA-2021-9560.html">https://linux.oracle.com/errata/ELSA-2021-9560.html</a><br><a href="https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/RBUUWUGXVILQXVWEOU7N42ICHPJNAEUP/">https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/RBUUWUGXVILQXVWEOU7N42ICHPJNAEUP/</a><br><a href="https://security.gentoo.org/glsa/202107-07">https://security.gentoo.org/glsa/202107-07</a><br><a href="https://security.netapp.com/advisory/ntap-20210629-0005/">https://security.netapp.com/advisory/ntap-20210629-0005/</a><br><a href="https://sourceware.org/bugzilla/show_bug.cgi?id=27896">https://sourceware.org/bugzilla/show_bug.cgi?id=27896</a><br><a href="https://sourceware.org/bugzilla/show_bug.cgi?id=27896#c1">https://sourceware.org/bugzilla/show_bug.cgi?id=27896#c1</a><br></details>  |
| libc6         |    CVE-2021-35942   |   MEDIUM  |  2.27-3ubuntu1.4 |  | <details><summary>Expand...</summary><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2021-35942">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2021-35942</a><br><a href="https://linux.oracle.com/cve/CVE-2021-35942.html">https://linux.oracle.com/cve/CVE-2021-35942.html</a><br><a href="https://linux.oracle.com/errata/ELSA-2021-9560.html">https://linux.oracle.com/errata/ELSA-2021-9560.html</a><br><a href="https://security.netapp.com/advisory/ntap-20210827-0005/">https://security.netapp.com/advisory/ntap-20210827-0005/</a><br><a href="https://sourceware.org/bugzilla/show_bug.cgi?id=28011">https://sourceware.org/bugzilla/show_bug.cgi?id=28011</a><br><a href="https://sourceware.org/git/?p=glibc.git;a=commit;h=5adda61f62b77384718b4c0d8336ade8f2b4b35c">https://sourceware.org/git/?p=glibc.git;a=commit;h=5adda61f62b77384718b4c0d8336ade8f2b4b35c</a><br><a href="https://sourceware.org/git/?p=glibc.git;a=commitdiff;h=5adda61f62b77384718b4c0d8336ade8f2b4b35c">https://sourceware.org/git/?p=glibc.git;a=commitdiff;h=5adda61f62b77384718b4c0d8336ade8f2b4b35c</a><br><a href="https://sourceware.org/glibc/wiki/Security%20Exceptions">https://sourceware.org/glibc/wiki/Security%20Exceptions</a><br></details>  |
| libc6         |    CVE-2021-38604   |   MEDIUM  |  2.27-3ubuntu1.4 |  | <details><summary>Expand...</summary><a href="https://blog.tuxcare.com/cve/tuxcare-team-identifies-cve-2021-38604-a-new-vulnerability-in-glibc">https://blog.tuxcare.com/cve/tuxcare-team-identifies-cve-2021-38604-a-new-vulnerability-in-glibc</a><br><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2021-38604">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2021-38604</a><br><a href="https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/GYEXYM37RCJWJ6B5KQUYQI4NZBDDYSXP/">https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/GYEXYM37RCJWJ6B5KQUYQI4NZBDDYSXP/</a><br><a href="https://security.netapp.com/advisory/ntap-20210909-0005/">https://security.netapp.com/advisory/ntap-20210909-0005/</a><br><a href="https://sourceware.org/bugzilla/show_bug.cgi?id=28213">https://sourceware.org/bugzilla/show_bug.cgi?id=28213</a><br><a href="https://sourceware.org/git/?p=glibc.git;a=commit;h=4cc79c217744743077bf7a0ec5e0a4318f1e6641">https://sourceware.org/git/?p=glibc.git;a=commit;h=4cc79c217744743077bf7a0ec5e0a4318f1e6641</a><br><a href="https://sourceware.org/git/?p=glibc.git;a=commit;h=b805aebd42364fe696e417808a700fdb9800c9e8">https://sourceware.org/git/?p=glibc.git;a=commit;h=b805aebd42364fe696e417808a700fdb9800c9e8</a><br></details>  |
| libc6         |    CVE-2009-5155   |   LOW  |  2.27-3ubuntu1.4 |  | <details><summary>Expand...</summary><a href="http://git.savannah.gnu.org/cgit/gnulib.git/commit/?id=5513b40999149090987a0341c018d05d3eea1272">http://git.savannah.gnu.org/cgit/gnulib.git/commit/?id=5513b40999149090987a0341c018d05d3eea1272</a><br><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2009-5155">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2009-5155</a><br><a href="https://debbugs.gnu.org/cgi/bugreport.cgi?bug=22793">https://debbugs.gnu.org/cgi/bugreport.cgi?bug=22793</a><br><a href="https://debbugs.gnu.org/cgi/bugreport.cgi?bug=32806">https://debbugs.gnu.org/cgi/bugreport.cgi?bug=32806</a><br><a href="https://debbugs.gnu.org/cgi/bugreport.cgi?bug=34238">https://debbugs.gnu.org/cgi/bugreport.cgi?bug=34238</a><br><a href="https://lists.apache.org/thread.html/r58af02e294bd07f487e2c64ffc0a29b837db5600e33b6e698b9d696b@%3Cissues.bookkeeper.apache.org%3E">https://lists.apache.org/thread.html/r58af02e294bd07f487e2c64ffc0a29b837db5600e33b6e698b9d696b@%3Cissues.bookkeeper.apache.org%3E</a><br><a href="https://lists.apache.org/thread.html/rf4c02775860db415b4955778a131c2795223f61cb8c6a450893651e4@%3Cissues.bookkeeper.apache.org%3E">https://lists.apache.org/thread.html/rf4c02775860db415b4955778a131c2795223f61cb8c6a450893651e4@%3Cissues.bookkeeper.apache.org%3E</a><br><a href="https://security.netapp.com/advisory/ntap-20190315-0002/">https://security.netapp.com/advisory/ntap-20190315-0002/</a><br><a href="https://sourceware.org/bugzilla/show_bug.cgi?id=11053">https://sourceware.org/bugzilla/show_bug.cgi?id=11053</a><br><a href="https://sourceware.org/bugzilla/show_bug.cgi?id=18986">https://sourceware.org/bugzilla/show_bug.cgi?id=18986</a><br><a href="https://sourceware.org/git/gitweb.cgi?p=glibc.git;h=eb04c21373e2a2885f3d52ff192b0499afe3c672">https://sourceware.org/git/gitweb.cgi?p=glibc.git;h=eb04c21373e2a2885f3d52ff192b0499afe3c672</a><br><a href="https://support.f5.com/csp/article/K64119434">https://support.f5.com/csp/article/K64119434</a><br><a href="https://support.f5.com/csp/article/K64119434?utm_source=f5support&amp;amp;utm_medium=RSS">https://support.f5.com/csp/article/K64119434?utm_source=f5support&amp;amp;utm_medium=RSS</a><br><a href="https://ubuntu.com/security/notices/USN-4954-1">https://ubuntu.com/security/notices/USN-4954-1</a><br></details>  |
| libc6         |    CVE-2015-8985   |   LOW  |  2.27-3ubuntu1.4 |  | <details><summary>Expand...</summary><a href="http://www.openwall.com/lists/oss-security/2017/02/14/9">http://www.openwall.com/lists/oss-security/2017/02/14/9</a><br><a href="http://www.securityfocus.com/bid/76916">http://www.securityfocus.com/bid/76916</a><br><a href="https://bugs.debian.org/cgi-bin/bugreport.cgi?bug=779392">https://bugs.debian.org/cgi-bin/bugreport.cgi?bug=779392</a><br><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2015-8985">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2015-8985</a><br><a href="https://security.gentoo.org/glsa/201908-06">https://security.gentoo.org/glsa/201908-06</a><br></details>  |
| libc6         |    CVE-2016-10228   |   LOW  |  2.27-3ubuntu1.4 |  | <details><summary>Expand...</summary><a href="http://openwall.com/lists/oss-security/2017/03/01/10">http://openwall.com/lists/oss-security/2017/03/01/10</a><br><a href="http://www.securityfocus.com/bid/96525">http://www.securityfocus.com/bid/96525</a><br><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2016-10228">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2016-10228</a><br><a href="https://linux.oracle.com/cve/CVE-2016-10228.html">https://linux.oracle.com/cve/CVE-2016-10228.html</a><br><a href="https://linux.oracle.com/errata/ELSA-2021-9344.html">https://linux.oracle.com/errata/ELSA-2021-9344.html</a><br><a href="https://lists.apache.org/thread.html/rf9fa47ab66495c78bb4120b0754dd9531ca2ff0430f6685ac9b07772@%3Cdev.mina.apache.org%3E">https://lists.apache.org/thread.html/rf9fa47ab66495c78bb4120b0754dd9531ca2ff0430f6685ac9b07772@%3Cdev.mina.apache.org%3E</a><br><a href="https://security.gentoo.org/glsa/202101-20">https://security.gentoo.org/glsa/202101-20</a><br><a href="https://sourceware.org/bugzilla/show_bug.cgi?id=19519">https://sourceware.org/bugzilla/show_bug.cgi?id=19519</a><br><a href="https://sourceware.org/bugzilla/show_bug.cgi?id=19519#c21">https://sourceware.org/bugzilla/show_bug.cgi?id=19519#c21</a><br><a href="https://sourceware.org/bugzilla/show_bug.cgi?id=26224">https://sourceware.org/bugzilla/show_bug.cgi?id=26224</a><br></details>  |
| libc6         |    CVE-2016-10739   |   LOW  |  2.27-3ubuntu1.4 |  | <details><summary>Expand...</summary><a href="http://lists.opensuse.org/opensuse-security-announce/2019-04/msg00082.html">http://lists.opensuse.org/opensuse-security-announce/2019-04/msg00082.html</a><br><a href="http://www.securityfocus.com/bid/106672">http://www.securityfocus.com/bid/106672</a><br><a href="https://access.redhat.com/errata/RHSA-2019:2118">https://access.redhat.com/errata/RHSA-2019:2118</a><br><a href="https://access.redhat.com/errata/RHSA-2019:3513">https://access.redhat.com/errata/RHSA-2019:3513</a><br><a href="https://bugzilla.redhat.com/show_bug.cgi?id=1347549">https://bugzilla.redhat.com/show_bug.cgi?id=1347549</a><br><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2016-10739">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2016-10739</a><br><a href="https://linux.oracle.com/cve/CVE-2016-10739.html">https://linux.oracle.com/cve/CVE-2016-10739.html</a><br><a href="https://linux.oracle.com/errata/ELSA-2019-3513.html">https://linux.oracle.com/errata/ELSA-2019-3513.html</a><br><a href="https://sourceware.org/bugzilla/show_bug.cgi?id=20018">https://sourceware.org/bugzilla/show_bug.cgi?id=20018</a><br></details>  |
| libc6         |    CVE-2019-25013   |   LOW  |  2.27-3ubuntu1.4 |  | <details><summary>Expand...</summary><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2019-25013">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2019-25013</a><br><a href="https://linux.oracle.com/cve/CVE-2019-25013.html">https://linux.oracle.com/cve/CVE-2019-25013.html</a><br><a href="https://linux.oracle.com/errata/ELSA-2021-9344.html">https://linux.oracle.com/errata/ELSA-2021-9344.html</a><br><a href="https://lists.apache.org/thread.html/r32d767ac804e9b8aad4355bb85960a6a1385eab7afff549a5e98660f@%3Cjira.kafka.apache.org%3E">https://lists.apache.org/thread.html/r32d767ac804e9b8aad4355bb85960a6a1385eab7afff549a5e98660f@%3Cjira.kafka.apache.org%3E</a><br><a href="https://lists.apache.org/thread.html/r448bb851cc8e6e3f93f3c28c70032b37062625d81214744474ac49e7@%3Cdev.kafka.apache.org%3E">https://lists.apache.org/thread.html/r448bb851cc8e6e3f93f3c28c70032b37062625d81214744474ac49e7@%3Cdev.kafka.apache.org%3E</a><br><a href="https://lists.apache.org/thread.html/r4806a391091e082bdea17266452ca656ebc176e51bb3932733b3a0a2@%3Cjira.kafka.apache.org%3E">https://lists.apache.org/thread.html/r4806a391091e082bdea17266452ca656ebc176e51bb3932733b3a0a2@%3Cjira.kafka.apache.org%3E</a><br><a href="https://lists.apache.org/thread.html/r499e4f96d0b5109ef083f2feccd33c51650c1b7d7068aa3bd47efca9@%3Cjira.kafka.apache.org%3E">https://lists.apache.org/thread.html/r499e4f96d0b5109ef083f2feccd33c51650c1b7d7068aa3bd47efca9@%3Cjira.kafka.apache.org%3E</a><br><a href="https://lists.apache.org/thread.html/r5af4430421bb6f9973294691a7904bbd260937e9eef96b20556f43ff@%3Cjira.kafka.apache.org%3E">https://lists.apache.org/thread.html/r5af4430421bb6f9973294691a7904bbd260937e9eef96b20556f43ff@%3Cjira.kafka.apache.org%3E</a><br><a href="https://lists.apache.org/thread.html/r750eee18542bc02bd8350861c424ee60a9b9b225568fa09436a37ece@%3Cissues.zookeeper.apache.org%3E">https://lists.apache.org/thread.html/r750eee18542bc02bd8350861c424ee60a9b9b225568fa09436a37ece@%3Cissues.zookeeper.apache.org%3E</a><br><a href="https://lists.apache.org/thread.html/r7a2e94adfe0a2f0a1d42e4927e8c32ecac97d37db9cb68095fe9ddbc@%3Cdev.zookeeper.apache.org%3E">https://lists.apache.org/thread.html/r7a2e94adfe0a2f0a1d42e4927e8c32ecac97d37db9cb68095fe9ddbc@%3Cdev.zookeeper.apache.org%3E</a><br><a href="https://lists.apache.org/thread.html/rd2354f9ccce41e494fbadcbc5ad87218de6ec0fff8a7b54c8462226c@%3Cissues.zookeeper.apache.org%3E">https://lists.apache.org/thread.html/rd2354f9ccce41e494fbadcbc5ad87218de6ec0fff8a7b54c8462226c@%3Cissues.zookeeper.apache.org%3E</a><br><a href="https://lists.apache.org/thread.html/rf9fa47ab66495c78bb4120b0754dd9531ca2ff0430f6685ac9b07772@%3Cdev.mina.apache.org%3E">https://lists.apache.org/thread.html/rf9fa47ab66495c78bb4120b0754dd9531ca2ff0430f6685ac9b07772@%3Cdev.mina.apache.org%3E</a><br><a href="https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/4Y6TX47P47KABSFOL26FLDNVCWXDKDEZ/">https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/4Y6TX47P47KABSFOL26FLDNVCWXDKDEZ/</a><br><a href="https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/TVCUNLQ3HXGS4VPUQKWTJGRAW2KTFGXS/">https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/TVCUNLQ3HXGS4VPUQKWTJGRAW2KTFGXS/</a><br><a href="https://security.netapp.com/advisory/ntap-20210205-0004/">https://security.netapp.com/advisory/ntap-20210205-0004/</a><br><a href="https://sourceware.org/bugzilla/show_bug.cgi?id=24973">https://sourceware.org/bugzilla/show_bug.cgi?id=24973</a><br><a href="https://sourceware.org/git/?p=glibc.git;a=commit;h=ee7a3144c9922808181009b7b3e50e852fb4999b">https://sourceware.org/git/?p=glibc.git;a=commit;h=ee7a3144c9922808181009b7b3e50e852fb4999b</a><br></details>  |
| libc6         |    CVE-2020-27618   |   LOW  |  2.27-3ubuntu1.4 |  | <details><summary>Expand...</summary><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2020-27618">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2020-27618</a><br><a href="https://linux.oracle.com/cve/CVE-2020-27618.html">https://linux.oracle.com/cve/CVE-2020-27618.html</a><br><a href="https://linux.oracle.com/errata/ELSA-2021-9344.html">https://linux.oracle.com/errata/ELSA-2021-9344.html</a><br><a href="https://security.netapp.com/advisory/ntap-20210401-0006/">https://security.netapp.com/advisory/ntap-20210401-0006/</a><br><a href="https://sourceware.org/bugzilla/show_bug.cgi?id=19519#c21">https://sourceware.org/bugzilla/show_bug.cgi?id=19519#c21</a><br><a href="https://sourceware.org/bugzilla/show_bug.cgi?id=26224">https://sourceware.org/bugzilla/show_bug.cgi?id=26224</a><br></details>  |
| libc6         |    CVE-2020-6096   |   LOW  |  2.27-3ubuntu1.4 |  | <details><summary>Expand...</summary><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2020-6096">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2020-6096</a><br><a href="https://lists.apache.org/thread.html/rf9fa47ab66495c78bb4120b0754dd9531ca2ff0430f6685ac9b07772@%3Cdev.mina.apache.org%3E">https://lists.apache.org/thread.html/rf9fa47ab66495c78bb4120b0754dd9531ca2ff0430f6685ac9b07772@%3Cdev.mina.apache.org%3E</a><br><a href="https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/SPYXTDOOB4PQGTYAMZAZNJIB3FF6YQXI/">https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/SPYXTDOOB4PQGTYAMZAZNJIB3FF6YQXI/</a><br><a href="https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/URXOIA2LDUKHQXK4BE55BQBRI6ZZG3Y6/">https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/URXOIA2LDUKHQXK4BE55BQBRI6ZZG3Y6/</a><br><a href="https://security.gentoo.org/glsa/202101-20">https://security.gentoo.org/glsa/202101-20</a><br><a href="https://sourceware.org/bugzilla/attachment.cgi?id=12334">https://sourceware.org/bugzilla/attachment.cgi?id=12334</a><br><a href="https://sourceware.org/bugzilla/show_bug.cgi?id=25620">https://sourceware.org/bugzilla/show_bug.cgi?id=25620</a><br><a href="https://talosintelligence.com/vulnerability_reports/TALOS-2020-1019">https://talosintelligence.com/vulnerability_reports/TALOS-2020-1019</a><br><a href="https://ubuntu.com/security/notices/USN-4954-1">https://ubuntu.com/security/notices/USN-4954-1</a><br><a href="https://www.talosintelligence.com/vulnerability_reports/TALOS-2020-1019">https://www.talosintelligence.com/vulnerability_reports/TALOS-2020-1019</a><br></details>  |
| libc6         |    CVE-2021-3326   |   LOW  |  2.27-3ubuntu1.4 |  | <details><summary>Expand...</summary><a href="http://www.openwall.com/lists/oss-security/2021/01/28/2">http://www.openwall.com/lists/oss-security/2021/01/28/2</a><br><a href="https://bugs.chromium.org/p/project-zero/issues/detail?id=2146">https://bugs.chromium.org/p/project-zero/issues/detail?id=2146</a><br><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2021-3326">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2021-3326</a><br><a href="https://linux.oracle.com/cve/CVE-2021-3326.html">https://linux.oracle.com/cve/CVE-2021-3326.html</a><br><a href="https://linux.oracle.com/errata/ELSA-2021-9344.html">https://linux.oracle.com/errata/ELSA-2021-9344.html</a><br><a href="https://security.netapp.com/advisory/ntap-20210304-0007/">https://security.netapp.com/advisory/ntap-20210304-0007/</a><br><a href="https://sourceware.org/bugzilla/show_bug.cgi?id=27256">https://sourceware.org/bugzilla/show_bug.cgi?id=27256</a><br><a href="https://sourceware.org/git/?p=glibc.git;a=commit;h=7d88c6142c6efc160c0ee5e4f85cde382c072888">https://sourceware.org/git/?p=glibc.git;a=commit;h=7d88c6142c6efc160c0ee5e4f85cde382c072888</a><br><a href="https://sourceware.org/pipermail/libc-alpha/2021-January/122058.html">https://sourceware.org/pipermail/libc-alpha/2021-January/122058.html</a><br></details>  |
| libc6         |    CVE-2021-33574   |   LOW  |  2.27-3ubuntu1.4 |  | <details><summary>Expand...</summary><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2021-33574">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2021-33574</a><br><a href="https://linux.oracle.com/cve/CVE-2021-33574.html">https://linux.oracle.com/cve/CVE-2021-33574.html</a><br><a href="https://linux.oracle.com/errata/ELSA-2021-9560.html">https://linux.oracle.com/errata/ELSA-2021-9560.html</a><br><a href="https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/RBUUWUGXVILQXVWEOU7N42ICHPJNAEUP/">https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/RBUUWUGXVILQXVWEOU7N42ICHPJNAEUP/</a><br><a href="https://security.gentoo.org/glsa/202107-07">https://security.gentoo.org/glsa/202107-07</a><br><a href="https://security.netapp.com/advisory/ntap-20210629-0005/">https://security.netapp.com/advisory/ntap-20210629-0005/</a><br><a href="https://sourceware.org/bugzilla/show_bug.cgi?id=27896">https://sourceware.org/bugzilla/show_bug.cgi?id=27896</a><br><a href="https://sourceware.org/bugzilla/show_bug.cgi?id=27896#c1">https://sourceware.org/bugzilla/show_bug.cgi?id=27896#c1</a><br></details>  |
| libc6-dev         |    CVE-2021-35942   |   MEDIUM  |  2.27-3ubuntu1.4 |  | <details><summary>Expand...</summary><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2021-35942">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2021-35942</a><br><a href="https://linux.oracle.com/cve/CVE-2021-35942.html">https://linux.oracle.com/cve/CVE-2021-35942.html</a><br><a href="https://linux.oracle.com/errata/ELSA-2021-9560.html">https://linux.oracle.com/errata/ELSA-2021-9560.html</a><br><a href="https://security.netapp.com/advisory/ntap-20210827-0005/">https://security.netapp.com/advisory/ntap-20210827-0005/</a><br><a href="https://sourceware.org/bugzilla/show_bug.cgi?id=28011">https://sourceware.org/bugzilla/show_bug.cgi?id=28011</a><br><a href="https://sourceware.org/git/?p=glibc.git;a=commit;h=5adda61f62b77384718b4c0d8336ade8f2b4b35c">https://sourceware.org/git/?p=glibc.git;a=commit;h=5adda61f62b77384718b4c0d8336ade8f2b4b35c</a><br><a href="https://sourceware.org/git/?p=glibc.git;a=commitdiff;h=5adda61f62b77384718b4c0d8336ade8f2b4b35c">https://sourceware.org/git/?p=glibc.git;a=commitdiff;h=5adda61f62b77384718b4c0d8336ade8f2b4b35c</a><br><a href="https://sourceware.org/glibc/wiki/Security%20Exceptions">https://sourceware.org/glibc/wiki/Security%20Exceptions</a><br></details>  |
| libc6-dev         |    CVE-2021-38604   |   MEDIUM  |  2.27-3ubuntu1.4 |  | <details><summary>Expand...</summary><a href="https://blog.tuxcare.com/cve/tuxcare-team-identifies-cve-2021-38604-a-new-vulnerability-in-glibc">https://blog.tuxcare.com/cve/tuxcare-team-identifies-cve-2021-38604-a-new-vulnerability-in-glibc</a><br><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2021-38604">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2021-38604</a><br><a href="https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/GYEXYM37RCJWJ6B5KQUYQI4NZBDDYSXP/">https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/GYEXYM37RCJWJ6B5KQUYQI4NZBDDYSXP/</a><br><a href="https://security.netapp.com/advisory/ntap-20210909-0005/">https://security.netapp.com/advisory/ntap-20210909-0005/</a><br><a href="https://sourceware.org/bugzilla/show_bug.cgi?id=28213">https://sourceware.org/bugzilla/show_bug.cgi?id=28213</a><br><a href="https://sourceware.org/git/?p=glibc.git;a=commit;h=4cc79c217744743077bf7a0ec5e0a4318f1e6641">https://sourceware.org/git/?p=glibc.git;a=commit;h=4cc79c217744743077bf7a0ec5e0a4318f1e6641</a><br><a href="https://sourceware.org/git/?p=glibc.git;a=commit;h=b805aebd42364fe696e417808a700fdb9800c9e8">https://sourceware.org/git/?p=glibc.git;a=commit;h=b805aebd42364fe696e417808a700fdb9800c9e8</a><br></details>  |
| libc6-dev         |    CVE-2009-5155   |   LOW  |  2.27-3ubuntu1.4 |  | <details><summary>Expand...</summary><a href="http://git.savannah.gnu.org/cgit/gnulib.git/commit/?id=5513b40999149090987a0341c018d05d3eea1272">http://git.savannah.gnu.org/cgit/gnulib.git/commit/?id=5513b40999149090987a0341c018d05d3eea1272</a><br><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2009-5155">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2009-5155</a><br><a href="https://debbugs.gnu.org/cgi/bugreport.cgi?bug=22793">https://debbugs.gnu.org/cgi/bugreport.cgi?bug=22793</a><br><a href="https://debbugs.gnu.org/cgi/bugreport.cgi?bug=32806">https://debbugs.gnu.org/cgi/bugreport.cgi?bug=32806</a><br><a href="https://debbugs.gnu.org/cgi/bugreport.cgi?bug=34238">https://debbugs.gnu.org/cgi/bugreport.cgi?bug=34238</a><br><a href="https://lists.apache.org/thread.html/r58af02e294bd07f487e2c64ffc0a29b837db5600e33b6e698b9d696b@%3Cissues.bookkeeper.apache.org%3E">https://lists.apache.org/thread.html/r58af02e294bd07f487e2c64ffc0a29b837db5600e33b6e698b9d696b@%3Cissues.bookkeeper.apache.org%3E</a><br><a href="https://lists.apache.org/thread.html/rf4c02775860db415b4955778a131c2795223f61cb8c6a450893651e4@%3Cissues.bookkeeper.apache.org%3E">https://lists.apache.org/thread.html/rf4c02775860db415b4955778a131c2795223f61cb8c6a450893651e4@%3Cissues.bookkeeper.apache.org%3E</a><br><a href="https://security.netapp.com/advisory/ntap-20190315-0002/">https://security.netapp.com/advisory/ntap-20190315-0002/</a><br><a href="https://sourceware.org/bugzilla/show_bug.cgi?id=11053">https://sourceware.org/bugzilla/show_bug.cgi?id=11053</a><br><a href="https://sourceware.org/bugzilla/show_bug.cgi?id=18986">https://sourceware.org/bugzilla/show_bug.cgi?id=18986</a><br><a href="https://sourceware.org/git/gitweb.cgi?p=glibc.git;h=eb04c21373e2a2885f3d52ff192b0499afe3c672">https://sourceware.org/git/gitweb.cgi?p=glibc.git;h=eb04c21373e2a2885f3d52ff192b0499afe3c672</a><br><a href="https://support.f5.com/csp/article/K64119434">https://support.f5.com/csp/article/K64119434</a><br><a href="https://support.f5.com/csp/article/K64119434?utm_source=f5support&amp;amp;utm_medium=RSS">https://support.f5.com/csp/article/K64119434?utm_source=f5support&amp;amp;utm_medium=RSS</a><br><a href="https://ubuntu.com/security/notices/USN-4954-1">https://ubuntu.com/security/notices/USN-4954-1</a><br></details>  |
| libc6-dev         |    CVE-2015-8985   |   LOW  |  2.27-3ubuntu1.4 |  | <details><summary>Expand...</summary><a href="http://www.openwall.com/lists/oss-security/2017/02/14/9">http://www.openwall.com/lists/oss-security/2017/02/14/9</a><br><a href="http://www.securityfocus.com/bid/76916">http://www.securityfocus.com/bid/76916</a><br><a href="https://bugs.debian.org/cgi-bin/bugreport.cgi?bug=779392">https://bugs.debian.org/cgi-bin/bugreport.cgi?bug=779392</a><br><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2015-8985">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2015-8985</a><br><a href="https://security.gentoo.org/glsa/201908-06">https://security.gentoo.org/glsa/201908-06</a><br></details>  |
| libc6-dev         |    CVE-2016-10228   |   LOW  |  2.27-3ubuntu1.4 |  | <details><summary>Expand...</summary><a href="http://openwall.com/lists/oss-security/2017/03/01/10">http://openwall.com/lists/oss-security/2017/03/01/10</a><br><a href="http://www.securityfocus.com/bid/96525">http://www.securityfocus.com/bid/96525</a><br><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2016-10228">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2016-10228</a><br><a href="https://linux.oracle.com/cve/CVE-2016-10228.html">https://linux.oracle.com/cve/CVE-2016-10228.html</a><br><a href="https://linux.oracle.com/errata/ELSA-2021-9344.html">https://linux.oracle.com/errata/ELSA-2021-9344.html</a><br><a href="https://lists.apache.org/thread.html/rf9fa47ab66495c78bb4120b0754dd9531ca2ff0430f6685ac9b07772@%3Cdev.mina.apache.org%3E">https://lists.apache.org/thread.html/rf9fa47ab66495c78bb4120b0754dd9531ca2ff0430f6685ac9b07772@%3Cdev.mina.apache.org%3E</a><br><a href="https://security.gentoo.org/glsa/202101-20">https://security.gentoo.org/glsa/202101-20</a><br><a href="https://sourceware.org/bugzilla/show_bug.cgi?id=19519">https://sourceware.org/bugzilla/show_bug.cgi?id=19519</a><br><a href="https://sourceware.org/bugzilla/show_bug.cgi?id=19519#c21">https://sourceware.org/bugzilla/show_bug.cgi?id=19519#c21</a><br><a href="https://sourceware.org/bugzilla/show_bug.cgi?id=26224">https://sourceware.org/bugzilla/show_bug.cgi?id=26224</a><br></details>  |
| libc6-dev         |    CVE-2016-10739   |   LOW  |  2.27-3ubuntu1.4 |  | <details><summary>Expand...</summary><a href="http://lists.opensuse.org/opensuse-security-announce/2019-04/msg00082.html">http://lists.opensuse.org/opensuse-security-announce/2019-04/msg00082.html</a><br><a href="http://www.securityfocus.com/bid/106672">http://www.securityfocus.com/bid/106672</a><br><a href="https://access.redhat.com/errata/RHSA-2019:2118">https://access.redhat.com/errata/RHSA-2019:2118</a><br><a href="https://access.redhat.com/errata/RHSA-2019:3513">https://access.redhat.com/errata/RHSA-2019:3513</a><br><a href="https://bugzilla.redhat.com/show_bug.cgi?id=1347549">https://bugzilla.redhat.com/show_bug.cgi?id=1347549</a><br><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2016-10739">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2016-10739</a><br><a href="https://linux.oracle.com/cve/CVE-2016-10739.html">https://linux.oracle.com/cve/CVE-2016-10739.html</a><br><a href="https://linux.oracle.com/errata/ELSA-2019-3513.html">https://linux.oracle.com/errata/ELSA-2019-3513.html</a><br><a href="https://sourceware.org/bugzilla/show_bug.cgi?id=20018">https://sourceware.org/bugzilla/show_bug.cgi?id=20018</a><br></details>  |
| libc6-dev         |    CVE-2019-25013   |   LOW  |  2.27-3ubuntu1.4 |  | <details><summary>Expand...</summary><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2019-25013">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2019-25013</a><br><a href="https://linux.oracle.com/cve/CVE-2019-25013.html">https://linux.oracle.com/cve/CVE-2019-25013.html</a><br><a href="https://linux.oracle.com/errata/ELSA-2021-9344.html">https://linux.oracle.com/errata/ELSA-2021-9344.html</a><br><a href="https://lists.apache.org/thread.html/r32d767ac804e9b8aad4355bb85960a6a1385eab7afff549a5e98660f@%3Cjira.kafka.apache.org%3E">https://lists.apache.org/thread.html/r32d767ac804e9b8aad4355bb85960a6a1385eab7afff549a5e98660f@%3Cjira.kafka.apache.org%3E</a><br><a href="https://lists.apache.org/thread.html/r448bb851cc8e6e3f93f3c28c70032b37062625d81214744474ac49e7@%3Cdev.kafka.apache.org%3E">https://lists.apache.org/thread.html/r448bb851cc8e6e3f93f3c28c70032b37062625d81214744474ac49e7@%3Cdev.kafka.apache.org%3E</a><br><a href="https://lists.apache.org/thread.html/r4806a391091e082bdea17266452ca656ebc176e51bb3932733b3a0a2@%3Cjira.kafka.apache.org%3E">https://lists.apache.org/thread.html/r4806a391091e082bdea17266452ca656ebc176e51bb3932733b3a0a2@%3Cjira.kafka.apache.org%3E</a><br><a href="https://lists.apache.org/thread.html/r499e4f96d0b5109ef083f2feccd33c51650c1b7d7068aa3bd47efca9@%3Cjira.kafka.apache.org%3E">https://lists.apache.org/thread.html/r499e4f96d0b5109ef083f2feccd33c51650c1b7d7068aa3bd47efca9@%3Cjira.kafka.apache.org%3E</a><br><a href="https://lists.apache.org/thread.html/r5af4430421bb6f9973294691a7904bbd260937e9eef96b20556f43ff@%3Cjira.kafka.apache.org%3E">https://lists.apache.org/thread.html/r5af4430421bb6f9973294691a7904bbd260937e9eef96b20556f43ff@%3Cjira.kafka.apache.org%3E</a><br><a href="https://lists.apache.org/thread.html/r750eee18542bc02bd8350861c424ee60a9b9b225568fa09436a37ece@%3Cissues.zookeeper.apache.org%3E">https://lists.apache.org/thread.html/r750eee18542bc02bd8350861c424ee60a9b9b225568fa09436a37ece@%3Cissues.zookeeper.apache.org%3E</a><br><a href="https://lists.apache.org/thread.html/r7a2e94adfe0a2f0a1d42e4927e8c32ecac97d37db9cb68095fe9ddbc@%3Cdev.zookeeper.apache.org%3E">https://lists.apache.org/thread.html/r7a2e94adfe0a2f0a1d42e4927e8c32ecac97d37db9cb68095fe9ddbc@%3Cdev.zookeeper.apache.org%3E</a><br><a href="https://lists.apache.org/thread.html/rd2354f9ccce41e494fbadcbc5ad87218de6ec0fff8a7b54c8462226c@%3Cissues.zookeeper.apache.org%3E">https://lists.apache.org/thread.html/rd2354f9ccce41e494fbadcbc5ad87218de6ec0fff8a7b54c8462226c@%3Cissues.zookeeper.apache.org%3E</a><br><a href="https://lists.apache.org/thread.html/rf9fa47ab66495c78bb4120b0754dd9531ca2ff0430f6685ac9b07772@%3Cdev.mina.apache.org%3E">https://lists.apache.org/thread.html/rf9fa47ab66495c78bb4120b0754dd9531ca2ff0430f6685ac9b07772@%3Cdev.mina.apache.org%3E</a><br><a href="https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/4Y6TX47P47KABSFOL26FLDNVCWXDKDEZ/">https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/4Y6TX47P47KABSFOL26FLDNVCWXDKDEZ/</a><br><a href="https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/TVCUNLQ3HXGS4VPUQKWTJGRAW2KTFGXS/">https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/TVCUNLQ3HXGS4VPUQKWTJGRAW2KTFGXS/</a><br><a href="https://security.netapp.com/advisory/ntap-20210205-0004/">https://security.netapp.com/advisory/ntap-20210205-0004/</a><br><a href="https://sourceware.org/bugzilla/show_bug.cgi?id=24973">https://sourceware.org/bugzilla/show_bug.cgi?id=24973</a><br><a href="https://sourceware.org/git/?p=glibc.git;a=commit;h=ee7a3144c9922808181009b7b3e50e852fb4999b">https://sourceware.org/git/?p=glibc.git;a=commit;h=ee7a3144c9922808181009b7b3e50e852fb4999b</a><br></details>  |
| libc6-dev         |    CVE-2020-27618   |   LOW  |  2.27-3ubuntu1.4 |  | <details><summary>Expand...</summary><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2020-27618">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2020-27618</a><br><a href="https://linux.oracle.com/cve/CVE-2020-27618.html">https://linux.oracle.com/cve/CVE-2020-27618.html</a><br><a href="https://linux.oracle.com/errata/ELSA-2021-9344.html">https://linux.oracle.com/errata/ELSA-2021-9344.html</a><br><a href="https://security.netapp.com/advisory/ntap-20210401-0006/">https://security.netapp.com/advisory/ntap-20210401-0006/</a><br><a href="https://sourceware.org/bugzilla/show_bug.cgi?id=19519#c21">https://sourceware.org/bugzilla/show_bug.cgi?id=19519#c21</a><br><a href="https://sourceware.org/bugzilla/show_bug.cgi?id=26224">https://sourceware.org/bugzilla/show_bug.cgi?id=26224</a><br></details>  |
| libc6-dev         |    CVE-2020-6096   |   LOW  |  2.27-3ubuntu1.4 |  | <details><summary>Expand...</summary><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2020-6096">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2020-6096</a><br><a href="https://lists.apache.org/thread.html/rf9fa47ab66495c78bb4120b0754dd9531ca2ff0430f6685ac9b07772@%3Cdev.mina.apache.org%3E">https://lists.apache.org/thread.html/rf9fa47ab66495c78bb4120b0754dd9531ca2ff0430f6685ac9b07772@%3Cdev.mina.apache.org%3E</a><br><a href="https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/SPYXTDOOB4PQGTYAMZAZNJIB3FF6YQXI/">https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/SPYXTDOOB4PQGTYAMZAZNJIB3FF6YQXI/</a><br><a href="https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/URXOIA2LDUKHQXK4BE55BQBRI6ZZG3Y6/">https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/URXOIA2LDUKHQXK4BE55BQBRI6ZZG3Y6/</a><br><a href="https://security.gentoo.org/glsa/202101-20">https://security.gentoo.org/glsa/202101-20</a><br><a href="https://sourceware.org/bugzilla/attachment.cgi?id=12334">https://sourceware.org/bugzilla/attachment.cgi?id=12334</a><br><a href="https://sourceware.org/bugzilla/show_bug.cgi?id=25620">https://sourceware.org/bugzilla/show_bug.cgi?id=25620</a><br><a href="https://talosintelligence.com/vulnerability_reports/TALOS-2020-1019">https://talosintelligence.com/vulnerability_reports/TALOS-2020-1019</a><br><a href="https://ubuntu.com/security/notices/USN-4954-1">https://ubuntu.com/security/notices/USN-4954-1</a><br><a href="https://www.talosintelligence.com/vulnerability_reports/TALOS-2020-1019">https://www.talosintelligence.com/vulnerability_reports/TALOS-2020-1019</a><br></details>  |
| libc6-dev         |    CVE-2021-3326   |   LOW  |  2.27-3ubuntu1.4 |  | <details><summary>Expand...</summary><a href="http://www.openwall.com/lists/oss-security/2021/01/28/2">http://www.openwall.com/lists/oss-security/2021/01/28/2</a><br><a href="https://bugs.chromium.org/p/project-zero/issues/detail?id=2146">https://bugs.chromium.org/p/project-zero/issues/detail?id=2146</a><br><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2021-3326">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2021-3326</a><br><a href="https://linux.oracle.com/cve/CVE-2021-3326.html">https://linux.oracle.com/cve/CVE-2021-3326.html</a><br><a href="https://linux.oracle.com/errata/ELSA-2021-9344.html">https://linux.oracle.com/errata/ELSA-2021-9344.html</a><br><a href="https://security.netapp.com/advisory/ntap-20210304-0007/">https://security.netapp.com/advisory/ntap-20210304-0007/</a><br><a href="https://sourceware.org/bugzilla/show_bug.cgi?id=27256">https://sourceware.org/bugzilla/show_bug.cgi?id=27256</a><br><a href="https://sourceware.org/git/?p=glibc.git;a=commit;h=7d88c6142c6efc160c0ee5e4f85cde382c072888">https://sourceware.org/git/?p=glibc.git;a=commit;h=7d88c6142c6efc160c0ee5e4f85cde382c072888</a><br><a href="https://sourceware.org/pipermail/libc-alpha/2021-January/122058.html">https://sourceware.org/pipermail/libc-alpha/2021-January/122058.html</a><br></details>  |
| libc6-dev         |    CVE-2021-33574   |   LOW  |  2.27-3ubuntu1.4 |  | <details><summary>Expand...</summary><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2021-33574">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2021-33574</a><br><a href="https://linux.oracle.com/cve/CVE-2021-33574.html">https://linux.oracle.com/cve/CVE-2021-33574.html</a><br><a href="https://linux.oracle.com/errata/ELSA-2021-9560.html">https://linux.oracle.com/errata/ELSA-2021-9560.html</a><br><a href="https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/RBUUWUGXVILQXVWEOU7N42ICHPJNAEUP/">https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/RBUUWUGXVILQXVWEOU7N42ICHPJNAEUP/</a><br><a href="https://security.gentoo.org/glsa/202107-07">https://security.gentoo.org/glsa/202107-07</a><br><a href="https://security.netapp.com/advisory/ntap-20210629-0005/">https://security.netapp.com/advisory/ntap-20210629-0005/</a><br><a href="https://sourceware.org/bugzilla/show_bug.cgi?id=27896">https://sourceware.org/bugzilla/show_bug.cgi?id=27896</a><br><a href="https://sourceware.org/bugzilla/show_bug.cgi?id=27896#c1">https://sourceware.org/bugzilla/show_bug.cgi?id=27896#c1</a><br></details>  |
| libcairo2         |    CVE-2017-7475   |   LOW  |  1.15.10-2ubuntu0.1 |  | <details><summary>Expand...</summary><a href="http://seclists.org/oss-sec/2017/q2/151">http://seclists.org/oss-sec/2017/q2/151</a><br><a href="https://bugs.freedesktop.org/show_bug.cgi?id=100763">https://bugs.freedesktop.org/show_bug.cgi?id=100763</a><br><a href="https://bugzilla.redhat.com/show_bug.cgi?id=CVE-2017-7475">https://bugzilla.redhat.com/show_bug.cgi?id=CVE-2017-7475</a><br><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2017-7475">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2017-7475</a><br><a href="https://github.com/advisories/GHSA-5v3f-73gv-x7x5">https://github.com/advisories/GHSA-5v3f-73gv-x7x5</a><br><a href="https://lists.apache.org/thread.html/rf9fa47ab66495c78bb4120b0754dd9531ca2ff0430f6685ac9b07772@%3Cdev.mina.apache.org%3E">https://lists.apache.org/thread.html/rf9fa47ab66495c78bb4120b0754dd9531ca2ff0430f6685ac9b07772@%3Cdev.mina.apache.org%3E</a><br><a href="https://nvd.nist.gov/vuln/detail/CVE-2017-7475">https://nvd.nist.gov/vuln/detail/CVE-2017-7475</a><br></details>  |
| libcairo2         |    CVE-2017-9814   |   LOW  |  1.15.10-2ubuntu0.1 |  | <details><summary>Expand...</summary><a href="http://lists.opensuse.org/opensuse-security-announce/2020-07/msg00042.html">http://lists.opensuse.org/opensuse-security-announce/2020-07/msg00042.html</a><br><a href="https://bugs.freedesktop.org/show_bug.cgi?id=101547">https://bugs.freedesktop.org/show_bug.cgi?id=101547</a><br><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2017-9814">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2017-9814</a><br><a href="https://lists.apache.org/thread.html/rf9fa47ab66495c78bb4120b0754dd9531ca2ff0430f6685ac9b07772@%3Cdev.mina.apache.org%3E">https://lists.apache.org/thread.html/rf9fa47ab66495c78bb4120b0754dd9531ca2ff0430f6685ac9b07772@%3Cdev.mina.apache.org%3E</a><br><a href="https://security.gentoo.org/glsa/201904-01">https://security.gentoo.org/glsa/201904-01</a><br></details>  |
| libcairo2         |    CVE-2018-18064   |   LOW  |  1.15.10-2ubuntu0.1 |  | <details><summary>Expand...</summary><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2018-18064">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2018-18064</a><br><a href="https://gitlab.freedesktop.org/cairo/cairo/issues/341">https://gitlab.freedesktop.org/cairo/cairo/issues/341</a><br><a href="https://lists.apache.org/thread.html/rf9fa47ab66495c78bb4120b0754dd9531ca2ff0430f6685ac9b07772@%3Cdev.mina.apache.org%3E">https://lists.apache.org/thread.html/rf9fa47ab66495c78bb4120b0754dd9531ca2ff0430f6685ac9b07772@%3Cdev.mina.apache.org%3E</a><br></details>  |
| libcairo2         |    CVE-2019-6461   |   LOW  |  1.15.10-2ubuntu0.1 |  | <details><summary>Expand...</summary><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2019-6461">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2019-6461</a><br><a href="https://github.com/TeamSeri0us/pocs/tree/master/gerbv">https://github.com/TeamSeri0us/pocs/tree/master/gerbv</a><br><a href="https://gitlab.freedesktop.org/cairo/cairo/issues/352">https://gitlab.freedesktop.org/cairo/cairo/issues/352</a><br><a href="https://lists.apache.org/thread.html/rf9fa47ab66495c78bb4120b0754dd9531ca2ff0430f6685ac9b07772@%3Cdev.mina.apache.org%3E">https://lists.apache.org/thread.html/rf9fa47ab66495c78bb4120b0754dd9531ca2ff0430f6685ac9b07772@%3Cdev.mina.apache.org%3E</a><br></details>  |
| libcairo2         |    CVE-2019-6462   |   LOW  |  1.15.10-2ubuntu0.1 |  | <details><summary>Expand...</summary><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2019-6462">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2019-6462</a><br><a href="https://github.com/TeamSeri0us/pocs/tree/master/gerbv">https://github.com/TeamSeri0us/pocs/tree/master/gerbv</a><br><a href="https://gitlab.freedesktop.org/cairo/cairo/issues/353">https://gitlab.freedesktop.org/cairo/cairo/issues/353</a><br><a href="https://lists.apache.org/thread.html/rf9fa47ab66495c78bb4120b0754dd9531ca2ff0430f6685ac9b07772@%3Cdev.mina.apache.org%3E">https://lists.apache.org/thread.html/rf9fa47ab66495c78bb4120b0754dd9531ca2ff0430f6685ac9b07772@%3Cdev.mina.apache.org%3E</a><br></details>  |
| libcc1-0         |    CVE-2020-13844   |   MEDIUM  |  8.4.0-1ubuntu1~18.04 |  | <details><summary>Expand...</summary><a href="http://lists.llvm.org/pipermail/llvm-dev/2020-June/142109.html">http://lists.llvm.org/pipermail/llvm-dev/2020-June/142109.html</a><br><a href="http://lists.opensuse.org/opensuse-security-announce/2020-10/msg00039.html">http://lists.opensuse.org/opensuse-security-announce/2020-10/msg00039.html</a><br><a href="http://lists.opensuse.org/opensuse-security-announce/2020-10/msg00040.html">http://lists.opensuse.org/opensuse-security-announce/2020-10/msg00040.html</a><br><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2020-13844">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2020-13844</a><br><a href="https://developer.arm.com/support/arm-security-updates/speculative-processor-vulnerability">https://developer.arm.com/support/arm-security-updates/speculative-processor-vulnerability</a><br><a href="https://developer.arm.com/support/arm-security-updates/speculative-processor-vulnerability/downloads/straight-line-speculation">https://developer.arm.com/support/arm-security-updates/speculative-processor-vulnerability/downloads/straight-line-speculation</a><br><a href="https://developer.arm.com/support/arm-security-updates/speculative-processor-vulnerability/frequently-asked-questions">https://developer.arm.com/support/arm-security-updates/speculative-processor-vulnerability/frequently-asked-questions</a><br><a href="https://gcc.gnu.org/pipermail/gcc-patches/2020-June/547520.html">https://gcc.gnu.org/pipermail/gcc-patches/2020-June/547520.html</a><br><a href="https://git.kernel.org/pub/scm/linux/kernel/git/torvalds/linux.git/commit/?id=679db70801da9fda91d26caf13bf5b5ccc74e8e8">https://git.kernel.org/pub/scm/linux/kernel/git/torvalds/linux.git/commit/?id=679db70801da9fda91d26caf13bf5b5ccc74e8e8</a><br></details>  |
| libcilkrts5         |    CVE-2020-13844   |   MEDIUM  |  7.5.0-3ubuntu1~18.04 |  | <details><summary>Expand...</summary><a href="http://lists.llvm.org/pipermail/llvm-dev/2020-June/142109.html">http://lists.llvm.org/pipermail/llvm-dev/2020-June/142109.html</a><br><a href="http://lists.opensuse.org/opensuse-security-announce/2020-10/msg00039.html">http://lists.opensuse.org/opensuse-security-announce/2020-10/msg00039.html</a><br><a href="http://lists.opensuse.org/opensuse-security-announce/2020-10/msg00040.html">http://lists.opensuse.org/opensuse-security-announce/2020-10/msg00040.html</a><br><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2020-13844">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2020-13844</a><br><a href="https://developer.arm.com/support/arm-security-updates/speculative-processor-vulnerability">https://developer.arm.com/support/arm-security-updates/speculative-processor-vulnerability</a><br><a href="https://developer.arm.com/support/arm-security-updates/speculative-processor-vulnerability/downloads/straight-line-speculation">https://developer.arm.com/support/arm-security-updates/speculative-processor-vulnerability/downloads/straight-line-speculation</a><br><a href="https://developer.arm.com/support/arm-security-updates/speculative-processor-vulnerability/frequently-asked-questions">https://developer.arm.com/support/arm-security-updates/speculative-processor-vulnerability/frequently-asked-questions</a><br><a href="https://gcc.gnu.org/pipermail/gcc-patches/2020-June/547520.html">https://gcc.gnu.org/pipermail/gcc-patches/2020-June/547520.html</a><br><a href="https://git.kernel.org/pub/scm/linux/kernel/git/torvalds/linux.git/commit/?id=679db70801da9fda91d26caf13bf5b5ccc74e8e8">https://git.kernel.org/pub/scm/linux/kernel/git/torvalds/linux.git/commit/?id=679db70801da9fda91d26caf13bf5b5ccc74e8e8</a><br></details>  |
| libgcc-7-dev         |    CVE-2020-13844   |   MEDIUM  |  7.5.0-3ubuntu1~18.04 |  | <details><summary>Expand...</summary><a href="http://lists.llvm.org/pipermail/llvm-dev/2020-June/142109.html">http://lists.llvm.org/pipermail/llvm-dev/2020-June/142109.html</a><br><a href="http://lists.opensuse.org/opensuse-security-announce/2020-10/msg00039.html">http://lists.opensuse.org/opensuse-security-announce/2020-10/msg00039.html</a><br><a href="http://lists.opensuse.org/opensuse-security-announce/2020-10/msg00040.html">http://lists.opensuse.org/opensuse-security-announce/2020-10/msg00040.html</a><br><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2020-13844">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2020-13844</a><br><a href="https://developer.arm.com/support/arm-security-updates/speculative-processor-vulnerability">https://developer.arm.com/support/arm-security-updates/speculative-processor-vulnerability</a><br><a href="https://developer.arm.com/support/arm-security-updates/speculative-processor-vulnerability/downloads/straight-line-speculation">https://developer.arm.com/support/arm-security-updates/speculative-processor-vulnerability/downloads/straight-line-speculation</a><br><a href="https://developer.arm.com/support/arm-security-updates/speculative-processor-vulnerability/frequently-asked-questions">https://developer.arm.com/support/arm-security-updates/speculative-processor-vulnerability/frequently-asked-questions</a><br><a href="https://gcc.gnu.org/pipermail/gcc-patches/2020-June/547520.html">https://gcc.gnu.org/pipermail/gcc-patches/2020-June/547520.html</a><br><a href="https://git.kernel.org/pub/scm/linux/kernel/git/torvalds/linux.git/commit/?id=679db70801da9fda91d26caf13bf5b5ccc74e8e8">https://git.kernel.org/pub/scm/linux/kernel/git/torvalds/linux.git/commit/?id=679db70801da9fda91d26caf13bf5b5ccc74e8e8</a><br></details>  |
| libgcc1         |    CVE-2020-13844   |   MEDIUM  |  8.4.0-1ubuntu1~18.04 |  | <details><summary>Expand...</summary><a href="http://lists.llvm.org/pipermail/llvm-dev/2020-June/142109.html">http://lists.llvm.org/pipermail/llvm-dev/2020-June/142109.html</a><br><a href="http://lists.opensuse.org/opensuse-security-announce/2020-10/msg00039.html">http://lists.opensuse.org/opensuse-security-announce/2020-10/msg00039.html</a><br><a href="http://lists.opensuse.org/opensuse-security-announce/2020-10/msg00040.html">http://lists.opensuse.org/opensuse-security-announce/2020-10/msg00040.html</a><br><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2020-13844">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2020-13844</a><br><a href="https://developer.arm.com/support/arm-security-updates/speculative-processor-vulnerability">https://developer.arm.com/support/arm-security-updates/speculative-processor-vulnerability</a><br><a href="https://developer.arm.com/support/arm-security-updates/speculative-processor-vulnerability/downloads/straight-line-speculation">https://developer.arm.com/support/arm-security-updates/speculative-processor-vulnerability/downloads/straight-line-speculation</a><br><a href="https://developer.arm.com/support/arm-security-updates/speculative-processor-vulnerability/frequently-asked-questions">https://developer.arm.com/support/arm-security-updates/speculative-processor-vulnerability/frequently-asked-questions</a><br><a href="https://gcc.gnu.org/pipermail/gcc-patches/2020-June/547520.html">https://gcc.gnu.org/pipermail/gcc-patches/2020-June/547520.html</a><br><a href="https://git.kernel.org/pub/scm/linux/kernel/git/torvalds/linux.git/commit/?id=679db70801da9fda91d26caf13bf5b5ccc74e8e8">https://git.kernel.org/pub/scm/linux/kernel/git/torvalds/linux.git/commit/?id=679db70801da9fda91d26caf13bf5b5ccc74e8e8</a><br></details>  |
| libgif7         |    CVE-2020-23922   |   LOW  |  5.1.4-2ubuntu0.1 |  | <details><summary>Expand...</summary><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2020-23922">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2020-23922</a><br><a href="https://lists.apache.org/thread.html/r58af02e294bd07f487e2c64ffc0a29b837db5600e33b6e698b9d696b@%3Cissues.bookkeeper.apache.org%3E">https://lists.apache.org/thread.html/r58af02e294bd07f487e2c64ffc0a29b837db5600e33b6e698b9d696b@%3Cissues.bookkeeper.apache.org%3E</a><br><a href="https://lists.apache.org/thread.html/rf4c02775860db415b4955778a131c2795223f61cb8c6a450893651e4@%3Cissues.bookkeeper.apache.org%3E">https://lists.apache.org/thread.html/rf4c02775860db415b4955778a131c2795223f61cb8c6a450893651e4@%3Cissues.bookkeeper.apache.org%3E</a><br><a href="https://sourceforge.net/p/giflib/bugs/151/">https://sourceforge.net/p/giflib/bugs/151/</a><br></details>  |
| libgnutls30         |    CVE-2018-16868   |   LOW  |  3.5.18-1ubuntu1.5 |  | <details><summary>Expand...</summary><a href="http://cat.eyalro.net/">http://cat.eyalro.net/</a><br><a href="http://lists.opensuse.org/opensuse-security-announce/2019-05/msg00017.html">http://lists.opensuse.org/opensuse-security-announce/2019-05/msg00017.html</a><br><a href="http://lists.opensuse.org/opensuse-security-announce/2019-05/msg00068.html">http://lists.opensuse.org/opensuse-security-announce/2019-05/msg00068.html</a><br><a href="http://www.securityfocus.com/bid/106080">http://www.securityfocus.com/bid/106080</a><br><a href="https://bugzilla.redhat.com/show_bug.cgi?id=CVE-2018-16868">https://bugzilla.redhat.com/show_bug.cgi?id=CVE-2018-16868</a><br><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2018-16868">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2018-16868</a><br></details>  |
| libgomp1         |    CVE-2020-13844   |   MEDIUM  |  8.4.0-1ubuntu1~18.04 |  | <details><summary>Expand...</summary><a href="http://lists.llvm.org/pipermail/llvm-dev/2020-June/142109.html">http://lists.llvm.org/pipermail/llvm-dev/2020-June/142109.html</a><br><a href="http://lists.opensuse.org/opensuse-security-announce/2020-10/msg00039.html">http://lists.opensuse.org/opensuse-security-announce/2020-10/msg00039.html</a><br><a href="http://lists.opensuse.org/opensuse-security-announce/2020-10/msg00040.html">http://lists.opensuse.org/opensuse-security-announce/2020-10/msg00040.html</a><br><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2020-13844">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2020-13844</a><br><a href="https://developer.arm.com/support/arm-security-updates/speculative-processor-vulnerability">https://developer.arm.com/support/arm-security-updates/speculative-processor-vulnerability</a><br><a href="https://developer.arm.com/support/arm-security-updates/speculative-processor-vulnerability/downloads/straight-line-speculation">https://developer.arm.com/support/arm-security-updates/speculative-processor-vulnerability/downloads/straight-line-speculation</a><br><a href="https://developer.arm.com/support/arm-security-updates/speculative-processor-vulnerability/frequently-asked-questions">https://developer.arm.com/support/arm-security-updates/speculative-processor-vulnerability/frequently-asked-questions</a><br><a href="https://gcc.gnu.org/pipermail/gcc-patches/2020-June/547520.html">https://gcc.gnu.org/pipermail/gcc-patches/2020-June/547520.html</a><br><a href="https://git.kernel.org/pub/scm/linux/kernel/git/torvalds/linux.git/commit/?id=679db70801da9fda91d26caf13bf5b5ccc74e8e8">https://git.kernel.org/pub/scm/linux/kernel/git/torvalds/linux.git/commit/?id=679db70801da9fda91d26caf13bf5b5ccc74e8e8</a><br></details>  |
| libgssapi-krb5-2         |    CVE-2018-20217   |   MEDIUM  |  1.16-2ubuntu0.2 |  | <details><summary>Expand...</summary><a href="http://krbdev.mit.edu/rt/Ticket/Display.html?id=8763">http://krbdev.mit.edu/rt/Ticket/Display.html?id=8763</a><br><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2018-20217">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2018-20217</a><br><a href="https://github.com/krb5/krb5/commit/5e6d1796106df8ba6bc1973ee0917c170d929086">https://github.com/krb5/krb5/commit/5e6d1796106df8ba6bc1973ee0917c170d929086</a><br><a href="https://lists.debian.org/debian-lts-announce/2019/01/msg00020.html">https://lists.debian.org/debian-lts-announce/2019/01/msg00020.html</a><br><a href="https://lists.debian.org/debian-lts-announce/2021/09/msg00019.html">https://lists.debian.org/debian-lts-announce/2021/09/msg00019.html</a><br><a href="https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/2KNHELH4YHNT6H2ESJWX2UIDXLBNGB2O/">https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/2KNHELH4YHNT6H2ESJWX2UIDXLBNGB2O/</a><br><a href="https://security.netapp.com/advisory/ntap-20190416-0006/">https://security.netapp.com/advisory/ntap-20190416-0006/</a><br></details>  |
| libgssapi-krb5-2         |    CVE-2021-36222   |   MEDIUM  |  1.16-2ubuntu0.2 |  | <details><summary>Expand...</summary><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2021-36222">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2021-36222</a><br><a href="https://github.com/krb5/krb5/commit/fc98f520caefff2e5ee9a0026fdf5109944b3562">https://github.com/krb5/krb5/commit/fc98f520caefff2e5ee9a0026fdf5109944b3562</a><br><a href="https://github.com/krb5/krb5/releases">https://github.com/krb5/krb5/releases</a><br><a href="https://linux.oracle.com/cve/CVE-2021-36222.html">https://linux.oracle.com/cve/CVE-2021-36222.html</a><br><a href="https://linux.oracle.com/errata/ELSA-2021-3576.html">https://linux.oracle.com/errata/ELSA-2021-3576.html</a><br><a href="https://security.netapp.com/advisory/ntap-20211022-0003/">https://security.netapp.com/advisory/ntap-20211022-0003/</a><br><a href="https://security.netapp.com/advisory/ntap-20211104-0007/">https://security.netapp.com/advisory/ntap-20211104-0007/</a><br><a href="https://web.mit.edu/kerberos/advisories/">https://web.mit.edu/kerberos/advisories/</a><br><a href="https://www.debian.org/security/2021/dsa-4944">https://www.debian.org/security/2021/dsa-4944</a><br><a href="https://www.oracle.com/security-alerts/cpuoct2021.html">https://www.oracle.com/security-alerts/cpuoct2021.html</a><br></details>  |
| libgssapi-krb5-2         |    CVE-2018-5709   |   LOW  |  1.16-2ubuntu0.2 |  | <details><summary>Expand...</summary><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2018-5709">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2018-5709</a><br><a href="https://github.com/poojamnit/Kerberos-V5-1.16-Vulnerabilities/tree/master/Integer%20Overflow">https://github.com/poojamnit/Kerberos-V5-1.16-Vulnerabilities/tree/master/Integer%20Overflow</a><br><a href="https://lists.apache.org/thread.html/rf9fa47ab66495c78bb4120b0754dd9531ca2ff0430f6685ac9b07772@%3Cdev.mina.apache.org%3E">https://lists.apache.org/thread.html/rf9fa47ab66495c78bb4120b0754dd9531ca2ff0430f6685ac9b07772@%3Cdev.mina.apache.org%3E</a><br></details>  |
| libgssapi-krb5-2         |    CVE-2018-5710   |   LOW  |  1.16-2ubuntu0.2 |  | <details><summary>Expand...</summary><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2018-5710">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2018-5710</a><br><a href="https://github.com/poojamnit/Kerberos-V5-1.16-Vulnerabilities/tree/master/Denial%20Of%20Service(DoS)">https://github.com/poojamnit/Kerberos-V5-1.16-Vulnerabilities/tree/master/Denial%20Of%20Service(DoS)</a><br></details>  |
| libgssapi3-heimdal         |    CVE-2019-12098   |   LOW  |  7.5.0+dfsg-1 |  | <details><summary>Expand...</summary><a href="http://lists.opensuse.org/opensuse-security-announce/2019-07/msg00002.html">http://lists.opensuse.org/opensuse-security-announce/2019-07/msg00002.html</a><br><a href="http://lists.opensuse.org/opensuse-security-announce/2019-07/msg00003.html">http://lists.opensuse.org/opensuse-security-announce/2019-07/msg00003.html</a><br><a href="http://lists.opensuse.org/opensuse-security-announce/2019-08/msg00026.html">http://lists.opensuse.org/opensuse-security-announce/2019-08/msg00026.html</a><br><a href="http://www.h5l.org/pipermail/heimdal-announce/2019-May/000009.html">http://www.h5l.org/pipermail/heimdal-announce/2019-May/000009.html</a><br><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2019-12098">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2019-12098</a><br><a href="https://github.com/heimdal/heimdal/commit/2f7f3d9960aa6ea21358bdf3687cee5149aa35cf">https://github.com/heimdal/heimdal/commit/2f7f3d9960aa6ea21358bdf3687cee5149aa35cf</a><br><a href="https://github.com/heimdal/heimdal/compare/3e58559...bbafe72">https://github.com/heimdal/heimdal/compare/3e58559...bbafe72</a><br><a href="https://github.com/heimdal/heimdal/releases/tag/heimdal-7.6.0">https://github.com/heimdal/heimdal/releases/tag/heimdal-7.6.0</a><br><a href="https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/GIXEDVVMPD6ZAJSMI2EZ7FNEIVNWE5PD/">https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/GIXEDVVMPD6ZAJSMI2EZ7FNEIVNWE5PD/</a><br><a href="https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/SLXXIF4LOQEAEDAF4UGP2AO6WDNTDFUB/">https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/SLXXIF4LOQEAEDAF4UGP2AO6WDNTDFUB/</a><br><a href="https://seclists.org/bugtraq/2019/Jun/1">https://seclists.org/bugtraq/2019/Jun/1</a><br><a href="https://www.debian.org/security/2019/dsa-4455">https://www.debian.org/security/2019/dsa-4455</a><br></details>  |
| libgssapi3-heimdal         |    CVE-2021-3671   |   LOW  |  7.5.0+dfsg-1 |  | <details><summary>Expand...</summary><a href="https://bugzilla.redhat.com/show_bug.cgi?id=2013080,">https://bugzilla.redhat.com/show_bug.cgi?id=2013080,</a><br><a href="https://bugzilla.samba.org/show_bug.cgi?id=14770,">https://bugzilla.samba.org/show_bug.cgi?id=14770,</a><br><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2021-3671">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2021-3671</a><br><a href="https://github.com/heimdal/heimdal/commit/04171147948d0a3636bc6374181926f0fb2ec83a">https://github.com/heimdal/heimdal/commit/04171147948d0a3636bc6374181926f0fb2ec83a</a><br><a href="https://ubuntu.com/security/notices/USN-5142-1">https://ubuntu.com/security/notices/USN-5142-1</a><br><a href="https://ubuntu.com/security/notices/USN-5174-1">https://ubuntu.com/security/notices/USN-5174-1</a><br></details>  |
| libhcrypto4-heimdal         |    CVE-2019-12098   |   LOW  |  7.5.0+dfsg-1 |  | <details><summary>Expand...</summary><a href="http://lists.opensuse.org/opensuse-security-announce/2019-07/msg00002.html">http://lists.opensuse.org/opensuse-security-announce/2019-07/msg00002.html</a><br><a href="http://lists.opensuse.org/opensuse-security-announce/2019-07/msg00003.html">http://lists.opensuse.org/opensuse-security-announce/2019-07/msg00003.html</a><br><a href="http://lists.opensuse.org/opensuse-security-announce/2019-08/msg00026.html">http://lists.opensuse.org/opensuse-security-announce/2019-08/msg00026.html</a><br><a href="http://www.h5l.org/pipermail/heimdal-announce/2019-May/000009.html">http://www.h5l.org/pipermail/heimdal-announce/2019-May/000009.html</a><br><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2019-12098">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2019-12098</a><br><a href="https://github.com/heimdal/heimdal/commit/2f7f3d9960aa6ea21358bdf3687cee5149aa35cf">https://github.com/heimdal/heimdal/commit/2f7f3d9960aa6ea21358bdf3687cee5149aa35cf</a><br><a href="https://github.com/heimdal/heimdal/compare/3e58559...bbafe72">https://github.com/heimdal/heimdal/compare/3e58559...bbafe72</a><br><a href="https://github.com/heimdal/heimdal/releases/tag/heimdal-7.6.0">https://github.com/heimdal/heimdal/releases/tag/heimdal-7.6.0</a><br><a href="https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/GIXEDVVMPD6ZAJSMI2EZ7FNEIVNWE5PD/">https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/GIXEDVVMPD6ZAJSMI2EZ7FNEIVNWE5PD/</a><br><a href="https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/SLXXIF4LOQEAEDAF4UGP2AO6WDNTDFUB/">https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/SLXXIF4LOQEAEDAF4UGP2AO6WDNTDFUB/</a><br><a href="https://seclists.org/bugtraq/2019/Jun/1">https://seclists.org/bugtraq/2019/Jun/1</a><br><a href="https://www.debian.org/security/2019/dsa-4455">https://www.debian.org/security/2019/dsa-4455</a><br></details>  |
| libhcrypto4-heimdal         |    CVE-2021-3671   |   LOW  |  7.5.0+dfsg-1 |  | <details><summary>Expand...</summary><a href="https://bugzilla.redhat.com/show_bug.cgi?id=2013080,">https://bugzilla.redhat.com/show_bug.cgi?id=2013080,</a><br><a href="https://bugzilla.samba.org/show_bug.cgi?id=14770,">https://bugzilla.samba.org/show_bug.cgi?id=14770,</a><br><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2021-3671">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2021-3671</a><br><a href="https://github.com/heimdal/heimdal/commit/04171147948d0a3636bc6374181926f0fb2ec83a">https://github.com/heimdal/heimdal/commit/04171147948d0a3636bc6374181926f0fb2ec83a</a><br><a href="https://ubuntu.com/security/notices/USN-5142-1">https://ubuntu.com/security/notices/USN-5142-1</a><br><a href="https://ubuntu.com/security/notices/USN-5174-1">https://ubuntu.com/security/notices/USN-5174-1</a><br></details>  |
| libheimbase1-heimdal         |    CVE-2019-12098   |   LOW  |  7.5.0+dfsg-1 |  | <details><summary>Expand...</summary><a href="http://lists.opensuse.org/opensuse-security-announce/2019-07/msg00002.html">http://lists.opensuse.org/opensuse-security-announce/2019-07/msg00002.html</a><br><a href="http://lists.opensuse.org/opensuse-security-announce/2019-07/msg00003.html">http://lists.opensuse.org/opensuse-security-announce/2019-07/msg00003.html</a><br><a href="http://lists.opensuse.org/opensuse-security-announce/2019-08/msg00026.html">http://lists.opensuse.org/opensuse-security-announce/2019-08/msg00026.html</a><br><a href="http://www.h5l.org/pipermail/heimdal-announce/2019-May/000009.html">http://www.h5l.org/pipermail/heimdal-announce/2019-May/000009.html</a><br><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2019-12098">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2019-12098</a><br><a href="https://github.com/heimdal/heimdal/commit/2f7f3d9960aa6ea21358bdf3687cee5149aa35cf">https://github.com/heimdal/heimdal/commit/2f7f3d9960aa6ea21358bdf3687cee5149aa35cf</a><br><a href="https://github.com/heimdal/heimdal/compare/3e58559...bbafe72">https://github.com/heimdal/heimdal/compare/3e58559...bbafe72</a><br><a href="https://github.com/heimdal/heimdal/releases/tag/heimdal-7.6.0">https://github.com/heimdal/heimdal/releases/tag/heimdal-7.6.0</a><br><a href="https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/GIXEDVVMPD6ZAJSMI2EZ7FNEIVNWE5PD/">https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/GIXEDVVMPD6ZAJSMI2EZ7FNEIVNWE5PD/</a><br><a href="https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/SLXXIF4LOQEAEDAF4UGP2AO6WDNTDFUB/">https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/SLXXIF4LOQEAEDAF4UGP2AO6WDNTDFUB/</a><br><a href="https://seclists.org/bugtraq/2019/Jun/1">https://seclists.org/bugtraq/2019/Jun/1</a><br><a href="https://www.debian.org/security/2019/dsa-4455">https://www.debian.org/security/2019/dsa-4455</a><br></details>  |
| libheimbase1-heimdal         |    CVE-2021-3671   |   LOW  |  7.5.0+dfsg-1 |  | <details><summary>Expand...</summary><a href="https://bugzilla.redhat.com/show_bug.cgi?id=2013080,">https://bugzilla.redhat.com/show_bug.cgi?id=2013080,</a><br><a href="https://bugzilla.samba.org/show_bug.cgi?id=14770,">https://bugzilla.samba.org/show_bug.cgi?id=14770,</a><br><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2021-3671">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2021-3671</a><br><a href="https://github.com/heimdal/heimdal/commit/04171147948d0a3636bc6374181926f0fb2ec83a">https://github.com/heimdal/heimdal/commit/04171147948d0a3636bc6374181926f0fb2ec83a</a><br><a href="https://ubuntu.com/security/notices/USN-5142-1">https://ubuntu.com/security/notices/USN-5142-1</a><br><a href="https://ubuntu.com/security/notices/USN-5174-1">https://ubuntu.com/security/notices/USN-5174-1</a><br></details>  |
| libheimntlm0-heimdal         |    CVE-2019-12098   |   LOW  |  7.5.0+dfsg-1 |  | <details><summary>Expand...</summary><a href="http://lists.opensuse.org/opensuse-security-announce/2019-07/msg00002.html">http://lists.opensuse.org/opensuse-security-announce/2019-07/msg00002.html</a><br><a href="http://lists.opensuse.org/opensuse-security-announce/2019-07/msg00003.html">http://lists.opensuse.org/opensuse-security-announce/2019-07/msg00003.html</a><br><a href="http://lists.opensuse.org/opensuse-security-announce/2019-08/msg00026.html">http://lists.opensuse.org/opensuse-security-announce/2019-08/msg00026.html</a><br><a href="http://www.h5l.org/pipermail/heimdal-announce/2019-May/000009.html">http://www.h5l.org/pipermail/heimdal-announce/2019-May/000009.html</a><br><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2019-12098">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2019-12098</a><br><a href="https://github.com/heimdal/heimdal/commit/2f7f3d9960aa6ea21358bdf3687cee5149aa35cf">https://github.com/heimdal/heimdal/commit/2f7f3d9960aa6ea21358bdf3687cee5149aa35cf</a><br><a href="https://github.com/heimdal/heimdal/compare/3e58559...bbafe72">https://github.com/heimdal/heimdal/compare/3e58559...bbafe72</a><br><a href="https://github.com/heimdal/heimdal/releases/tag/heimdal-7.6.0">https://github.com/heimdal/heimdal/releases/tag/heimdal-7.6.0</a><br><a href="https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/GIXEDVVMPD6ZAJSMI2EZ7FNEIVNWE5PD/">https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/GIXEDVVMPD6ZAJSMI2EZ7FNEIVNWE5PD/</a><br><a href="https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/SLXXIF4LOQEAEDAF4UGP2AO6WDNTDFUB/">https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/SLXXIF4LOQEAEDAF4UGP2AO6WDNTDFUB/</a><br><a href="https://seclists.org/bugtraq/2019/Jun/1">https://seclists.org/bugtraq/2019/Jun/1</a><br><a href="https://www.debian.org/security/2019/dsa-4455">https://www.debian.org/security/2019/dsa-4455</a><br></details>  |
| libheimntlm0-heimdal         |    CVE-2021-3671   |   LOW  |  7.5.0+dfsg-1 |  | <details><summary>Expand...</summary><a href="https://bugzilla.redhat.com/show_bug.cgi?id=2013080,">https://bugzilla.redhat.com/show_bug.cgi?id=2013080,</a><br><a href="https://bugzilla.samba.org/show_bug.cgi?id=14770,">https://bugzilla.samba.org/show_bug.cgi?id=14770,</a><br><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2021-3671">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2021-3671</a><br><a href="https://github.com/heimdal/heimdal/commit/04171147948d0a3636bc6374181926f0fb2ec83a">https://github.com/heimdal/heimdal/commit/04171147948d0a3636bc6374181926f0fb2ec83a</a><br><a href="https://ubuntu.com/security/notices/USN-5142-1">https://ubuntu.com/security/notices/USN-5142-1</a><br><a href="https://ubuntu.com/security/notices/USN-5174-1">https://ubuntu.com/security/notices/USN-5174-1</a><br></details>  |
| libhx509-5-heimdal         |    CVE-2019-12098   |   LOW  |  7.5.0+dfsg-1 |  | <details><summary>Expand...</summary><a href="http://lists.opensuse.org/opensuse-security-announce/2019-07/msg00002.html">http://lists.opensuse.org/opensuse-security-announce/2019-07/msg00002.html</a><br><a href="http://lists.opensuse.org/opensuse-security-announce/2019-07/msg00003.html">http://lists.opensuse.org/opensuse-security-announce/2019-07/msg00003.html</a><br><a href="http://lists.opensuse.org/opensuse-security-announce/2019-08/msg00026.html">http://lists.opensuse.org/opensuse-security-announce/2019-08/msg00026.html</a><br><a href="http://www.h5l.org/pipermail/heimdal-announce/2019-May/000009.html">http://www.h5l.org/pipermail/heimdal-announce/2019-May/000009.html</a><br><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2019-12098">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2019-12098</a><br><a href="https://github.com/heimdal/heimdal/commit/2f7f3d9960aa6ea21358bdf3687cee5149aa35cf">https://github.com/heimdal/heimdal/commit/2f7f3d9960aa6ea21358bdf3687cee5149aa35cf</a><br><a href="https://github.com/heimdal/heimdal/compare/3e58559...bbafe72">https://github.com/heimdal/heimdal/compare/3e58559...bbafe72</a><br><a href="https://github.com/heimdal/heimdal/releases/tag/heimdal-7.6.0">https://github.com/heimdal/heimdal/releases/tag/heimdal-7.6.0</a><br><a href="https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/GIXEDVVMPD6ZAJSMI2EZ7FNEIVNWE5PD/">https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/GIXEDVVMPD6ZAJSMI2EZ7FNEIVNWE5PD/</a><br><a href="https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/SLXXIF4LOQEAEDAF4UGP2AO6WDNTDFUB/">https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/SLXXIF4LOQEAEDAF4UGP2AO6WDNTDFUB/</a><br><a href="https://seclists.org/bugtraq/2019/Jun/1">https://seclists.org/bugtraq/2019/Jun/1</a><br><a href="https://www.debian.org/security/2019/dsa-4455">https://www.debian.org/security/2019/dsa-4455</a><br></details>  |
| libhx509-5-heimdal         |    CVE-2021-3671   |   LOW  |  7.5.0+dfsg-1 |  | <details><summary>Expand...</summary><a href="https://bugzilla.redhat.com/show_bug.cgi?id=2013080,">https://bugzilla.redhat.com/show_bug.cgi?id=2013080,</a><br><a href="https://bugzilla.samba.org/show_bug.cgi?id=14770,">https://bugzilla.samba.org/show_bug.cgi?id=14770,</a><br><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2021-3671">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2021-3671</a><br><a href="https://github.com/heimdal/heimdal/commit/04171147948d0a3636bc6374181926f0fb2ec83a">https://github.com/heimdal/heimdal/commit/04171147948d0a3636bc6374181926f0fb2ec83a</a><br><a href="https://ubuntu.com/security/notices/USN-5142-1">https://ubuntu.com/security/notices/USN-5142-1</a><br><a href="https://ubuntu.com/security/notices/USN-5174-1">https://ubuntu.com/security/notices/USN-5174-1</a><br></details>  |
| libitm1         |    CVE-2020-13844   |   MEDIUM  |  8.4.0-1ubuntu1~18.04 |  | <details><summary>Expand...</summary><a href="http://lists.llvm.org/pipermail/llvm-dev/2020-June/142109.html">http://lists.llvm.org/pipermail/llvm-dev/2020-June/142109.html</a><br><a href="http://lists.opensuse.org/opensuse-security-announce/2020-10/msg00039.html">http://lists.opensuse.org/opensuse-security-announce/2020-10/msg00039.html</a><br><a href="http://lists.opensuse.org/opensuse-security-announce/2020-10/msg00040.html">http://lists.opensuse.org/opensuse-security-announce/2020-10/msg00040.html</a><br><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2020-13844">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2020-13844</a><br><a href="https://developer.arm.com/support/arm-security-updates/speculative-processor-vulnerability">https://developer.arm.com/support/arm-security-updates/speculative-processor-vulnerability</a><br><a href="https://developer.arm.com/support/arm-security-updates/speculative-processor-vulnerability/downloads/straight-line-speculation">https://developer.arm.com/support/arm-security-updates/speculative-processor-vulnerability/downloads/straight-line-speculation</a><br><a href="https://developer.arm.com/support/arm-security-updates/speculative-processor-vulnerability/frequently-asked-questions">https://developer.arm.com/support/arm-security-updates/speculative-processor-vulnerability/frequently-asked-questions</a><br><a href="https://gcc.gnu.org/pipermail/gcc-patches/2020-June/547520.html">https://gcc.gnu.org/pipermail/gcc-patches/2020-June/547520.html</a><br><a href="https://git.kernel.org/pub/scm/linux/kernel/git/torvalds/linux.git/commit/?id=679db70801da9fda91d26caf13bf5b5ccc74e8e8">https://git.kernel.org/pub/scm/linux/kernel/git/torvalds/linux.git/commit/?id=679db70801da9fda91d26caf13bf5b5ccc74e8e8</a><br></details>  |
| libjbig0         |    CVE-2017-9937   |   LOW  |  2.1-3.1build1 |  | <details><summary>Expand...</summary><a href="http://bugzilla.maptools.org/show_bug.cgi?id=2707">http://bugzilla.maptools.org/show_bug.cgi?id=2707</a><br><a href="http://www.securityfocus.com/bid/99304">http://www.securityfocus.com/bid/99304</a><br><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2017-9937">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2017-9937</a><br><a href="https://lists.apache.org/thread.html/rf9fa47ab66495c78bb4120b0754dd9531ca2ff0430f6685ac9b07772@%3Cdev.mina.apache.org%3E">https://lists.apache.org/thread.html/rf9fa47ab66495c78bb4120b0754dd9531ca2ff0430f6685ac9b07772@%3Cdev.mina.apache.org%3E</a><br></details>  |
| libjpeg-turbo8         |    CVE-2018-11813   |   LOW  |  1.5.2-0ubuntu5.18.04.4 |  | <details><summary>Expand...</summary><a href="http://lists.opensuse.org/opensuse-security-announce/2019-04/msg00015.html">http://lists.opensuse.org/opensuse-security-announce/2019-04/msg00015.html</a><br><a href="http://lists.opensuse.org/opensuse-security-announce/2019-05/msg00015.html">http://lists.opensuse.org/opensuse-security-announce/2019-05/msg00015.html</a><br><a href="http://www.ijg.org/files/jpegsrc.v9d.tar.gz">http://www.ijg.org/files/jpegsrc.v9d.tar.gz</a><br><a href="https://access.redhat.com/errata/RHSA-2019:2052">https://access.redhat.com/errata/RHSA-2019:2052</a><br><a href="https://bugs.gentoo.org/727908">https://bugs.gentoo.org/727908</a><br><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2018-11813">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2018-11813</a><br><a href="https://github.com/ChijinZ/security_advisories/blob/master/libjpeg-v9c/mail.pdf">https://github.com/ChijinZ/security_advisories/blob/master/libjpeg-v9c/mail.pdf</a><br><a href="https://github.com/ChijinZ/security_advisories/tree/master/libjpeg-v9c">https://github.com/ChijinZ/security_advisories/tree/master/libjpeg-v9c</a><br><a href="https://linux.oracle.com/cve/CVE-2018-11813.html">https://linux.oracle.com/cve/CVE-2018-11813.html</a><br><a href="https://linux.oracle.com/errata/ELSA-2019-2052.html">https://linux.oracle.com/errata/ELSA-2019-2052.html</a><br></details>  |
| libjpeg-turbo8         |    CVE-2020-17541   |   LOW  |  1.5.2-0ubuntu5.18.04.4 |  | <details><summary>Expand...</summary><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2020-17541">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2020-17541</a><br><a href="https://github.com/libjpeg-turbo/libjpeg-turbo/issues/392">https://github.com/libjpeg-turbo/libjpeg-turbo/issues/392</a><br><a href="https://linux.oracle.com/cve/CVE-2020-17541.html">https://linux.oracle.com/cve/CVE-2020-17541.html</a><br><a href="https://linux.oracle.com/errata/ELSA-2021-4288.html">https://linux.oracle.com/errata/ELSA-2021-4288.html</a><br></details>  |
| libk5crypto3         |    CVE-2018-20217   |   MEDIUM  |  1.16-2ubuntu0.2 |  | <details><summary>Expand...</summary><a href="http://krbdev.mit.edu/rt/Ticket/Display.html?id=8763">http://krbdev.mit.edu/rt/Ticket/Display.html?id=8763</a><br><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2018-20217">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2018-20217</a><br><a href="https://github.com/krb5/krb5/commit/5e6d1796106df8ba6bc1973ee0917c170d929086">https://github.com/krb5/krb5/commit/5e6d1796106df8ba6bc1973ee0917c170d929086</a><br><a href="https://lists.debian.org/debian-lts-announce/2019/01/msg00020.html">https://lists.debian.org/debian-lts-announce/2019/01/msg00020.html</a><br><a href="https://lists.debian.org/debian-lts-announce/2021/09/msg00019.html">https://lists.debian.org/debian-lts-announce/2021/09/msg00019.html</a><br><a href="https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/2KNHELH4YHNT6H2ESJWX2UIDXLBNGB2O/">https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/2KNHELH4YHNT6H2ESJWX2UIDXLBNGB2O/</a><br><a href="https://security.netapp.com/advisory/ntap-20190416-0006/">https://security.netapp.com/advisory/ntap-20190416-0006/</a><br></details>  |
| libk5crypto3         |    CVE-2021-36222   |   MEDIUM  |  1.16-2ubuntu0.2 |  | <details><summary>Expand...</summary><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2021-36222">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2021-36222</a><br><a href="https://github.com/krb5/krb5/commit/fc98f520caefff2e5ee9a0026fdf5109944b3562">https://github.com/krb5/krb5/commit/fc98f520caefff2e5ee9a0026fdf5109944b3562</a><br><a href="https://github.com/krb5/krb5/releases">https://github.com/krb5/krb5/releases</a><br><a href="https://linux.oracle.com/cve/CVE-2021-36222.html">https://linux.oracle.com/cve/CVE-2021-36222.html</a><br><a href="https://linux.oracle.com/errata/ELSA-2021-3576.html">https://linux.oracle.com/errata/ELSA-2021-3576.html</a><br><a href="https://security.netapp.com/advisory/ntap-20211022-0003/">https://security.netapp.com/advisory/ntap-20211022-0003/</a><br><a href="https://security.netapp.com/advisory/ntap-20211104-0007/">https://security.netapp.com/advisory/ntap-20211104-0007/</a><br><a href="https://web.mit.edu/kerberos/advisories/">https://web.mit.edu/kerberos/advisories/</a><br><a href="https://www.debian.org/security/2021/dsa-4944">https://www.debian.org/security/2021/dsa-4944</a><br><a href="https://www.oracle.com/security-alerts/cpuoct2021.html">https://www.oracle.com/security-alerts/cpuoct2021.html</a><br></details>  |
| libk5crypto3         |    CVE-2018-5709   |   LOW  |  1.16-2ubuntu0.2 |  | <details><summary>Expand...</summary><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2018-5709">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2018-5709</a><br><a href="https://github.com/poojamnit/Kerberos-V5-1.16-Vulnerabilities/tree/master/Integer%20Overflow">https://github.com/poojamnit/Kerberos-V5-1.16-Vulnerabilities/tree/master/Integer%20Overflow</a><br><a href="https://lists.apache.org/thread.html/rf9fa47ab66495c78bb4120b0754dd9531ca2ff0430f6685ac9b07772@%3Cdev.mina.apache.org%3E">https://lists.apache.org/thread.html/rf9fa47ab66495c78bb4120b0754dd9531ca2ff0430f6685ac9b07772@%3Cdev.mina.apache.org%3E</a><br></details>  |
| libk5crypto3         |    CVE-2018-5710   |   LOW  |  1.16-2ubuntu0.2 |  | <details><summary>Expand...</summary><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2018-5710">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2018-5710</a><br><a href="https://github.com/poojamnit/Kerberos-V5-1.16-Vulnerabilities/tree/master/Denial%20Of%20Service(DoS)">https://github.com/poojamnit/Kerberos-V5-1.16-Vulnerabilities/tree/master/Denial%20Of%20Service(DoS)</a><br></details>  |
| libkrb5-26-heimdal         |    CVE-2019-12098   |   LOW  |  7.5.0+dfsg-1 |  | <details><summary>Expand...</summary><a href="http://lists.opensuse.org/opensuse-security-announce/2019-07/msg00002.html">http://lists.opensuse.org/opensuse-security-announce/2019-07/msg00002.html</a><br><a href="http://lists.opensuse.org/opensuse-security-announce/2019-07/msg00003.html">http://lists.opensuse.org/opensuse-security-announce/2019-07/msg00003.html</a><br><a href="http://lists.opensuse.org/opensuse-security-announce/2019-08/msg00026.html">http://lists.opensuse.org/opensuse-security-announce/2019-08/msg00026.html</a><br><a href="http://www.h5l.org/pipermail/heimdal-announce/2019-May/000009.html">http://www.h5l.org/pipermail/heimdal-announce/2019-May/000009.html</a><br><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2019-12098">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2019-12098</a><br><a href="https://github.com/heimdal/heimdal/commit/2f7f3d9960aa6ea21358bdf3687cee5149aa35cf">https://github.com/heimdal/heimdal/commit/2f7f3d9960aa6ea21358bdf3687cee5149aa35cf</a><br><a href="https://github.com/heimdal/heimdal/compare/3e58559...bbafe72">https://github.com/heimdal/heimdal/compare/3e58559...bbafe72</a><br><a href="https://github.com/heimdal/heimdal/releases/tag/heimdal-7.6.0">https://github.com/heimdal/heimdal/releases/tag/heimdal-7.6.0</a><br><a href="https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/GIXEDVVMPD6ZAJSMI2EZ7FNEIVNWE5PD/">https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/GIXEDVVMPD6ZAJSMI2EZ7FNEIVNWE5PD/</a><br><a href="https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/SLXXIF4LOQEAEDAF4UGP2AO6WDNTDFUB/">https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/SLXXIF4LOQEAEDAF4UGP2AO6WDNTDFUB/</a><br><a href="https://seclists.org/bugtraq/2019/Jun/1">https://seclists.org/bugtraq/2019/Jun/1</a><br><a href="https://www.debian.org/security/2019/dsa-4455">https://www.debian.org/security/2019/dsa-4455</a><br></details>  |
| libkrb5-26-heimdal         |    CVE-2021-3671   |   LOW  |  7.5.0+dfsg-1 |  | <details><summary>Expand...</summary><a href="https://bugzilla.redhat.com/show_bug.cgi?id=2013080,">https://bugzilla.redhat.com/show_bug.cgi?id=2013080,</a><br><a href="https://bugzilla.samba.org/show_bug.cgi?id=14770,">https://bugzilla.samba.org/show_bug.cgi?id=14770,</a><br><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2021-3671">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2021-3671</a><br><a href="https://github.com/heimdal/heimdal/commit/04171147948d0a3636bc6374181926f0fb2ec83a">https://github.com/heimdal/heimdal/commit/04171147948d0a3636bc6374181926f0fb2ec83a</a><br><a href="https://ubuntu.com/security/notices/USN-5142-1">https://ubuntu.com/security/notices/USN-5142-1</a><br><a href="https://ubuntu.com/security/notices/USN-5174-1">https://ubuntu.com/security/notices/USN-5174-1</a><br></details>  |
| libkrb5-3         |    CVE-2018-20217   |   MEDIUM  |  1.16-2ubuntu0.2 |  | <details><summary>Expand...</summary><a href="http://krbdev.mit.edu/rt/Ticket/Display.html?id=8763">http://krbdev.mit.edu/rt/Ticket/Display.html?id=8763</a><br><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2018-20217">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2018-20217</a><br><a href="https://github.com/krb5/krb5/commit/5e6d1796106df8ba6bc1973ee0917c170d929086">https://github.com/krb5/krb5/commit/5e6d1796106df8ba6bc1973ee0917c170d929086</a><br><a href="https://lists.debian.org/debian-lts-announce/2019/01/msg00020.html">https://lists.debian.org/debian-lts-announce/2019/01/msg00020.html</a><br><a href="https://lists.debian.org/debian-lts-announce/2021/09/msg00019.html">https://lists.debian.org/debian-lts-announce/2021/09/msg00019.html</a><br><a href="https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/2KNHELH4YHNT6H2ESJWX2UIDXLBNGB2O/">https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/2KNHELH4YHNT6H2ESJWX2UIDXLBNGB2O/</a><br><a href="https://security.netapp.com/advisory/ntap-20190416-0006/">https://security.netapp.com/advisory/ntap-20190416-0006/</a><br></details>  |
| libkrb5-3         |    CVE-2021-36222   |   MEDIUM  |  1.16-2ubuntu0.2 |  | <details><summary>Expand...</summary><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2021-36222">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2021-36222</a><br><a href="https://github.com/krb5/krb5/commit/fc98f520caefff2e5ee9a0026fdf5109944b3562">https://github.com/krb5/krb5/commit/fc98f520caefff2e5ee9a0026fdf5109944b3562</a><br><a href="https://github.com/krb5/krb5/releases">https://github.com/krb5/krb5/releases</a><br><a href="https://linux.oracle.com/cve/CVE-2021-36222.html">https://linux.oracle.com/cve/CVE-2021-36222.html</a><br><a href="https://linux.oracle.com/errata/ELSA-2021-3576.html">https://linux.oracle.com/errata/ELSA-2021-3576.html</a><br><a href="https://security.netapp.com/advisory/ntap-20211022-0003/">https://security.netapp.com/advisory/ntap-20211022-0003/</a><br><a href="https://security.netapp.com/advisory/ntap-20211104-0007/">https://security.netapp.com/advisory/ntap-20211104-0007/</a><br><a href="https://web.mit.edu/kerberos/advisories/">https://web.mit.edu/kerberos/advisories/</a><br><a href="https://www.debian.org/security/2021/dsa-4944">https://www.debian.org/security/2021/dsa-4944</a><br><a href="https://www.oracle.com/security-alerts/cpuoct2021.html">https://www.oracle.com/security-alerts/cpuoct2021.html</a><br></details>  |
| libkrb5-3         |    CVE-2018-5709   |   LOW  |  1.16-2ubuntu0.2 |  | <details><summary>Expand...</summary><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2018-5709">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2018-5709</a><br><a href="https://github.com/poojamnit/Kerberos-V5-1.16-Vulnerabilities/tree/master/Integer%20Overflow">https://github.com/poojamnit/Kerberos-V5-1.16-Vulnerabilities/tree/master/Integer%20Overflow</a><br><a href="https://lists.apache.org/thread.html/rf9fa47ab66495c78bb4120b0754dd9531ca2ff0430f6685ac9b07772@%3Cdev.mina.apache.org%3E">https://lists.apache.org/thread.html/rf9fa47ab66495c78bb4120b0754dd9531ca2ff0430f6685ac9b07772@%3Cdev.mina.apache.org%3E</a><br></details>  |
| libkrb5-3         |    CVE-2018-5710   |   LOW  |  1.16-2ubuntu0.2 |  | <details><summary>Expand...</summary><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2018-5710">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2018-5710</a><br><a href="https://github.com/poojamnit/Kerberos-V5-1.16-Vulnerabilities/tree/master/Denial%20Of%20Service(DoS)">https://github.com/poojamnit/Kerberos-V5-1.16-Vulnerabilities/tree/master/Denial%20Of%20Service(DoS)</a><br></details>  |
| libkrb5support0         |    CVE-2018-20217   |   MEDIUM  |  1.16-2ubuntu0.2 |  | <details><summary>Expand...</summary><a href="http://krbdev.mit.edu/rt/Ticket/Display.html?id=8763">http://krbdev.mit.edu/rt/Ticket/Display.html?id=8763</a><br><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2018-20217">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2018-20217</a><br><a href="https://github.com/krb5/krb5/commit/5e6d1796106df8ba6bc1973ee0917c170d929086">https://github.com/krb5/krb5/commit/5e6d1796106df8ba6bc1973ee0917c170d929086</a><br><a href="https://lists.debian.org/debian-lts-announce/2019/01/msg00020.html">https://lists.debian.org/debian-lts-announce/2019/01/msg00020.html</a><br><a href="https://lists.debian.org/debian-lts-announce/2021/09/msg00019.html">https://lists.debian.org/debian-lts-announce/2021/09/msg00019.html</a><br><a href="https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/2KNHELH4YHNT6H2ESJWX2UIDXLBNGB2O/">https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/2KNHELH4YHNT6H2ESJWX2UIDXLBNGB2O/</a><br><a href="https://security.netapp.com/advisory/ntap-20190416-0006/">https://security.netapp.com/advisory/ntap-20190416-0006/</a><br></details>  |
| libkrb5support0         |    CVE-2021-36222   |   MEDIUM  |  1.16-2ubuntu0.2 |  | <details><summary>Expand...</summary><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2021-36222">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2021-36222</a><br><a href="https://github.com/krb5/krb5/commit/fc98f520caefff2e5ee9a0026fdf5109944b3562">https://github.com/krb5/krb5/commit/fc98f520caefff2e5ee9a0026fdf5109944b3562</a><br><a href="https://github.com/krb5/krb5/releases">https://github.com/krb5/krb5/releases</a><br><a href="https://linux.oracle.com/cve/CVE-2021-36222.html">https://linux.oracle.com/cve/CVE-2021-36222.html</a><br><a href="https://linux.oracle.com/errata/ELSA-2021-3576.html">https://linux.oracle.com/errata/ELSA-2021-3576.html</a><br><a href="https://security.netapp.com/advisory/ntap-20211022-0003/">https://security.netapp.com/advisory/ntap-20211022-0003/</a><br><a href="https://security.netapp.com/advisory/ntap-20211104-0007/">https://security.netapp.com/advisory/ntap-20211104-0007/</a><br><a href="https://web.mit.edu/kerberos/advisories/">https://web.mit.edu/kerberos/advisories/</a><br><a href="https://www.debian.org/security/2021/dsa-4944">https://www.debian.org/security/2021/dsa-4944</a><br><a href="https://www.oracle.com/security-alerts/cpuoct2021.html">https://www.oracle.com/security-alerts/cpuoct2021.html</a><br></details>  |
| libkrb5support0         |    CVE-2018-5709   |   LOW  |  1.16-2ubuntu0.2 |  | <details><summary>Expand...</summary><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2018-5709">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2018-5709</a><br><a href="https://github.com/poojamnit/Kerberos-V5-1.16-Vulnerabilities/tree/master/Integer%20Overflow">https://github.com/poojamnit/Kerberos-V5-1.16-Vulnerabilities/tree/master/Integer%20Overflow</a><br><a href="https://lists.apache.org/thread.html/rf9fa47ab66495c78bb4120b0754dd9531ca2ff0430f6685ac9b07772@%3Cdev.mina.apache.org%3E">https://lists.apache.org/thread.html/rf9fa47ab66495c78bb4120b0754dd9531ca2ff0430f6685ac9b07772@%3Cdev.mina.apache.org%3E</a><br></details>  |
| libkrb5support0         |    CVE-2018-5710   |   LOW  |  1.16-2ubuntu0.2 |  | <details><summary>Expand...</summary><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2018-5710">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2018-5710</a><br><a href="https://github.com/poojamnit/Kerberos-V5-1.16-Vulnerabilities/tree/master/Denial%20Of%20Service(DoS)">https://github.com/poojamnit/Kerberos-V5-1.16-Vulnerabilities/tree/master/Denial%20Of%20Service(DoS)</a><br></details>  |
| liblsan0         |    CVE-2020-13844   |   MEDIUM  |  8.4.0-1ubuntu1~18.04 |  | <details><summary>Expand...</summary><a href="http://lists.llvm.org/pipermail/llvm-dev/2020-June/142109.html">http://lists.llvm.org/pipermail/llvm-dev/2020-June/142109.html</a><br><a href="http://lists.opensuse.org/opensuse-security-announce/2020-10/msg00039.html">http://lists.opensuse.org/opensuse-security-announce/2020-10/msg00039.html</a><br><a href="http://lists.opensuse.org/opensuse-security-announce/2020-10/msg00040.html">http://lists.opensuse.org/opensuse-security-announce/2020-10/msg00040.html</a><br><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2020-13844">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2020-13844</a><br><a href="https://developer.arm.com/support/arm-security-updates/speculative-processor-vulnerability">https://developer.arm.com/support/arm-security-updates/speculative-processor-vulnerability</a><br><a href="https://developer.arm.com/support/arm-security-updates/speculative-processor-vulnerability/downloads/straight-line-speculation">https://developer.arm.com/support/arm-security-updates/speculative-processor-vulnerability/downloads/straight-line-speculation</a><br><a href="https://developer.arm.com/support/arm-security-updates/speculative-processor-vulnerability/frequently-asked-questions">https://developer.arm.com/support/arm-security-updates/speculative-processor-vulnerability/frequently-asked-questions</a><br><a href="https://gcc.gnu.org/pipermail/gcc-patches/2020-June/547520.html">https://gcc.gnu.org/pipermail/gcc-patches/2020-June/547520.html</a><br><a href="https://git.kernel.org/pub/scm/linux/kernel/git/torvalds/linux.git/commit/?id=679db70801da9fda91d26caf13bf5b5ccc74e8e8">https://git.kernel.org/pub/scm/linux/kernel/git/torvalds/linux.git/commit/?id=679db70801da9fda91d26caf13bf5b5ccc74e8e8</a><br></details>  |
| libmono-2.0-dev         |    CVE-2018-1002208   |   LOW  |  6.12.0.122-0xamarin1+ubuntu1804b1 |  | <details><summary>Expand...</summary><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2018-1002208">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2018-1002208</a><br><a href="https://github.com/icsharpcode/SharpZipLib/issues/232">https://github.com/icsharpcode/SharpZipLib/issues/232</a><br><a href="https://github.com/icsharpcode/SharpZipLib/wiki/Release-1.0">https://github.com/icsharpcode/SharpZipLib/wiki/Release-1.0</a><br><a href="https://github.com/snyk/zip-slip-vulnerability">https://github.com/snyk/zip-slip-vulnerability</a><br><a href="https://snyk.io/research/zip-slip-vulnerability">https://snyk.io/research/zip-slip-vulnerability</a><br><a href="https://snyk.io/vuln/SNYK-DOTNET-SHARPZIPLIB-60247">https://snyk.io/vuln/SNYK-DOTNET-SHARPZIPLIB-60247</a><br></details>  |
| libmono-accessibility4.0-cil         |    CVE-2018-1002208   |   LOW  |  6.12.0.122-0xamarin1+ubuntu1804b1 |  | <details><summary>Expand...</summary><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2018-1002208">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2018-1002208</a><br><a href="https://github.com/icsharpcode/SharpZipLib/issues/232">https://github.com/icsharpcode/SharpZipLib/issues/232</a><br><a href="https://github.com/icsharpcode/SharpZipLib/wiki/Release-1.0">https://github.com/icsharpcode/SharpZipLib/wiki/Release-1.0</a><br><a href="https://github.com/snyk/zip-slip-vulnerability">https://github.com/snyk/zip-slip-vulnerability</a><br><a href="https://snyk.io/research/zip-slip-vulnerability">https://snyk.io/research/zip-slip-vulnerability</a><br><a href="https://snyk.io/vuln/SNYK-DOTNET-SHARPZIPLIB-60247">https://snyk.io/vuln/SNYK-DOTNET-SHARPZIPLIB-60247</a><br></details>  |
| libmono-btls-interface4.0-cil         |    CVE-2018-1002208   |   LOW  |  6.12.0.122-0xamarin1+ubuntu1804b1 |  | <details><summary>Expand...</summary><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2018-1002208">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2018-1002208</a><br><a href="https://github.com/icsharpcode/SharpZipLib/issues/232">https://github.com/icsharpcode/SharpZipLib/issues/232</a><br><a href="https://github.com/icsharpcode/SharpZipLib/wiki/Release-1.0">https://github.com/icsharpcode/SharpZipLib/wiki/Release-1.0</a><br><a href="https://github.com/snyk/zip-slip-vulnerability">https://github.com/snyk/zip-slip-vulnerability</a><br><a href="https://snyk.io/research/zip-slip-vulnerability">https://snyk.io/research/zip-slip-vulnerability</a><br><a href="https://snyk.io/vuln/SNYK-DOTNET-SHARPZIPLIB-60247">https://snyk.io/vuln/SNYK-DOTNET-SHARPZIPLIB-60247</a><br></details>  |
| libmono-cairo4.0-cil         |    CVE-2018-1002208   |   LOW  |  6.12.0.122-0xamarin1+ubuntu1804b1 |  | <details><summary>Expand...</summary><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2018-1002208">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2018-1002208</a><br><a href="https://github.com/icsharpcode/SharpZipLib/issues/232">https://github.com/icsharpcode/SharpZipLib/issues/232</a><br><a href="https://github.com/icsharpcode/SharpZipLib/wiki/Release-1.0">https://github.com/icsharpcode/SharpZipLib/wiki/Release-1.0</a><br><a href="https://github.com/snyk/zip-slip-vulnerability">https://github.com/snyk/zip-slip-vulnerability</a><br><a href="https://snyk.io/research/zip-slip-vulnerability">https://snyk.io/research/zip-slip-vulnerability</a><br><a href="https://snyk.io/vuln/SNYK-DOTNET-SHARPZIPLIB-60247">https://snyk.io/vuln/SNYK-DOTNET-SHARPZIPLIB-60247</a><br></details>  |
| libmono-cecil-private-cil         |    CVE-2018-1002208   |   LOW  |  6.12.0.122-0xamarin1+ubuntu1804b1 |  | <details><summary>Expand...</summary><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2018-1002208">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2018-1002208</a><br><a href="https://github.com/icsharpcode/SharpZipLib/issues/232">https://github.com/icsharpcode/SharpZipLib/issues/232</a><br><a href="https://github.com/icsharpcode/SharpZipLib/wiki/Release-1.0">https://github.com/icsharpcode/SharpZipLib/wiki/Release-1.0</a><br><a href="https://github.com/snyk/zip-slip-vulnerability">https://github.com/snyk/zip-slip-vulnerability</a><br><a href="https://snyk.io/research/zip-slip-vulnerability">https://snyk.io/research/zip-slip-vulnerability</a><br><a href="https://snyk.io/vuln/SNYK-DOTNET-SHARPZIPLIB-60247">https://snyk.io/vuln/SNYK-DOTNET-SHARPZIPLIB-60247</a><br></details>  |
| libmono-cil-dev         |    CVE-2018-1002208   |   LOW  |  6.12.0.122-0xamarin1+ubuntu1804b1 |  | <details><summary>Expand...</summary><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2018-1002208">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2018-1002208</a><br><a href="https://github.com/icsharpcode/SharpZipLib/issues/232">https://github.com/icsharpcode/SharpZipLib/issues/232</a><br><a href="https://github.com/icsharpcode/SharpZipLib/wiki/Release-1.0">https://github.com/icsharpcode/SharpZipLib/wiki/Release-1.0</a><br><a href="https://github.com/snyk/zip-slip-vulnerability">https://github.com/snyk/zip-slip-vulnerability</a><br><a href="https://snyk.io/research/zip-slip-vulnerability">https://snyk.io/research/zip-slip-vulnerability</a><br><a href="https://snyk.io/vuln/SNYK-DOTNET-SHARPZIPLIB-60247">https://snyk.io/vuln/SNYK-DOTNET-SHARPZIPLIB-60247</a><br></details>  |
| libmono-codecontracts4.0-cil         |    CVE-2018-1002208   |   LOW  |  6.12.0.122-0xamarin1+ubuntu1804b1 |  | <details><summary>Expand...</summary><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2018-1002208">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2018-1002208</a><br><a href="https://github.com/icsharpcode/SharpZipLib/issues/232">https://github.com/icsharpcode/SharpZipLib/issues/232</a><br><a href="https://github.com/icsharpcode/SharpZipLib/wiki/Release-1.0">https://github.com/icsharpcode/SharpZipLib/wiki/Release-1.0</a><br><a href="https://github.com/snyk/zip-slip-vulnerability">https://github.com/snyk/zip-slip-vulnerability</a><br><a href="https://snyk.io/research/zip-slip-vulnerability">https://snyk.io/research/zip-slip-vulnerability</a><br><a href="https://snyk.io/vuln/SNYK-DOTNET-SHARPZIPLIB-60247">https://snyk.io/vuln/SNYK-DOTNET-SHARPZIPLIB-60247</a><br></details>  |
| libmono-compilerservices-symbolwriter4.0-cil         |    CVE-2018-1002208   |   LOW  |  6.12.0.122-0xamarin1+ubuntu1804b1 |  | <details><summary>Expand...</summary><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2018-1002208">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2018-1002208</a><br><a href="https://github.com/icsharpcode/SharpZipLib/issues/232">https://github.com/icsharpcode/SharpZipLib/issues/232</a><br><a href="https://github.com/icsharpcode/SharpZipLib/wiki/Release-1.0">https://github.com/icsharpcode/SharpZipLib/wiki/Release-1.0</a><br><a href="https://github.com/snyk/zip-slip-vulnerability">https://github.com/snyk/zip-slip-vulnerability</a><br><a href="https://snyk.io/research/zip-slip-vulnerability">https://snyk.io/research/zip-slip-vulnerability</a><br><a href="https://snyk.io/vuln/SNYK-DOTNET-SHARPZIPLIB-60247">https://snyk.io/vuln/SNYK-DOTNET-SHARPZIPLIB-60247</a><br></details>  |
| libmono-corlib4.5-cil         |    CVE-2018-1002208   |   LOW  |  6.12.0.122-0xamarin1+ubuntu1804b1 |  | <details><summary>Expand...</summary><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2018-1002208">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2018-1002208</a><br><a href="https://github.com/icsharpcode/SharpZipLib/issues/232">https://github.com/icsharpcode/SharpZipLib/issues/232</a><br><a href="https://github.com/icsharpcode/SharpZipLib/wiki/Release-1.0">https://github.com/icsharpcode/SharpZipLib/wiki/Release-1.0</a><br><a href="https://github.com/snyk/zip-slip-vulnerability">https://github.com/snyk/zip-slip-vulnerability</a><br><a href="https://snyk.io/research/zip-slip-vulnerability">https://snyk.io/research/zip-slip-vulnerability</a><br><a href="https://snyk.io/vuln/SNYK-DOTNET-SHARPZIPLIB-60247">https://snyk.io/vuln/SNYK-DOTNET-SHARPZIPLIB-60247</a><br></details>  |
| libmono-cscompmgd0.0-cil         |    CVE-2018-1002208   |   LOW  |  6.12.0.122-0xamarin1+ubuntu1804b1 |  | <details><summary>Expand...</summary><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2018-1002208">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2018-1002208</a><br><a href="https://github.com/icsharpcode/SharpZipLib/issues/232">https://github.com/icsharpcode/SharpZipLib/issues/232</a><br><a href="https://github.com/icsharpcode/SharpZipLib/wiki/Release-1.0">https://github.com/icsharpcode/SharpZipLib/wiki/Release-1.0</a><br><a href="https://github.com/snyk/zip-slip-vulnerability">https://github.com/snyk/zip-slip-vulnerability</a><br><a href="https://snyk.io/research/zip-slip-vulnerability">https://snyk.io/research/zip-slip-vulnerability</a><br><a href="https://snyk.io/vuln/SNYK-DOTNET-SHARPZIPLIB-60247">https://snyk.io/vuln/SNYK-DOTNET-SHARPZIPLIB-60247</a><br></details>  |
| libmono-csharp4.0c-cil         |    CVE-2018-1002208   |   LOW  |  6.12.0.122-0xamarin1+ubuntu1804b1 |  | <details><summary>Expand...</summary><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2018-1002208">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2018-1002208</a><br><a href="https://github.com/icsharpcode/SharpZipLib/issues/232">https://github.com/icsharpcode/SharpZipLib/issues/232</a><br><a href="https://github.com/icsharpcode/SharpZipLib/wiki/Release-1.0">https://github.com/icsharpcode/SharpZipLib/wiki/Release-1.0</a><br><a href="https://github.com/snyk/zip-slip-vulnerability">https://github.com/snyk/zip-slip-vulnerability</a><br><a href="https://snyk.io/research/zip-slip-vulnerability">https://snyk.io/research/zip-slip-vulnerability</a><br><a href="https://snyk.io/vuln/SNYK-DOTNET-SHARPZIPLIB-60247">https://snyk.io/vuln/SNYK-DOTNET-SHARPZIPLIB-60247</a><br></details>  |
| libmono-custommarshalers4.0-cil         |    CVE-2018-1002208   |   LOW  |  6.12.0.122-0xamarin1+ubuntu1804b1 |  | <details><summary>Expand...</summary><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2018-1002208">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2018-1002208</a><br><a href="https://github.com/icsharpcode/SharpZipLib/issues/232">https://github.com/icsharpcode/SharpZipLib/issues/232</a><br><a href="https://github.com/icsharpcode/SharpZipLib/wiki/Release-1.0">https://github.com/icsharpcode/SharpZipLib/wiki/Release-1.0</a><br><a href="https://github.com/snyk/zip-slip-vulnerability">https://github.com/snyk/zip-slip-vulnerability</a><br><a href="https://snyk.io/research/zip-slip-vulnerability">https://snyk.io/research/zip-slip-vulnerability</a><br><a href="https://snyk.io/vuln/SNYK-DOTNET-SHARPZIPLIB-60247">https://snyk.io/vuln/SNYK-DOTNET-SHARPZIPLIB-60247</a><br></details>  |
| libmono-data-tds4.0-cil         |    CVE-2018-1002208   |   LOW  |  6.12.0.122-0xamarin1+ubuntu1804b1 |  | <details><summary>Expand...</summary><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2018-1002208">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2018-1002208</a><br><a href="https://github.com/icsharpcode/SharpZipLib/issues/232">https://github.com/icsharpcode/SharpZipLib/issues/232</a><br><a href="https://github.com/icsharpcode/SharpZipLib/wiki/Release-1.0">https://github.com/icsharpcode/SharpZipLib/wiki/Release-1.0</a><br><a href="https://github.com/snyk/zip-slip-vulnerability">https://github.com/snyk/zip-slip-vulnerability</a><br><a href="https://snyk.io/research/zip-slip-vulnerability">https://snyk.io/research/zip-slip-vulnerability</a><br><a href="https://snyk.io/vuln/SNYK-DOTNET-SHARPZIPLIB-60247">https://snyk.io/vuln/SNYK-DOTNET-SHARPZIPLIB-60247</a><br></details>  |
| libmono-db2-1.0-cil         |    CVE-2018-1002208   |   LOW  |  6.12.0.122-0xamarin1+ubuntu1804b1 |  | <details><summary>Expand...</summary><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2018-1002208">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2018-1002208</a><br><a href="https://github.com/icsharpcode/SharpZipLib/issues/232">https://github.com/icsharpcode/SharpZipLib/issues/232</a><br><a href="https://github.com/icsharpcode/SharpZipLib/wiki/Release-1.0">https://github.com/icsharpcode/SharpZipLib/wiki/Release-1.0</a><br><a href="https://github.com/snyk/zip-slip-vulnerability">https://github.com/snyk/zip-slip-vulnerability</a><br><a href="https://snyk.io/research/zip-slip-vulnerability">https://snyk.io/research/zip-slip-vulnerability</a><br><a href="https://snyk.io/vuln/SNYK-DOTNET-SHARPZIPLIB-60247">https://snyk.io/vuln/SNYK-DOTNET-SHARPZIPLIB-60247</a><br></details>  |
| libmono-debugger-soft4.0a-cil         |    CVE-2018-1002208   |   LOW  |  6.12.0.122-0xamarin1+ubuntu1804b1 |  | <details><summary>Expand...</summary><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2018-1002208">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2018-1002208</a><br><a href="https://github.com/icsharpcode/SharpZipLib/issues/232">https://github.com/icsharpcode/SharpZipLib/issues/232</a><br><a href="https://github.com/icsharpcode/SharpZipLib/wiki/Release-1.0">https://github.com/icsharpcode/SharpZipLib/wiki/Release-1.0</a><br><a href="https://github.com/snyk/zip-slip-vulnerability">https://github.com/snyk/zip-slip-vulnerability</a><br><a href="https://snyk.io/research/zip-slip-vulnerability">https://snyk.io/research/zip-slip-vulnerability</a><br><a href="https://snyk.io/vuln/SNYK-DOTNET-SHARPZIPLIB-60247">https://snyk.io/vuln/SNYK-DOTNET-SHARPZIPLIB-60247</a><br></details>  |
| libmono-http4.0-cil         |    CVE-2018-1002208   |   LOW  |  6.12.0.122-0xamarin1+ubuntu1804b1 |  | <details><summary>Expand...</summary><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2018-1002208">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2018-1002208</a><br><a href="https://github.com/icsharpcode/SharpZipLib/issues/232">https://github.com/icsharpcode/SharpZipLib/issues/232</a><br><a href="https://github.com/icsharpcode/SharpZipLib/wiki/Release-1.0">https://github.com/icsharpcode/SharpZipLib/wiki/Release-1.0</a><br><a href="https://github.com/snyk/zip-slip-vulnerability">https://github.com/snyk/zip-slip-vulnerability</a><br><a href="https://snyk.io/research/zip-slip-vulnerability">https://snyk.io/research/zip-slip-vulnerability</a><br><a href="https://snyk.io/vuln/SNYK-DOTNET-SHARPZIPLIB-60247">https://snyk.io/vuln/SNYK-DOTNET-SHARPZIPLIB-60247</a><br></details>  |
| libmono-i18n-cjk4.0-cil         |    CVE-2018-1002208   |   LOW  |  6.12.0.122-0xamarin1+ubuntu1804b1 |  | <details><summary>Expand...</summary><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2018-1002208">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2018-1002208</a><br><a href="https://github.com/icsharpcode/SharpZipLib/issues/232">https://github.com/icsharpcode/SharpZipLib/issues/232</a><br><a href="https://github.com/icsharpcode/SharpZipLib/wiki/Release-1.0">https://github.com/icsharpcode/SharpZipLib/wiki/Release-1.0</a><br><a href="https://github.com/snyk/zip-slip-vulnerability">https://github.com/snyk/zip-slip-vulnerability</a><br><a href="https://snyk.io/research/zip-slip-vulnerability">https://snyk.io/research/zip-slip-vulnerability</a><br><a href="https://snyk.io/vuln/SNYK-DOTNET-SHARPZIPLIB-60247">https://snyk.io/vuln/SNYK-DOTNET-SHARPZIPLIB-60247</a><br></details>  |
| libmono-i18n-mideast4.0-cil         |    CVE-2018-1002208   |   LOW  |  6.12.0.122-0xamarin1+ubuntu1804b1 |  | <details><summary>Expand...</summary><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2018-1002208">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2018-1002208</a><br><a href="https://github.com/icsharpcode/SharpZipLib/issues/232">https://github.com/icsharpcode/SharpZipLib/issues/232</a><br><a href="https://github.com/icsharpcode/SharpZipLib/wiki/Release-1.0">https://github.com/icsharpcode/SharpZipLib/wiki/Release-1.0</a><br><a href="https://github.com/snyk/zip-slip-vulnerability">https://github.com/snyk/zip-slip-vulnerability</a><br><a href="https://snyk.io/research/zip-slip-vulnerability">https://snyk.io/research/zip-slip-vulnerability</a><br><a href="https://snyk.io/vuln/SNYK-DOTNET-SHARPZIPLIB-60247">https://snyk.io/vuln/SNYK-DOTNET-SHARPZIPLIB-60247</a><br></details>  |
| libmono-i18n-other4.0-cil         |    CVE-2018-1002208   |   LOW  |  6.12.0.122-0xamarin1+ubuntu1804b1 |  | <details><summary>Expand...</summary><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2018-1002208">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2018-1002208</a><br><a href="https://github.com/icsharpcode/SharpZipLib/issues/232">https://github.com/icsharpcode/SharpZipLib/issues/232</a><br><a href="https://github.com/icsharpcode/SharpZipLib/wiki/Release-1.0">https://github.com/icsharpcode/SharpZipLib/wiki/Release-1.0</a><br><a href="https://github.com/snyk/zip-slip-vulnerability">https://github.com/snyk/zip-slip-vulnerability</a><br><a href="https://snyk.io/research/zip-slip-vulnerability">https://snyk.io/research/zip-slip-vulnerability</a><br><a href="https://snyk.io/vuln/SNYK-DOTNET-SHARPZIPLIB-60247">https://snyk.io/vuln/SNYK-DOTNET-SHARPZIPLIB-60247</a><br></details>  |
| libmono-i18n-rare4.0-cil         |    CVE-2018-1002208   |   LOW  |  6.12.0.122-0xamarin1+ubuntu1804b1 |  | <details><summary>Expand...</summary><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2018-1002208">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2018-1002208</a><br><a href="https://github.com/icsharpcode/SharpZipLib/issues/232">https://github.com/icsharpcode/SharpZipLib/issues/232</a><br><a href="https://github.com/icsharpcode/SharpZipLib/wiki/Release-1.0">https://github.com/icsharpcode/SharpZipLib/wiki/Release-1.0</a><br><a href="https://github.com/snyk/zip-slip-vulnerability">https://github.com/snyk/zip-slip-vulnerability</a><br><a href="https://snyk.io/research/zip-slip-vulnerability">https://snyk.io/research/zip-slip-vulnerability</a><br><a href="https://snyk.io/vuln/SNYK-DOTNET-SHARPZIPLIB-60247">https://snyk.io/vuln/SNYK-DOTNET-SHARPZIPLIB-60247</a><br></details>  |
| libmono-i18n-west4.0-cil         |    CVE-2018-1002208   |   LOW  |  6.12.0.122-0xamarin1+ubuntu1804b1 |  | <details><summary>Expand...</summary><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2018-1002208">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2018-1002208</a><br><a href="https://github.com/icsharpcode/SharpZipLib/issues/232">https://github.com/icsharpcode/SharpZipLib/issues/232</a><br><a href="https://github.com/icsharpcode/SharpZipLib/wiki/Release-1.0">https://github.com/icsharpcode/SharpZipLib/wiki/Release-1.0</a><br><a href="https://github.com/snyk/zip-slip-vulnerability">https://github.com/snyk/zip-slip-vulnerability</a><br><a href="https://snyk.io/research/zip-slip-vulnerability">https://snyk.io/research/zip-slip-vulnerability</a><br><a href="https://snyk.io/vuln/SNYK-DOTNET-SHARPZIPLIB-60247">https://snyk.io/vuln/SNYK-DOTNET-SHARPZIPLIB-60247</a><br></details>  |
| libmono-i18n4.0-all         |    CVE-2018-1002208   |   LOW  |  6.12.0.122-0xamarin1+ubuntu1804b1 |  | <details><summary>Expand...</summary><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2018-1002208">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2018-1002208</a><br><a href="https://github.com/icsharpcode/SharpZipLib/issues/232">https://github.com/icsharpcode/SharpZipLib/issues/232</a><br><a href="https://github.com/icsharpcode/SharpZipLib/wiki/Release-1.0">https://github.com/icsharpcode/SharpZipLib/wiki/Release-1.0</a><br><a href="https://github.com/snyk/zip-slip-vulnerability">https://github.com/snyk/zip-slip-vulnerability</a><br><a href="https://snyk.io/research/zip-slip-vulnerability">https://snyk.io/research/zip-slip-vulnerability</a><br><a href="https://snyk.io/vuln/SNYK-DOTNET-SHARPZIPLIB-60247">https://snyk.io/vuln/SNYK-DOTNET-SHARPZIPLIB-60247</a><br></details>  |
| libmono-i18n4.0-cil         |    CVE-2018-1002208   |   LOW  |  6.12.0.122-0xamarin1+ubuntu1804b1 |  | <details><summary>Expand...</summary><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2018-1002208">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2018-1002208</a><br><a href="https://github.com/icsharpcode/SharpZipLib/issues/232">https://github.com/icsharpcode/SharpZipLib/issues/232</a><br><a href="https://github.com/icsharpcode/SharpZipLib/wiki/Release-1.0">https://github.com/icsharpcode/SharpZipLib/wiki/Release-1.0</a><br><a href="https://github.com/snyk/zip-slip-vulnerability">https://github.com/snyk/zip-slip-vulnerability</a><br><a href="https://snyk.io/research/zip-slip-vulnerability">https://snyk.io/research/zip-slip-vulnerability</a><br><a href="https://snyk.io/vuln/SNYK-DOTNET-SHARPZIPLIB-60247">https://snyk.io/vuln/SNYK-DOTNET-SHARPZIPLIB-60247</a><br></details>  |
| libmono-ldap4.0-cil         |    CVE-2018-1002208   |   LOW  |  6.12.0.122-0xamarin1+ubuntu1804b1 |  | <details><summary>Expand...</summary><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2018-1002208">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2018-1002208</a><br><a href="https://github.com/icsharpcode/SharpZipLib/issues/232">https://github.com/icsharpcode/SharpZipLib/issues/232</a><br><a href="https://github.com/icsharpcode/SharpZipLib/wiki/Release-1.0">https://github.com/icsharpcode/SharpZipLib/wiki/Release-1.0</a><br><a href="https://github.com/snyk/zip-slip-vulnerability">https://github.com/snyk/zip-slip-vulnerability</a><br><a href="https://snyk.io/research/zip-slip-vulnerability">https://snyk.io/research/zip-slip-vulnerability</a><br><a href="https://snyk.io/vuln/SNYK-DOTNET-SHARPZIPLIB-60247">https://snyk.io/vuln/SNYK-DOTNET-SHARPZIPLIB-60247</a><br></details>  |
| libmono-management4.0-cil         |    CVE-2018-1002208   |   LOW  |  6.12.0.122-0xamarin1+ubuntu1804b1 |  | <details><summary>Expand...</summary><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2018-1002208">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2018-1002208</a><br><a href="https://github.com/icsharpcode/SharpZipLib/issues/232">https://github.com/icsharpcode/SharpZipLib/issues/232</a><br><a href="https://github.com/icsharpcode/SharpZipLib/wiki/Release-1.0">https://github.com/icsharpcode/SharpZipLib/wiki/Release-1.0</a><br><a href="https://github.com/snyk/zip-slip-vulnerability">https://github.com/snyk/zip-slip-vulnerability</a><br><a href="https://snyk.io/research/zip-slip-vulnerability">https://snyk.io/research/zip-slip-vulnerability</a><br><a href="https://snyk.io/vuln/SNYK-DOTNET-SHARPZIPLIB-60247">https://snyk.io/vuln/SNYK-DOTNET-SHARPZIPLIB-60247</a><br></details>  |
| libmono-messaging-rabbitmq4.0-cil         |    CVE-2018-1002208   |   LOW  |  6.12.0.122-0xamarin1+ubuntu1804b1 |  | <details><summary>Expand...</summary><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2018-1002208">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2018-1002208</a><br><a href="https://github.com/icsharpcode/SharpZipLib/issues/232">https://github.com/icsharpcode/SharpZipLib/issues/232</a><br><a href="https://github.com/icsharpcode/SharpZipLib/wiki/Release-1.0">https://github.com/icsharpcode/SharpZipLib/wiki/Release-1.0</a><br><a href="https://github.com/snyk/zip-slip-vulnerability">https://github.com/snyk/zip-slip-vulnerability</a><br><a href="https://snyk.io/research/zip-slip-vulnerability">https://snyk.io/research/zip-slip-vulnerability</a><br><a href="https://snyk.io/vuln/SNYK-DOTNET-SHARPZIPLIB-60247">https://snyk.io/vuln/SNYK-DOTNET-SHARPZIPLIB-60247</a><br></details>  |
| libmono-messaging4.0-cil         |    CVE-2018-1002208   |   LOW  |  6.12.0.122-0xamarin1+ubuntu1804b1 |  | <details><summary>Expand...</summary><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2018-1002208">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2018-1002208</a><br><a href="https://github.com/icsharpcode/SharpZipLib/issues/232">https://github.com/icsharpcode/SharpZipLib/issues/232</a><br><a href="https://github.com/icsharpcode/SharpZipLib/wiki/Release-1.0">https://github.com/icsharpcode/SharpZipLib/wiki/Release-1.0</a><br><a href="https://github.com/snyk/zip-slip-vulnerability">https://github.com/snyk/zip-slip-vulnerability</a><br><a href="https://snyk.io/research/zip-slip-vulnerability">https://snyk.io/research/zip-slip-vulnerability</a><br><a href="https://snyk.io/vuln/SNYK-DOTNET-SHARPZIPLIB-60247">https://snyk.io/vuln/SNYK-DOTNET-SHARPZIPLIB-60247</a><br></details>  |
| libmono-microsoft-build-engine4.0-cil         |    CVE-2018-1002208   |   LOW  |  6.12.0.122-0xamarin1+ubuntu1804b1 |  | <details><summary>Expand...</summary><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2018-1002208">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2018-1002208</a><br><a href="https://github.com/icsharpcode/SharpZipLib/issues/232">https://github.com/icsharpcode/SharpZipLib/issues/232</a><br><a href="https://github.com/icsharpcode/SharpZipLib/wiki/Release-1.0">https://github.com/icsharpcode/SharpZipLib/wiki/Release-1.0</a><br><a href="https://github.com/snyk/zip-slip-vulnerability">https://github.com/snyk/zip-slip-vulnerability</a><br><a href="https://snyk.io/research/zip-slip-vulnerability">https://snyk.io/research/zip-slip-vulnerability</a><br><a href="https://snyk.io/vuln/SNYK-DOTNET-SHARPZIPLIB-60247">https://snyk.io/vuln/SNYK-DOTNET-SHARPZIPLIB-60247</a><br></details>  |
| libmono-microsoft-build-framework4.0-cil         |    CVE-2018-1002208   |   LOW  |  6.12.0.122-0xamarin1+ubuntu1804b1 |  | <details><summary>Expand...</summary><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2018-1002208">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2018-1002208</a><br><a href="https://github.com/icsharpcode/SharpZipLib/issues/232">https://github.com/icsharpcode/SharpZipLib/issues/232</a><br><a href="https://github.com/icsharpcode/SharpZipLib/wiki/Release-1.0">https://github.com/icsharpcode/SharpZipLib/wiki/Release-1.0</a><br><a href="https://github.com/snyk/zip-slip-vulnerability">https://github.com/snyk/zip-slip-vulnerability</a><br><a href="https://snyk.io/research/zip-slip-vulnerability">https://snyk.io/research/zip-slip-vulnerability</a><br><a href="https://snyk.io/vuln/SNYK-DOTNET-SHARPZIPLIB-60247">https://snyk.io/vuln/SNYK-DOTNET-SHARPZIPLIB-60247</a><br></details>  |
| libmono-microsoft-build-tasks-v4.0-4.0-cil         |    CVE-2018-1002208   |   LOW  |  6.12.0.122-0xamarin1+ubuntu1804b1 |  | <details><summary>Expand...</summary><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2018-1002208">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2018-1002208</a><br><a href="https://github.com/icsharpcode/SharpZipLib/issues/232">https://github.com/icsharpcode/SharpZipLib/issues/232</a><br><a href="https://github.com/icsharpcode/SharpZipLib/wiki/Release-1.0">https://github.com/icsharpcode/SharpZipLib/wiki/Release-1.0</a><br><a href="https://github.com/snyk/zip-slip-vulnerability">https://github.com/snyk/zip-slip-vulnerability</a><br><a href="https://snyk.io/research/zip-slip-vulnerability">https://snyk.io/research/zip-slip-vulnerability</a><br><a href="https://snyk.io/vuln/SNYK-DOTNET-SHARPZIPLIB-60247">https://snyk.io/vuln/SNYK-DOTNET-SHARPZIPLIB-60247</a><br></details>  |
| libmono-microsoft-build-utilities-v4.0-4.0-cil         |    CVE-2018-1002208   |   LOW  |  6.12.0.122-0xamarin1+ubuntu1804b1 |  | <details><summary>Expand...</summary><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2018-1002208">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2018-1002208</a><br><a href="https://github.com/icsharpcode/SharpZipLib/issues/232">https://github.com/icsharpcode/SharpZipLib/issues/232</a><br><a href="https://github.com/icsharpcode/SharpZipLib/wiki/Release-1.0">https://github.com/icsharpcode/SharpZipLib/wiki/Release-1.0</a><br><a href="https://github.com/snyk/zip-slip-vulnerability">https://github.com/snyk/zip-slip-vulnerability</a><br><a href="https://snyk.io/research/zip-slip-vulnerability">https://snyk.io/research/zip-slip-vulnerability</a><br><a href="https://snyk.io/vuln/SNYK-DOTNET-SHARPZIPLIB-60247">https://snyk.io/vuln/SNYK-DOTNET-SHARPZIPLIB-60247</a><br></details>  |
| libmono-microsoft-build4.0-cil         |    CVE-2018-1002208   |   LOW  |  6.12.0.122-0xamarin1+ubuntu1804b1 |  | <details><summary>Expand...</summary><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2018-1002208">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2018-1002208</a><br><a href="https://github.com/icsharpcode/SharpZipLib/issues/232">https://github.com/icsharpcode/SharpZipLib/issues/232</a><br><a href="https://github.com/icsharpcode/SharpZipLib/wiki/Release-1.0">https://github.com/icsharpcode/SharpZipLib/wiki/Release-1.0</a><br><a href="https://github.com/snyk/zip-slip-vulnerability">https://github.com/snyk/zip-slip-vulnerability</a><br><a href="https://snyk.io/research/zip-slip-vulnerability">https://snyk.io/research/zip-slip-vulnerability</a><br><a href="https://snyk.io/vuln/SNYK-DOTNET-SHARPZIPLIB-60247">https://snyk.io/vuln/SNYK-DOTNET-SHARPZIPLIB-60247</a><br></details>  |
| libmono-microsoft-csharp4.0-cil         |    CVE-2018-1002208   |   LOW  |  6.12.0.122-0xamarin1+ubuntu1804b1 |  | <details><summary>Expand...</summary><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2018-1002208">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2018-1002208</a><br><a href="https://github.com/icsharpcode/SharpZipLib/issues/232">https://github.com/icsharpcode/SharpZipLib/issues/232</a><br><a href="https://github.com/icsharpcode/SharpZipLib/wiki/Release-1.0">https://github.com/icsharpcode/SharpZipLib/wiki/Release-1.0</a><br><a href="https://github.com/snyk/zip-slip-vulnerability">https://github.com/snyk/zip-slip-vulnerability</a><br><a href="https://snyk.io/research/zip-slip-vulnerability">https://snyk.io/research/zip-slip-vulnerability</a><br><a href="https://snyk.io/vuln/SNYK-DOTNET-SHARPZIPLIB-60247">https://snyk.io/vuln/SNYK-DOTNET-SHARPZIPLIB-60247</a><br></details>  |
| libmono-microsoft-visualc10.0-cil         |    CVE-2018-1002208   |   LOW  |  6.12.0.122-0xamarin1+ubuntu1804b1 |  | <details><summary>Expand...</summary><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2018-1002208">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2018-1002208</a><br><a href="https://github.com/icsharpcode/SharpZipLib/issues/232">https://github.com/icsharpcode/SharpZipLib/issues/232</a><br><a href="https://github.com/icsharpcode/SharpZipLib/wiki/Release-1.0">https://github.com/icsharpcode/SharpZipLib/wiki/Release-1.0</a><br><a href="https://github.com/snyk/zip-slip-vulnerability">https://github.com/snyk/zip-slip-vulnerability</a><br><a href="https://snyk.io/research/zip-slip-vulnerability">https://snyk.io/research/zip-slip-vulnerability</a><br><a href="https://snyk.io/vuln/SNYK-DOTNET-SHARPZIPLIB-60247">https://snyk.io/vuln/SNYK-DOTNET-SHARPZIPLIB-60247</a><br></details>  |
| libmono-microsoft-web-infrastructure1.0-cil         |    CVE-2018-1002208   |   LOW  |  6.12.0.122-0xamarin1+ubuntu1804b1 |  | <details><summary>Expand...</summary><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2018-1002208">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2018-1002208</a><br><a href="https://github.com/icsharpcode/SharpZipLib/issues/232">https://github.com/icsharpcode/SharpZipLib/issues/232</a><br><a href="https://github.com/icsharpcode/SharpZipLib/wiki/Release-1.0">https://github.com/icsharpcode/SharpZipLib/wiki/Release-1.0</a><br><a href="https://github.com/snyk/zip-slip-vulnerability">https://github.com/snyk/zip-slip-vulnerability</a><br><a href="https://snyk.io/research/zip-slip-vulnerability">https://snyk.io/research/zip-slip-vulnerability</a><br><a href="https://snyk.io/vuln/SNYK-DOTNET-SHARPZIPLIB-60247">https://snyk.io/vuln/SNYK-DOTNET-SHARPZIPLIB-60247</a><br></details>  |
| libmono-oracle4.0-cil         |    CVE-2018-1002208   |   LOW  |  6.12.0.122-0xamarin1+ubuntu1804b1 |  | <details><summary>Expand...</summary><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2018-1002208">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2018-1002208</a><br><a href="https://github.com/icsharpcode/SharpZipLib/issues/232">https://github.com/icsharpcode/SharpZipLib/issues/232</a><br><a href="https://github.com/icsharpcode/SharpZipLib/wiki/Release-1.0">https://github.com/icsharpcode/SharpZipLib/wiki/Release-1.0</a><br><a href="https://github.com/snyk/zip-slip-vulnerability">https://github.com/snyk/zip-slip-vulnerability</a><br><a href="https://snyk.io/research/zip-slip-vulnerability">https://snyk.io/research/zip-slip-vulnerability</a><br><a href="https://snyk.io/vuln/SNYK-DOTNET-SHARPZIPLIB-60247">https://snyk.io/vuln/SNYK-DOTNET-SHARPZIPLIB-60247</a><br></details>  |
| libmono-parallel4.0-cil         |    CVE-2018-1002208   |   LOW  |  6.12.0.122-0xamarin1+ubuntu1804b1 |  | <details><summary>Expand...</summary><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2018-1002208">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2018-1002208</a><br><a href="https://github.com/icsharpcode/SharpZipLib/issues/232">https://github.com/icsharpcode/SharpZipLib/issues/232</a><br><a href="https://github.com/icsharpcode/SharpZipLib/wiki/Release-1.0">https://github.com/icsharpcode/SharpZipLib/wiki/Release-1.0</a><br><a href="https://github.com/snyk/zip-slip-vulnerability">https://github.com/snyk/zip-slip-vulnerability</a><br><a href="https://snyk.io/research/zip-slip-vulnerability">https://snyk.io/research/zip-slip-vulnerability</a><br><a href="https://snyk.io/vuln/SNYK-DOTNET-SHARPZIPLIB-60247">https://snyk.io/vuln/SNYK-DOTNET-SHARPZIPLIB-60247</a><br></details>  |
| libmono-peapi4.0a-cil         |    CVE-2018-1002208   |   LOW  |  6.12.0.122-0xamarin1+ubuntu1804b1 |  | <details><summary>Expand...</summary><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2018-1002208">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2018-1002208</a><br><a href="https://github.com/icsharpcode/SharpZipLib/issues/232">https://github.com/icsharpcode/SharpZipLib/issues/232</a><br><a href="https://github.com/icsharpcode/SharpZipLib/wiki/Release-1.0">https://github.com/icsharpcode/SharpZipLib/wiki/Release-1.0</a><br><a href="https://github.com/snyk/zip-slip-vulnerability">https://github.com/snyk/zip-slip-vulnerability</a><br><a href="https://snyk.io/research/zip-slip-vulnerability">https://snyk.io/research/zip-slip-vulnerability</a><br><a href="https://snyk.io/vuln/SNYK-DOTNET-SHARPZIPLIB-60247">https://snyk.io/vuln/SNYK-DOTNET-SHARPZIPLIB-60247</a><br></details>  |
| libmono-posix4.0-cil         |    CVE-2018-1002208   |   LOW  |  6.12.0.122-0xamarin1+ubuntu1804b1 |  | <details><summary>Expand...</summary><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2018-1002208">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2018-1002208</a><br><a href="https://github.com/icsharpcode/SharpZipLib/issues/232">https://github.com/icsharpcode/SharpZipLib/issues/232</a><br><a href="https://github.com/icsharpcode/SharpZipLib/wiki/Release-1.0">https://github.com/icsharpcode/SharpZipLib/wiki/Release-1.0</a><br><a href="https://github.com/snyk/zip-slip-vulnerability">https://github.com/snyk/zip-slip-vulnerability</a><br><a href="https://snyk.io/research/zip-slip-vulnerability">https://snyk.io/research/zip-slip-vulnerability</a><br><a href="https://snyk.io/vuln/SNYK-DOTNET-SHARPZIPLIB-60247">https://snyk.io/vuln/SNYK-DOTNET-SHARPZIPLIB-60247</a><br></details>  |
| libmono-rabbitmq4.0-cil         |    CVE-2018-1002208   |   LOW  |  6.12.0.122-0xamarin1+ubuntu1804b1 |  | <details><summary>Expand...</summary><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2018-1002208">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2018-1002208</a><br><a href="https://github.com/icsharpcode/SharpZipLib/issues/232">https://github.com/icsharpcode/SharpZipLib/issues/232</a><br><a href="https://github.com/icsharpcode/SharpZipLib/wiki/Release-1.0">https://github.com/icsharpcode/SharpZipLib/wiki/Release-1.0</a><br><a href="https://github.com/snyk/zip-slip-vulnerability">https://github.com/snyk/zip-slip-vulnerability</a><br><a href="https://snyk.io/research/zip-slip-vulnerability">https://snyk.io/research/zip-slip-vulnerability</a><br><a href="https://snyk.io/vuln/SNYK-DOTNET-SHARPZIPLIB-60247">https://snyk.io/vuln/SNYK-DOTNET-SHARPZIPLIB-60247</a><br></details>  |
| libmono-relaxng4.0-cil         |    CVE-2018-1002208   |   LOW  |  6.12.0.122-0xamarin1+ubuntu1804b1 |  | <details><summary>Expand...</summary><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2018-1002208">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2018-1002208</a><br><a href="https://github.com/icsharpcode/SharpZipLib/issues/232">https://github.com/icsharpcode/SharpZipLib/issues/232</a><br><a href="https://github.com/icsharpcode/SharpZipLib/wiki/Release-1.0">https://github.com/icsharpcode/SharpZipLib/wiki/Release-1.0</a><br><a href="https://github.com/snyk/zip-slip-vulnerability">https://github.com/snyk/zip-slip-vulnerability</a><br><a href="https://snyk.io/research/zip-slip-vulnerability">https://snyk.io/research/zip-slip-vulnerability</a><br><a href="https://snyk.io/vuln/SNYK-DOTNET-SHARPZIPLIB-60247">https://snyk.io/vuln/SNYK-DOTNET-SHARPZIPLIB-60247</a><br></details>  |
| libmono-security4.0-cil         |    CVE-2018-1002208   |   LOW  |  6.12.0.122-0xamarin1+ubuntu1804b1 |  | <details><summary>Expand...</summary><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2018-1002208">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2018-1002208</a><br><a href="https://github.com/icsharpcode/SharpZipLib/issues/232">https://github.com/icsharpcode/SharpZipLib/issues/232</a><br><a href="https://github.com/icsharpcode/SharpZipLib/wiki/Release-1.0">https://github.com/icsharpcode/SharpZipLib/wiki/Release-1.0</a><br><a href="https://github.com/snyk/zip-slip-vulnerability">https://github.com/snyk/zip-slip-vulnerability</a><br><a href="https://snyk.io/research/zip-slip-vulnerability">https://snyk.io/research/zip-slip-vulnerability</a><br><a href="https://snyk.io/vuln/SNYK-DOTNET-SHARPZIPLIB-60247">https://snyk.io/vuln/SNYK-DOTNET-SHARPZIPLIB-60247</a><br></details>  |
| libmono-sharpzip4.84-cil         |    CVE-2018-1002208   |   LOW  |  6.12.0.122-0xamarin1+ubuntu1804b1 |  | <details><summary>Expand...</summary><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2018-1002208">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2018-1002208</a><br><a href="https://github.com/icsharpcode/SharpZipLib/issues/232">https://github.com/icsharpcode/SharpZipLib/issues/232</a><br><a href="https://github.com/icsharpcode/SharpZipLib/wiki/Release-1.0">https://github.com/icsharpcode/SharpZipLib/wiki/Release-1.0</a><br><a href="https://github.com/snyk/zip-slip-vulnerability">https://github.com/snyk/zip-slip-vulnerability</a><br><a href="https://snyk.io/research/zip-slip-vulnerability">https://snyk.io/research/zip-slip-vulnerability</a><br><a href="https://snyk.io/vuln/SNYK-DOTNET-SHARPZIPLIB-60247">https://snyk.io/vuln/SNYK-DOTNET-SHARPZIPLIB-60247</a><br></details>  |
| libmono-simd4.0-cil         |    CVE-2018-1002208   |   LOW  |  6.12.0.122-0xamarin1+ubuntu1804b1 |  | <details><summary>Expand...</summary><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2018-1002208">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2018-1002208</a><br><a href="https://github.com/icsharpcode/SharpZipLib/issues/232">https://github.com/icsharpcode/SharpZipLib/issues/232</a><br><a href="https://github.com/icsharpcode/SharpZipLib/wiki/Release-1.0">https://github.com/icsharpcode/SharpZipLib/wiki/Release-1.0</a><br><a href="https://github.com/snyk/zip-slip-vulnerability">https://github.com/snyk/zip-slip-vulnerability</a><br><a href="https://snyk.io/research/zip-slip-vulnerability">https://snyk.io/research/zip-slip-vulnerability</a><br><a href="https://snyk.io/vuln/SNYK-DOTNET-SHARPZIPLIB-60247">https://snyk.io/vuln/SNYK-DOTNET-SHARPZIPLIB-60247</a><br></details>  |
| libmono-smdiagnostics0.0-cil         |    CVE-2018-1002208   |   LOW  |  6.12.0.122-0xamarin1+ubuntu1804b1 |  | <details><summary>Expand...</summary><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2018-1002208">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2018-1002208</a><br><a href="https://github.com/icsharpcode/SharpZipLib/issues/232">https://github.com/icsharpcode/SharpZipLib/issues/232</a><br><a href="https://github.com/icsharpcode/SharpZipLib/wiki/Release-1.0">https://github.com/icsharpcode/SharpZipLib/wiki/Release-1.0</a><br><a href="https://github.com/snyk/zip-slip-vulnerability">https://github.com/snyk/zip-slip-vulnerability</a><br><a href="https://snyk.io/research/zip-slip-vulnerability">https://snyk.io/research/zip-slip-vulnerability</a><br><a href="https://snyk.io/vuln/SNYK-DOTNET-SHARPZIPLIB-60247">https://snyk.io/vuln/SNYK-DOTNET-SHARPZIPLIB-60247</a><br></details>  |
| libmono-sqlite4.0-cil         |    CVE-2018-1002208   |   LOW  |  6.12.0.122-0xamarin1+ubuntu1804b1 |  | <details><summary>Expand...</summary><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2018-1002208">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2018-1002208</a><br><a href="https://github.com/icsharpcode/SharpZipLib/issues/232">https://github.com/icsharpcode/SharpZipLib/issues/232</a><br><a href="https://github.com/icsharpcode/SharpZipLib/wiki/Release-1.0">https://github.com/icsharpcode/SharpZipLib/wiki/Release-1.0</a><br><a href="https://github.com/snyk/zip-slip-vulnerability">https://github.com/snyk/zip-slip-vulnerability</a><br><a href="https://snyk.io/research/zip-slip-vulnerability">https://snyk.io/research/zip-slip-vulnerability</a><br><a href="https://snyk.io/vuln/SNYK-DOTNET-SHARPZIPLIB-60247">https://snyk.io/vuln/SNYK-DOTNET-SHARPZIPLIB-60247</a><br></details>  |
| libmono-system-componentmodel-composition4.0-cil         |    CVE-2018-1002208   |   LOW  |  6.12.0.122-0xamarin1+ubuntu1804b1 |  | <details><summary>Expand...</summary><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2018-1002208">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2018-1002208</a><br><a href="https://github.com/icsharpcode/SharpZipLib/issues/232">https://github.com/icsharpcode/SharpZipLib/issues/232</a><br><a href="https://github.com/icsharpcode/SharpZipLib/wiki/Release-1.0">https://github.com/icsharpcode/SharpZipLib/wiki/Release-1.0</a><br><a href="https://github.com/snyk/zip-slip-vulnerability">https://github.com/snyk/zip-slip-vulnerability</a><br><a href="https://snyk.io/research/zip-slip-vulnerability">https://snyk.io/research/zip-slip-vulnerability</a><br><a href="https://snyk.io/vuln/SNYK-DOTNET-SHARPZIPLIB-60247">https://snyk.io/vuln/SNYK-DOTNET-SHARPZIPLIB-60247</a><br></details>  |
| libmono-system-componentmodel-dataannotations4.0-cil         |    CVE-2018-1002208   |   LOW  |  6.12.0.122-0xamarin1+ubuntu1804b1 |  | <details><summary>Expand...</summary><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2018-1002208">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2018-1002208</a><br><a href="https://github.com/icsharpcode/SharpZipLib/issues/232">https://github.com/icsharpcode/SharpZipLib/issues/232</a><br><a href="https://github.com/icsharpcode/SharpZipLib/wiki/Release-1.0">https://github.com/icsharpcode/SharpZipLib/wiki/Release-1.0</a><br><a href="https://github.com/snyk/zip-slip-vulnerability">https://github.com/snyk/zip-slip-vulnerability</a><br><a href="https://snyk.io/research/zip-slip-vulnerability">https://snyk.io/research/zip-slip-vulnerability</a><br><a href="https://snyk.io/vuln/SNYK-DOTNET-SHARPZIPLIB-60247">https://snyk.io/vuln/SNYK-DOTNET-SHARPZIPLIB-60247</a><br></details>  |
| libmono-system-configuration-install4.0-cil         |    CVE-2018-1002208   |   LOW  |  6.12.0.122-0xamarin1+ubuntu1804b1 |  | <details><summary>Expand...</summary><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2018-1002208">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2018-1002208</a><br><a href="https://github.com/icsharpcode/SharpZipLib/issues/232">https://github.com/icsharpcode/SharpZipLib/issues/232</a><br><a href="https://github.com/icsharpcode/SharpZipLib/wiki/Release-1.0">https://github.com/icsharpcode/SharpZipLib/wiki/Release-1.0</a><br><a href="https://github.com/snyk/zip-slip-vulnerability">https://github.com/snyk/zip-slip-vulnerability</a><br><a href="https://snyk.io/research/zip-slip-vulnerability">https://snyk.io/research/zip-slip-vulnerability</a><br><a href="https://snyk.io/vuln/SNYK-DOTNET-SHARPZIPLIB-60247">https://snyk.io/vuln/SNYK-DOTNET-SHARPZIPLIB-60247</a><br></details>  |
| libmono-system-configuration4.0-cil         |    CVE-2018-1002208   |   LOW  |  6.12.0.122-0xamarin1+ubuntu1804b1 |  | <details><summary>Expand...</summary><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2018-1002208">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2018-1002208</a><br><a href="https://github.com/icsharpcode/SharpZipLib/issues/232">https://github.com/icsharpcode/SharpZipLib/issues/232</a><br><a href="https://github.com/icsharpcode/SharpZipLib/wiki/Release-1.0">https://github.com/icsharpcode/SharpZipLib/wiki/Release-1.0</a><br><a href="https://github.com/snyk/zip-slip-vulnerability">https://github.com/snyk/zip-slip-vulnerability</a><br><a href="https://snyk.io/research/zip-slip-vulnerability">https://snyk.io/research/zip-slip-vulnerability</a><br><a href="https://snyk.io/vuln/SNYK-DOTNET-SHARPZIPLIB-60247">https://snyk.io/vuln/SNYK-DOTNET-SHARPZIPLIB-60247</a><br></details>  |
| libmono-system-core4.0-cil         |    CVE-2018-1002208   |   LOW  |  6.12.0.122-0xamarin1+ubuntu1804b1 |  | <details><summary>Expand...</summary><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2018-1002208">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2018-1002208</a><br><a href="https://github.com/icsharpcode/SharpZipLib/issues/232">https://github.com/icsharpcode/SharpZipLib/issues/232</a><br><a href="https://github.com/icsharpcode/SharpZipLib/wiki/Release-1.0">https://github.com/icsharpcode/SharpZipLib/wiki/Release-1.0</a><br><a href="https://github.com/snyk/zip-slip-vulnerability">https://github.com/snyk/zip-slip-vulnerability</a><br><a href="https://snyk.io/research/zip-slip-vulnerability">https://snyk.io/research/zip-slip-vulnerability</a><br><a href="https://snyk.io/vuln/SNYK-DOTNET-SHARPZIPLIB-60247">https://snyk.io/vuln/SNYK-DOTNET-SHARPZIPLIB-60247</a><br></details>  |
| libmono-system-data-datasetextensions4.0-cil         |    CVE-2018-1002208   |   LOW  |  6.12.0.122-0xamarin1+ubuntu1804b1 |  | <details><summary>Expand...</summary><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2018-1002208">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2018-1002208</a><br><a href="https://github.com/icsharpcode/SharpZipLib/issues/232">https://github.com/icsharpcode/SharpZipLib/issues/232</a><br><a href="https://github.com/icsharpcode/SharpZipLib/wiki/Release-1.0">https://github.com/icsharpcode/SharpZipLib/wiki/Release-1.0</a><br><a href="https://github.com/snyk/zip-slip-vulnerability">https://github.com/snyk/zip-slip-vulnerability</a><br><a href="https://snyk.io/research/zip-slip-vulnerability">https://snyk.io/research/zip-slip-vulnerability</a><br><a href="https://snyk.io/vuln/SNYK-DOTNET-SHARPZIPLIB-60247">https://snyk.io/vuln/SNYK-DOTNET-SHARPZIPLIB-60247</a><br></details>  |
| libmono-system-data-entity4.0-cil         |    CVE-2018-1002208   |   LOW  |  6.12.0.122-0xamarin1+ubuntu1804b1 |  | <details><summary>Expand...</summary><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2018-1002208">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2018-1002208</a><br><a href="https://github.com/icsharpcode/SharpZipLib/issues/232">https://github.com/icsharpcode/SharpZipLib/issues/232</a><br><a href="https://github.com/icsharpcode/SharpZipLib/wiki/Release-1.0">https://github.com/icsharpcode/SharpZipLib/wiki/Release-1.0</a><br><a href="https://github.com/snyk/zip-slip-vulnerability">https://github.com/snyk/zip-slip-vulnerability</a><br><a href="https://snyk.io/research/zip-slip-vulnerability">https://snyk.io/research/zip-slip-vulnerability</a><br><a href="https://snyk.io/vuln/SNYK-DOTNET-SHARPZIPLIB-60247">https://snyk.io/vuln/SNYK-DOTNET-SHARPZIPLIB-60247</a><br></details>  |
| libmono-system-data-linq4.0-cil         |    CVE-2018-1002208   |   LOW  |  6.12.0.122-0xamarin1+ubuntu1804b1 |  | <details><summary>Expand...</summary><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2018-1002208">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2018-1002208</a><br><a href="https://github.com/icsharpcode/SharpZipLib/issues/232">https://github.com/icsharpcode/SharpZipLib/issues/232</a><br><a href="https://github.com/icsharpcode/SharpZipLib/wiki/Release-1.0">https://github.com/icsharpcode/SharpZipLib/wiki/Release-1.0</a><br><a href="https://github.com/snyk/zip-slip-vulnerability">https://github.com/snyk/zip-slip-vulnerability</a><br><a href="https://snyk.io/research/zip-slip-vulnerability">https://snyk.io/research/zip-slip-vulnerability</a><br><a href="https://snyk.io/vuln/SNYK-DOTNET-SHARPZIPLIB-60247">https://snyk.io/vuln/SNYK-DOTNET-SHARPZIPLIB-60247</a><br></details>  |
| libmono-system-data-services-client4.0-cil         |    CVE-2018-1002208   |   LOW  |  6.12.0.122-0xamarin1+ubuntu1804b1 |  | <details><summary>Expand...</summary><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2018-1002208">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2018-1002208</a><br><a href="https://github.com/icsharpcode/SharpZipLib/issues/232">https://github.com/icsharpcode/SharpZipLib/issues/232</a><br><a href="https://github.com/icsharpcode/SharpZipLib/wiki/Release-1.0">https://github.com/icsharpcode/SharpZipLib/wiki/Release-1.0</a><br><a href="https://github.com/snyk/zip-slip-vulnerability">https://github.com/snyk/zip-slip-vulnerability</a><br><a href="https://snyk.io/research/zip-slip-vulnerability">https://snyk.io/research/zip-slip-vulnerability</a><br><a href="https://snyk.io/vuln/SNYK-DOTNET-SHARPZIPLIB-60247">https://snyk.io/vuln/SNYK-DOTNET-SHARPZIPLIB-60247</a><br></details>  |
| libmono-system-data-services4.0-cil         |    CVE-2018-1002208   |   LOW  |  6.12.0.122-0xamarin1+ubuntu1804b1 |  | <details><summary>Expand...</summary><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2018-1002208">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2018-1002208</a><br><a href="https://github.com/icsharpcode/SharpZipLib/issues/232">https://github.com/icsharpcode/SharpZipLib/issues/232</a><br><a href="https://github.com/icsharpcode/SharpZipLib/wiki/Release-1.0">https://github.com/icsharpcode/SharpZipLib/wiki/Release-1.0</a><br><a href="https://github.com/snyk/zip-slip-vulnerability">https://github.com/snyk/zip-slip-vulnerability</a><br><a href="https://snyk.io/research/zip-slip-vulnerability">https://snyk.io/research/zip-slip-vulnerability</a><br><a href="https://snyk.io/vuln/SNYK-DOTNET-SHARPZIPLIB-60247">https://snyk.io/vuln/SNYK-DOTNET-SHARPZIPLIB-60247</a><br></details>  |
| libmono-system-data4.0-cil         |    CVE-2018-1002208   |   LOW  |  6.12.0.122-0xamarin1+ubuntu1804b1 |  | <details><summary>Expand...</summary><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2018-1002208">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2018-1002208</a><br><a href="https://github.com/icsharpcode/SharpZipLib/issues/232">https://github.com/icsharpcode/SharpZipLib/issues/232</a><br><a href="https://github.com/icsharpcode/SharpZipLib/wiki/Release-1.0">https://github.com/icsharpcode/SharpZipLib/wiki/Release-1.0</a><br><a href="https://github.com/snyk/zip-slip-vulnerability">https://github.com/snyk/zip-slip-vulnerability</a><br><a href="https://snyk.io/research/zip-slip-vulnerability">https://snyk.io/research/zip-slip-vulnerability</a><br><a href="https://snyk.io/vuln/SNYK-DOTNET-SHARPZIPLIB-60247">https://snyk.io/vuln/SNYK-DOTNET-SHARPZIPLIB-60247</a><br></details>  |
| libmono-system-deployment4.0-cil         |    CVE-2018-1002208   |   LOW  |  6.12.0.122-0xamarin1+ubuntu1804b1 |  | <details><summary>Expand...</summary><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2018-1002208">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2018-1002208</a><br><a href="https://github.com/icsharpcode/SharpZipLib/issues/232">https://github.com/icsharpcode/SharpZipLib/issues/232</a><br><a href="https://github.com/icsharpcode/SharpZipLib/wiki/Release-1.0">https://github.com/icsharpcode/SharpZipLib/wiki/Release-1.0</a><br><a href="https://github.com/snyk/zip-slip-vulnerability">https://github.com/snyk/zip-slip-vulnerability</a><br><a href="https://snyk.io/research/zip-slip-vulnerability">https://snyk.io/research/zip-slip-vulnerability</a><br><a href="https://snyk.io/vuln/SNYK-DOTNET-SHARPZIPLIB-60247">https://snyk.io/vuln/SNYK-DOTNET-SHARPZIPLIB-60247</a><br></details>  |
| libmono-system-design4.0-cil         |    CVE-2018-1002208   |   LOW  |  6.12.0.122-0xamarin1+ubuntu1804b1 |  | <details><summary>Expand...</summary><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2018-1002208">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2018-1002208</a><br><a href="https://github.com/icsharpcode/SharpZipLib/issues/232">https://github.com/icsharpcode/SharpZipLib/issues/232</a><br><a href="https://github.com/icsharpcode/SharpZipLib/wiki/Release-1.0">https://github.com/icsharpcode/SharpZipLib/wiki/Release-1.0</a><br><a href="https://github.com/snyk/zip-slip-vulnerability">https://github.com/snyk/zip-slip-vulnerability</a><br><a href="https://snyk.io/research/zip-slip-vulnerability">https://snyk.io/research/zip-slip-vulnerability</a><br><a href="https://snyk.io/vuln/SNYK-DOTNET-SHARPZIPLIB-60247">https://snyk.io/vuln/SNYK-DOTNET-SHARPZIPLIB-60247</a><br></details>  |
| libmono-system-drawing-design4.0-cil         |    CVE-2018-1002208   |   LOW  |  6.12.0.122-0xamarin1+ubuntu1804b1 |  | <details><summary>Expand...</summary><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2018-1002208">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2018-1002208</a><br><a href="https://github.com/icsharpcode/SharpZipLib/issues/232">https://github.com/icsharpcode/SharpZipLib/issues/232</a><br><a href="https://github.com/icsharpcode/SharpZipLib/wiki/Release-1.0">https://github.com/icsharpcode/SharpZipLib/wiki/Release-1.0</a><br><a href="https://github.com/snyk/zip-slip-vulnerability">https://github.com/snyk/zip-slip-vulnerability</a><br><a href="https://snyk.io/research/zip-slip-vulnerability">https://snyk.io/research/zip-slip-vulnerability</a><br><a href="https://snyk.io/vuln/SNYK-DOTNET-SHARPZIPLIB-60247">https://snyk.io/vuln/SNYK-DOTNET-SHARPZIPLIB-60247</a><br></details>  |
| libmono-system-drawing4.0-cil         |    CVE-2018-1002208   |   LOW  |  6.12.0.122-0xamarin1+ubuntu1804b1 |  | <details><summary>Expand...</summary><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2018-1002208">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2018-1002208</a><br><a href="https://github.com/icsharpcode/SharpZipLib/issues/232">https://github.com/icsharpcode/SharpZipLib/issues/232</a><br><a href="https://github.com/icsharpcode/SharpZipLib/wiki/Release-1.0">https://github.com/icsharpcode/SharpZipLib/wiki/Release-1.0</a><br><a href="https://github.com/snyk/zip-slip-vulnerability">https://github.com/snyk/zip-slip-vulnerability</a><br><a href="https://snyk.io/research/zip-slip-vulnerability">https://snyk.io/research/zip-slip-vulnerability</a><br><a href="https://snyk.io/vuln/SNYK-DOTNET-SHARPZIPLIB-60247">https://snyk.io/vuln/SNYK-DOTNET-SHARPZIPLIB-60247</a><br></details>  |
| libmono-system-dynamic4.0-cil         |    CVE-2018-1002208   |   LOW  |  6.12.0.122-0xamarin1+ubuntu1804b1 |  | <details><summary>Expand...</summary><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2018-1002208">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2018-1002208</a><br><a href="https://github.com/icsharpcode/SharpZipLib/issues/232">https://github.com/icsharpcode/SharpZipLib/issues/232</a><br><a href="https://github.com/icsharpcode/SharpZipLib/wiki/Release-1.0">https://github.com/icsharpcode/SharpZipLib/wiki/Release-1.0</a><br><a href="https://github.com/snyk/zip-slip-vulnerability">https://github.com/snyk/zip-slip-vulnerability</a><br><a href="https://snyk.io/research/zip-slip-vulnerability">https://snyk.io/research/zip-slip-vulnerability</a><br><a href="https://snyk.io/vuln/SNYK-DOTNET-SHARPZIPLIB-60247">https://snyk.io/vuln/SNYK-DOTNET-SHARPZIPLIB-60247</a><br></details>  |
| libmono-system-enterpriseservices4.0-cil         |    CVE-2018-1002208   |   LOW  |  6.12.0.122-0xamarin1+ubuntu1804b1 |  | <details><summary>Expand...</summary><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2018-1002208">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2018-1002208</a><br><a href="https://github.com/icsharpcode/SharpZipLib/issues/232">https://github.com/icsharpcode/SharpZipLib/issues/232</a><br><a href="https://github.com/icsharpcode/SharpZipLib/wiki/Release-1.0">https://github.com/icsharpcode/SharpZipLib/wiki/Release-1.0</a><br><a href="https://github.com/snyk/zip-slip-vulnerability">https://github.com/snyk/zip-slip-vulnerability</a><br><a href="https://snyk.io/research/zip-slip-vulnerability">https://snyk.io/research/zip-slip-vulnerability</a><br><a href="https://snyk.io/vuln/SNYK-DOTNET-SHARPZIPLIB-60247">https://snyk.io/vuln/SNYK-DOTNET-SHARPZIPLIB-60247</a><br></details>  |
| libmono-system-identitymodel-selectors4.0-cil         |    CVE-2018-1002208   |   LOW  |  6.12.0.122-0xamarin1+ubuntu1804b1 |  | <details><summary>Expand...</summary><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2018-1002208">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2018-1002208</a><br><a href="https://github.com/icsharpcode/SharpZipLib/issues/232">https://github.com/icsharpcode/SharpZipLib/issues/232</a><br><a href="https://github.com/icsharpcode/SharpZipLib/wiki/Release-1.0">https://github.com/icsharpcode/SharpZipLib/wiki/Release-1.0</a><br><a href="https://github.com/snyk/zip-slip-vulnerability">https://github.com/snyk/zip-slip-vulnerability</a><br><a href="https://snyk.io/research/zip-slip-vulnerability">https://snyk.io/research/zip-slip-vulnerability</a><br><a href="https://snyk.io/vuln/SNYK-DOTNET-SHARPZIPLIB-60247">https://snyk.io/vuln/SNYK-DOTNET-SHARPZIPLIB-60247</a><br></details>  |
| libmono-system-identitymodel4.0-cil         |    CVE-2018-1002208   |   LOW  |  6.12.0.122-0xamarin1+ubuntu1804b1 |  | <details><summary>Expand...</summary><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2018-1002208">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2018-1002208</a><br><a href="https://github.com/icsharpcode/SharpZipLib/issues/232">https://github.com/icsharpcode/SharpZipLib/issues/232</a><br><a href="https://github.com/icsharpcode/SharpZipLib/wiki/Release-1.0">https://github.com/icsharpcode/SharpZipLib/wiki/Release-1.0</a><br><a href="https://github.com/snyk/zip-slip-vulnerability">https://github.com/snyk/zip-slip-vulnerability</a><br><a href="https://snyk.io/research/zip-slip-vulnerability">https://snyk.io/research/zip-slip-vulnerability</a><br><a href="https://snyk.io/vuln/SNYK-DOTNET-SHARPZIPLIB-60247">https://snyk.io/vuln/SNYK-DOTNET-SHARPZIPLIB-60247</a><br></details>  |
| libmono-system-io-compression-filesystem4.0-cil         |    CVE-2018-1002208   |   LOW  |  6.12.0.122-0xamarin1+ubuntu1804b1 |  | <details><summary>Expand...</summary><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2018-1002208">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2018-1002208</a><br><a href="https://github.com/icsharpcode/SharpZipLib/issues/232">https://github.com/icsharpcode/SharpZipLib/issues/232</a><br><a href="https://github.com/icsharpcode/SharpZipLib/wiki/Release-1.0">https://github.com/icsharpcode/SharpZipLib/wiki/Release-1.0</a><br><a href="https://github.com/snyk/zip-slip-vulnerability">https://github.com/snyk/zip-slip-vulnerability</a><br><a href="https://snyk.io/research/zip-slip-vulnerability">https://snyk.io/research/zip-slip-vulnerability</a><br><a href="https://snyk.io/vuln/SNYK-DOTNET-SHARPZIPLIB-60247">https://snyk.io/vuln/SNYK-DOTNET-SHARPZIPLIB-60247</a><br></details>  |
| libmono-system-io-compression4.0-cil         |    CVE-2018-1002208   |   LOW  |  6.12.0.122-0xamarin1+ubuntu1804b1 |  | <details><summary>Expand...</summary><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2018-1002208">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2018-1002208</a><br><a href="https://github.com/icsharpcode/SharpZipLib/issues/232">https://github.com/icsharpcode/SharpZipLib/issues/232</a><br><a href="https://github.com/icsharpcode/SharpZipLib/wiki/Release-1.0">https://github.com/icsharpcode/SharpZipLib/wiki/Release-1.0</a><br><a href="https://github.com/snyk/zip-slip-vulnerability">https://github.com/snyk/zip-slip-vulnerability</a><br><a href="https://snyk.io/research/zip-slip-vulnerability">https://snyk.io/research/zip-slip-vulnerability</a><br><a href="https://snyk.io/vuln/SNYK-DOTNET-SHARPZIPLIB-60247">https://snyk.io/vuln/SNYK-DOTNET-SHARPZIPLIB-60247</a><br></details>  |
| libmono-system-json-microsoft4.0-cil         |    CVE-2018-1002208   |   LOW  |  6.12.0.122-0xamarin1+ubuntu1804b1 |  | <details><summary>Expand...</summary><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2018-1002208">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2018-1002208</a><br><a href="https://github.com/icsharpcode/SharpZipLib/issues/232">https://github.com/icsharpcode/SharpZipLib/issues/232</a><br><a href="https://github.com/icsharpcode/SharpZipLib/wiki/Release-1.0">https://github.com/icsharpcode/SharpZipLib/wiki/Release-1.0</a><br><a href="https://github.com/snyk/zip-slip-vulnerability">https://github.com/snyk/zip-slip-vulnerability</a><br><a href="https://snyk.io/research/zip-slip-vulnerability">https://snyk.io/research/zip-slip-vulnerability</a><br><a href="https://snyk.io/vuln/SNYK-DOTNET-SHARPZIPLIB-60247">https://snyk.io/vuln/SNYK-DOTNET-SHARPZIPLIB-60247</a><br></details>  |
| libmono-system-json4.0-cil         |    CVE-2018-1002208   |   LOW  |  6.12.0.122-0xamarin1+ubuntu1804b1 |  | <details><summary>Expand...</summary><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2018-1002208">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2018-1002208</a><br><a href="https://github.com/icsharpcode/SharpZipLib/issues/232">https://github.com/icsharpcode/SharpZipLib/issues/232</a><br><a href="https://github.com/icsharpcode/SharpZipLib/wiki/Release-1.0">https://github.com/icsharpcode/SharpZipLib/wiki/Release-1.0</a><br><a href="https://github.com/snyk/zip-slip-vulnerability">https://github.com/snyk/zip-slip-vulnerability</a><br><a href="https://snyk.io/research/zip-slip-vulnerability">https://snyk.io/research/zip-slip-vulnerability</a><br><a href="https://snyk.io/vuln/SNYK-DOTNET-SHARPZIPLIB-60247">https://snyk.io/vuln/SNYK-DOTNET-SHARPZIPLIB-60247</a><br></details>  |
| libmono-system-ldap-protocols4.0-cil         |    CVE-2018-1002208   |   LOW  |  6.12.0.122-0xamarin1+ubuntu1804b1 |  | <details><summary>Expand...</summary><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2018-1002208">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2018-1002208</a><br><a href="https://github.com/icsharpcode/SharpZipLib/issues/232">https://github.com/icsharpcode/SharpZipLib/issues/232</a><br><a href="https://github.com/icsharpcode/SharpZipLib/wiki/Release-1.0">https://github.com/icsharpcode/SharpZipLib/wiki/Release-1.0</a><br><a href="https://github.com/snyk/zip-slip-vulnerability">https://github.com/snyk/zip-slip-vulnerability</a><br><a href="https://snyk.io/research/zip-slip-vulnerability">https://snyk.io/research/zip-slip-vulnerability</a><br><a href="https://snyk.io/vuln/SNYK-DOTNET-SHARPZIPLIB-60247">https://snyk.io/vuln/SNYK-DOTNET-SHARPZIPLIB-60247</a><br></details>  |
| libmono-system-ldap4.0-cil         |    CVE-2018-1002208   |   LOW  |  6.12.0.122-0xamarin1+ubuntu1804b1 |  | <details><summary>Expand...</summary><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2018-1002208">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2018-1002208</a><br><a href="https://github.com/icsharpcode/SharpZipLib/issues/232">https://github.com/icsharpcode/SharpZipLib/issues/232</a><br><a href="https://github.com/icsharpcode/SharpZipLib/wiki/Release-1.0">https://github.com/icsharpcode/SharpZipLib/wiki/Release-1.0</a><br><a href="https://github.com/snyk/zip-slip-vulnerability">https://github.com/snyk/zip-slip-vulnerability</a><br><a href="https://snyk.io/research/zip-slip-vulnerability">https://snyk.io/research/zip-slip-vulnerability</a><br><a href="https://snyk.io/vuln/SNYK-DOTNET-SHARPZIPLIB-60247">https://snyk.io/vuln/SNYK-DOTNET-SHARPZIPLIB-60247</a><br></details>  |
| libmono-system-management4.0-cil         |    CVE-2018-1002208   |   LOW  |  6.12.0.122-0xamarin1+ubuntu1804b1 |  | <details><summary>Expand...</summary><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2018-1002208">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2018-1002208</a><br><a href="https://github.com/icsharpcode/SharpZipLib/issues/232">https://github.com/icsharpcode/SharpZipLib/issues/232</a><br><a href="https://github.com/icsharpcode/SharpZipLib/wiki/Release-1.0">https://github.com/icsharpcode/SharpZipLib/wiki/Release-1.0</a><br><a href="https://github.com/snyk/zip-slip-vulnerability">https://github.com/snyk/zip-slip-vulnerability</a><br><a href="https://snyk.io/research/zip-slip-vulnerability">https://snyk.io/research/zip-slip-vulnerability</a><br><a href="https://snyk.io/vuln/SNYK-DOTNET-SHARPZIPLIB-60247">https://snyk.io/vuln/SNYK-DOTNET-SHARPZIPLIB-60247</a><br></details>  |
| libmono-system-messaging4.0-cil         |    CVE-2018-1002208   |   LOW  |  6.12.0.122-0xamarin1+ubuntu1804b1 |  | <details><summary>Expand...</summary><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2018-1002208">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2018-1002208</a><br><a href="https://github.com/icsharpcode/SharpZipLib/issues/232">https://github.com/icsharpcode/SharpZipLib/issues/232</a><br><a href="https://github.com/icsharpcode/SharpZipLib/wiki/Release-1.0">https://github.com/icsharpcode/SharpZipLib/wiki/Release-1.0</a><br><a href="https://github.com/snyk/zip-slip-vulnerability">https://github.com/snyk/zip-slip-vulnerability</a><br><a href="https://snyk.io/research/zip-slip-vulnerability">https://snyk.io/research/zip-slip-vulnerability</a><br><a href="https://snyk.io/vuln/SNYK-DOTNET-SHARPZIPLIB-60247">https://snyk.io/vuln/SNYK-DOTNET-SHARPZIPLIB-60247</a><br></details>  |
| libmono-system-net-http-formatting4.0-cil         |    CVE-2018-1002208   |   LOW  |  6.12.0.122-0xamarin1+ubuntu1804b1 |  | <details><summary>Expand...</summary><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2018-1002208">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2018-1002208</a><br><a href="https://github.com/icsharpcode/SharpZipLib/issues/232">https://github.com/icsharpcode/SharpZipLib/issues/232</a><br><a href="https://github.com/icsharpcode/SharpZipLib/wiki/Release-1.0">https://github.com/icsharpcode/SharpZipLib/wiki/Release-1.0</a><br><a href="https://github.com/snyk/zip-slip-vulnerability">https://github.com/snyk/zip-slip-vulnerability</a><br><a href="https://snyk.io/research/zip-slip-vulnerability">https://snyk.io/research/zip-slip-vulnerability</a><br><a href="https://snyk.io/vuln/SNYK-DOTNET-SHARPZIPLIB-60247">https://snyk.io/vuln/SNYK-DOTNET-SHARPZIPLIB-60247</a><br></details>  |
| libmono-system-net-http-webrequest4.0-cil         |    CVE-2018-1002208   |   LOW  |  6.12.0.122-0xamarin1+ubuntu1804b1 |  | <details><summary>Expand...</summary><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2018-1002208">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2018-1002208</a><br><a href="https://github.com/icsharpcode/SharpZipLib/issues/232">https://github.com/icsharpcode/SharpZipLib/issues/232</a><br><a href="https://github.com/icsharpcode/SharpZipLib/wiki/Release-1.0">https://github.com/icsharpcode/SharpZipLib/wiki/Release-1.0</a><br><a href="https://github.com/snyk/zip-slip-vulnerability">https://github.com/snyk/zip-slip-vulnerability</a><br><a href="https://snyk.io/research/zip-slip-vulnerability">https://snyk.io/research/zip-slip-vulnerability</a><br><a href="https://snyk.io/vuln/SNYK-DOTNET-SHARPZIPLIB-60247">https://snyk.io/vuln/SNYK-DOTNET-SHARPZIPLIB-60247</a><br></details>  |
| libmono-system-net-http4.0-cil         |    CVE-2018-1002208   |   LOW  |  6.12.0.122-0xamarin1+ubuntu1804b1 |  | <details><summary>Expand...</summary><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2018-1002208">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2018-1002208</a><br><a href="https://github.com/icsharpcode/SharpZipLib/issues/232">https://github.com/icsharpcode/SharpZipLib/issues/232</a><br><a href="https://github.com/icsharpcode/SharpZipLib/wiki/Release-1.0">https://github.com/icsharpcode/SharpZipLib/wiki/Release-1.0</a><br><a href="https://github.com/snyk/zip-slip-vulnerability">https://github.com/snyk/zip-slip-vulnerability</a><br><a href="https://snyk.io/research/zip-slip-vulnerability">https://snyk.io/research/zip-slip-vulnerability</a><br><a href="https://snyk.io/vuln/SNYK-DOTNET-SHARPZIPLIB-60247">https://snyk.io/vuln/SNYK-DOTNET-SHARPZIPLIB-60247</a><br></details>  |
| libmono-system-net4.0-cil         |    CVE-2018-1002208   |   LOW  |  6.12.0.122-0xamarin1+ubuntu1804b1 |  | <details><summary>Expand...</summary><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2018-1002208">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2018-1002208</a><br><a href="https://github.com/icsharpcode/SharpZipLib/issues/232">https://github.com/icsharpcode/SharpZipLib/issues/232</a><br><a href="https://github.com/icsharpcode/SharpZipLib/wiki/Release-1.0">https://github.com/icsharpcode/SharpZipLib/wiki/Release-1.0</a><br><a href="https://github.com/snyk/zip-slip-vulnerability">https://github.com/snyk/zip-slip-vulnerability</a><br><a href="https://snyk.io/research/zip-slip-vulnerability">https://snyk.io/research/zip-slip-vulnerability</a><br><a href="https://snyk.io/vuln/SNYK-DOTNET-SHARPZIPLIB-60247">https://snyk.io/vuln/SNYK-DOTNET-SHARPZIPLIB-60247</a><br></details>  |
| libmono-system-numerics-vectors4.0-cil         |    CVE-2018-1002208   |   LOW  |  6.12.0.122-0xamarin1+ubuntu1804b1 |  | <details><summary>Expand...</summary><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2018-1002208">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2018-1002208</a><br><a href="https://github.com/icsharpcode/SharpZipLib/issues/232">https://github.com/icsharpcode/SharpZipLib/issues/232</a><br><a href="https://github.com/icsharpcode/SharpZipLib/wiki/Release-1.0">https://github.com/icsharpcode/SharpZipLib/wiki/Release-1.0</a><br><a href="https://github.com/snyk/zip-slip-vulnerability">https://github.com/snyk/zip-slip-vulnerability</a><br><a href="https://snyk.io/research/zip-slip-vulnerability">https://snyk.io/research/zip-slip-vulnerability</a><br><a href="https://snyk.io/vuln/SNYK-DOTNET-SHARPZIPLIB-60247">https://snyk.io/vuln/SNYK-DOTNET-SHARPZIPLIB-60247</a><br></details>  |
| libmono-system-numerics4.0-cil         |    CVE-2018-1002208   |   LOW  |  6.12.0.122-0xamarin1+ubuntu1804b1 |  | <details><summary>Expand...</summary><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2018-1002208">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2018-1002208</a><br><a href="https://github.com/icsharpcode/SharpZipLib/issues/232">https://github.com/icsharpcode/SharpZipLib/issues/232</a><br><a href="https://github.com/icsharpcode/SharpZipLib/wiki/Release-1.0">https://github.com/icsharpcode/SharpZipLib/wiki/Release-1.0</a><br><a href="https://github.com/snyk/zip-slip-vulnerability">https://github.com/snyk/zip-slip-vulnerability</a><br><a href="https://snyk.io/research/zip-slip-vulnerability">https://snyk.io/research/zip-slip-vulnerability</a><br><a href="https://snyk.io/vuln/SNYK-DOTNET-SHARPZIPLIB-60247">https://snyk.io/vuln/SNYK-DOTNET-SHARPZIPLIB-60247</a><br></details>  |
| libmono-system-reactive-core2.2-cil         |    CVE-2018-1002208   |   LOW  |  6.12.0.122-0xamarin1+ubuntu1804b1 |  | <details><summary>Expand...</summary><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2018-1002208">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2018-1002208</a><br><a href="https://github.com/icsharpcode/SharpZipLib/issues/232">https://github.com/icsharpcode/SharpZipLib/issues/232</a><br><a href="https://github.com/icsharpcode/SharpZipLib/wiki/Release-1.0">https://github.com/icsharpcode/SharpZipLib/wiki/Release-1.0</a><br><a href="https://github.com/snyk/zip-slip-vulnerability">https://github.com/snyk/zip-slip-vulnerability</a><br><a href="https://snyk.io/research/zip-slip-vulnerability">https://snyk.io/research/zip-slip-vulnerability</a><br><a href="https://snyk.io/vuln/SNYK-DOTNET-SHARPZIPLIB-60247">https://snyk.io/vuln/SNYK-DOTNET-SHARPZIPLIB-60247</a><br></details>  |
| libmono-system-reactive-debugger2.2-cil         |    CVE-2018-1002208   |   LOW  |  6.12.0.122-0xamarin1+ubuntu1804b1 |  | <details><summary>Expand...</summary><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2018-1002208">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2018-1002208</a><br><a href="https://github.com/icsharpcode/SharpZipLib/issues/232">https://github.com/icsharpcode/SharpZipLib/issues/232</a><br><a href="https://github.com/icsharpcode/SharpZipLib/wiki/Release-1.0">https://github.com/icsharpcode/SharpZipLib/wiki/Release-1.0</a><br><a href="https://github.com/snyk/zip-slip-vulnerability">https://github.com/snyk/zip-slip-vulnerability</a><br><a href="https://snyk.io/research/zip-slip-vulnerability">https://snyk.io/research/zip-slip-vulnerability</a><br><a href="https://snyk.io/vuln/SNYK-DOTNET-SHARPZIPLIB-60247">https://snyk.io/vuln/SNYK-DOTNET-SHARPZIPLIB-60247</a><br></details>  |
| libmono-system-reactive-experimental2.2-cil         |    CVE-2018-1002208   |   LOW  |  6.12.0.122-0xamarin1+ubuntu1804b1 |  | <details><summary>Expand...</summary><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2018-1002208">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2018-1002208</a><br><a href="https://github.com/icsharpcode/SharpZipLib/issues/232">https://github.com/icsharpcode/SharpZipLib/issues/232</a><br><a href="https://github.com/icsharpcode/SharpZipLib/wiki/Release-1.0">https://github.com/icsharpcode/SharpZipLib/wiki/Release-1.0</a><br><a href="https://github.com/snyk/zip-slip-vulnerability">https://github.com/snyk/zip-slip-vulnerability</a><br><a href="https://snyk.io/research/zip-slip-vulnerability">https://snyk.io/research/zip-slip-vulnerability</a><br><a href="https://snyk.io/vuln/SNYK-DOTNET-SHARPZIPLIB-60247">https://snyk.io/vuln/SNYK-DOTNET-SHARPZIPLIB-60247</a><br></details>  |
| libmono-system-reactive-interfaces2.2-cil         |    CVE-2018-1002208   |   LOW  |  6.12.0.122-0xamarin1+ubuntu1804b1 |  | <details><summary>Expand...</summary><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2018-1002208">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2018-1002208</a><br><a href="https://github.com/icsharpcode/SharpZipLib/issues/232">https://github.com/icsharpcode/SharpZipLib/issues/232</a><br><a href="https://github.com/icsharpcode/SharpZipLib/wiki/Release-1.0">https://github.com/icsharpcode/SharpZipLib/wiki/Release-1.0</a><br><a href="https://github.com/snyk/zip-slip-vulnerability">https://github.com/snyk/zip-slip-vulnerability</a><br><a href="https://snyk.io/research/zip-slip-vulnerability">https://snyk.io/research/zip-slip-vulnerability</a><br><a href="https://snyk.io/vuln/SNYK-DOTNET-SHARPZIPLIB-60247">https://snyk.io/vuln/SNYK-DOTNET-SHARPZIPLIB-60247</a><br></details>  |
| libmono-system-reactive-linq2.2-cil         |    CVE-2018-1002208   |   LOW  |  6.12.0.122-0xamarin1+ubuntu1804b1 |  | <details><summary>Expand...</summary><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2018-1002208">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2018-1002208</a><br><a href="https://github.com/icsharpcode/SharpZipLib/issues/232">https://github.com/icsharpcode/SharpZipLib/issues/232</a><br><a href="https://github.com/icsharpcode/SharpZipLib/wiki/Release-1.0">https://github.com/icsharpcode/SharpZipLib/wiki/Release-1.0</a><br><a href="https://github.com/snyk/zip-slip-vulnerability">https://github.com/snyk/zip-slip-vulnerability</a><br><a href="https://snyk.io/research/zip-slip-vulnerability">https://snyk.io/research/zip-slip-vulnerability</a><br><a href="https://snyk.io/vuln/SNYK-DOTNET-SHARPZIPLIB-60247">https://snyk.io/vuln/SNYK-DOTNET-SHARPZIPLIB-60247</a><br></details>  |
| libmono-system-reactive-observable-aliases0.0-cil         |    CVE-2018-1002208   |   LOW  |  6.12.0.122-0xamarin1+ubuntu1804b1 |  | <details><summary>Expand...</summary><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2018-1002208">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2018-1002208</a><br><a href="https://github.com/icsharpcode/SharpZipLib/issues/232">https://github.com/icsharpcode/SharpZipLib/issues/232</a><br><a href="https://github.com/icsharpcode/SharpZipLib/wiki/Release-1.0">https://github.com/icsharpcode/SharpZipLib/wiki/Release-1.0</a><br><a href="https://github.com/snyk/zip-slip-vulnerability">https://github.com/snyk/zip-slip-vulnerability</a><br><a href="https://snyk.io/research/zip-slip-vulnerability">https://snyk.io/research/zip-slip-vulnerability</a><br><a href="https://snyk.io/vuln/SNYK-DOTNET-SHARPZIPLIB-60247">https://snyk.io/vuln/SNYK-DOTNET-SHARPZIPLIB-60247</a><br></details>  |
| libmono-system-reactive-platformservices2.2-cil         |    CVE-2018-1002208   |   LOW  |  6.12.0.122-0xamarin1+ubuntu1804b1 |  | <details><summary>Expand...</summary><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2018-1002208">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2018-1002208</a><br><a href="https://github.com/icsharpcode/SharpZipLib/issues/232">https://github.com/icsharpcode/SharpZipLib/issues/232</a><br><a href="https://github.com/icsharpcode/SharpZipLib/wiki/Release-1.0">https://github.com/icsharpcode/SharpZipLib/wiki/Release-1.0</a><br><a href="https://github.com/snyk/zip-slip-vulnerability">https://github.com/snyk/zip-slip-vulnerability</a><br><a href="https://snyk.io/research/zip-slip-vulnerability">https://snyk.io/research/zip-slip-vulnerability</a><br><a href="https://snyk.io/vuln/SNYK-DOTNET-SHARPZIPLIB-60247">https://snyk.io/vuln/SNYK-DOTNET-SHARPZIPLIB-60247</a><br></details>  |
| libmono-system-reactive-providers2.2-cil         |    CVE-2018-1002208   |   LOW  |  6.12.0.122-0xamarin1+ubuntu1804b1 |  | <details><summary>Expand...</summary><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2018-1002208">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2018-1002208</a><br><a href="https://github.com/icsharpcode/SharpZipLib/issues/232">https://github.com/icsharpcode/SharpZipLib/issues/232</a><br><a href="https://github.com/icsharpcode/SharpZipLib/wiki/Release-1.0">https://github.com/icsharpcode/SharpZipLib/wiki/Release-1.0</a><br><a href="https://github.com/snyk/zip-slip-vulnerability">https://github.com/snyk/zip-slip-vulnerability</a><br><a href="https://snyk.io/research/zip-slip-vulnerability">https://snyk.io/research/zip-slip-vulnerability</a><br><a href="https://snyk.io/vuln/SNYK-DOTNET-SHARPZIPLIB-60247">https://snyk.io/vuln/SNYK-DOTNET-SHARPZIPLIB-60247</a><br></details>  |
| libmono-system-reactive-runtime-remoting2.2-cil         |    CVE-2018-1002208   |   LOW  |  6.12.0.122-0xamarin1+ubuntu1804b1 |  | <details><summary>Expand...</summary><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2018-1002208">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2018-1002208</a><br><a href="https://github.com/icsharpcode/SharpZipLib/issues/232">https://github.com/icsharpcode/SharpZipLib/issues/232</a><br><a href="https://github.com/icsharpcode/SharpZipLib/wiki/Release-1.0">https://github.com/icsharpcode/SharpZipLib/wiki/Release-1.0</a><br><a href="https://github.com/snyk/zip-slip-vulnerability">https://github.com/snyk/zip-slip-vulnerability</a><br><a href="https://snyk.io/research/zip-slip-vulnerability">https://snyk.io/research/zip-slip-vulnerability</a><br><a href="https://snyk.io/vuln/SNYK-DOTNET-SHARPZIPLIB-60247">https://snyk.io/vuln/SNYK-DOTNET-SHARPZIPLIB-60247</a><br></details>  |
| libmono-system-reactive-windows-forms2.2-cil         |    CVE-2018-1002208   |   LOW  |  6.12.0.122-0xamarin1+ubuntu1804b1 |  | <details><summary>Expand...</summary><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2018-1002208">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2018-1002208</a><br><a href="https://github.com/icsharpcode/SharpZipLib/issues/232">https://github.com/icsharpcode/SharpZipLib/issues/232</a><br><a href="https://github.com/icsharpcode/SharpZipLib/wiki/Release-1.0">https://github.com/icsharpcode/SharpZipLib/wiki/Release-1.0</a><br><a href="https://github.com/snyk/zip-slip-vulnerability">https://github.com/snyk/zip-slip-vulnerability</a><br><a href="https://snyk.io/research/zip-slip-vulnerability">https://snyk.io/research/zip-slip-vulnerability</a><br><a href="https://snyk.io/vuln/SNYK-DOTNET-SHARPZIPLIB-60247">https://snyk.io/vuln/SNYK-DOTNET-SHARPZIPLIB-60247</a><br></details>  |
| libmono-system-reactive-windows-threading2.2-cil         |    CVE-2018-1002208   |   LOW  |  6.12.0.122-0xamarin1+ubuntu1804b1 |  | <details><summary>Expand...</summary><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2018-1002208">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2018-1002208</a><br><a href="https://github.com/icsharpcode/SharpZipLib/issues/232">https://github.com/icsharpcode/SharpZipLib/issues/232</a><br><a href="https://github.com/icsharpcode/SharpZipLib/wiki/Release-1.0">https://github.com/icsharpcode/SharpZipLib/wiki/Release-1.0</a><br><a href="https://github.com/snyk/zip-slip-vulnerability">https://github.com/snyk/zip-slip-vulnerability</a><br><a href="https://snyk.io/research/zip-slip-vulnerability">https://snyk.io/research/zip-slip-vulnerability</a><br><a href="https://snyk.io/vuln/SNYK-DOTNET-SHARPZIPLIB-60247">https://snyk.io/vuln/SNYK-DOTNET-SHARPZIPLIB-60247</a><br></details>  |
| libmono-system-reflection-context4.0-cil         |    CVE-2018-1002208   |   LOW  |  6.12.0.122-0xamarin1+ubuntu1804b1 |  | <details><summary>Expand...</summary><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2018-1002208">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2018-1002208</a><br><a href="https://github.com/icsharpcode/SharpZipLib/issues/232">https://github.com/icsharpcode/SharpZipLib/issues/232</a><br><a href="https://github.com/icsharpcode/SharpZipLib/wiki/Release-1.0">https://github.com/icsharpcode/SharpZipLib/wiki/Release-1.0</a><br><a href="https://github.com/snyk/zip-slip-vulnerability">https://github.com/snyk/zip-slip-vulnerability</a><br><a href="https://snyk.io/research/zip-slip-vulnerability">https://snyk.io/research/zip-slip-vulnerability</a><br><a href="https://snyk.io/vuln/SNYK-DOTNET-SHARPZIPLIB-60247">https://snyk.io/vuln/SNYK-DOTNET-SHARPZIPLIB-60247</a><br></details>  |
| libmono-system-runtime-caching4.0-cil         |    CVE-2018-1002208   |   LOW  |  6.12.0.122-0xamarin1+ubuntu1804b1 |  | <details><summary>Expand...</summary><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2018-1002208">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2018-1002208</a><br><a href="https://github.com/icsharpcode/SharpZipLib/issues/232">https://github.com/icsharpcode/SharpZipLib/issues/232</a><br><a href="https://github.com/icsharpcode/SharpZipLib/wiki/Release-1.0">https://github.com/icsharpcode/SharpZipLib/wiki/Release-1.0</a><br><a href="https://github.com/snyk/zip-slip-vulnerability">https://github.com/snyk/zip-slip-vulnerability</a><br><a href="https://snyk.io/research/zip-slip-vulnerability">https://snyk.io/research/zip-slip-vulnerability</a><br><a href="https://snyk.io/vuln/SNYK-DOTNET-SHARPZIPLIB-60247">https://snyk.io/vuln/SNYK-DOTNET-SHARPZIPLIB-60247</a><br></details>  |
| libmono-system-runtime-durableinstancing4.0-cil         |    CVE-2018-1002208   |   LOW  |  6.12.0.122-0xamarin1+ubuntu1804b1 |  | <details><summary>Expand...</summary><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2018-1002208">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2018-1002208</a><br><a href="https://github.com/icsharpcode/SharpZipLib/issues/232">https://github.com/icsharpcode/SharpZipLib/issues/232</a><br><a href="https://github.com/icsharpcode/SharpZipLib/wiki/Release-1.0">https://github.com/icsharpcode/SharpZipLib/wiki/Release-1.0</a><br><a href="https://github.com/snyk/zip-slip-vulnerability">https://github.com/snyk/zip-slip-vulnerability</a><br><a href="https://snyk.io/research/zip-slip-vulnerability">https://snyk.io/research/zip-slip-vulnerability</a><br><a href="https://snyk.io/vuln/SNYK-DOTNET-SHARPZIPLIB-60247">https://snyk.io/vuln/SNYK-DOTNET-SHARPZIPLIB-60247</a><br></details>  |
| libmono-system-runtime-serialization-formatters-soap4.0-cil         |    CVE-2018-1002208   |   LOW  |  6.12.0.122-0xamarin1+ubuntu1804b1 |  | <details><summary>Expand...</summary><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2018-1002208">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2018-1002208</a><br><a href="https://github.com/icsharpcode/SharpZipLib/issues/232">https://github.com/icsharpcode/SharpZipLib/issues/232</a><br><a href="https://github.com/icsharpcode/SharpZipLib/wiki/Release-1.0">https://github.com/icsharpcode/SharpZipLib/wiki/Release-1.0</a><br><a href="https://github.com/snyk/zip-slip-vulnerability">https://github.com/snyk/zip-slip-vulnerability</a><br><a href="https://snyk.io/research/zip-slip-vulnerability">https://snyk.io/research/zip-slip-vulnerability</a><br><a href="https://snyk.io/vuln/SNYK-DOTNET-SHARPZIPLIB-60247">https://snyk.io/vuln/SNYK-DOTNET-SHARPZIPLIB-60247</a><br></details>  |
| libmono-system-runtime-serialization4.0-cil         |    CVE-2018-1002208   |   LOW  |  6.12.0.122-0xamarin1+ubuntu1804b1 |  | <details><summary>Expand...</summary><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2018-1002208">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2018-1002208</a><br><a href="https://github.com/icsharpcode/SharpZipLib/issues/232">https://github.com/icsharpcode/SharpZipLib/issues/232</a><br><a href="https://github.com/icsharpcode/SharpZipLib/wiki/Release-1.0">https://github.com/icsharpcode/SharpZipLib/wiki/Release-1.0</a><br><a href="https://github.com/snyk/zip-slip-vulnerability">https://github.com/snyk/zip-slip-vulnerability</a><br><a href="https://snyk.io/research/zip-slip-vulnerability">https://snyk.io/research/zip-slip-vulnerability</a><br><a href="https://snyk.io/vuln/SNYK-DOTNET-SHARPZIPLIB-60247">https://snyk.io/vuln/SNYK-DOTNET-SHARPZIPLIB-60247</a><br></details>  |
| libmono-system-runtime4.0-cil         |    CVE-2018-1002208   |   LOW  |  6.12.0.122-0xamarin1+ubuntu1804b1 |  | <details><summary>Expand...</summary><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2018-1002208">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2018-1002208</a><br><a href="https://github.com/icsharpcode/SharpZipLib/issues/232">https://github.com/icsharpcode/SharpZipLib/issues/232</a><br><a href="https://github.com/icsharpcode/SharpZipLib/wiki/Release-1.0">https://github.com/icsharpcode/SharpZipLib/wiki/Release-1.0</a><br><a href="https://github.com/snyk/zip-slip-vulnerability">https://github.com/snyk/zip-slip-vulnerability</a><br><a href="https://snyk.io/research/zip-slip-vulnerability">https://snyk.io/research/zip-slip-vulnerability</a><br><a href="https://snyk.io/vuln/SNYK-DOTNET-SHARPZIPLIB-60247">https://snyk.io/vuln/SNYK-DOTNET-SHARPZIPLIB-60247</a><br></details>  |
| libmono-system-security4.0-cil         |    CVE-2018-1002208   |   LOW  |  6.12.0.122-0xamarin1+ubuntu1804b1 |  | <details><summary>Expand...</summary><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2018-1002208">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2018-1002208</a><br><a href="https://github.com/icsharpcode/SharpZipLib/issues/232">https://github.com/icsharpcode/SharpZipLib/issues/232</a><br><a href="https://github.com/icsharpcode/SharpZipLib/wiki/Release-1.0">https://github.com/icsharpcode/SharpZipLib/wiki/Release-1.0</a><br><a href="https://github.com/snyk/zip-slip-vulnerability">https://github.com/snyk/zip-slip-vulnerability</a><br><a href="https://snyk.io/research/zip-slip-vulnerability">https://snyk.io/research/zip-slip-vulnerability</a><br><a href="https://snyk.io/vuln/SNYK-DOTNET-SHARPZIPLIB-60247">https://snyk.io/vuln/SNYK-DOTNET-SHARPZIPLIB-60247</a><br></details>  |
| libmono-system-servicemodel-activation4.0-cil         |    CVE-2018-1002208   |   LOW  |  6.12.0.122-0xamarin1+ubuntu1804b1 |  | <details><summary>Expand...</summary><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2018-1002208">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2018-1002208</a><br><a href="https://github.com/icsharpcode/SharpZipLib/issues/232">https://github.com/icsharpcode/SharpZipLib/issues/232</a><br><a href="https://github.com/icsharpcode/SharpZipLib/wiki/Release-1.0">https://github.com/icsharpcode/SharpZipLib/wiki/Release-1.0</a><br><a href="https://github.com/snyk/zip-slip-vulnerability">https://github.com/snyk/zip-slip-vulnerability</a><br><a href="https://snyk.io/research/zip-slip-vulnerability">https://snyk.io/research/zip-slip-vulnerability</a><br><a href="https://snyk.io/vuln/SNYK-DOTNET-SHARPZIPLIB-60247">https://snyk.io/vuln/SNYK-DOTNET-SHARPZIPLIB-60247</a><br></details>  |
| libmono-system-servicemodel-discovery4.0-cil         |    CVE-2018-1002208   |   LOW  |  6.12.0.122-0xamarin1+ubuntu1804b1 |  | <details><summary>Expand...</summary><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2018-1002208">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2018-1002208</a><br><a href="https://github.com/icsharpcode/SharpZipLib/issues/232">https://github.com/icsharpcode/SharpZipLib/issues/232</a><br><a href="https://github.com/icsharpcode/SharpZipLib/wiki/Release-1.0">https://github.com/icsharpcode/SharpZipLib/wiki/Release-1.0</a><br><a href="https://github.com/snyk/zip-slip-vulnerability">https://github.com/snyk/zip-slip-vulnerability</a><br><a href="https://snyk.io/research/zip-slip-vulnerability">https://snyk.io/research/zip-slip-vulnerability</a><br><a href="https://snyk.io/vuln/SNYK-DOTNET-SHARPZIPLIB-60247">https://snyk.io/vuln/SNYK-DOTNET-SHARPZIPLIB-60247</a><br></details>  |
| libmono-system-servicemodel-internals0.0-cil         |    CVE-2018-1002208   |   LOW  |  6.12.0.122-0xamarin1+ubuntu1804b1 |  | <details><summary>Expand...</summary><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2018-1002208">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2018-1002208</a><br><a href="https://github.com/icsharpcode/SharpZipLib/issues/232">https://github.com/icsharpcode/SharpZipLib/issues/232</a><br><a href="https://github.com/icsharpcode/SharpZipLib/wiki/Release-1.0">https://github.com/icsharpcode/SharpZipLib/wiki/Release-1.0</a><br><a href="https://github.com/snyk/zip-slip-vulnerability">https://github.com/snyk/zip-slip-vulnerability</a><br><a href="https://snyk.io/research/zip-slip-vulnerability">https://snyk.io/research/zip-slip-vulnerability</a><br><a href="https://snyk.io/vuln/SNYK-DOTNET-SHARPZIPLIB-60247">https://snyk.io/vuln/SNYK-DOTNET-SHARPZIPLIB-60247</a><br></details>  |
| libmono-system-servicemodel-routing4.0-cil         |    CVE-2018-1002208   |   LOW  |  6.12.0.122-0xamarin1+ubuntu1804b1 |  | <details><summary>Expand...</summary><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2018-1002208">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2018-1002208</a><br><a href="https://github.com/icsharpcode/SharpZipLib/issues/232">https://github.com/icsharpcode/SharpZipLib/issues/232</a><br><a href="https://github.com/icsharpcode/SharpZipLib/wiki/Release-1.0">https://github.com/icsharpcode/SharpZipLib/wiki/Release-1.0</a><br><a href="https://github.com/snyk/zip-slip-vulnerability">https://github.com/snyk/zip-slip-vulnerability</a><br><a href="https://snyk.io/research/zip-slip-vulnerability">https://snyk.io/research/zip-slip-vulnerability</a><br><a href="https://snyk.io/vuln/SNYK-DOTNET-SHARPZIPLIB-60247">https://snyk.io/vuln/SNYK-DOTNET-SHARPZIPLIB-60247</a><br></details>  |
| libmono-system-servicemodel-web4.0-cil         |    CVE-2018-1002208   |   LOW  |  6.12.0.122-0xamarin1+ubuntu1804b1 |  | <details><summary>Expand...</summary><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2018-1002208">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2018-1002208</a><br><a href="https://github.com/icsharpcode/SharpZipLib/issues/232">https://github.com/icsharpcode/SharpZipLib/issues/232</a><br><a href="https://github.com/icsharpcode/SharpZipLib/wiki/Release-1.0">https://github.com/icsharpcode/SharpZipLib/wiki/Release-1.0</a><br><a href="https://github.com/snyk/zip-slip-vulnerability">https://github.com/snyk/zip-slip-vulnerability</a><br><a href="https://snyk.io/research/zip-slip-vulnerability">https://snyk.io/research/zip-slip-vulnerability</a><br><a href="https://snyk.io/vuln/SNYK-DOTNET-SHARPZIPLIB-60247">https://snyk.io/vuln/SNYK-DOTNET-SHARPZIPLIB-60247</a><br></details>  |
| libmono-system-servicemodel4.0a-cil         |    CVE-2018-1002208   |   LOW  |  6.12.0.122-0xamarin1+ubuntu1804b1 |  | <details><summary>Expand...</summary><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2018-1002208">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2018-1002208</a><br><a href="https://github.com/icsharpcode/SharpZipLib/issues/232">https://github.com/icsharpcode/SharpZipLib/issues/232</a><br><a href="https://github.com/icsharpcode/SharpZipLib/wiki/Release-1.0">https://github.com/icsharpcode/SharpZipLib/wiki/Release-1.0</a><br><a href="https://github.com/snyk/zip-slip-vulnerability">https://github.com/snyk/zip-slip-vulnerability</a><br><a href="https://snyk.io/research/zip-slip-vulnerability">https://snyk.io/research/zip-slip-vulnerability</a><br><a href="https://snyk.io/vuln/SNYK-DOTNET-SHARPZIPLIB-60247">https://snyk.io/vuln/SNYK-DOTNET-SHARPZIPLIB-60247</a><br></details>  |
| libmono-system-serviceprocess4.0-cil         |    CVE-2018-1002208   |   LOW  |  6.12.0.122-0xamarin1+ubuntu1804b1 |  | <details><summary>Expand...</summary><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2018-1002208">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2018-1002208</a><br><a href="https://github.com/icsharpcode/SharpZipLib/issues/232">https://github.com/icsharpcode/SharpZipLib/issues/232</a><br><a href="https://github.com/icsharpcode/SharpZipLib/wiki/Release-1.0">https://github.com/icsharpcode/SharpZipLib/wiki/Release-1.0</a><br><a href="https://github.com/snyk/zip-slip-vulnerability">https://github.com/snyk/zip-slip-vulnerability</a><br><a href="https://snyk.io/research/zip-slip-vulnerability">https://snyk.io/research/zip-slip-vulnerability</a><br><a href="https://snyk.io/vuln/SNYK-DOTNET-SHARPZIPLIB-60247">https://snyk.io/vuln/SNYK-DOTNET-SHARPZIPLIB-60247</a><br></details>  |
| libmono-system-threading-tasks-dataflow4.0-cil         |    CVE-2018-1002208   |   LOW  |  6.12.0.122-0xamarin1+ubuntu1804b1 |  | <details><summary>Expand...</summary><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2018-1002208">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2018-1002208</a><br><a href="https://github.com/icsharpcode/SharpZipLib/issues/232">https://github.com/icsharpcode/SharpZipLib/issues/232</a><br><a href="https://github.com/icsharpcode/SharpZipLib/wiki/Release-1.0">https://github.com/icsharpcode/SharpZipLib/wiki/Release-1.0</a><br><a href="https://github.com/snyk/zip-slip-vulnerability">https://github.com/snyk/zip-slip-vulnerability</a><br><a href="https://snyk.io/research/zip-slip-vulnerability">https://snyk.io/research/zip-slip-vulnerability</a><br><a href="https://snyk.io/vuln/SNYK-DOTNET-SHARPZIPLIB-60247">https://snyk.io/vuln/SNYK-DOTNET-SHARPZIPLIB-60247</a><br></details>  |
| libmono-system-transactions4.0-cil         |    CVE-2018-1002208   |   LOW  |  6.12.0.122-0xamarin1+ubuntu1804b1 |  | <details><summary>Expand...</summary><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2018-1002208">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2018-1002208</a><br><a href="https://github.com/icsharpcode/SharpZipLib/issues/232">https://github.com/icsharpcode/SharpZipLib/issues/232</a><br><a href="https://github.com/icsharpcode/SharpZipLib/wiki/Release-1.0">https://github.com/icsharpcode/SharpZipLib/wiki/Release-1.0</a><br><a href="https://github.com/snyk/zip-slip-vulnerability">https://github.com/snyk/zip-slip-vulnerability</a><br><a href="https://snyk.io/research/zip-slip-vulnerability">https://snyk.io/research/zip-slip-vulnerability</a><br><a href="https://snyk.io/vuln/SNYK-DOTNET-SHARPZIPLIB-60247">https://snyk.io/vuln/SNYK-DOTNET-SHARPZIPLIB-60247</a><br></details>  |
| libmono-system-web-abstractions4.0-cil         |    CVE-2018-1002208   |   LOW  |  6.12.0.122-0xamarin1+ubuntu1804b1 |  | <details><summary>Expand...</summary><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2018-1002208">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2018-1002208</a><br><a href="https://github.com/icsharpcode/SharpZipLib/issues/232">https://github.com/icsharpcode/SharpZipLib/issues/232</a><br><a href="https://github.com/icsharpcode/SharpZipLib/wiki/Release-1.0">https://github.com/icsharpcode/SharpZipLib/wiki/Release-1.0</a><br><a href="https://github.com/snyk/zip-slip-vulnerability">https://github.com/snyk/zip-slip-vulnerability</a><br><a href="https://snyk.io/research/zip-slip-vulnerability">https://snyk.io/research/zip-slip-vulnerability</a><br><a href="https://snyk.io/vuln/SNYK-DOTNET-SHARPZIPLIB-60247">https://snyk.io/vuln/SNYK-DOTNET-SHARPZIPLIB-60247</a><br></details>  |
| libmono-system-web-applicationservices4.0-cil         |    CVE-2018-1002208   |   LOW  |  6.12.0.122-0xamarin1+ubuntu1804b1 |  | <details><summary>Expand...</summary><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2018-1002208">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2018-1002208</a><br><a href="https://github.com/icsharpcode/SharpZipLib/issues/232">https://github.com/icsharpcode/SharpZipLib/issues/232</a><br><a href="https://github.com/icsharpcode/SharpZipLib/wiki/Release-1.0">https://github.com/icsharpcode/SharpZipLib/wiki/Release-1.0</a><br><a href="https://github.com/snyk/zip-slip-vulnerability">https://github.com/snyk/zip-slip-vulnerability</a><br><a href="https://snyk.io/research/zip-slip-vulnerability">https://snyk.io/research/zip-slip-vulnerability</a><br><a href="https://snyk.io/vuln/SNYK-DOTNET-SHARPZIPLIB-60247">https://snyk.io/vuln/SNYK-DOTNET-SHARPZIPLIB-60247</a><br></details>  |
| libmono-system-web-dynamicdata4.0-cil         |    CVE-2018-1002208   |   LOW  |  6.12.0.122-0xamarin1+ubuntu1804b1 |  | <details><summary>Expand...</summary><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2018-1002208">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2018-1002208</a><br><a href="https://github.com/icsharpcode/SharpZipLib/issues/232">https://github.com/icsharpcode/SharpZipLib/issues/232</a><br><a href="https://github.com/icsharpcode/SharpZipLib/wiki/Release-1.0">https://github.com/icsharpcode/SharpZipLib/wiki/Release-1.0</a><br><a href="https://github.com/snyk/zip-slip-vulnerability">https://github.com/snyk/zip-slip-vulnerability</a><br><a href="https://snyk.io/research/zip-slip-vulnerability">https://snyk.io/research/zip-slip-vulnerability</a><br><a href="https://snyk.io/vuln/SNYK-DOTNET-SHARPZIPLIB-60247">https://snyk.io/vuln/SNYK-DOTNET-SHARPZIPLIB-60247</a><br></details>  |
| libmono-system-web-extensions-design4.0-cil         |    CVE-2018-1002208   |   LOW  |  6.12.0.122-0xamarin1+ubuntu1804b1 |  | <details><summary>Expand...</summary><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2018-1002208">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2018-1002208</a><br><a href="https://github.com/icsharpcode/SharpZipLib/issues/232">https://github.com/icsharpcode/SharpZipLib/issues/232</a><br><a href="https://github.com/icsharpcode/SharpZipLib/wiki/Release-1.0">https://github.com/icsharpcode/SharpZipLib/wiki/Release-1.0</a><br><a href="https://github.com/snyk/zip-slip-vulnerability">https://github.com/snyk/zip-slip-vulnerability</a><br><a href="https://snyk.io/research/zip-slip-vulnerability">https://snyk.io/research/zip-slip-vulnerability</a><br><a href="https://snyk.io/vuln/SNYK-DOTNET-SHARPZIPLIB-60247">https://snyk.io/vuln/SNYK-DOTNET-SHARPZIPLIB-60247</a><br></details>  |
| libmono-system-web-extensions4.0-cil         |    CVE-2018-1002208   |   LOW  |  6.12.0.122-0xamarin1+ubuntu1804b1 |  | <details><summary>Expand...</summary><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2018-1002208">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2018-1002208</a><br><a href="https://github.com/icsharpcode/SharpZipLib/issues/232">https://github.com/icsharpcode/SharpZipLib/issues/232</a><br><a href="https://github.com/icsharpcode/SharpZipLib/wiki/Release-1.0">https://github.com/icsharpcode/SharpZipLib/wiki/Release-1.0</a><br><a href="https://github.com/snyk/zip-slip-vulnerability">https://github.com/snyk/zip-slip-vulnerability</a><br><a href="https://snyk.io/research/zip-slip-vulnerability">https://snyk.io/research/zip-slip-vulnerability</a><br><a href="https://snyk.io/vuln/SNYK-DOTNET-SHARPZIPLIB-60247">https://snyk.io/vuln/SNYK-DOTNET-SHARPZIPLIB-60247</a><br></details>  |
| libmono-system-web-http-selfhost4.0-cil         |    CVE-2018-1002208   |   LOW  |  6.12.0.122-0xamarin1+ubuntu1804b1 |  | <details><summary>Expand...</summary><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2018-1002208">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2018-1002208</a><br><a href="https://github.com/icsharpcode/SharpZipLib/issues/232">https://github.com/icsharpcode/SharpZipLib/issues/232</a><br><a href="https://github.com/icsharpcode/SharpZipLib/wiki/Release-1.0">https://github.com/icsharpcode/SharpZipLib/wiki/Release-1.0</a><br><a href="https://github.com/snyk/zip-slip-vulnerability">https://github.com/snyk/zip-slip-vulnerability</a><br><a href="https://snyk.io/research/zip-slip-vulnerability">https://snyk.io/research/zip-slip-vulnerability</a><br><a href="https://snyk.io/vuln/SNYK-DOTNET-SHARPZIPLIB-60247">https://snyk.io/vuln/SNYK-DOTNET-SHARPZIPLIB-60247</a><br></details>  |
| libmono-system-web-http-webhost4.0-cil         |    CVE-2018-1002208   |   LOW  |  6.12.0.122-0xamarin1+ubuntu1804b1 |  | <details><summary>Expand...</summary><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2018-1002208">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2018-1002208</a><br><a href="https://github.com/icsharpcode/SharpZipLib/issues/232">https://github.com/icsharpcode/SharpZipLib/issues/232</a><br><a href="https://github.com/icsharpcode/SharpZipLib/wiki/Release-1.0">https://github.com/icsharpcode/SharpZipLib/wiki/Release-1.0</a><br><a href="https://github.com/snyk/zip-slip-vulnerability">https://github.com/snyk/zip-slip-vulnerability</a><br><a href="https://snyk.io/research/zip-slip-vulnerability">https://snyk.io/research/zip-slip-vulnerability</a><br><a href="https://snyk.io/vuln/SNYK-DOTNET-SHARPZIPLIB-60247">https://snyk.io/vuln/SNYK-DOTNET-SHARPZIPLIB-60247</a><br></details>  |
| libmono-system-web-http4.0-cil         |    CVE-2018-1002208   |   LOW  |  6.12.0.122-0xamarin1+ubuntu1804b1 |  | <details><summary>Expand...</summary><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2018-1002208">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2018-1002208</a><br><a href="https://github.com/icsharpcode/SharpZipLib/issues/232">https://github.com/icsharpcode/SharpZipLib/issues/232</a><br><a href="https://github.com/icsharpcode/SharpZipLib/wiki/Release-1.0">https://github.com/icsharpcode/SharpZipLib/wiki/Release-1.0</a><br><a href="https://github.com/snyk/zip-slip-vulnerability">https://github.com/snyk/zip-slip-vulnerability</a><br><a href="https://snyk.io/research/zip-slip-vulnerability">https://snyk.io/research/zip-slip-vulnerability</a><br><a href="https://snyk.io/vuln/SNYK-DOTNET-SHARPZIPLIB-60247">https://snyk.io/vuln/SNYK-DOTNET-SHARPZIPLIB-60247</a><br></details>  |
| libmono-system-web-mobile4.0-cil         |    CVE-2018-1002208   |   LOW  |  6.12.0.122-0xamarin1+ubuntu1804b1 |  | <details><summary>Expand...</summary><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2018-1002208">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2018-1002208</a><br><a href="https://github.com/icsharpcode/SharpZipLib/issues/232">https://github.com/icsharpcode/SharpZipLib/issues/232</a><br><a href="https://github.com/icsharpcode/SharpZipLib/wiki/Release-1.0">https://github.com/icsharpcode/SharpZipLib/wiki/Release-1.0</a><br><a href="https://github.com/snyk/zip-slip-vulnerability">https://github.com/snyk/zip-slip-vulnerability</a><br><a href="https://snyk.io/research/zip-slip-vulnerability">https://snyk.io/research/zip-slip-vulnerability</a><br><a href="https://snyk.io/vuln/SNYK-DOTNET-SHARPZIPLIB-60247">https://snyk.io/vuln/SNYK-DOTNET-SHARPZIPLIB-60247</a><br></details>  |
| libmono-system-web-mvc3.0-cil         |    CVE-2018-1002208   |   LOW  |  6.12.0.122-0xamarin1+ubuntu1804b1 |  | <details><summary>Expand...</summary><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2018-1002208">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2018-1002208</a><br><a href="https://github.com/icsharpcode/SharpZipLib/issues/232">https://github.com/icsharpcode/SharpZipLib/issues/232</a><br><a href="https://github.com/icsharpcode/SharpZipLib/wiki/Release-1.0">https://github.com/icsharpcode/SharpZipLib/wiki/Release-1.0</a><br><a href="https://github.com/snyk/zip-slip-vulnerability">https://github.com/snyk/zip-slip-vulnerability</a><br><a href="https://snyk.io/research/zip-slip-vulnerability">https://snyk.io/research/zip-slip-vulnerability</a><br><a href="https://snyk.io/vuln/SNYK-DOTNET-SHARPZIPLIB-60247">https://snyk.io/vuln/SNYK-DOTNET-SHARPZIPLIB-60247</a><br></details>  |
| libmono-system-web-razor2.0-cil         |    CVE-2018-1002208   |   LOW  |  6.12.0.122-0xamarin1+ubuntu1804b1 |  | <details><summary>Expand...</summary><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2018-1002208">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2018-1002208</a><br><a href="https://github.com/icsharpcode/SharpZipLib/issues/232">https://github.com/icsharpcode/SharpZipLib/issues/232</a><br><a href="https://github.com/icsharpcode/SharpZipLib/wiki/Release-1.0">https://github.com/icsharpcode/SharpZipLib/wiki/Release-1.0</a><br><a href="https://github.com/snyk/zip-slip-vulnerability">https://github.com/snyk/zip-slip-vulnerability</a><br><a href="https://snyk.io/research/zip-slip-vulnerability">https://snyk.io/research/zip-slip-vulnerability</a><br><a href="https://snyk.io/vuln/SNYK-DOTNET-SHARPZIPLIB-60247">https://snyk.io/vuln/SNYK-DOTNET-SHARPZIPLIB-60247</a><br></details>  |
| libmono-system-web-regularexpressions4.0-cil         |    CVE-2018-1002208   |   LOW  |  6.12.0.122-0xamarin1+ubuntu1804b1 |  | <details><summary>Expand...</summary><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2018-1002208">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2018-1002208</a><br><a href="https://github.com/icsharpcode/SharpZipLib/issues/232">https://github.com/icsharpcode/SharpZipLib/issues/232</a><br><a href="https://github.com/icsharpcode/SharpZipLib/wiki/Release-1.0">https://github.com/icsharpcode/SharpZipLib/wiki/Release-1.0</a><br><a href="https://github.com/snyk/zip-slip-vulnerability">https://github.com/snyk/zip-slip-vulnerability</a><br><a href="https://snyk.io/research/zip-slip-vulnerability">https://snyk.io/research/zip-slip-vulnerability</a><br><a href="https://snyk.io/vuln/SNYK-DOTNET-SHARPZIPLIB-60247">https://snyk.io/vuln/SNYK-DOTNET-SHARPZIPLIB-60247</a><br></details>  |
| libmono-system-web-routing4.0-cil         |    CVE-2018-1002208   |   LOW  |  6.12.0.122-0xamarin1+ubuntu1804b1 |  | <details><summary>Expand...</summary><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2018-1002208">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2018-1002208</a><br><a href="https://github.com/icsharpcode/SharpZipLib/issues/232">https://github.com/icsharpcode/SharpZipLib/issues/232</a><br><a href="https://github.com/icsharpcode/SharpZipLib/wiki/Release-1.0">https://github.com/icsharpcode/SharpZipLib/wiki/Release-1.0</a><br><a href="https://github.com/snyk/zip-slip-vulnerability">https://github.com/snyk/zip-slip-vulnerability</a><br><a href="https://snyk.io/research/zip-slip-vulnerability">https://snyk.io/research/zip-slip-vulnerability</a><br><a href="https://snyk.io/vuln/SNYK-DOTNET-SHARPZIPLIB-60247">https://snyk.io/vuln/SNYK-DOTNET-SHARPZIPLIB-60247</a><br></details>  |
| libmono-system-web-services4.0-cil         |    CVE-2018-1002208   |   LOW  |  6.12.0.122-0xamarin1+ubuntu1804b1 |  | <details><summary>Expand...</summary><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2018-1002208">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2018-1002208</a><br><a href="https://github.com/icsharpcode/SharpZipLib/issues/232">https://github.com/icsharpcode/SharpZipLib/issues/232</a><br><a href="https://github.com/icsharpcode/SharpZipLib/wiki/Release-1.0">https://github.com/icsharpcode/SharpZipLib/wiki/Release-1.0</a><br><a href="https://github.com/snyk/zip-slip-vulnerability">https://github.com/snyk/zip-slip-vulnerability</a><br><a href="https://snyk.io/research/zip-slip-vulnerability">https://snyk.io/research/zip-slip-vulnerability</a><br><a href="https://snyk.io/vuln/SNYK-DOTNET-SHARPZIPLIB-60247">https://snyk.io/vuln/SNYK-DOTNET-SHARPZIPLIB-60247</a><br></details>  |
| libmono-system-web-webpages-deployment2.0-cil         |    CVE-2018-1002208   |   LOW  |  6.12.0.122-0xamarin1+ubuntu1804b1 |  | <details><summary>Expand...</summary><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2018-1002208">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2018-1002208</a><br><a href="https://github.com/icsharpcode/SharpZipLib/issues/232">https://github.com/icsharpcode/SharpZipLib/issues/232</a><br><a href="https://github.com/icsharpcode/SharpZipLib/wiki/Release-1.0">https://github.com/icsharpcode/SharpZipLib/wiki/Release-1.0</a><br><a href="https://github.com/snyk/zip-slip-vulnerability">https://github.com/snyk/zip-slip-vulnerability</a><br><a href="https://snyk.io/research/zip-slip-vulnerability">https://snyk.io/research/zip-slip-vulnerability</a><br><a href="https://snyk.io/vuln/SNYK-DOTNET-SHARPZIPLIB-60247">https://snyk.io/vuln/SNYK-DOTNET-SHARPZIPLIB-60247</a><br></details>  |
| libmono-system-web-webpages-razor2.0-cil         |    CVE-2018-1002208   |   LOW  |  6.12.0.122-0xamarin1+ubuntu1804b1 |  | <details><summary>Expand...</summary><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2018-1002208">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2018-1002208</a><br><a href="https://github.com/icsharpcode/SharpZipLib/issues/232">https://github.com/icsharpcode/SharpZipLib/issues/232</a><br><a href="https://github.com/icsharpcode/SharpZipLib/wiki/Release-1.0">https://github.com/icsharpcode/SharpZipLib/wiki/Release-1.0</a><br><a href="https://github.com/snyk/zip-slip-vulnerability">https://github.com/snyk/zip-slip-vulnerability</a><br><a href="https://snyk.io/research/zip-slip-vulnerability">https://snyk.io/research/zip-slip-vulnerability</a><br><a href="https://snyk.io/vuln/SNYK-DOTNET-SHARPZIPLIB-60247">https://snyk.io/vuln/SNYK-DOTNET-SHARPZIPLIB-60247</a><br></details>  |
| libmono-system-web-webpages2.0-cil         |    CVE-2018-1002208   |   LOW  |  6.12.0.122-0xamarin1+ubuntu1804b1 |  | <details><summary>Expand...</summary><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2018-1002208">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2018-1002208</a><br><a href="https://github.com/icsharpcode/SharpZipLib/issues/232">https://github.com/icsharpcode/SharpZipLib/issues/232</a><br><a href="https://github.com/icsharpcode/SharpZipLib/wiki/Release-1.0">https://github.com/icsharpcode/SharpZipLib/wiki/Release-1.0</a><br><a href="https://github.com/snyk/zip-slip-vulnerability">https://github.com/snyk/zip-slip-vulnerability</a><br><a href="https://snyk.io/research/zip-slip-vulnerability">https://snyk.io/research/zip-slip-vulnerability</a><br><a href="https://snyk.io/vuln/SNYK-DOTNET-SHARPZIPLIB-60247">https://snyk.io/vuln/SNYK-DOTNET-SHARPZIPLIB-60247</a><br></details>  |
| libmono-system-web4.0-cil         |    CVE-2018-1002208   |   LOW  |  6.12.0.122-0xamarin1+ubuntu1804b1 |  | <details><summary>Expand...</summary><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2018-1002208">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2018-1002208</a><br><a href="https://github.com/icsharpcode/SharpZipLib/issues/232">https://github.com/icsharpcode/SharpZipLib/issues/232</a><br><a href="https://github.com/icsharpcode/SharpZipLib/wiki/Release-1.0">https://github.com/icsharpcode/SharpZipLib/wiki/Release-1.0</a><br><a href="https://github.com/snyk/zip-slip-vulnerability">https://github.com/snyk/zip-slip-vulnerability</a><br><a href="https://snyk.io/research/zip-slip-vulnerability">https://snyk.io/research/zip-slip-vulnerability</a><br><a href="https://snyk.io/vuln/SNYK-DOTNET-SHARPZIPLIB-60247">https://snyk.io/vuln/SNYK-DOTNET-SHARPZIPLIB-60247</a><br></details>  |
| libmono-system-windows-forms-datavisualization4.0a-cil         |    CVE-2018-1002208   |   LOW  |  6.12.0.122-0xamarin1+ubuntu1804b1 |  | <details><summary>Expand...</summary><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2018-1002208">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2018-1002208</a><br><a href="https://github.com/icsharpcode/SharpZipLib/issues/232">https://github.com/icsharpcode/SharpZipLib/issues/232</a><br><a href="https://github.com/icsharpcode/SharpZipLib/wiki/Release-1.0">https://github.com/icsharpcode/SharpZipLib/wiki/Release-1.0</a><br><a href="https://github.com/snyk/zip-slip-vulnerability">https://github.com/snyk/zip-slip-vulnerability</a><br><a href="https://snyk.io/research/zip-slip-vulnerability">https://snyk.io/research/zip-slip-vulnerability</a><br><a href="https://snyk.io/vuln/SNYK-DOTNET-SHARPZIPLIB-60247">https://snyk.io/vuln/SNYK-DOTNET-SHARPZIPLIB-60247</a><br></details>  |
| libmono-system-windows-forms4.0-cil         |    CVE-2018-1002208   |   LOW  |  6.12.0.122-0xamarin1+ubuntu1804b1 |  | <details><summary>Expand...</summary><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2018-1002208">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2018-1002208</a><br><a href="https://github.com/icsharpcode/SharpZipLib/issues/232">https://github.com/icsharpcode/SharpZipLib/issues/232</a><br><a href="https://github.com/icsharpcode/SharpZipLib/wiki/Release-1.0">https://github.com/icsharpcode/SharpZipLib/wiki/Release-1.0</a><br><a href="https://github.com/snyk/zip-slip-vulnerability">https://github.com/snyk/zip-slip-vulnerability</a><br><a href="https://snyk.io/research/zip-slip-vulnerability">https://snyk.io/research/zip-slip-vulnerability</a><br><a href="https://snyk.io/vuln/SNYK-DOTNET-SHARPZIPLIB-60247">https://snyk.io/vuln/SNYK-DOTNET-SHARPZIPLIB-60247</a><br></details>  |
| libmono-system-windows4.0-cil         |    CVE-2018-1002208   |   LOW  |  6.12.0.122-0xamarin1+ubuntu1804b1 |  | <details><summary>Expand...</summary><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2018-1002208">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2018-1002208</a><br><a href="https://github.com/icsharpcode/SharpZipLib/issues/232">https://github.com/icsharpcode/SharpZipLib/issues/232</a><br><a href="https://github.com/icsharpcode/SharpZipLib/wiki/Release-1.0">https://github.com/icsharpcode/SharpZipLib/wiki/Release-1.0</a><br><a href="https://github.com/snyk/zip-slip-vulnerability">https://github.com/snyk/zip-slip-vulnerability</a><br><a href="https://snyk.io/research/zip-slip-vulnerability">https://snyk.io/research/zip-slip-vulnerability</a><br><a href="https://snyk.io/vuln/SNYK-DOTNET-SHARPZIPLIB-60247">https://snyk.io/vuln/SNYK-DOTNET-SHARPZIPLIB-60247</a><br></details>  |
| libmono-system-workflow-activities4.0-cil         |    CVE-2018-1002208   |   LOW  |  6.12.0.122-0xamarin1+ubuntu1804b1 |  | <details><summary>Expand...</summary><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2018-1002208">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2018-1002208</a><br><a href="https://github.com/icsharpcode/SharpZipLib/issues/232">https://github.com/icsharpcode/SharpZipLib/issues/232</a><br><a href="https://github.com/icsharpcode/SharpZipLib/wiki/Release-1.0">https://github.com/icsharpcode/SharpZipLib/wiki/Release-1.0</a><br><a href="https://github.com/snyk/zip-slip-vulnerability">https://github.com/snyk/zip-slip-vulnerability</a><br><a href="https://snyk.io/research/zip-slip-vulnerability">https://snyk.io/research/zip-slip-vulnerability</a><br><a href="https://snyk.io/vuln/SNYK-DOTNET-SHARPZIPLIB-60247">https://snyk.io/vuln/SNYK-DOTNET-SHARPZIPLIB-60247</a><br></details>  |
| libmono-system-workflow-componentmodel4.0-cil         |    CVE-2018-1002208   |   LOW  |  6.12.0.122-0xamarin1+ubuntu1804b1 |  | <details><summary>Expand...</summary><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2018-1002208">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2018-1002208</a><br><a href="https://github.com/icsharpcode/SharpZipLib/issues/232">https://github.com/icsharpcode/SharpZipLib/issues/232</a><br><a href="https://github.com/icsharpcode/SharpZipLib/wiki/Release-1.0">https://github.com/icsharpcode/SharpZipLib/wiki/Release-1.0</a><br><a href="https://github.com/snyk/zip-slip-vulnerability">https://github.com/snyk/zip-slip-vulnerability</a><br><a href="https://snyk.io/research/zip-slip-vulnerability">https://snyk.io/research/zip-slip-vulnerability</a><br><a href="https://snyk.io/vuln/SNYK-DOTNET-SHARPZIPLIB-60247">https://snyk.io/vuln/SNYK-DOTNET-SHARPZIPLIB-60247</a><br></details>  |
| libmono-system-workflow-runtime4.0-cil         |    CVE-2018-1002208   |   LOW  |  6.12.0.122-0xamarin1+ubuntu1804b1 |  | <details><summary>Expand...</summary><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2018-1002208">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2018-1002208</a><br><a href="https://github.com/icsharpcode/SharpZipLib/issues/232">https://github.com/icsharpcode/SharpZipLib/issues/232</a><br><a href="https://github.com/icsharpcode/SharpZipLib/wiki/Release-1.0">https://github.com/icsharpcode/SharpZipLib/wiki/Release-1.0</a><br><a href="https://github.com/snyk/zip-slip-vulnerability">https://github.com/snyk/zip-slip-vulnerability</a><br><a href="https://snyk.io/research/zip-slip-vulnerability">https://snyk.io/research/zip-slip-vulnerability</a><br><a href="https://snyk.io/vuln/SNYK-DOTNET-SHARPZIPLIB-60247">https://snyk.io/vuln/SNYK-DOTNET-SHARPZIPLIB-60247</a><br></details>  |
| libmono-system-xaml4.0-cil         |    CVE-2018-1002208   |   LOW  |  6.12.0.122-0xamarin1+ubuntu1804b1 |  | <details><summary>Expand...</summary><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2018-1002208">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2018-1002208</a><br><a href="https://github.com/icsharpcode/SharpZipLib/issues/232">https://github.com/icsharpcode/SharpZipLib/issues/232</a><br><a href="https://github.com/icsharpcode/SharpZipLib/wiki/Release-1.0">https://github.com/icsharpcode/SharpZipLib/wiki/Release-1.0</a><br><a href="https://github.com/snyk/zip-slip-vulnerability">https://github.com/snyk/zip-slip-vulnerability</a><br><a href="https://snyk.io/research/zip-slip-vulnerability">https://snyk.io/research/zip-slip-vulnerability</a><br><a href="https://snyk.io/vuln/SNYK-DOTNET-SHARPZIPLIB-60247">https://snyk.io/vuln/SNYK-DOTNET-SHARPZIPLIB-60247</a><br></details>  |
| libmono-system-xml-linq4.0-cil         |    CVE-2018-1002208   |   LOW  |  6.12.0.122-0xamarin1+ubuntu1804b1 |  | <details><summary>Expand...</summary><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2018-1002208">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2018-1002208</a><br><a href="https://github.com/icsharpcode/SharpZipLib/issues/232">https://github.com/icsharpcode/SharpZipLib/issues/232</a><br><a href="https://github.com/icsharpcode/SharpZipLib/wiki/Release-1.0">https://github.com/icsharpcode/SharpZipLib/wiki/Release-1.0</a><br><a href="https://github.com/snyk/zip-slip-vulnerability">https://github.com/snyk/zip-slip-vulnerability</a><br><a href="https://snyk.io/research/zip-slip-vulnerability">https://snyk.io/research/zip-slip-vulnerability</a><br><a href="https://snyk.io/vuln/SNYK-DOTNET-SHARPZIPLIB-60247">https://snyk.io/vuln/SNYK-DOTNET-SHARPZIPLIB-60247</a><br></details>  |
| libmono-system-xml-serialization4.0-cil         |    CVE-2018-1002208   |   LOW  |  6.12.0.122-0xamarin1+ubuntu1804b1 |  | <details><summary>Expand...</summary><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2018-1002208">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2018-1002208</a><br><a href="https://github.com/icsharpcode/SharpZipLib/issues/232">https://github.com/icsharpcode/SharpZipLib/issues/232</a><br><a href="https://github.com/icsharpcode/SharpZipLib/wiki/Release-1.0">https://github.com/icsharpcode/SharpZipLib/wiki/Release-1.0</a><br><a href="https://github.com/snyk/zip-slip-vulnerability">https://github.com/snyk/zip-slip-vulnerability</a><br><a href="https://snyk.io/research/zip-slip-vulnerability">https://snyk.io/research/zip-slip-vulnerability</a><br><a href="https://snyk.io/vuln/SNYK-DOTNET-SHARPZIPLIB-60247">https://snyk.io/vuln/SNYK-DOTNET-SHARPZIPLIB-60247</a><br></details>  |
| libmono-system-xml4.0-cil         |    CVE-2018-1002208   |   LOW  |  6.12.0.122-0xamarin1+ubuntu1804b1 |  | <details><summary>Expand...</summary><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2018-1002208">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2018-1002208</a><br><a href="https://github.com/icsharpcode/SharpZipLib/issues/232">https://github.com/icsharpcode/SharpZipLib/issues/232</a><br><a href="https://github.com/icsharpcode/SharpZipLib/wiki/Release-1.0">https://github.com/icsharpcode/SharpZipLib/wiki/Release-1.0</a><br><a href="https://github.com/snyk/zip-slip-vulnerability">https://github.com/snyk/zip-slip-vulnerability</a><br><a href="https://snyk.io/research/zip-slip-vulnerability">https://snyk.io/research/zip-slip-vulnerability</a><br><a href="https://snyk.io/vuln/SNYK-DOTNET-SHARPZIPLIB-60247">https://snyk.io/vuln/SNYK-DOTNET-SHARPZIPLIB-60247</a><br></details>  |
| libmono-system4.0-cil         |    CVE-2018-1002208   |   LOW  |  6.12.0.122-0xamarin1+ubuntu1804b1 |  | <details><summary>Expand...</summary><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2018-1002208">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2018-1002208</a><br><a href="https://github.com/icsharpcode/SharpZipLib/issues/232">https://github.com/icsharpcode/SharpZipLib/issues/232</a><br><a href="https://github.com/icsharpcode/SharpZipLib/wiki/Release-1.0">https://github.com/icsharpcode/SharpZipLib/wiki/Release-1.0</a><br><a href="https://github.com/snyk/zip-slip-vulnerability">https://github.com/snyk/zip-slip-vulnerability</a><br><a href="https://snyk.io/research/zip-slip-vulnerability">https://snyk.io/research/zip-slip-vulnerability</a><br><a href="https://snyk.io/vuln/SNYK-DOTNET-SHARPZIPLIB-60247">https://snyk.io/vuln/SNYK-DOTNET-SHARPZIPLIB-60247</a><br></details>  |
| libmono-tasklets4.0-cil         |    CVE-2018-1002208   |   LOW  |  6.12.0.122-0xamarin1+ubuntu1804b1 |  | <details><summary>Expand...</summary><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2018-1002208">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2018-1002208</a><br><a href="https://github.com/icsharpcode/SharpZipLib/issues/232">https://github.com/icsharpcode/SharpZipLib/issues/232</a><br><a href="https://github.com/icsharpcode/SharpZipLib/wiki/Release-1.0">https://github.com/icsharpcode/SharpZipLib/wiki/Release-1.0</a><br><a href="https://github.com/snyk/zip-slip-vulnerability">https://github.com/snyk/zip-slip-vulnerability</a><br><a href="https://snyk.io/research/zip-slip-vulnerability">https://snyk.io/research/zip-slip-vulnerability</a><br><a href="https://snyk.io/vuln/SNYK-DOTNET-SHARPZIPLIB-60247">https://snyk.io/vuln/SNYK-DOTNET-SHARPZIPLIB-60247</a><br></details>  |
| libmono-webbrowser4.0-cil         |    CVE-2018-1002208   |   LOW  |  6.12.0.122-0xamarin1+ubuntu1804b1 |  | <details><summary>Expand...</summary><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2018-1002208">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2018-1002208</a><br><a href="https://github.com/icsharpcode/SharpZipLib/issues/232">https://github.com/icsharpcode/SharpZipLib/issues/232</a><br><a href="https://github.com/icsharpcode/SharpZipLib/wiki/Release-1.0">https://github.com/icsharpcode/SharpZipLib/wiki/Release-1.0</a><br><a href="https://github.com/snyk/zip-slip-vulnerability">https://github.com/snyk/zip-slip-vulnerability</a><br><a href="https://snyk.io/research/zip-slip-vulnerability">https://snyk.io/research/zip-slip-vulnerability</a><br><a href="https://snyk.io/vuln/SNYK-DOTNET-SHARPZIPLIB-60247">https://snyk.io/vuln/SNYK-DOTNET-SHARPZIPLIB-60247</a><br></details>  |
| libmono-webmatrix-data4.0-cil         |    CVE-2018-1002208   |   LOW  |  6.12.0.122-0xamarin1+ubuntu1804b1 |  | <details><summary>Expand...</summary><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2018-1002208">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2018-1002208</a><br><a href="https://github.com/icsharpcode/SharpZipLib/issues/232">https://github.com/icsharpcode/SharpZipLib/issues/232</a><br><a href="https://github.com/icsharpcode/SharpZipLib/wiki/Release-1.0">https://github.com/icsharpcode/SharpZipLib/wiki/Release-1.0</a><br><a href="https://github.com/snyk/zip-slip-vulnerability">https://github.com/snyk/zip-slip-vulnerability</a><br><a href="https://snyk.io/research/zip-slip-vulnerability">https://snyk.io/research/zip-slip-vulnerability</a><br><a href="https://snyk.io/vuln/SNYK-DOTNET-SHARPZIPLIB-60247">https://snyk.io/vuln/SNYK-DOTNET-SHARPZIPLIB-60247</a><br></details>  |
| libmono-windowsbase4.0-cil         |    CVE-2018-1002208   |   LOW  |  6.12.0.122-0xamarin1+ubuntu1804b1 |  | <details><summary>Expand...</summary><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2018-1002208">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2018-1002208</a><br><a href="https://github.com/icsharpcode/SharpZipLib/issues/232">https://github.com/icsharpcode/SharpZipLib/issues/232</a><br><a href="https://github.com/icsharpcode/SharpZipLib/wiki/Release-1.0">https://github.com/icsharpcode/SharpZipLib/wiki/Release-1.0</a><br><a href="https://github.com/snyk/zip-slip-vulnerability">https://github.com/snyk/zip-slip-vulnerability</a><br><a href="https://snyk.io/research/zip-slip-vulnerability">https://snyk.io/research/zip-slip-vulnerability</a><br><a href="https://snyk.io/vuln/SNYK-DOTNET-SHARPZIPLIB-60247">https://snyk.io/vuln/SNYK-DOTNET-SHARPZIPLIB-60247</a><br></details>  |
| libmono-xbuild-tasks4.0-cil         |    CVE-2018-1002208   |   LOW  |  6.12.0.122-0xamarin1+ubuntu1804b1 |  | <details><summary>Expand...</summary><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2018-1002208">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2018-1002208</a><br><a href="https://github.com/icsharpcode/SharpZipLib/issues/232">https://github.com/icsharpcode/SharpZipLib/issues/232</a><br><a href="https://github.com/icsharpcode/SharpZipLib/wiki/Release-1.0">https://github.com/icsharpcode/SharpZipLib/wiki/Release-1.0</a><br><a href="https://github.com/snyk/zip-slip-vulnerability">https://github.com/snyk/zip-slip-vulnerability</a><br><a href="https://snyk.io/research/zip-slip-vulnerability">https://snyk.io/research/zip-slip-vulnerability</a><br><a href="https://snyk.io/vuln/SNYK-DOTNET-SHARPZIPLIB-60247">https://snyk.io/vuln/SNYK-DOTNET-SHARPZIPLIB-60247</a><br></details>  |
| libmonosgen-2.0-1         |    CVE-2018-1002208   |   LOW  |  6.12.0.122-0xamarin1+ubuntu1804b1 |  | <details><summary>Expand...</summary><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2018-1002208">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2018-1002208</a><br><a href="https://github.com/icsharpcode/SharpZipLib/issues/232">https://github.com/icsharpcode/SharpZipLib/issues/232</a><br><a href="https://github.com/icsharpcode/SharpZipLib/wiki/Release-1.0">https://github.com/icsharpcode/SharpZipLib/wiki/Release-1.0</a><br><a href="https://github.com/snyk/zip-slip-vulnerability">https://github.com/snyk/zip-slip-vulnerability</a><br><a href="https://snyk.io/research/zip-slip-vulnerability">https://snyk.io/research/zip-slip-vulnerability</a><br><a href="https://snyk.io/vuln/SNYK-DOTNET-SHARPZIPLIB-60247">https://snyk.io/vuln/SNYK-DOTNET-SHARPZIPLIB-60247</a><br></details>  |
| libmonosgen-2.0-dev         |    CVE-2018-1002208   |   LOW  |  6.12.0.122-0xamarin1+ubuntu1804b1 |  | <details><summary>Expand...</summary><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2018-1002208">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2018-1002208</a><br><a href="https://github.com/icsharpcode/SharpZipLib/issues/232">https://github.com/icsharpcode/SharpZipLib/issues/232</a><br><a href="https://github.com/icsharpcode/SharpZipLib/wiki/Release-1.0">https://github.com/icsharpcode/SharpZipLib/wiki/Release-1.0</a><br><a href="https://github.com/snyk/zip-slip-vulnerability">https://github.com/snyk/zip-slip-vulnerability</a><br><a href="https://snyk.io/research/zip-slip-vulnerability">https://snyk.io/research/zip-slip-vulnerability</a><br><a href="https://snyk.io/vuln/SNYK-DOTNET-SHARPZIPLIB-60247">https://snyk.io/vuln/SNYK-DOTNET-SHARPZIPLIB-60247</a><br></details>  |
| libmpx2         |    CVE-2020-13844   |   MEDIUM  |  8.4.0-1ubuntu1~18.04 |  | <details><summary>Expand...</summary><a href="http://lists.llvm.org/pipermail/llvm-dev/2020-June/142109.html">http://lists.llvm.org/pipermail/llvm-dev/2020-June/142109.html</a><br><a href="http://lists.opensuse.org/opensuse-security-announce/2020-10/msg00039.html">http://lists.opensuse.org/opensuse-security-announce/2020-10/msg00039.html</a><br><a href="http://lists.opensuse.org/opensuse-security-announce/2020-10/msg00040.html">http://lists.opensuse.org/opensuse-security-announce/2020-10/msg00040.html</a><br><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2020-13844">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2020-13844</a><br><a href="https://developer.arm.com/support/arm-security-updates/speculative-processor-vulnerability">https://developer.arm.com/support/arm-security-updates/speculative-processor-vulnerability</a><br><a href="https://developer.arm.com/support/arm-security-updates/speculative-processor-vulnerability/downloads/straight-line-speculation">https://developer.arm.com/support/arm-security-updates/speculative-processor-vulnerability/downloads/straight-line-speculation</a><br><a href="https://developer.arm.com/support/arm-security-updates/speculative-processor-vulnerability/frequently-asked-questions">https://developer.arm.com/support/arm-security-updates/speculative-processor-vulnerability/frequently-asked-questions</a><br><a href="https://gcc.gnu.org/pipermail/gcc-patches/2020-June/547520.html">https://gcc.gnu.org/pipermail/gcc-patches/2020-June/547520.html</a><br><a href="https://git.kernel.org/pub/scm/linux/kernel/git/torvalds/linux.git/commit/?id=679db70801da9fda91d26caf13bf5b5ccc74e8e8">https://git.kernel.org/pub/scm/linux/kernel/git/torvalds/linux.git/commit/?id=679db70801da9fda91d26caf13bf5b5ccc74e8e8</a><br></details>  |
| libncurses5         |    CVE-2019-17594   |   LOW  |  6.1-1ubuntu1.18.04 |  | <details><summary>Expand...</summary><a href="http://lists.opensuse.org/opensuse-security-announce/2019-11/msg00059.html">http://lists.opensuse.org/opensuse-security-announce/2019-11/msg00059.html</a><br><a href="http://lists.opensuse.org/opensuse-security-announce/2019-11/msg00061.html">http://lists.opensuse.org/opensuse-security-announce/2019-11/msg00061.html</a><br><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2019-17594">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2019-17594</a><br><a href="https://linux.oracle.com/cve/CVE-2019-17594.html">https://linux.oracle.com/cve/CVE-2019-17594.html</a><br><a href="https://linux.oracle.com/errata/ELSA-2021-4426.html">https://linux.oracle.com/errata/ELSA-2021-4426.html</a><br><a href="https://lists.gnu.org/archive/html/bug-ncurses/2019-10/msg00017.html">https://lists.gnu.org/archive/html/bug-ncurses/2019-10/msg00017.html</a><br><a href="https://lists.gnu.org/archive/html/bug-ncurses/2019-10/msg00045.html">https://lists.gnu.org/archive/html/bug-ncurses/2019-10/msg00045.html</a><br><a href="https://security.gentoo.org/glsa/202101-28">https://security.gentoo.org/glsa/202101-28</a><br></details>  |
| libncurses5         |    CVE-2019-17595   |   LOW  |  6.1-1ubuntu1.18.04 |  | <details><summary>Expand...</summary><a href="http://lists.opensuse.org/opensuse-security-announce/2019-11/msg00059.html">http://lists.opensuse.org/opensuse-security-announce/2019-11/msg00059.html</a><br><a href="http://lists.opensuse.org/opensuse-security-announce/2019-11/msg00061.html">http://lists.opensuse.org/opensuse-security-announce/2019-11/msg00061.html</a><br><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2019-17595">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2019-17595</a><br><a href="https://linux.oracle.com/cve/CVE-2019-17595.html">https://linux.oracle.com/cve/CVE-2019-17595.html</a><br><a href="https://linux.oracle.com/errata/ELSA-2021-4426.html">https://linux.oracle.com/errata/ELSA-2021-4426.html</a><br><a href="https://lists.gnu.org/archive/html/bug-ncurses/2019-10/msg00013.html">https://lists.gnu.org/archive/html/bug-ncurses/2019-10/msg00013.html</a><br><a href="https://lists.gnu.org/archive/html/bug-ncurses/2019-10/msg00045.html">https://lists.gnu.org/archive/html/bug-ncurses/2019-10/msg00045.html</a><br><a href="https://security.gentoo.org/glsa/202101-28">https://security.gentoo.org/glsa/202101-28</a><br></details>  |
| libncursesw5         |    CVE-2019-17594   |   LOW  |  6.1-1ubuntu1.18.04 |  | <details><summary>Expand...</summary><a href="http://lists.opensuse.org/opensuse-security-announce/2019-11/msg00059.html">http://lists.opensuse.org/opensuse-security-announce/2019-11/msg00059.html</a><br><a href="http://lists.opensuse.org/opensuse-security-announce/2019-11/msg00061.html">http://lists.opensuse.org/opensuse-security-announce/2019-11/msg00061.html</a><br><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2019-17594">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2019-17594</a><br><a href="https://linux.oracle.com/cve/CVE-2019-17594.html">https://linux.oracle.com/cve/CVE-2019-17594.html</a><br><a href="https://linux.oracle.com/errata/ELSA-2021-4426.html">https://linux.oracle.com/errata/ELSA-2021-4426.html</a><br><a href="https://lists.gnu.org/archive/html/bug-ncurses/2019-10/msg00017.html">https://lists.gnu.org/archive/html/bug-ncurses/2019-10/msg00017.html</a><br><a href="https://lists.gnu.org/archive/html/bug-ncurses/2019-10/msg00045.html">https://lists.gnu.org/archive/html/bug-ncurses/2019-10/msg00045.html</a><br><a href="https://security.gentoo.org/glsa/202101-28">https://security.gentoo.org/glsa/202101-28</a><br></details>  |
| libncursesw5         |    CVE-2019-17595   |   LOW  |  6.1-1ubuntu1.18.04 |  | <details><summary>Expand...</summary><a href="http://lists.opensuse.org/opensuse-security-announce/2019-11/msg00059.html">http://lists.opensuse.org/opensuse-security-announce/2019-11/msg00059.html</a><br><a href="http://lists.opensuse.org/opensuse-security-announce/2019-11/msg00061.html">http://lists.opensuse.org/opensuse-security-announce/2019-11/msg00061.html</a><br><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2019-17595">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2019-17595</a><br><a href="https://linux.oracle.com/cve/CVE-2019-17595.html">https://linux.oracle.com/cve/CVE-2019-17595.html</a><br><a href="https://linux.oracle.com/errata/ELSA-2021-4426.html">https://linux.oracle.com/errata/ELSA-2021-4426.html</a><br><a href="https://lists.gnu.org/archive/html/bug-ncurses/2019-10/msg00013.html">https://lists.gnu.org/archive/html/bug-ncurses/2019-10/msg00013.html</a><br><a href="https://lists.gnu.org/archive/html/bug-ncurses/2019-10/msg00045.html">https://lists.gnu.org/archive/html/bug-ncurses/2019-10/msg00045.html</a><br><a href="https://security.gentoo.org/glsa/202101-28">https://security.gentoo.org/glsa/202101-28</a><br></details>  |
| libnghttp2-14         |    CVE-2019-9511   |   MEDIUM  |  1.30.0-1ubuntu1 |  | <details><summary>Expand...</summary><a href="http://lists.opensuse.org/opensuse-security-announce/2019-09/msg00031.html">http://lists.opensuse.org/opensuse-security-announce/2019-09/msg00031.html</a><br><a href="http://lists.opensuse.org/opensuse-security-announce/2019-09/msg00032.html">http://lists.opensuse.org/opensuse-security-announce/2019-09/msg00032.html</a><br><a href="http://lists.opensuse.org/opensuse-security-announce/2019-09/msg00035.html">http://lists.opensuse.org/opensuse-security-announce/2019-09/msg00035.html</a><br><a href="http://lists.opensuse.org/opensuse-security-announce/2019-10/msg00003.html">http://lists.opensuse.org/opensuse-security-announce/2019-10/msg00003.html</a><br><a href="http://lists.opensuse.org/opensuse-security-announce/2019-10/msg00005.html">http://lists.opensuse.org/opensuse-security-announce/2019-10/msg00005.html</a><br><a href="http://lists.opensuse.org/opensuse-security-announce/2019-10/msg00014.html">http://lists.opensuse.org/opensuse-security-announce/2019-10/msg00014.html</a><br><a href="https://access.redhat.com/errata/RHSA-2019:2692">https://access.redhat.com/errata/RHSA-2019:2692</a><br><a href="https://access.redhat.com/errata/RHSA-2019:2745">https://access.redhat.com/errata/RHSA-2019:2745</a><br><a href="https://access.redhat.com/errata/RHSA-2019:2746">https://access.redhat.com/errata/RHSA-2019:2746</a><br><a href="https://access.redhat.com/errata/RHSA-2019:2775">https://access.redhat.com/errata/RHSA-2019:2775</a><br><a href="https://access.redhat.com/errata/RHSA-2019:2799">https://access.redhat.com/errata/RHSA-2019:2799</a><br><a href="https://access.redhat.com/errata/RHSA-2019:2925">https://access.redhat.com/errata/RHSA-2019:2925</a><br><a href="https://access.redhat.com/errata/RHSA-2019:2939">https://access.redhat.com/errata/RHSA-2019:2939</a><br><a href="https://access.redhat.com/errata/RHSA-2019:2949">https://access.redhat.com/errata/RHSA-2019:2949</a><br><a href="https://access.redhat.com/errata/RHSA-2019:2955">https://access.redhat.com/errata/RHSA-2019:2955</a><br><a href="https://access.redhat.com/errata/RHSA-2019:2966">https://access.redhat.com/errata/RHSA-2019:2966</a><br><a href="https://access.redhat.com/errata/RHSA-2019:3041">https://access.redhat.com/errata/RHSA-2019:3041</a><br><a href="https://access.redhat.com/errata/RHSA-2019:3932">https://access.redhat.com/errata/RHSA-2019:3932</a><br><a href="https://access.redhat.com/errata/RHSA-2019:3933">https://access.redhat.com/errata/RHSA-2019:3933</a><br><a href="https://access.redhat.com/errata/RHSA-2019:3935">https://access.redhat.com/errata/RHSA-2019:3935</a><br><a href="https://access.redhat.com/errata/RHSA-2019:4018">https://access.redhat.com/errata/RHSA-2019:4018</a><br><a href="https://access.redhat.com/errata/RHSA-2019:4019">https://access.redhat.com/errata/RHSA-2019:4019</a><br><a href="https://access.redhat.com/errata/RHSA-2019:4020">https://access.redhat.com/errata/RHSA-2019:4020</a><br><a href="https://access.redhat.com/errata/RHSA-2019:4021">https://access.redhat.com/errata/RHSA-2019:4021</a><br><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2019-9511">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2019-9511</a><br><a href="https://github.com/Netflix/security-bulletins/blob/master/advisories/third-party/2019-002.md">https://github.com/Netflix/security-bulletins/blob/master/advisories/third-party/2019-002.md</a><br><a href="https://kb.cert.org/vuls/id/605641/">https://kb.cert.org/vuls/id/605641/</a><br><a href="https://kc.mcafee.com/corporate/index?page=content&amp;id=SB10296">https://kc.mcafee.com/corporate/index?page=content&amp;id=SB10296</a><br><a href="https://linux.oracle.com/cve/CVE-2019-9511.html">https://linux.oracle.com/cve/CVE-2019-9511.html</a><br><a href="https://linux.oracle.com/errata/ELSA-2020-5862.html">https://linux.oracle.com/errata/ELSA-2020-5862.html</a><br><a href="https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/BP556LEG3WENHZI5TAQ6ZEBFTJB4E2IS/">https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/BP556LEG3WENHZI5TAQ6ZEBFTJB4E2IS/</a><br><a href="https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/JUBYAF6ED3O4XCHQ5C2HYENJLXYXZC4M/">https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/JUBYAF6ED3O4XCHQ5C2HYENJLXYXZC4M/</a><br><a href="https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/LZLUYPYY3RX4ZJDWZRJIKSULYRJ4PXW7/">https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/LZLUYPYY3RX4ZJDWZRJIKSULYRJ4PXW7/</a><br><a href="https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/POPAEC4FWL4UU4LDEGPY5NPALU24FFQD/">https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/POPAEC4FWL4UU4LDEGPY5NPALU24FFQD/</a><br><a href="https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/TAZZEVTCN2B4WT6AIBJ7XGYJMBTORJU5/">https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/TAZZEVTCN2B4WT6AIBJ7XGYJMBTORJU5/</a><br><a href="https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/XHTKU7YQ5EEP2XNSAV4M4VJ7QCBOJMOD/">https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/XHTKU7YQ5EEP2XNSAV4M4VJ7QCBOJMOD/</a><br><a href="https://nodejs.org/en/blog/vulnerability/aug-2019-security-releases/">https://nodejs.org/en/blog/vulnerability/aug-2019-security-releases/</a><br><a href="https://seclists.org/bugtraq/2019/Aug/40">https://seclists.org/bugtraq/2019/Aug/40</a><br><a href="https://seclists.org/bugtraq/2019/Sep/1">https://seclists.org/bugtraq/2019/Sep/1</a><br><a href="https://security.netapp.com/advisory/ntap-20190823-0002/">https://security.netapp.com/advisory/ntap-20190823-0002/</a><br><a href="https://security.netapp.com/advisory/ntap-20190823-0005/">https://security.netapp.com/advisory/ntap-20190823-0005/</a><br><a href="https://support.f5.com/csp/article/K02591030">https://support.f5.com/csp/article/K02591030</a><br><a href="https://support.f5.com/csp/article/K02591030?utm_source=f5support&amp;amp;utm_medium=RSS">https://support.f5.com/csp/article/K02591030?utm_source=f5support&amp;amp;utm_medium=RSS</a><br><a href="https://ubuntu.com/security/notices/USN-4099-1">https://ubuntu.com/security/notices/USN-4099-1</a><br><a href="https://usn.ubuntu.com/4099-1/">https://usn.ubuntu.com/4099-1/</a><br><a href="https://www.debian.org/security/2019/dsa-4505">https://www.debian.org/security/2019/dsa-4505</a><br><a href="https://www.debian.org/security/2019/dsa-4511">https://www.debian.org/security/2019/dsa-4511</a><br><a href="https://www.debian.org/security/2020/dsa-4669">https://www.debian.org/security/2020/dsa-4669</a><br><a href="https://www.nginx.com/blog/nginx-updates-mitigate-august-2019-http-2-vulnerabilities/">https://www.nginx.com/blog/nginx-updates-mitigate-august-2019-http-2-vulnerabilities/</a><br><a href="https://www.oracle.com/security-alerts/cpujan2021.html">https://www.oracle.com/security-alerts/cpujan2021.html</a><br><a href="https://www.oracle.com/security-alerts/cpuoct2020.html">https://www.oracle.com/security-alerts/cpuoct2020.html</a><br><a href="https://www.oracle.com/technetwork/security-advisory/cpuoct2019-5072832.html">https://www.oracle.com/technetwork/security-advisory/cpuoct2019-5072832.html</a><br><a href="https://www.synology.com/security/advisory/Synology_SA_19_33">https://www.synology.com/security/advisory/Synology_SA_19_33</a><br></details>  |
| libnghttp2-14         |    CVE-2019-9513   |   MEDIUM  |  1.30.0-1ubuntu1 |  | <details><summary>Expand...</summary><a href="http://lists.opensuse.org/opensuse-security-announce/2019-09/msg00031.html">http://lists.opensuse.org/opensuse-security-announce/2019-09/msg00031.html</a><br><a href="http://lists.opensuse.org/opensuse-security-announce/2019-09/msg00032.html">http://lists.opensuse.org/opensuse-security-announce/2019-09/msg00032.html</a><br><a href="http://lists.opensuse.org/opensuse-security-announce/2019-09/msg00035.html">http://lists.opensuse.org/opensuse-security-announce/2019-09/msg00035.html</a><br><a href="http://lists.opensuse.org/opensuse-security-announce/2019-10/msg00003.html">http://lists.opensuse.org/opensuse-security-announce/2019-10/msg00003.html</a><br><a href="http://lists.opensuse.org/opensuse-security-announce/2019-10/msg00005.html">http://lists.opensuse.org/opensuse-security-announce/2019-10/msg00005.html</a><br><a href="http://lists.opensuse.org/opensuse-security-announce/2019-10/msg00014.html">http://lists.opensuse.org/opensuse-security-announce/2019-10/msg00014.html</a><br><a href="https://access.redhat.com/errata/RHSA-2019:2692">https://access.redhat.com/errata/RHSA-2019:2692</a><br><a href="https://access.redhat.com/errata/RHSA-2019:2745">https://access.redhat.com/errata/RHSA-2019:2745</a><br><a href="https://access.redhat.com/errata/RHSA-2019:2746">https://access.redhat.com/errata/RHSA-2019:2746</a><br><a href="https://access.redhat.com/errata/RHSA-2019:2775">https://access.redhat.com/errata/RHSA-2019:2775</a><br><a href="https://access.redhat.com/errata/RHSA-2019:2799">https://access.redhat.com/errata/RHSA-2019:2799</a><br><a href="https://access.redhat.com/errata/RHSA-2019:2925">https://access.redhat.com/errata/RHSA-2019:2925</a><br><a href="https://access.redhat.com/errata/RHSA-2019:2939">https://access.redhat.com/errata/RHSA-2019:2939</a><br><a href="https://access.redhat.com/errata/RHSA-2019:2949">https://access.redhat.com/errata/RHSA-2019:2949</a><br><a href="https://access.redhat.com/errata/RHSA-2019:2955">https://access.redhat.com/errata/RHSA-2019:2955</a><br><a href="https://access.redhat.com/errata/RHSA-2019:2966">https://access.redhat.com/errata/RHSA-2019:2966</a><br><a href="https://access.redhat.com/errata/RHSA-2019:3041">https://access.redhat.com/errata/RHSA-2019:3041</a><br><a href="https://access.redhat.com/errata/RHSA-2019:3932">https://access.redhat.com/errata/RHSA-2019:3932</a><br><a href="https://access.redhat.com/errata/RHSA-2019:3933">https://access.redhat.com/errata/RHSA-2019:3933</a><br><a href="https://access.redhat.com/errata/RHSA-2019:3935">https://access.redhat.com/errata/RHSA-2019:3935</a><br><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2019-9513">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2019-9513</a><br><a href="https://github.com/Netflix/security-bulletins/blob/master/advisories/third-party/2019-002.md">https://github.com/Netflix/security-bulletins/blob/master/advisories/third-party/2019-002.md</a><br><a href="https://kb.cert.org/vuls/id/605641/">https://kb.cert.org/vuls/id/605641/</a><br><a href="https://kc.mcafee.com/corporate/index?page=content&amp;id=SB10296">https://kc.mcafee.com/corporate/index?page=content&amp;id=SB10296</a><br><a href="https://linux.oracle.com/cve/CVE-2019-9513.html">https://linux.oracle.com/cve/CVE-2019-9513.html</a><br><a href="https://linux.oracle.com/errata/ELSA-2019-2925.html">https://linux.oracle.com/errata/ELSA-2019-2925.html</a><br><a href="https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/4ZQGHE3WTYLYAYJEIDJVF2FIGQTAYPMC/">https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/4ZQGHE3WTYLYAYJEIDJVF2FIGQTAYPMC/</a><br><a href="https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/CMNFX5MNYRWWIMO4BTKYQCGUDMHO3AXP/">https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/CMNFX5MNYRWWIMO4BTKYQCGUDMHO3AXP/</a><br><a href="https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/JUBYAF6ED3O4XCHQ5C2HYENJLXYXZC4M/">https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/JUBYAF6ED3O4XCHQ5C2HYENJLXYXZC4M/</a><br><a href="https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/LZLUYPYY3RX4ZJDWZRJIKSULYRJ4PXW7/">https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/LZLUYPYY3RX4ZJDWZRJIKSULYRJ4PXW7/</a><br><a href="https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/POPAEC4FWL4UU4LDEGPY5NPALU24FFQD/">https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/POPAEC4FWL4UU4LDEGPY5NPALU24FFQD/</a><br><a href="https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/TAZZEVTCN2B4WT6AIBJ7XGYJMBTORJU5/">https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/TAZZEVTCN2B4WT6AIBJ7XGYJMBTORJU5/</a><br><a href="https://nghttp2.org/blog/2019/08/19/nghttp2-v1-39-2/">https://nghttp2.org/blog/2019/08/19/nghttp2-v1-39-2/</a><br><a href="https://nodejs.org/en/blog/vulnerability/aug-2019-security-releases/">https://nodejs.org/en/blog/vulnerability/aug-2019-security-releases/</a><br><a href="https://seclists.org/bugtraq/2019/Aug/40">https://seclists.org/bugtraq/2019/Aug/40</a><br><a href="https://seclists.org/bugtraq/2019/Sep/1">https://seclists.org/bugtraq/2019/Sep/1</a><br><a href="https://security.netapp.com/advisory/ntap-20190823-0002/">https://security.netapp.com/advisory/ntap-20190823-0002/</a><br><a href="https://security.netapp.com/advisory/ntap-20190823-0005/">https://security.netapp.com/advisory/ntap-20190823-0005/</a><br><a href="https://support.f5.com/csp/article/K02591030">https://support.f5.com/csp/article/K02591030</a><br><a href="https://support.f5.com/csp/article/K02591030?utm_source=f5support&amp;amp;utm_medium=RSS">https://support.f5.com/csp/article/K02591030?utm_source=f5support&amp;amp;utm_medium=RSS</a><br><a href="https://ubuntu.com/security/notices/USN-4099-1">https://ubuntu.com/security/notices/USN-4099-1</a><br><a href="https://usn.ubuntu.com/4099-1/">https://usn.ubuntu.com/4099-1/</a><br><a href="https://www.debian.org/security/2019/dsa-4505">https://www.debian.org/security/2019/dsa-4505</a><br><a href="https://www.debian.org/security/2019/dsa-4511">https://www.debian.org/security/2019/dsa-4511</a><br><a href="https://www.debian.org/security/2020/dsa-4669">https://www.debian.org/security/2020/dsa-4669</a><br><a href="https://www.nginx.com/blog/nginx-updates-mitigate-august-2019-http-2-vulnerabilities/">https://www.nginx.com/blog/nginx-updates-mitigate-august-2019-http-2-vulnerabilities/</a><br><a href="https://www.oracle.com/security-alerts/cpujan2021.html">https://www.oracle.com/security-alerts/cpujan2021.html</a><br><a href="https://www.oracle.com/security-alerts/cpuoct2020.html">https://www.oracle.com/security-alerts/cpuoct2020.html</a><br><a href="https://www.synology.com/security/advisory/Synology_SA_19_33">https://www.synology.com/security/advisory/Synology_SA_19_33</a><br></details>  |
| libpcre3         |    CVE-2017-11164   |   LOW  |  2:8.39-9 |  | <details><summary>Expand...</summary><a href="http://openwall.com/lists/oss-security/2017/07/11/3">http://openwall.com/lists/oss-security/2017/07/11/3</a><br><a href="http://www.securityfocus.com/bid/99575">http://www.securityfocus.com/bid/99575</a><br><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2017-11164">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2017-11164</a><br><a href="https://lists.apache.org/thread.html/rf9fa47ab66495c78bb4120b0754dd9531ca2ff0430f6685ac9b07772@%3Cdev.mina.apache.org%3E">https://lists.apache.org/thread.html/rf9fa47ab66495c78bb4120b0754dd9531ca2ff0430f6685ac9b07772@%3Cdev.mina.apache.org%3E</a><br></details>  |
| libpcre3         |    CVE-2019-20838   |   LOW  |  2:8.39-9 |  | <details><summary>Expand...</summary><a href="http://seclists.org/fulldisclosure/2020/Dec/32">http://seclists.org/fulldisclosure/2020/Dec/32</a><br><a href="http://seclists.org/fulldisclosure/2021/Feb/14">http://seclists.org/fulldisclosure/2021/Feb/14</a><br><a href="https://bugs.gentoo.org/717920">https://bugs.gentoo.org/717920</a><br><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2019-20838">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2019-20838</a><br><a href="https://linux.oracle.com/cve/CVE-2019-20838.html">https://linux.oracle.com/cve/CVE-2019-20838.html</a><br><a href="https://linux.oracle.com/errata/ELSA-2021-4373.html">https://linux.oracle.com/errata/ELSA-2021-4373.html</a><br><a href="https://lists.apache.org/thread.html/rf9fa47ab66495c78bb4120b0754dd9531ca2ff0430f6685ac9b07772@%3Cdev.mina.apache.org%3E">https://lists.apache.org/thread.html/rf9fa47ab66495c78bb4120b0754dd9531ca2ff0430f6685ac9b07772@%3Cdev.mina.apache.org%3E</a><br><a href="https://support.apple.com/kb/HT211931">https://support.apple.com/kb/HT211931</a><br><a href="https://support.apple.com/kb/HT212147">https://support.apple.com/kb/HT212147</a><br><a href="https://www.pcre.org/original/changelog.txt">https://www.pcre.org/original/changelog.txt</a><br></details>  |
| libpcre3         |    CVE-2020-14155   |   LOW  |  2:8.39-9 |  | <details><summary>Expand...</summary><a href="http://seclists.org/fulldisclosure/2020/Dec/32">http://seclists.org/fulldisclosure/2020/Dec/32</a><br><a href="http://seclists.org/fulldisclosure/2021/Feb/14">http://seclists.org/fulldisclosure/2021/Feb/14</a><br><a href="https://about.gitlab.com/releases/2020/07/01/security-release-13-1-2-release/">https://about.gitlab.com/releases/2020/07/01/security-release-13-1-2-release/</a><br><a href="https://bugs.gentoo.org/717920">https://bugs.gentoo.org/717920</a><br><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2020-14155">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2020-14155</a><br><a href="https://linux.oracle.com/cve/CVE-2020-14155.html">https://linux.oracle.com/cve/CVE-2020-14155.html</a><br><a href="https://linux.oracle.com/errata/ELSA-2021-4373.html">https://linux.oracle.com/errata/ELSA-2021-4373.html</a><br><a href="https://lists.apache.org/thread.html/rf9fa47ab66495c78bb4120b0754dd9531ca2ff0430f6685ac9b07772@%3Cdev.mina.apache.org%3E">https://lists.apache.org/thread.html/rf9fa47ab66495c78bb4120b0754dd9531ca2ff0430f6685ac9b07772@%3Cdev.mina.apache.org%3E</a><br><a href="https://support.apple.com/kb/HT211931">https://support.apple.com/kb/HT211931</a><br><a href="https://support.apple.com/kb/HT212147">https://support.apple.com/kb/HT212147</a><br><a href="https://www.pcre.org/original/changelog.txt">https://www.pcre.org/original/changelog.txt</a><br></details>  |
| libperl5.26         |    CVE-2020-16156   |   MEDIUM  |  5.26.1-6ubuntu0.5 |  | <details><summary>Expand...</summary><a href="http://blogs.perl.org/users/neilb/2021/11/addressing-cpan-vulnerabilities-related-to-checksums.html">http://blogs.perl.org/users/neilb/2021/11/addressing-cpan-vulnerabilities-related-to-checksums.html</a><br><a href="https://blog.hackeriet.no/cpan-signature-verification-vulnerabilities/">https://blog.hackeriet.no/cpan-signature-verification-vulnerabilities/</a><br><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2020-16156">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2020-16156</a><br><a href="https://github.com/andk/cpanpm/commit/b27c51adf0fda25dee84cb72cb2b1bf7d832148c">https://github.com/andk/cpanpm/commit/b27c51adf0fda25dee84cb72cb2b1bf7d832148c</a><br><a href="https://metacpan.org/pod/distribution/CPAN/scripts/cpan">https://metacpan.org/pod/distribution/CPAN/scripts/cpan</a><br></details>  |
| libpng16-16         |    CVE-2018-14048   |   LOW  |  1.6.34-1ubuntu0.18.04.2 |  | <details><summary>Expand...</summary><a href="http://packetstormsecurity.com/files/152561/Slackware-Security-Advisory-libpng-Updates.html">http://packetstormsecurity.com/files/152561/Slackware-Security-Advisory-libpng-Updates.html</a><br><a href="http://www.oracle.com/technetwork/security-advisory/cpuoct2018-4428296.html">http://www.oracle.com/technetwork/security-advisory/cpuoct2018-4428296.html</a><br><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2018-14048">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2018-14048</a><br><a href="https://github.com/fouzhe/security/tree/master/libpng">https://github.com/fouzhe/security/tree/master/libpng</a><br><a href="https://github.com/glennrp/libpng/issues/238">https://github.com/glennrp/libpng/issues/238</a><br><a href="https://seclists.org/bugtraq/2019/Apr/30">https://seclists.org/bugtraq/2019/Apr/30</a><br><a href="https://security.gentoo.org/glsa/201908-02">https://security.gentoo.org/glsa/201908-02</a><br></details>  |
| libquadmath0         |    CVE-2020-13844   |   MEDIUM  |  8.4.0-1ubuntu1~18.04 |  | <details><summary>Expand...</summary><a href="http://lists.llvm.org/pipermail/llvm-dev/2020-June/142109.html">http://lists.llvm.org/pipermail/llvm-dev/2020-June/142109.html</a><br><a href="http://lists.opensuse.org/opensuse-security-announce/2020-10/msg00039.html">http://lists.opensuse.org/opensuse-security-announce/2020-10/msg00039.html</a><br><a href="http://lists.opensuse.org/opensuse-security-announce/2020-10/msg00040.html">http://lists.opensuse.org/opensuse-security-announce/2020-10/msg00040.html</a><br><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2020-13844">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2020-13844</a><br><a href="https://developer.arm.com/support/arm-security-updates/speculative-processor-vulnerability">https://developer.arm.com/support/arm-security-updates/speculative-processor-vulnerability</a><br><a href="https://developer.arm.com/support/arm-security-updates/speculative-processor-vulnerability/downloads/straight-line-speculation">https://developer.arm.com/support/arm-security-updates/speculative-processor-vulnerability/downloads/straight-line-speculation</a><br><a href="https://developer.arm.com/support/arm-security-updates/speculative-processor-vulnerability/frequently-asked-questions">https://developer.arm.com/support/arm-security-updates/speculative-processor-vulnerability/frequently-asked-questions</a><br><a href="https://gcc.gnu.org/pipermail/gcc-patches/2020-June/547520.html">https://gcc.gnu.org/pipermail/gcc-patches/2020-June/547520.html</a><br><a href="https://git.kernel.org/pub/scm/linux/kernel/git/torvalds/linux.git/commit/?id=679db70801da9fda91d26caf13bf5b5ccc74e8e8">https://git.kernel.org/pub/scm/linux/kernel/git/torvalds/linux.git/commit/?id=679db70801da9fda91d26caf13bf5b5ccc74e8e8</a><br></details>  |
| libroken18-heimdal         |    CVE-2019-12098   |   LOW  |  7.5.0+dfsg-1 |  | <details><summary>Expand...</summary><a href="http://lists.opensuse.org/opensuse-security-announce/2019-07/msg00002.html">http://lists.opensuse.org/opensuse-security-announce/2019-07/msg00002.html</a><br><a href="http://lists.opensuse.org/opensuse-security-announce/2019-07/msg00003.html">http://lists.opensuse.org/opensuse-security-announce/2019-07/msg00003.html</a><br><a href="http://lists.opensuse.org/opensuse-security-announce/2019-08/msg00026.html">http://lists.opensuse.org/opensuse-security-announce/2019-08/msg00026.html</a><br><a href="http://www.h5l.org/pipermail/heimdal-announce/2019-May/000009.html">http://www.h5l.org/pipermail/heimdal-announce/2019-May/000009.html</a><br><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2019-12098">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2019-12098</a><br><a href="https://github.com/heimdal/heimdal/commit/2f7f3d9960aa6ea21358bdf3687cee5149aa35cf">https://github.com/heimdal/heimdal/commit/2f7f3d9960aa6ea21358bdf3687cee5149aa35cf</a><br><a href="https://github.com/heimdal/heimdal/compare/3e58559...bbafe72">https://github.com/heimdal/heimdal/compare/3e58559...bbafe72</a><br><a href="https://github.com/heimdal/heimdal/releases/tag/heimdal-7.6.0">https://github.com/heimdal/heimdal/releases/tag/heimdal-7.6.0</a><br><a href="https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/GIXEDVVMPD6ZAJSMI2EZ7FNEIVNWE5PD/">https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/GIXEDVVMPD6ZAJSMI2EZ7FNEIVNWE5PD/</a><br><a href="https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/SLXXIF4LOQEAEDAF4UGP2AO6WDNTDFUB/">https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/SLXXIF4LOQEAEDAF4UGP2AO6WDNTDFUB/</a><br><a href="https://seclists.org/bugtraq/2019/Jun/1">https://seclists.org/bugtraq/2019/Jun/1</a><br><a href="https://www.debian.org/security/2019/dsa-4455">https://www.debian.org/security/2019/dsa-4455</a><br></details>  |
| libroken18-heimdal         |    CVE-2021-3671   |   LOW  |  7.5.0+dfsg-1 |  | <details><summary>Expand...</summary><a href="https://bugzilla.redhat.com/show_bug.cgi?id=2013080,">https://bugzilla.redhat.com/show_bug.cgi?id=2013080,</a><br><a href="https://bugzilla.samba.org/show_bug.cgi?id=14770,">https://bugzilla.samba.org/show_bug.cgi?id=14770,</a><br><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2021-3671">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2021-3671</a><br><a href="https://github.com/heimdal/heimdal/commit/04171147948d0a3636bc6374181926f0fb2ec83a">https://github.com/heimdal/heimdal/commit/04171147948d0a3636bc6374181926f0fb2ec83a</a><br><a href="https://ubuntu.com/security/notices/USN-5142-1">https://ubuntu.com/security/notices/USN-5142-1</a><br><a href="https://ubuntu.com/security/notices/USN-5174-1">https://ubuntu.com/security/notices/USN-5174-1</a><br></details>  |
| libsqlite3-0         |    CVE-2020-9794   |   MEDIUM  |  3.22.0-1ubuntu0.4 |  | <details><summary>Expand...</summary><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2020-9794">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2020-9794</a><br><a href="https://lists.apache.org/thread.html/rf9fa47ab66495c78bb4120b0754dd9531ca2ff0430f6685ac9b07772@%3Cdev.mina.apache.org%3E">https://lists.apache.org/thread.html/rf9fa47ab66495c78bb4120b0754dd9531ca2ff0430f6685ac9b07772@%3Cdev.mina.apache.org%3E</a><br><a href="https://support.apple.com/HT211168">https://support.apple.com/HT211168</a><br><a href="https://support.apple.com/HT211170">https://support.apple.com/HT211170</a><br><a href="https://support.apple.com/HT211171">https://support.apple.com/HT211171</a><br><a href="https://support.apple.com/HT211175">https://support.apple.com/HT211175</a><br><a href="https://support.apple.com/HT211178">https://support.apple.com/HT211178</a><br><a href="https://support.apple.com/HT211179">https://support.apple.com/HT211179</a><br><a href="https://support.apple.com/HT211181">https://support.apple.com/HT211181</a><br><a href="https://vuldb.com/?id.155768">https://vuldb.com/?id.155768</a><br></details>  |
| libsqlite3-0         |    CVE-2020-9849   |   LOW  |  3.22.0-1ubuntu0.4 |  | <details><summary>Expand...</summary><a href="http://seclists.org/fulldisclosure/2020/Dec/32">http://seclists.org/fulldisclosure/2020/Dec/32</a><br><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2020-9849">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2020-9849</a><br><a href="https://lists.apache.org/thread.html/rf9fa47ab66495c78bb4120b0754dd9531ca2ff0430f6685ac9b07772@%3Cdev.mina.apache.org%3E">https://lists.apache.org/thread.html/rf9fa47ab66495c78bb4120b0754dd9531ca2ff0430f6685ac9b07772@%3Cdev.mina.apache.org%3E</a><br><a href="https://support.apple.com/en-us/HT211843">https://support.apple.com/en-us/HT211843</a><br><a href="https://support.apple.com/en-us/HT211844">https://support.apple.com/en-us/HT211844</a><br><a href="https://support.apple.com/en-us/HT211850">https://support.apple.com/en-us/HT211850</a><br><a href="https://support.apple.com/en-us/HT211931">https://support.apple.com/en-us/HT211931</a><br><a href="https://support.apple.com/en-us/HT211935">https://support.apple.com/en-us/HT211935</a><br><a href="https://support.apple.com/en-us/HT211952">https://support.apple.com/en-us/HT211952</a><br><a href="https://www.rapid7.com/db/vulnerabilities/apple-osx-sqlite-cve-2020-9849/">https://www.rapid7.com/db/vulnerabilities/apple-osx-sqlite-cve-2020-9849/</a><br></details>  |
| libsqlite3-0         |    CVE-2020-9991   |   LOW  |  3.22.0-1ubuntu0.4 |  | <details><summary>Expand...</summary><a href="http://seclists.org/fulldisclosure/2020/Dec/32">http://seclists.org/fulldisclosure/2020/Dec/32</a><br><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2020-9991">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2020-9991</a><br><a href="https://lists.apache.org/thread.html/rf9fa47ab66495c78bb4120b0754dd9531ca2ff0430f6685ac9b07772@%3Cdev.mina.apache.org%3E">https://lists.apache.org/thread.html/rf9fa47ab66495c78bb4120b0754dd9531ca2ff0430f6685ac9b07772@%3Cdev.mina.apache.org%3E</a><br><a href="https://support.apple.com/en-us/HT211843">https://support.apple.com/en-us/HT211843</a><br><a href="https://support.apple.com/en-us/HT211844">https://support.apple.com/en-us/HT211844</a><br><a href="https://support.apple.com/en-us/HT211847">https://support.apple.com/en-us/HT211847</a><br><a href="https://support.apple.com/en-us/HT211850">https://support.apple.com/en-us/HT211850</a><br><a href="https://support.apple.com/en-us/HT211931">https://support.apple.com/en-us/HT211931</a><br><a href="https://support.apple.com/kb/HT211846">https://support.apple.com/kb/HT211846</a><br><a href="https://www.rapid7.com/db/vulnerabilities/apple-osx-sqlite-cve-2020-9991/">https://www.rapid7.com/db/vulnerabilities/apple-osx-sqlite-cve-2020-9991/</a><br></details>  |
| libstdc++-7-dev         |    CVE-2020-13844   |   MEDIUM  |  7.5.0-3ubuntu1~18.04 |  | <details><summary>Expand...</summary><a href="http://lists.llvm.org/pipermail/llvm-dev/2020-June/142109.html">http://lists.llvm.org/pipermail/llvm-dev/2020-June/142109.html</a><br><a href="http://lists.opensuse.org/opensuse-security-announce/2020-10/msg00039.html">http://lists.opensuse.org/opensuse-security-announce/2020-10/msg00039.html</a><br><a href="http://lists.opensuse.org/opensuse-security-announce/2020-10/msg00040.html">http://lists.opensuse.org/opensuse-security-announce/2020-10/msg00040.html</a><br><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2020-13844">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2020-13844</a><br><a href="https://developer.arm.com/support/arm-security-updates/speculative-processor-vulnerability">https://developer.arm.com/support/arm-security-updates/speculative-processor-vulnerability</a><br><a href="https://developer.arm.com/support/arm-security-updates/speculative-processor-vulnerability/downloads/straight-line-speculation">https://developer.arm.com/support/arm-security-updates/speculative-processor-vulnerability/downloads/straight-line-speculation</a><br><a href="https://developer.arm.com/support/arm-security-updates/speculative-processor-vulnerability/frequently-asked-questions">https://developer.arm.com/support/arm-security-updates/speculative-processor-vulnerability/frequently-asked-questions</a><br><a href="https://gcc.gnu.org/pipermail/gcc-patches/2020-June/547520.html">https://gcc.gnu.org/pipermail/gcc-patches/2020-June/547520.html</a><br><a href="https://git.kernel.org/pub/scm/linux/kernel/git/torvalds/linux.git/commit/?id=679db70801da9fda91d26caf13bf5b5ccc74e8e8">https://git.kernel.org/pub/scm/linux/kernel/git/torvalds/linux.git/commit/?id=679db70801da9fda91d26caf13bf5b5ccc74e8e8</a><br></details>  |
| libstdc++6         |    CVE-2020-13844   |   MEDIUM  |  8.4.0-1ubuntu1~18.04 |  | <details><summary>Expand...</summary><a href="http://lists.llvm.org/pipermail/llvm-dev/2020-June/142109.html">http://lists.llvm.org/pipermail/llvm-dev/2020-June/142109.html</a><br><a href="http://lists.opensuse.org/opensuse-security-announce/2020-10/msg00039.html">http://lists.opensuse.org/opensuse-security-announce/2020-10/msg00039.html</a><br><a href="http://lists.opensuse.org/opensuse-security-announce/2020-10/msg00040.html">http://lists.opensuse.org/opensuse-security-announce/2020-10/msg00040.html</a><br><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2020-13844">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2020-13844</a><br><a href="https://developer.arm.com/support/arm-security-updates/speculative-processor-vulnerability">https://developer.arm.com/support/arm-security-updates/speculative-processor-vulnerability</a><br><a href="https://developer.arm.com/support/arm-security-updates/speculative-processor-vulnerability/downloads/straight-line-speculation">https://developer.arm.com/support/arm-security-updates/speculative-processor-vulnerability/downloads/straight-line-speculation</a><br><a href="https://developer.arm.com/support/arm-security-updates/speculative-processor-vulnerability/frequently-asked-questions">https://developer.arm.com/support/arm-security-updates/speculative-processor-vulnerability/frequently-asked-questions</a><br><a href="https://gcc.gnu.org/pipermail/gcc-patches/2020-June/547520.html">https://gcc.gnu.org/pipermail/gcc-patches/2020-June/547520.html</a><br><a href="https://git.kernel.org/pub/scm/linux/kernel/git/torvalds/linux.git/commit/?id=679db70801da9fda91d26caf13bf5b5ccc74e8e8">https://git.kernel.org/pub/scm/linux/kernel/git/torvalds/linux.git/commit/?id=679db70801da9fda91d26caf13bf5b5ccc74e8e8</a><br></details>  |
| libtasn1-6         |    CVE-2018-1000654   |   LOW  |  4.13-2 |  | <details><summary>Expand...</summary><a href="http://lists.opensuse.org/opensuse-security-announce/2019-06/msg00009.html">http://lists.opensuse.org/opensuse-security-announce/2019-06/msg00009.html</a><br><a href="http://lists.opensuse.org/opensuse-security-announce/2019-06/msg00018.html">http://lists.opensuse.org/opensuse-security-announce/2019-06/msg00018.html</a><br><a href="http://www.securityfocus.com/bid/105151">http://www.securityfocus.com/bid/105151</a><br><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2018-1000654">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2018-1000654</a><br><a href="https://gitlab.com/gnutls/libtasn1/issues/4">https://gitlab.com/gnutls/libtasn1/issues/4</a><br><a href="https://lists.apache.org/thread.html/rf9fa47ab66495c78bb4120b0754dd9531ca2ff0430f6685ac9b07772@%3Cdev.mina.apache.org%3E">https://lists.apache.org/thread.html/rf9fa47ab66495c78bb4120b0754dd9531ca2ff0430f6685ac9b07772@%3Cdev.mina.apache.org%3E</a><br></details>  |
| libtiff5         |    CVE-2018-10126   |   LOW  |  4.0.9-5ubuntu0.4 |  | <details><summary>Expand...</summary><a href="http://bugzilla.maptools.org/show_bug.cgi?id=2786">http://bugzilla.maptools.org/show_bug.cgi?id=2786</a><br><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2018-10126">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2018-10126</a><br><a href="https://lists.apache.org/thread.html/rf9fa47ab66495c78bb4120b0754dd9531ca2ff0430f6685ac9b07772@%3Cdev.mina.apache.org%3E">https://lists.apache.org/thread.html/rf9fa47ab66495c78bb4120b0754dd9531ca2ff0430f6685ac9b07772@%3Cdev.mina.apache.org%3E</a><br></details>  |
| libtiff5         |    CVE-2020-19131   |   LOW  |  4.0.9-5ubuntu0.4 |  | <details><summary>Expand...</summary><a href="http://blog.topsec.com.cn/%E5%A4%A9%E8%9E%8D%E4%BF%A1%E5%85%B3%E4%BA%8Elibtiff%E4%B8%ADinvertimage%E5%87%BD%E6%95%B0%E5%A0%86%E6%BA%A2%E5%87%BA%E6%BC%8F%E6%B4%9E%E7%9A%84%E5%88%86%E6%9E%90/">http://blog.topsec.com.cn/%E5%A4%A9%E8%9E%8D%E4%BF%A1%E5%85%B3%E4%BA%8Elibtiff%E4%B8%ADinvertimage%E5%87%BD%E6%95%B0%E5%A0%86%E6%BA%A2%E5%87%BA%E6%BC%8F%E6%B4%9E%E7%9A%84%E5%88%86%E6%9E%90/</a><br><a href="http://bugzilla.maptools.org/show_bug.cgi?id=2831">http://bugzilla.maptools.org/show_bug.cgi?id=2831</a><br><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2020-19131">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2020-19131</a><br><a href="https://lists.debian.org/debian-lts-announce/2021/10/msg00004.html">https://lists.debian.org/debian-lts-announce/2021/10/msg00004.html</a><br></details>  |
| libtiff5         |    CVE-2020-19144   |   LOW  |  4.0.9-5ubuntu0.4 |  | <details><summary>Expand...</summary><a href="http://bugzilla.maptools.org/show_bug.cgi?id=2852">http://bugzilla.maptools.org/show_bug.cgi?id=2852</a><br><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2020-19144">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2020-19144</a><br><a href="https://gitlab.com/libtiff/libtiff/-/issues/159">https://gitlab.com/libtiff/libtiff/-/issues/159</a><br><a href="https://lists.debian.org/debian-lts-announce/2021/10/msg00004.html">https://lists.debian.org/debian-lts-announce/2021/10/msg00004.html</a><br><a href="https://security.netapp.com/advisory/ntap-20211004-0005/">https://security.netapp.com/advisory/ntap-20211004-0005/</a><br></details>  |
| libtinfo5         |    CVE-2019-17594   |   LOW  |  6.1-1ubuntu1.18.04 |  | <details><summary>Expand...</summary><a href="http://lists.opensuse.org/opensuse-security-announce/2019-11/msg00059.html">http://lists.opensuse.org/opensuse-security-announce/2019-11/msg00059.html</a><br><a href="http://lists.opensuse.org/opensuse-security-announce/2019-11/msg00061.html">http://lists.opensuse.org/opensuse-security-announce/2019-11/msg00061.html</a><br><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2019-17594">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2019-17594</a><br><a href="https://linux.oracle.com/cve/CVE-2019-17594.html">https://linux.oracle.com/cve/CVE-2019-17594.html</a><br><a href="https://linux.oracle.com/errata/ELSA-2021-4426.html">https://linux.oracle.com/errata/ELSA-2021-4426.html</a><br><a href="https://lists.gnu.org/archive/html/bug-ncurses/2019-10/msg00017.html">https://lists.gnu.org/archive/html/bug-ncurses/2019-10/msg00017.html</a><br><a href="https://lists.gnu.org/archive/html/bug-ncurses/2019-10/msg00045.html">https://lists.gnu.org/archive/html/bug-ncurses/2019-10/msg00045.html</a><br><a href="https://security.gentoo.org/glsa/202101-28">https://security.gentoo.org/glsa/202101-28</a><br></details>  |
| libtinfo5         |    CVE-2019-17595   |   LOW  |  6.1-1ubuntu1.18.04 |  | <details><summary>Expand...</summary><a href="http://lists.opensuse.org/opensuse-security-announce/2019-11/msg00059.html">http://lists.opensuse.org/opensuse-security-announce/2019-11/msg00059.html</a><br><a href="http://lists.opensuse.org/opensuse-security-announce/2019-11/msg00061.html">http://lists.opensuse.org/opensuse-security-announce/2019-11/msg00061.html</a><br><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2019-17595">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2019-17595</a><br><a href="https://linux.oracle.com/cve/CVE-2019-17595.html">https://linux.oracle.com/cve/CVE-2019-17595.html</a><br><a href="https://linux.oracle.com/errata/ELSA-2021-4426.html">https://linux.oracle.com/errata/ELSA-2021-4426.html</a><br><a href="https://lists.gnu.org/archive/html/bug-ncurses/2019-10/msg00013.html">https://lists.gnu.org/archive/html/bug-ncurses/2019-10/msg00013.html</a><br><a href="https://lists.gnu.org/archive/html/bug-ncurses/2019-10/msg00045.html">https://lists.gnu.org/archive/html/bug-ncurses/2019-10/msg00045.html</a><br><a href="https://security.gentoo.org/glsa/202101-28">https://security.gentoo.org/glsa/202101-28</a><br></details>  |
| libtsan0         |    CVE-2020-13844   |   MEDIUM  |  8.4.0-1ubuntu1~18.04 |  | <details><summary>Expand...</summary><a href="http://lists.llvm.org/pipermail/llvm-dev/2020-June/142109.html">http://lists.llvm.org/pipermail/llvm-dev/2020-June/142109.html</a><br><a href="http://lists.opensuse.org/opensuse-security-announce/2020-10/msg00039.html">http://lists.opensuse.org/opensuse-security-announce/2020-10/msg00039.html</a><br><a href="http://lists.opensuse.org/opensuse-security-announce/2020-10/msg00040.html">http://lists.opensuse.org/opensuse-security-announce/2020-10/msg00040.html</a><br><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2020-13844">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2020-13844</a><br><a href="https://developer.arm.com/support/arm-security-updates/speculative-processor-vulnerability">https://developer.arm.com/support/arm-security-updates/speculative-processor-vulnerability</a><br><a href="https://developer.arm.com/support/arm-security-updates/speculative-processor-vulnerability/downloads/straight-line-speculation">https://developer.arm.com/support/arm-security-updates/speculative-processor-vulnerability/downloads/straight-line-speculation</a><br><a href="https://developer.arm.com/support/arm-security-updates/speculative-processor-vulnerability/frequently-asked-questions">https://developer.arm.com/support/arm-security-updates/speculative-processor-vulnerability/frequently-asked-questions</a><br><a href="https://gcc.gnu.org/pipermail/gcc-patches/2020-June/547520.html">https://gcc.gnu.org/pipermail/gcc-patches/2020-June/547520.html</a><br><a href="https://git.kernel.org/pub/scm/linux/kernel/git/torvalds/linux.git/commit/?id=679db70801da9fda91d26caf13bf5b5ccc74e8e8">https://git.kernel.org/pub/scm/linux/kernel/git/torvalds/linux.git/commit/?id=679db70801da9fda91d26caf13bf5b5ccc74e8e8</a><br></details>  |
| libubsan0         |    CVE-2020-13844   |   MEDIUM  |  7.5.0-3ubuntu1~18.04 |  | <details><summary>Expand...</summary><a href="http://lists.llvm.org/pipermail/llvm-dev/2020-June/142109.html">http://lists.llvm.org/pipermail/llvm-dev/2020-June/142109.html</a><br><a href="http://lists.opensuse.org/opensuse-security-announce/2020-10/msg00039.html">http://lists.opensuse.org/opensuse-security-announce/2020-10/msg00039.html</a><br><a href="http://lists.opensuse.org/opensuse-security-announce/2020-10/msg00040.html">http://lists.opensuse.org/opensuse-security-announce/2020-10/msg00040.html</a><br><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2020-13844">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2020-13844</a><br><a href="https://developer.arm.com/support/arm-security-updates/speculative-processor-vulnerability">https://developer.arm.com/support/arm-security-updates/speculative-processor-vulnerability</a><br><a href="https://developer.arm.com/support/arm-security-updates/speculative-processor-vulnerability/downloads/straight-line-speculation">https://developer.arm.com/support/arm-security-updates/speculative-processor-vulnerability/downloads/straight-line-speculation</a><br><a href="https://developer.arm.com/support/arm-security-updates/speculative-processor-vulnerability/frequently-asked-questions">https://developer.arm.com/support/arm-security-updates/speculative-processor-vulnerability/frequently-asked-questions</a><br><a href="https://gcc.gnu.org/pipermail/gcc-patches/2020-June/547520.html">https://gcc.gnu.org/pipermail/gcc-patches/2020-June/547520.html</a><br><a href="https://git.kernel.org/pub/scm/linux/kernel/git/torvalds/linux.git/commit/?id=679db70801da9fda91d26caf13bf5b5ccc74e8e8">https://git.kernel.org/pub/scm/linux/kernel/git/torvalds/linux.git/commit/?id=679db70801da9fda91d26caf13bf5b5ccc74e8e8</a><br></details>  |
| libwind0-heimdal         |    CVE-2019-12098   |   LOW  |  7.5.0+dfsg-1 |  | <details><summary>Expand...</summary><a href="http://lists.opensuse.org/opensuse-security-announce/2019-07/msg00002.html">http://lists.opensuse.org/opensuse-security-announce/2019-07/msg00002.html</a><br><a href="http://lists.opensuse.org/opensuse-security-announce/2019-07/msg00003.html">http://lists.opensuse.org/opensuse-security-announce/2019-07/msg00003.html</a><br><a href="http://lists.opensuse.org/opensuse-security-announce/2019-08/msg00026.html">http://lists.opensuse.org/opensuse-security-announce/2019-08/msg00026.html</a><br><a href="http://www.h5l.org/pipermail/heimdal-announce/2019-May/000009.html">http://www.h5l.org/pipermail/heimdal-announce/2019-May/000009.html</a><br><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2019-12098">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2019-12098</a><br><a href="https://github.com/heimdal/heimdal/commit/2f7f3d9960aa6ea21358bdf3687cee5149aa35cf">https://github.com/heimdal/heimdal/commit/2f7f3d9960aa6ea21358bdf3687cee5149aa35cf</a><br><a href="https://github.com/heimdal/heimdal/compare/3e58559...bbafe72">https://github.com/heimdal/heimdal/compare/3e58559...bbafe72</a><br><a href="https://github.com/heimdal/heimdal/releases/tag/heimdal-7.6.0">https://github.com/heimdal/heimdal/releases/tag/heimdal-7.6.0</a><br><a href="https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/GIXEDVVMPD6ZAJSMI2EZ7FNEIVNWE5PD/">https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/GIXEDVVMPD6ZAJSMI2EZ7FNEIVNWE5PD/</a><br><a href="https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/SLXXIF4LOQEAEDAF4UGP2AO6WDNTDFUB/">https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/SLXXIF4LOQEAEDAF4UGP2AO6WDNTDFUB/</a><br><a href="https://seclists.org/bugtraq/2019/Jun/1">https://seclists.org/bugtraq/2019/Jun/1</a><br><a href="https://www.debian.org/security/2019/dsa-4455">https://www.debian.org/security/2019/dsa-4455</a><br></details>  |
| libwind0-heimdal         |    CVE-2021-3671   |   LOW  |  7.5.0+dfsg-1 |  | <details><summary>Expand...</summary><a href="https://bugzilla.redhat.com/show_bug.cgi?id=2013080,">https://bugzilla.redhat.com/show_bug.cgi?id=2013080,</a><br><a href="https://bugzilla.samba.org/show_bug.cgi?id=14770,">https://bugzilla.samba.org/show_bug.cgi?id=14770,</a><br><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2021-3671">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2021-3671</a><br><a href="https://github.com/heimdal/heimdal/commit/04171147948d0a3636bc6374181926f0fb2ec83a">https://github.com/heimdal/heimdal/commit/04171147948d0a3636bc6374181926f0fb2ec83a</a><br><a href="https://ubuntu.com/security/notices/USN-5142-1">https://ubuntu.com/security/notices/USN-5142-1</a><br><a href="https://ubuntu.com/security/notices/USN-5174-1">https://ubuntu.com/security/notices/USN-5174-1</a><br></details>  |
| linux-libc-dev         |    CVE-2013-7445   |   MEDIUM  |  4.15.0-163.171 |  | <details><summary>Expand...</summary><a href="https://bugzilla.kernel.org/show_bug.cgi?id=60533">https://bugzilla.kernel.org/show_bug.cgi?id=60533</a><br><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2013-7445">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2013-7445</a><br><a href="https://lists.freedesktop.org/archives/dri-devel/2015-September/089778.html (potential start towards fixing)">https://lists.freedesktop.org/archives/dri-devel/2015-September/089778.html (potential start towards fixing)</a><br></details>  |
| linux-libc-dev         |    CVE-2015-8553   |   MEDIUM  |  4.15.0-163.171 |  | <details><summary>Expand...</summary><a href="http://thread.gmane.org/gmane.linux.kernel/1924087/focus=1930758 (regression mention)">http://thread.gmane.org/gmane.linux.kernel/1924087/focus=1930758 (regression mention)</a><br><a href="http://xenbits.xen.org/xsa/advisory-120.html">http://xenbits.xen.org/xsa/advisory-120.html</a><br><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2015-8553">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2015-8553</a><br><a href="https://seclists.org/bugtraq/2019/Aug/18">https://seclists.org/bugtraq/2019/Aug/18</a><br><a href="https://www.debian.org/security/2019/dsa-4497">https://www.debian.org/security/2019/dsa-4497</a><br></details>  |
| linux-libc-dev         |    CVE-2016-8660   |   MEDIUM  |  4.15.0-163.171 |  | <details><summary>Expand...</summary><a href="http://www.openwall.com/lists/oss-security/2016/10/13/8">http://www.openwall.com/lists/oss-security/2016/10/13/8</a><br><a href="http://www.securityfocus.com/bid/93558">http://www.securityfocus.com/bid/93558</a><br><a href="https://bugzilla.redhat.com/show_bug.cgi?id=1384851">https://bugzilla.redhat.com/show_bug.cgi?id=1384851</a><br><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2016-8660">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2016-8660</a><br><a href="https://lore.kernel.org/linux-xfs/895314622.769515.1476375930648.JavaMail.zimbra@redhat.com/">https://lore.kernel.org/linux-xfs/895314622.769515.1476375930648.JavaMail.zimbra@redhat.com/</a><br><a href="https://marc.info/?l=linux-fsdevel&amp;m=147639177409294&amp;w=2">https://marc.info/?l=linux-fsdevel&amp;m=147639177409294&amp;w=2</a><br><a href="https://marc.info/?l=linux-xfs&amp;m=149498118228320&amp;w=2">https://marc.info/?l=linux-xfs&amp;m=149498118228320&amp;w=2</a><br></details>  |
| linux-libc-dev         |    CVE-2018-17977   |   MEDIUM  |  4.15.0-163.171 |  | <details><summary>Expand...</summary><a href="http://www.securityfocus.com/bid/105539">http://www.securityfocus.com/bid/105539</a><br><a href="https://bugzilla.suse.com/show_bug.cgi?id=1111609">https://bugzilla.suse.com/show_bug.cgi?id=1111609</a><br><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2018-17977">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2018-17977</a><br><a href="https://www.openwall.com/lists/oss-security/2018/10/05/5">https://www.openwall.com/lists/oss-security/2018/10/05/5</a><br></details>  |
| linux-libc-dev         |    CVE-2020-12363   |   MEDIUM  |  4.15.0-163.171 |  | <details><summary>Expand...</summary><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2020-12363">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2020-12363</a><br><a href="https://linux.oracle.com/cve/CVE-2020-12363.html">https://linux.oracle.com/cve/CVE-2020-12363.html</a><br><a href="https://linux.oracle.com/errata/ELSA-2021-2314.html">https://linux.oracle.com/errata/ELSA-2021-2314.html</a><br><a href="https://www.intel.com/content/www/us/en/security-center/advisory/intel-sa-00438.html">https://www.intel.com/content/www/us/en/security-center/advisory/intel-sa-00438.html</a><br></details>  |
| linux-libc-dev         |    CVE-2020-12364   |   MEDIUM  |  4.15.0-163.171 |  | <details><summary>Expand...</summary><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2020-12364">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2020-12364</a><br><a href="https://linux.oracle.com/cve/CVE-2020-12364.html">https://linux.oracle.com/cve/CVE-2020-12364.html</a><br><a href="https://linux.oracle.com/errata/ELSA-2021-2314.html">https://linux.oracle.com/errata/ELSA-2021-2314.html</a><br><a href="https://www.intel.com/content/www/us/en/security-center/advisory/intel-sa-00438.html">https://www.intel.com/content/www/us/en/security-center/advisory/intel-sa-00438.html</a><br></details>  |
| linux-libc-dev         |    CVE-2020-26141   |   MEDIUM  |  4.15.0-163.171 |  | <details><summary>Expand...</summary><a href="http://www.openwall.com/lists/oss-security/2021/05/11/12">http://www.openwall.com/lists/oss-security/2021/05/11/12</a><br><a href="https://cert-portal.siemens.com/productcert/pdf/ssa-913875.pdf">https://cert-portal.siemens.com/productcert/pdf/ssa-913875.pdf</a><br><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2020-26141">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2020-26141</a><br><a href="https://github.com/vanhoefm/fragattacks/blob/master/SUMMARY.md">https://github.com/vanhoefm/fragattacks/blob/master/SUMMARY.md</a><br><a href="https://linux.oracle.com/cve/CVE-2020-26141.html">https://linux.oracle.com/cve/CVE-2020-26141.html</a><br><a href="https://linux.oracle.com/errata/ELSA-2021-9459.html">https://linux.oracle.com/errata/ELSA-2021-9459.html</a><br><a href="https://lore.kernel.org/linux-wireless/20210511200110.c3f1d42c6746.I795593fcaae941c471425b8c7d5f7bb185d29142@changeid/">https://lore.kernel.org/linux-wireless/20210511200110.c3f1d42c6746.I795593fcaae941c471425b8c7d5f7bb185d29142@changeid/</a><br><a href="https://papers.mathyvanhoef.com/usenix2021.pdf">https://papers.mathyvanhoef.com/usenix2021.pdf</a><br><a href="https://tools.cisco.com/security/center/content/CiscoSecurityAdvisory/cisco-sa-wifi-faf-22epcEWu">https://tools.cisco.com/security/center/content/CiscoSecurityAdvisory/cisco-sa-wifi-faf-22epcEWu</a><br><a href="https://ubuntu.com/security/notices/USN-4997-1">https://ubuntu.com/security/notices/USN-4997-1</a><br><a href="https://ubuntu.com/security/notices/USN-4997-2">https://ubuntu.com/security/notices/USN-4997-2</a><br><a href="https://ubuntu.com/security/notices/USN-4999-1">https://ubuntu.com/security/notices/USN-4999-1</a><br><a href="https://ubuntu.com/security/notices/USN-5000-1">https://ubuntu.com/security/notices/USN-5000-1</a><br><a href="https://ubuntu.com/security/notices/USN-5000-2">https://ubuntu.com/security/notices/USN-5000-2</a><br><a href="https://ubuntu.com/security/notices/USN-5001-1">https://ubuntu.com/security/notices/USN-5001-1</a><br><a href="https://www.arista.com/en/support/advisories-notices/security-advisories/12602-security-advisory-63">https://www.arista.com/en/support/advisories-notices/security-advisories/12602-security-advisory-63</a><br><a href="https://www.fragattacks.com">https://www.fragattacks.com</a><br></details>  |
| linux-libc-dev         |    CVE-2020-26145   |   MEDIUM  |  4.15.0-163.171 |  | <details><summary>Expand...</summary><a href="http://www.openwall.com/lists/oss-security/2021/05/11/12">http://www.openwall.com/lists/oss-security/2021/05/11/12</a><br><a href="https://cert-portal.siemens.com/productcert/pdf/ssa-913875.pdf">https://cert-portal.siemens.com/productcert/pdf/ssa-913875.pdf</a><br><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2020-26145">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2020-26145</a><br><a href="https://github.com/vanhoefm/fragattacks/blob/master/SUMMARY.md">https://github.com/vanhoefm/fragattacks/blob/master/SUMMARY.md</a><br><a href="https://linux.oracle.com/cve/CVE-2020-26145.html">https://linux.oracle.com/cve/CVE-2020-26145.html</a><br><a href="https://linux.oracle.com/errata/ELSA-2021-9459.html">https://linux.oracle.com/errata/ELSA-2021-9459.html</a><br><a href="https://lore.kernel.org/linux-wireless/20210511200110.9ca6ca7945a9.I1e18b514590af17c155bda86699bc3a971a8dcf4@changeid/">https://lore.kernel.org/linux-wireless/20210511200110.9ca6ca7945a9.I1e18b514590af17c155bda86699bc3a971a8dcf4@changeid/</a><br><a href="https://papers.mathyvanhoef.com/usenix2021.pdf">https://papers.mathyvanhoef.com/usenix2021.pdf</a><br><a href="https://ubuntu.com/security/notices/USN-4997-1">https://ubuntu.com/security/notices/USN-4997-1</a><br><a href="https://ubuntu.com/security/notices/USN-4997-2">https://ubuntu.com/security/notices/USN-4997-2</a><br><a href="https://ubuntu.com/security/notices/USN-4999-1">https://ubuntu.com/security/notices/USN-4999-1</a><br><a href="https://ubuntu.com/security/notices/USN-5000-1">https://ubuntu.com/security/notices/USN-5000-1</a><br><a href="https://ubuntu.com/security/notices/USN-5000-2">https://ubuntu.com/security/notices/USN-5000-2</a><br><a href="https://ubuntu.com/security/notices/USN-5001-1">https://ubuntu.com/security/notices/USN-5001-1</a><br><a href="https://www.fragattacks.com">https://www.fragattacks.com</a><br></details>  |
| linux-libc-dev         |    CVE-2020-26541   |   MEDIUM  |  4.15.0-163.171 |  | <details><summary>Expand...</summary><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2020-26541">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2020-26541</a><br><a href="https://linux.oracle.com/cve/CVE-2020-26541.html">https://linux.oracle.com/cve/CVE-2020-26541.html</a><br><a href="https://linux.oracle.com/errata/ELSA-2021-2570.html">https://linux.oracle.com/errata/ELSA-2021-2570.html</a><br><a href="https://lkml.org/lkml/2020/9/15/1871">https://lkml.org/lkml/2020/9/15/1871</a><br><a href="https://lore.kernel.org/lkml/161428671215.677100.6372209948022011988.stgit@warthog.procyon.org.uk/">https://lore.kernel.org/lkml/161428671215.677100.6372209948022011988.stgit@warthog.procyon.org.uk/</a><br><a href="https://lore.kernel.org/lkml/1884195.1615482306@warthog.procyon.org.uk/">https://lore.kernel.org/lkml/1884195.1615482306@warthog.procyon.org.uk/</a><br><a href="https://lore.kernel.org/lkml/20200916004927.64276-1-eric.snowberg@oracle.com/">https://lore.kernel.org/lkml/20200916004927.64276-1-eric.snowberg@oracle.com/</a><br><a href="https://lore.kernel.org/lkml/20210122181054.32635-1-eric.snowberg@oracle.com/">https://lore.kernel.org/lkml/20210122181054.32635-1-eric.snowberg@oracle.com/</a><br><a href="https://ubuntu.com/security/notices/USN-5070-1">https://ubuntu.com/security/notices/USN-5070-1</a><br><a href="https://ubuntu.com/security/notices/USN-5106-1">https://ubuntu.com/security/notices/USN-5106-1</a><br><a href="https://ubuntu.com/security/notices/USN-5120-1">https://ubuntu.com/security/notices/USN-5120-1</a><br></details>  |
| linux-libc-dev         |    CVE-2020-27835   |   MEDIUM  |  4.15.0-163.171 |  | <details><summary>Expand...</summary><a href="https://bugzilla.redhat.com/show_bug.cgi?id=1901709">https://bugzilla.redhat.com/show_bug.cgi?id=1901709</a><br><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2020-27835">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2020-27835</a><br><a href="https://git.kernel.org/linus/3d2a9d642512c21a12d19b9250e7a835dcb41a79">https://git.kernel.org/linus/3d2a9d642512c21a12d19b9250e7a835dcb41a79</a><br><a href="https://linux.oracle.com/cve/CVE-2020-27835.html">https://linux.oracle.com/cve/CVE-2020-27835.html</a><br><a href="https://linux.oracle.com/errata/ELSA-2021-1578.html">https://linux.oracle.com/errata/ELSA-2021-1578.html</a><br><a href="https://ubuntu.com/security/notices/USN-4751-1">https://ubuntu.com/security/notices/USN-4751-1</a><br></details>  |
| linux-libc-dev         |    CVE-2020-36310   |   MEDIUM  |  4.15.0-163.171 |  | <details><summary>Expand...</summary><a href="https://bugzilla.redhat.com/show_bug.cgi?id=1769283#c148">https://bugzilla.redhat.com/show_bug.cgi?id=1769283#c148</a><br><a href="https://cdn.kernel.org/pub/linux/kernel/v5.x/ChangeLog-5.8">https://cdn.kernel.org/pub/linux/kernel/v5.x/ChangeLog-5.8</a><br><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2020-36310">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2020-36310</a><br><a href="https://git.kernel.org/linus/e72436bc3a5206f95bb384e741154166ddb3202e">https://git.kernel.org/linus/e72436bc3a5206f95bb384e741154166ddb3202e</a><br><a href="https://git.kernel.org/pub/scm/linux/kernel/git/torvalds/linux.git/commit/?id=e72436bc3a5206f95bb384e741154166ddb3202e">https://git.kernel.org/pub/scm/linux/kernel/git/torvalds/linux.git/commit/?id=e72436bc3a5206f95bb384e741154166ddb3202e</a><br><a href="https://linux.oracle.com/cve/CVE-2020-36310.html">https://linux.oracle.com/cve/CVE-2020-36310.html</a><br><a href="https://linux.oracle.com/errata/ELSA-2021-9307.html">https://linux.oracle.com/errata/ELSA-2021-9307.html</a><br></details>  |
| linux-libc-dev         |    CVE-2021-26932   |   MEDIUM  |  4.15.0-163.171 |  | <details><summary>Expand...</summary><a href="http://xenbits.xen.org/xsa/advisory-361.html">http://xenbits.xen.org/xsa/advisory-361.html</a><br><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2021-26932">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2021-26932</a><br><a href="https://linux.oracle.com/cve/CVE-2021-26932.html">https://linux.oracle.com/cve/CVE-2021-26932.html</a><br><a href="https://linux.oracle.com/errata/ELSA-2021-9136.html">https://linux.oracle.com/errata/ELSA-2021-9136.html</a><br><a href="https://lists.debian.org/debian-lts-announce/2021/03/msg00010.html">https://lists.debian.org/debian-lts-announce/2021/03/msg00010.html</a><br><a href="https://lists.debian.org/debian-lts-announce/2021/03/msg00035.html">https://lists.debian.org/debian-lts-announce/2021/03/msg00035.html</a><br><a href="https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/2XQR52ICKRK3GC4HDWLMWF2U55YGAR63/">https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/2XQR52ICKRK3GC4HDWLMWF2U55YGAR63/</a><br><a href="https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/GWQWPWYZRXVFJI5M3VCM72X27IB7CKOB/">https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/GWQWPWYZRXVFJI5M3VCM72X27IB7CKOB/</a><br><a href="https://security.netapp.com/advisory/ntap-20210326-0001/">https://security.netapp.com/advisory/ntap-20210326-0001/</a><br><a href="https://www.openwall.com/lists/oss-security/2021/02/16/3">https://www.openwall.com/lists/oss-security/2021/02/16/3</a><br><a href="https://xenbits.xen.org/xsa/advisory-361.html">https://xenbits.xen.org/xsa/advisory-361.html</a><br></details>  |
| linux-libc-dev         |    CVE-2021-33624   |   MEDIUM  |  4.15.0-163.171 |  | <details><summary>Expand...</summary><a href="http://www.openwall.com/lists/oss-security/2021/06/21/1">http://www.openwall.com/lists/oss-security/2021/06/21/1</a><br><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2021-33624">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2021-33624</a><br><a href="https://git.kernel.org/pub/scm/linux/kernel/git/torvalds/linux.git/patch/?id=9183671af6dbf60a1219371d4ed73e23f43b49db">https://git.kernel.org/pub/scm/linux/kernel/git/torvalds/linux.git/patch/?id=9183671af6dbf60a1219371d4ed73e23f43b49db</a><br><a href="https://git.kernel.org/pub/scm/linux/kernel/git/torvalds/linux.git/patch/?id=973377ffe8148180b2651825b92ae91988141b05">https://git.kernel.org/pub/scm/linux/kernel/git/torvalds/linux.git/patch/?id=973377ffe8148180b2651825b92ae91988141b05</a><br><a href="https://git.kernel.org/pub/scm/linux/kernel/git/torvalds/linux.git/patch/?id=d203b0fd863a2261e5d00b97f3d060c4c2a6db71">https://git.kernel.org/pub/scm/linux/kernel/git/torvalds/linux.git/patch/?id=d203b0fd863a2261e5d00b97f3d060c4c2a6db71</a><br><a href="https://git.kernel.org/pub/scm/linux/kernel/git/torvalds/linux.git/patch/?id=fe9a5ca7e370e613a9a75a13008a3845ea759d6e">https://git.kernel.org/pub/scm/linux/kernel/git/torvalds/linux.git/patch/?id=fe9a5ca7e370e613a9a75a13008a3845ea759d6e</a><br><a href="https://github.com/torvalds/linux/commit/9183671af6dbf60a1219371d4ed73e23f43b49db">https://github.com/torvalds/linux/commit/9183671af6dbf60a1219371d4ed73e23f43b49db</a><br><a href="https://lists.debian.org/debian-lts-announce/2021/10/msg00010.html">https://lists.debian.org/debian-lts-announce/2021/10/msg00010.html</a><br><a href="https://ubuntu.com/security/notices/USN-5091-1">https://ubuntu.com/security/notices/USN-5091-1</a><br><a href="https://ubuntu.com/security/notices/USN-5091-2">https://ubuntu.com/security/notices/USN-5091-2</a><br><a href="https://ubuntu.com/security/notices/USN-5092-1">https://ubuntu.com/security/notices/USN-5092-1</a><br><a href="https://ubuntu.com/security/notices/USN-5092-2">https://ubuntu.com/security/notices/USN-5092-2</a><br><a href="https://ubuntu.com/security/notices/USN-5115-1">https://ubuntu.com/security/notices/USN-5115-1</a><br><a href="https://www.openwall.com/lists/oss-security/2021/06/21/1">https://www.openwall.com/lists/oss-security/2021/06/21/1</a><br><a href="https://www.usenix.org/conference/usenixsecurity21/presentation/kirzner">https://www.usenix.org/conference/usenixsecurity21/presentation/kirzner</a><br></details>  |
| linux-libc-dev         |    CVE-2021-34556   |   MEDIUM  |  4.15.0-163.171 |  | <details><summary>Expand...</summary><a href="http://www.openwall.com/lists/oss-security/2021/08/01/3">http://www.openwall.com/lists/oss-security/2021/08/01/3</a><br><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2021-34556">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2021-34556</a><br><a href="https://git.kernel.org/pub/scm/linux/kernel/git/torvalds/linux.git/patch/?id=2039f26f3aca5b0e419b98f65dd36481337b86ee">https://git.kernel.org/pub/scm/linux/kernel/git/torvalds/linux.git/patch/?id=2039f26f3aca5b0e419b98f65dd36481337b86ee</a><br><a href="https://git.kernel.org/pub/scm/linux/kernel/git/torvalds/linux.git/patch/?id=f5e81d1117501546b7be050c5fbafa6efd2c722c">https://git.kernel.org/pub/scm/linux/kernel/git/torvalds/linux.git/patch/?id=f5e81d1117501546b7be050c5fbafa6efd2c722c</a><br><a href="https://lists.debian.org/debian-lts-announce/2021/10/msg00010.html">https://lists.debian.org/debian-lts-announce/2021/10/msg00010.html</a><br><a href="https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/565ZS55ZFEN62WVRRORT7R63RXW5F4T4/">https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/565ZS55ZFEN62WVRRORT7R63RXW5F4T4/</a><br><a href="https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/6JKK6XNRZX5BT5QVYOKGVJ2BHFZAP5EX/">https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/6JKK6XNRZX5BT5QVYOKGVJ2BHFZAP5EX/</a><br><a href="https://ubuntu.com/security/notices/USN-5092-1">https://ubuntu.com/security/notices/USN-5092-1</a><br><a href="https://ubuntu.com/security/notices/USN-5092-2">https://ubuntu.com/security/notices/USN-5092-2</a><br><a href="https://ubuntu.com/security/notices/USN-5096-1">https://ubuntu.com/security/notices/USN-5096-1</a><br><a href="https://ubuntu.com/security/notices/USN-5115-1">https://ubuntu.com/security/notices/USN-5115-1</a><br><a href="https://ubuntu.com/security/notices/USN-5137-1">https://ubuntu.com/security/notices/USN-5137-1</a><br><a href="https://ubuntu.com/security/notices/USN-5137-2">https://ubuntu.com/security/notices/USN-5137-2</a><br><a href="https://www.openwall.com/lists/oss-security/2021/08/01/3">https://www.openwall.com/lists/oss-security/2021/08/01/3</a><br></details>  |
| linux-libc-dev         |    CVE-2021-3506   |   MEDIUM  |  4.15.0-163.171 |  | <details><summary>Expand...</summary><a href="http://www.openwall.com/lists/oss-security/2021/05/08/1">http://www.openwall.com/lists/oss-security/2021/05/08/1</a><br><a href="https://bugzilla.redhat.com/show_bug.cgi?id=1944298">https://bugzilla.redhat.com/show_bug.cgi?id=1944298</a><br><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2021-3506">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2021-3506</a><br><a href="https://lists.debian.org/debian-lts-announce/2021/06/msg00019.html">https://lists.debian.org/debian-lts-announce/2021/06/msg00019.html</a><br><a href="https://lore.kernel.org/lkml/20210322114730.71103-1-yuchao0@huawei.com/">https://lore.kernel.org/lkml/20210322114730.71103-1-yuchao0@huawei.com/</a><br><a href="https://security.netapp.com/advisory/ntap-20210611-0007/">https://security.netapp.com/advisory/ntap-20210611-0007/</a><br><a href="https://ubuntu.com/security/notices/USN-4997-1">https://ubuntu.com/security/notices/USN-4997-1</a><br><a href="https://ubuntu.com/security/notices/USN-4997-2">https://ubuntu.com/security/notices/USN-4997-2</a><br><a href="https://ubuntu.com/security/notices/USN-5000-1">https://ubuntu.com/security/notices/USN-5000-1</a><br><a href="https://ubuntu.com/security/notices/USN-5000-2">https://ubuntu.com/security/notices/USN-5000-2</a><br><a href="https://ubuntu.com/security/notices/USN-5001-1">https://ubuntu.com/security/notices/USN-5001-1</a><br><a href="https://ubuntu.com/security/notices/USN-5016-1">https://ubuntu.com/security/notices/USN-5016-1</a><br><a href="https://www.mail-archive.com/linux-kernel@vger.kernel.org/msg2520013.html">https://www.mail-archive.com/linux-kernel@vger.kernel.org/msg2520013.html</a><br><a href="https://www.openwall.com/lists/oss-security/2021/03/28/2">https://www.openwall.com/lists/oss-security/2021/03/28/2</a><br></details>  |
| linux-libc-dev         |    CVE-2021-35477   |   MEDIUM  |  4.15.0-163.171 |  | <details><summary>Expand...</summary><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2021-35477">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2021-35477</a><br><a href="https://git.kernel.org/pub/scm/linux/kernel/git/torvalds/linux.git/patch/?id=2039f26f3aca5b0e419b98f65dd36481337b86ee">https://git.kernel.org/pub/scm/linux/kernel/git/torvalds/linux.git/patch/?id=2039f26f3aca5b0e419b98f65dd36481337b86ee</a><br><a href="https://git.kernel.org/pub/scm/linux/kernel/git/torvalds/linux.git/patch/?id=f5e81d1117501546b7be050c5fbafa6efd2c722c">https://git.kernel.org/pub/scm/linux/kernel/git/torvalds/linux.git/patch/?id=f5e81d1117501546b7be050c5fbafa6efd2c722c</a><br><a href="https://lists.debian.org/debian-lts-announce/2021/10/msg00010.html">https://lists.debian.org/debian-lts-announce/2021/10/msg00010.html</a><br><a href="https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/565ZS55ZFEN62WVRRORT7R63RXW5F4T4/">https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/565ZS55ZFEN62WVRRORT7R63RXW5F4T4/</a><br><a href="https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/6JKK6XNRZX5BT5QVYOKGVJ2BHFZAP5EX/">https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/6JKK6XNRZX5BT5QVYOKGVJ2BHFZAP5EX/</a><br><a href="https://ubuntu.com/security/notices/USN-5092-1">https://ubuntu.com/security/notices/USN-5092-1</a><br><a href="https://ubuntu.com/security/notices/USN-5092-2">https://ubuntu.com/security/notices/USN-5092-2</a><br><a href="https://ubuntu.com/security/notices/USN-5096-1">https://ubuntu.com/security/notices/USN-5096-1</a><br><a href="https://ubuntu.com/security/notices/USN-5115-1">https://ubuntu.com/security/notices/USN-5115-1</a><br><a href="https://ubuntu.com/security/notices/USN-5137-1">https://ubuntu.com/security/notices/USN-5137-1</a><br><a href="https://ubuntu.com/security/notices/USN-5137-2">https://ubuntu.com/security/notices/USN-5137-2</a><br><a href="https://www.openwall.com/lists/oss-security/2021/08/01/3">https://www.openwall.com/lists/oss-security/2021/08/01/3</a><br></details>  |
| linux-libc-dev         |    CVE-2021-39685   |   MEDIUM  |  4.15.0-163.171 |  | <details><summary>Expand...</summary><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2021-39685">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2021-39685</a><br><a href="https://github.com/szymonh/inspector-gadget">https://github.com/szymonh/inspector-gadget</a><br><a href="https://www.openwall.com/lists/oss-security/2021/12/15/4">https://www.openwall.com/lists/oss-security/2021/12/15/4</a><br></details>  |
| linux-libc-dev         |    CVE-2021-4083   |   MEDIUM  |  4.15.0-163.171 |  | <details><summary>Expand...</summary><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2021-4083">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2021-4083</a><br><a href="https://git.kernel.org/linus/054aa8d439b9185d4f5eb9a90282d1ce74772969 (5.16-rc4)">https://git.kernel.org/linus/054aa8d439b9185d4f5eb9a90282d1ce74772969 (5.16-rc4)</a><br><a href="https://git.kernel.org/pub/scm/linux/kernel/git/torvalds/linux.git/commit/?id=054aa8d439b9">https://git.kernel.org/pub/scm/linux/kernel/git/torvalds/linux.git/commit/?id=054aa8d439b9</a><br></details>  |
| linux-libc-dev         |    CVE-2021-43975   |   MEDIUM  |  4.15.0-163.171 |  | <details><summary>Expand...</summary><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2021-43975">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2021-43975</a><br><a href="https://git.kernel.org/pub/scm/linux/kernel/git/netdev/net.git/commit/?id=b922f622592af76b57cbc566eaeccda0b31a3496">https://git.kernel.org/pub/scm/linux/kernel/git/netdev/net.git/commit/?id=b922f622592af76b57cbc566eaeccda0b31a3496</a><br><a href="https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/X24M7KDC4OJOZNS3RDSYC7ELNELOLQ2N/">https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/X24M7KDC4OJOZNS3RDSYC7ELNELOLQ2N/</a><br><a href="https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/YODMYMGZYDXQKGJGX7TJG4XV4L5YLLBD/">https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/YODMYMGZYDXQKGJGX7TJG4XV4L5YLLBD/</a><br><a href="https://lore.kernel.org/netdev/163698540868.13805.17800408021782408762.git-patchwork-notify@kernel.org/T/">https://lore.kernel.org/netdev/163698540868.13805.17800408021782408762.git-patchwork-notify@kernel.org/T/</a><br><a href="https://security.netapp.com/advisory/ntap-20211210-0001/">https://security.netapp.com/advisory/ntap-20211210-0001/</a><br></details>  |
| linux-libc-dev         |    CVE-2016-10723   |   LOW  |  4.15.0-163.171 |  | <details><summary>Expand...</summary><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2016-10723">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2016-10723</a><br><a href="https://lore.kernel.org/lkml/195a512f-aecc-f8cf-f409-6c42ee924a8c@i-love.sakura.ne.jp/">https://lore.kernel.org/lkml/195a512f-aecc-f8cf-f409-6c42ee924a8c@i-love.sakura.ne.jp/</a><br><a href="https://lore.kernel.org/lkml/cb2d635c-c14d-c2cc-868a-d4c447364f0d@i-love.sakura.ne.jp/">https://lore.kernel.org/lkml/cb2d635c-c14d-c2cc-868a-d4c447364f0d@i-love.sakura.ne.jp/</a><br><a href="https://patchwork.kernel.org/patch/10395909/">https://patchwork.kernel.org/patch/10395909/</a><br><a href="https://patchwork.kernel.org/patch/9842889/">https://patchwork.kernel.org/patch/9842889/</a><br><a href="https://www.spinics.net/lists/linux-mm/msg117896.html">https://www.spinics.net/lists/linux-mm/msg117896.html</a><br></details>  |
| linux-libc-dev         |    CVE-2017-0537   |   LOW  |  4.15.0-163.171 |  | <details><summary>Expand...</summary><a href="http://www.securityfocus.com/bid/96831">http://www.securityfocus.com/bid/96831</a><br><a href="http://www.securitytracker.com/id/1037968">http://www.securitytracker.com/id/1037968</a><br><a href="https://android.googlesource.com/kernel/tegra.git/+/389b185cb2f17fff994dbdf8d4bac003d4b2b6b3%5E%21/#F0">https://android.googlesource.com/kernel/tegra.git/+/389b185cb2f17fff994dbdf8d4bac003d4b2b6b3%5E%21/#F0</a><br><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2017-0537">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2017-0537</a><br><a href="https://lore.kernel.org/lkml/1484647168-30135-1-git-send-email-jilin@nvidia.com/#t">https://lore.kernel.org/lkml/1484647168-30135-1-git-send-email-jilin@nvidia.com/#t</a><br><a href="https://source.android.com/security/bulletin/2017-01-01.html">https://source.android.com/security/bulletin/2017-01-01.html</a><br><a href="https://source.android.com/security/bulletin/2017-03-01">https://source.android.com/security/bulletin/2017-03-01</a><br><a href="https://source.android.com/security/bulletin/2017-03-01.html">https://source.android.com/security/bulletin/2017-03-01.html</a><br></details>  |
| linux-libc-dev         |    CVE-2017-13165   |   LOW  |  4.15.0-163.171 |  | <details><summary>Expand...</summary><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2017-13165">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2017-13165</a><br><a href="https://github.com/aosp-mirror/platform_system_core/commit/15ffc53f6d57a46e3041453865311035a18e047a">https://github.com/aosp-mirror/platform_system_core/commit/15ffc53f6d57a46e3041453865311035a18e047a</a><br><a href="https://source.android.com/security/bulletin/pixel/2017-12-01">https://source.android.com/security/bulletin/pixel/2017-12-01</a><br></details>  |
| linux-libc-dev         |    CVE-2017-13693   |   LOW  |  4.15.0-163.171 |  | <details><summary>Expand...</summary><a href="http://www.securityfocus.com/bid/100502">http://www.securityfocus.com/bid/100502</a><br><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2017-13693">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2017-13693</a><br><a href="https://github.com/acpica/acpica/pull/295/commits/987a3b5cf7175916e2a4b6ea5b8e70f830dfe732">https://github.com/acpica/acpica/pull/295/commits/987a3b5cf7175916e2a4b6ea5b8e70f830dfe732</a><br><a href="https://patchwork.kernel.org/patch/9919053/">https://patchwork.kernel.org/patch/9919053/</a><br></details>  |
| linux-libc-dev         |    CVE-2018-1121   |   LOW  |  4.15.0-163.171 |  | <details><summary>Expand...</summary><a href="http://seclists.org/oss-sec/2018/q2/122">http://seclists.org/oss-sec/2018/q2/122</a><br><a href="http://www.securityfocus.com/bid/104214">http://www.securityfocus.com/bid/104214</a><br><a href="https://bugzilla.redhat.com/show_bug.cgi?id=CVE-2018-1121">https://bugzilla.redhat.com/show_bug.cgi?id=CVE-2018-1121</a><br><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2018-1121">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2018-1121</a><br><a href="https://www.exploit-db.com/exploits/44806/">https://www.exploit-db.com/exploits/44806/</a><br><a href="https://www.qualys.com/2018/05/17/procps-ng-audit-report-advisory.txt">https://www.qualys.com/2018/05/17/procps-ng-audit-report-advisory.txt</a><br></details>  |
| linux-libc-dev         |    CVE-2018-12928   |   LOW  |  4.15.0-163.171 |  | <details><summary>Expand...</summary><a href="http://www.securityfocus.com/bid/104593">http://www.securityfocus.com/bid/104593</a><br><a href="https://bugs.launchpad.net/ubuntu/+source/linux/+bug/1763384">https://bugs.launchpad.net/ubuntu/+source/linux/+bug/1763384</a><br><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2018-12928">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2018-12928</a><br><a href="https://groups.google.com/forum/#!msg/syzkaller-bugs/9SgQk_6tSZ4/zLhTm4r1AwAJ">https://groups.google.com/forum/#!msg/syzkaller-bugs/9SgQk_6tSZ4/zLhTm4r1AwAJ</a><br><a href="https://lore.kernel.org/linux-fsdevel/20180418173028.GA30953@bombadil.infradead.org/">https://lore.kernel.org/linux-fsdevel/20180418173028.GA30953@bombadil.infradead.org/</a><br><a href="https://marc.info/?l=linux-fsdevel&amp;m=152407263325766&amp;w=2">https://marc.info/?l=linux-fsdevel&amp;m=152407263325766&amp;w=2</a><br></details>  |
| linux-libc-dev         |    CVE-2018-12929   |   LOW  |  4.15.0-163.171 |  | <details><summary>Expand...</summary><a href="http://www.securityfocus.com/bid/104588">http://www.securityfocus.com/bid/104588</a><br><a href="https://access.redhat.com/errata/RHSA-2019:0641">https://access.redhat.com/errata/RHSA-2019:0641</a><br><a href="https://bugs.launchpad.net/ubuntu/+source/linux/+bug/1763403">https://bugs.launchpad.net/ubuntu/+source/linux/+bug/1763403</a><br><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2018-12929">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2018-12929</a><br><a href="https://marc.info/?l=linux-ntfs-dev&amp;m=152413769810234&amp;w=2">https://marc.info/?l=linux-ntfs-dev&amp;m=152413769810234&amp;w=2</a><br></details>  |
| linux-libc-dev         |    CVE-2018-12930   |   LOW  |  4.15.0-163.171 |  | <details><summary>Expand...</summary><a href="http://www.securityfocus.com/bid/104588">http://www.securityfocus.com/bid/104588</a><br><a href="https://access.redhat.com/errata/RHSA-2019:0641">https://access.redhat.com/errata/RHSA-2019:0641</a><br><a href="https://bugs.launchpad.net/ubuntu/+source/linux/+bug/1763403">https://bugs.launchpad.net/ubuntu/+source/linux/+bug/1763403</a><br><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2018-12930">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2018-12930</a><br><a href="https://marc.info/?l=linux-ntfs-dev&amp;m=152413769810234&amp;w=2">https://marc.info/?l=linux-ntfs-dev&amp;m=152413769810234&amp;w=2</a><br></details>  |
| linux-libc-dev         |    CVE-2018-12931   |   LOW  |  4.15.0-163.171 |  | <details><summary>Expand...</summary><a href="http://www.securityfocus.com/bid/104588">http://www.securityfocus.com/bid/104588</a><br><a href="https://access.redhat.com/errata/RHSA-2019:0641">https://access.redhat.com/errata/RHSA-2019:0641</a><br><a href="https://bugs.launchpad.net/ubuntu/+source/linux/+bug/1763403">https://bugs.launchpad.net/ubuntu/+source/linux/+bug/1763403</a><br><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2018-12931">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2018-12931</a><br><a href="https://marc.info/?l=linux-ntfs-dev&amp;m=152413769810234&amp;w=2">https://marc.info/?l=linux-ntfs-dev&amp;m=152413769810234&amp;w=2</a><br></details>  |
| linux-libc-dev         |    CVE-2019-14899   |   LOW  |  4.15.0-163.171 |  | <details><summary>Expand...</summary><a href="http://seclists.org/fulldisclosure/2020/Dec/32">http://seclists.org/fulldisclosure/2020/Dec/32</a><br><a href="http://seclists.org/fulldisclosure/2020/Jul/23">http://seclists.org/fulldisclosure/2020/Jul/23</a><br><a href="http://seclists.org/fulldisclosure/2020/Jul/24">http://seclists.org/fulldisclosure/2020/Jul/24</a><br><a href="http://seclists.org/fulldisclosure/2020/Jul/25">http://seclists.org/fulldisclosure/2020/Jul/25</a><br><a href="http://seclists.org/fulldisclosure/2020/Nov/20">http://seclists.org/fulldisclosure/2020/Nov/20</a><br><a href="http://www.openwall.com/lists/oss-security/2020/08/13/2">http://www.openwall.com/lists/oss-security/2020/08/13/2</a><br><a href="http://www.openwall.com/lists/oss-security/2020/10/07/3">http://www.openwall.com/lists/oss-security/2020/10/07/3</a><br><a href="https://bugzilla.redhat.com/show_bug.cgi?id=CVE-2019-14899">https://bugzilla.redhat.com/show_bug.cgi?id=CVE-2019-14899</a><br><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2019-14899">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2019-14899</a><br><a href="https://openvpn.net/security-advisory/no-flaws-found-in-openvpn-software/">https://openvpn.net/security-advisory/no-flaws-found-in-openvpn-software/</a><br><a href="https://support.apple.com/kb/HT211288">https://support.apple.com/kb/HT211288</a><br><a href="https://support.apple.com/kb/HT211289">https://support.apple.com/kb/HT211289</a><br><a href="https://support.apple.com/kb/HT211290">https://support.apple.com/kb/HT211290</a><br><a href="https://support.apple.com/kb/HT211850">https://support.apple.com/kb/HT211850</a><br><a href="https://support.apple.com/kb/HT211931">https://support.apple.com/kb/HT211931</a><br><a href="https://www.openwall.com/lists/oss-security/2019/12/05/1">https://www.openwall.com/lists/oss-security/2019/12/05/1</a><br></details>  |
| linux-libc-dev         |    CVE-2019-15213   |   LOW  |  4.15.0-163.171 |  | <details><summary>Expand...</summary><a href="http://lists.opensuse.org/opensuse-security-announce/2019-12/msg00029.html">http://lists.opensuse.org/opensuse-security-announce/2019-12/msg00029.html</a><br><a href="http://www.openwall.com/lists/oss-security/2019/08/20/2">http://www.openwall.com/lists/oss-security/2019/08/20/2</a><br><a href="https://cdn.kernel.org/pub/linux/kernel/v5.x/ChangeLog-5.2.3">https://cdn.kernel.org/pub/linux/kernel/v5.x/ChangeLog-5.2.3</a><br><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2019-15213">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2019-15213</a><br><a href="https://git.kernel.org/pub/scm/linux/kernel/git/torvalds/linux.git/commit/?id=6cf97230cd5f36b7665099083272595c55d72be7">https://git.kernel.org/pub/scm/linux/kernel/git/torvalds/linux.git/commit/?id=6cf97230cd5f36b7665099083272595c55d72be7</a><br><a href="https://linux.oracle.com/cve/CVE-2019-15213.html">https://linux.oracle.com/cve/CVE-2019-15213.html</a><br><a href="https://linux.oracle.com/errata/ELSA-2019-4872.html">https://linux.oracle.com/errata/ELSA-2019-4872.html</a><br><a href="https://lore.kernel.org/linux-media/fe983331d14442a96db3f71066ca0488a8921840.camel@decadent.org.uk/">https://lore.kernel.org/linux-media/fe983331d14442a96db3f71066ca0488a8921840.camel@decadent.org.uk/</a><br><a href="https://security.netapp.com/advisory/ntap-20190905-0002/">https://security.netapp.com/advisory/ntap-20190905-0002/</a><br><a href="https://syzkaller.appspot.com/bug?id=a53c9c9dd2981bfdbfbcbc1ddbd35595eda8bced">https://syzkaller.appspot.com/bug?id=a53c9c9dd2981bfdbfbcbc1ddbd35595eda8bced</a><br></details>  |
| linux-libc-dev         |    CVE-2019-16230   |   LOW  |  4.15.0-163.171 |  | <details><summary>Expand...</summary><a href="https://bugzilla.suse.com/show_bug.cgi?id=1150468">https://bugzilla.suse.com/show_bug.cgi?id=1150468</a><br><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2019-16230">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2019-16230</a><br><a href="https://lkml.org/lkml/2019/9/9/487">https://lkml.org/lkml/2019/9/9/487</a><br><a href="https://security.netapp.com/advisory/ntap-20191004-0001/">https://security.netapp.com/advisory/ntap-20191004-0001/</a><br></details>  |
| linux-libc-dev         |    CVE-2019-19378   |   LOW  |  4.15.0-163.171 |  | <details><summary>Expand...</summary><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2019-19378">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2019-19378</a><br><a href="https://github.com/bobfuzzer/CVE/tree/master/CVE-2019-19378">https://github.com/bobfuzzer/CVE/tree/master/CVE-2019-19378</a><br><a href="https://security.netapp.com/advisory/ntap-20200103-0001/">https://security.netapp.com/advisory/ntap-20200103-0001/</a><br></details>  |
| linux-libc-dev         |    CVE-2019-19814   |   LOW  |  4.15.0-163.171 |  | <details><summary>Expand...</summary><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2019-19814">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2019-19814</a><br><a href="https://github.com/bobfuzzer/CVE/tree/master/CVE-2019-19814">https://github.com/bobfuzzer/CVE/tree/master/CVE-2019-19814</a><br><a href="https://security.netapp.com/advisory/ntap-20200103-0001/">https://security.netapp.com/advisory/ntap-20200103-0001/</a><br></details>  |
| linux-libc-dev         |    CVE-2019-19815   |   LOW  |  4.15.0-163.171 |  | <details><summary>Expand...</summary><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2019-19815">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2019-19815</a><br><a href="https://github.com/bobfuzzer/CVE/tree/master/CVE-2019-19815">https://github.com/bobfuzzer/CVE/tree/master/CVE-2019-19815</a><br><a href="https://github.com/torvalds/linux/commit/4969c06a0d83c9c3dc50b8efcdc8eeedfce896f6#diff-41a7fa4590d2af87e82101f2b4dadb56">https://github.com/torvalds/linux/commit/4969c06a0d83c9c3dc50b8efcdc8eeedfce896f6#diff-41a7fa4590d2af87e82101f2b4dadb56</a><br><a href="https://security.netapp.com/advisory/ntap-20200103-0001/">https://security.netapp.com/advisory/ntap-20200103-0001/</a><br></details>  |
| linux-libc-dev         |    CVE-2019-20425   |   LOW  |  4.15.0-163.171 |  | <details><summary>Expand...</summary><a href="http://lustre.org/">http://lustre.org/</a><br><a href="http://wiki.lustre.org/Lustre_2.12.3_Changelog">http://wiki.lustre.org/Lustre_2.12.3_Changelog</a><br><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2019-20425">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2019-20425</a><br><a href="https://jira.whamcloud.com/browse/LU-12613">https://jira.whamcloud.com/browse/LU-12613</a><br><a href="https://review.whamcloud.com/#/c/36209/">https://review.whamcloud.com/#/c/36209/</a><br></details>  |
| linux-libc-dev         |    CVE-2019-20429   |   LOW  |  4.15.0-163.171 |  | <details><summary>Expand...</summary><a href="http://lustre.org/">http://lustre.org/</a><br><a href="http://wiki.lustre.org/Lustre_2.12.3_Changelog">http://wiki.lustre.org/Lustre_2.12.3_Changelog</a><br><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2019-20429">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2019-20429</a><br><a href="https://git.whamcloud.com/?p=fs/lustre-release.git;a=commitdiff;h=268edb13d769994c4841864034d72f0bd7b36e12">https://git.whamcloud.com/?p=fs/lustre-release.git;a=commitdiff;h=268edb13d769994c4841864034d72f0bd7b36e12</a><br><a href="https://jira.whamcloud.com/browse/LU-12590">https://jira.whamcloud.com/browse/LU-12590</a><br><a href="https://review.whamcloud.com/#/c/36119/">https://review.whamcloud.com/#/c/36119/</a><br></details>  |
| linux-libc-dev         |    CVE-2020-11725   |   LOW  |  4.15.0-163.171 |  | <details><summary>Expand...</summary><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2020-11725">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2020-11725</a><br><a href="https://github.com/torvalds/linux/blob/3b2549a3740efb8af0150415737067d87e466c5b/sound/core/control.c#L1434-L1474">https://github.com/torvalds/linux/blob/3b2549a3740efb8af0150415737067d87e466c5b/sound/core/control.c#L1434-L1474</a><br><a href="https://lore.kernel.org/alsa-devel/s5h4ktmlfpx.wl-tiwai@suse.de/">https://lore.kernel.org/alsa-devel/s5h4ktmlfpx.wl-tiwai@suse.de/</a><br><a href="https://twitter.com/yabbadabbadrew/status/1248632267028582400">https://twitter.com/yabbadabbadrew/status/1248632267028582400</a><br></details>  |
| linux-libc-dev         |    CVE-2020-14304   |   LOW  |  4.15.0-163.171 |  | <details><summary>Expand...</summary><a href="https://bugs.debian.org/cgi-bin/bugreport.cgi?bug=960702">https://bugs.debian.org/cgi-bin/bugreport.cgi?bug=960702</a><br><a href="https://bugzilla.redhat.com/show_bug.cgi?id=CVE-2020-14304">https://bugzilla.redhat.com/show_bug.cgi?id=CVE-2020-14304</a><br><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2020-14304">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2020-14304</a><br><a href="https://linux.oracle.com/cve/CVE-2020-14304.html">https://linux.oracle.com/cve/CVE-2020-14304.html</a><br><a href="https://linux.oracle.com/errata/ELSA-2021-9410.html">https://linux.oracle.com/errata/ELSA-2021-9410.html</a><br><a href="https://lore.kernel.org/netdev/20200517172053.GA734488@decadent.org.uk/T/">https://lore.kernel.org/netdev/20200517172053.GA734488@decadent.org.uk/T/</a><br></details>  |
| linux-libc-dev         |    CVE-2020-35501   |   LOW  |  4.15.0-163.171 |  | <details><summary>Expand...</summary><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2020-35501">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2020-35501</a><br><a href="https://listman.redhat.com/archives/linux-audit/2018-July/msg00041.html">https://listman.redhat.com/archives/linux-audit/2018-July/msg00041.html</a><br><a href="https://www.openwall.com/lists/oss-security/2021/02/18/1">https://www.openwall.com/lists/oss-security/2021/02/18/1</a><br></details>  |
| linux-libc-dev         |    CVE-2021-32078   |   LOW  |  4.15.0-163.171 |  | <details><summary>Expand...</summary><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2021-32078">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2021-32078</a><br><a href="https://git.kernel.org/cgit/linux/kernel/git/torvalds/linux.git/commit/?id=298a58e165e447ccfaae35fe9f651f9d7e15166f">https://git.kernel.org/cgit/linux/kernel/git/torvalds/linux.git/commit/?id=298a58e165e447ccfaae35fe9f651f9d7e15166f</a><br><a href="https://git.kernel.org/linus/298a58e165e447ccfaae35fe9f651f9d7e15166f (5.13-rc1)">https://git.kernel.org/linus/298a58e165e447ccfaae35fe9f651f9d7e15166f (5.13-rc1)</a><br><a href="https://github.com/torvalds/linux/commit/298a58e165e447ccfaae35fe9f651f9d7e15166f">https://github.com/torvalds/linux/commit/298a58e165e447ccfaae35fe9f651f9d7e15166f</a><br><a href="https://kirtikumarar.com/CVE-2021-32078.txt">https://kirtikumarar.com/CVE-2021-32078.txt</a><br><a href="https://security.netapp.com/advisory/ntap-20210813-0002/">https://security.netapp.com/advisory/ntap-20210813-0002/</a><br></details>  |
| linux-libc-dev         |    CVE-2021-34981   |   LOW  |  4.15.0-163.171 |  | <details><summary>Expand...</summary><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2021-34981">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2021-34981</a><br><a href="https://git.kernel.org/linus/3cfdf8fcaafa62a4123f92eb0f4a72650da3a479 (5.14-rc1)">https://git.kernel.org/linus/3cfdf8fcaafa62a4123f92eb0f4a72650da3a479 (5.14-rc1)</a><br><a href="https://git.kernel.org/pub/scm/linux/kernel/git/torvalds/linux.git/commit/?id=3cfdf8fcaafa62a4123f92eb0f4a72650da3a479">https://git.kernel.org/pub/scm/linux/kernel/git/torvalds/linux.git/commit/?id=3cfdf8fcaafa62a4123f92eb0f4a72650da3a479</a><br><a href="https://www.zerodayinitiative.com/advisories/ZDI-21-1223/">https://www.zerodayinitiative.com/advisories/ZDI-21-1223/</a><br></details>  |
| linux-libc-dev         |    CVE-2021-3669   |   LOW  |  4.15.0-163.171 |  | <details><summary>Expand...</summary><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2021-3669">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2021-3669</a><br><a href="https://lore.kernel.org/all/20210809203554.1562989-1-aquini@redhat.com/">https://lore.kernel.org/all/20210809203554.1562989-1-aquini@redhat.com/</a><br></details>  |
| linux-libc-dev         |    CVE-2021-3772   |   LOW  |  4.15.0-163.171 |  | <details><summary>Expand...</summary><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2021-3772">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2021-3772</a><br><a href="https://git.kernel.org/pub/scm/linux/kernel/git/netdev/net.git/commit/?id=32f8807a48ae55be0e76880cfe8607a18b5bb0df">https://git.kernel.org/pub/scm/linux/kernel/git/netdev/net.git/commit/?id=32f8807a48ae55be0e76880cfe8607a18b5bb0df</a><br><a href="https://ubuntu.com/security/notices/USN-5165-1">https://ubuntu.com/security/notices/USN-5165-1</a><br></details>  |
| locales         |    CVE-2021-35942   |   MEDIUM  |  2.27-3ubuntu1.4 |  | <details><summary>Expand...</summary><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2021-35942">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2021-35942</a><br><a href="https://linux.oracle.com/cve/CVE-2021-35942.html">https://linux.oracle.com/cve/CVE-2021-35942.html</a><br><a href="https://linux.oracle.com/errata/ELSA-2021-9560.html">https://linux.oracle.com/errata/ELSA-2021-9560.html</a><br><a href="https://security.netapp.com/advisory/ntap-20210827-0005/">https://security.netapp.com/advisory/ntap-20210827-0005/</a><br><a href="https://sourceware.org/bugzilla/show_bug.cgi?id=28011">https://sourceware.org/bugzilla/show_bug.cgi?id=28011</a><br><a href="https://sourceware.org/git/?p=glibc.git;a=commit;h=5adda61f62b77384718b4c0d8336ade8f2b4b35c">https://sourceware.org/git/?p=glibc.git;a=commit;h=5adda61f62b77384718b4c0d8336ade8f2b4b35c</a><br><a href="https://sourceware.org/git/?p=glibc.git;a=commitdiff;h=5adda61f62b77384718b4c0d8336ade8f2b4b35c">https://sourceware.org/git/?p=glibc.git;a=commitdiff;h=5adda61f62b77384718b4c0d8336ade8f2b4b35c</a><br><a href="https://sourceware.org/glibc/wiki/Security%20Exceptions">https://sourceware.org/glibc/wiki/Security%20Exceptions</a><br></details>  |
| locales         |    CVE-2021-38604   |   MEDIUM  |  2.27-3ubuntu1.4 |  | <details><summary>Expand...</summary><a href="https://blog.tuxcare.com/cve/tuxcare-team-identifies-cve-2021-38604-a-new-vulnerability-in-glibc">https://blog.tuxcare.com/cve/tuxcare-team-identifies-cve-2021-38604-a-new-vulnerability-in-glibc</a><br><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2021-38604">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2021-38604</a><br><a href="https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/GYEXYM37RCJWJ6B5KQUYQI4NZBDDYSXP/">https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/GYEXYM37RCJWJ6B5KQUYQI4NZBDDYSXP/</a><br><a href="https://security.netapp.com/advisory/ntap-20210909-0005/">https://security.netapp.com/advisory/ntap-20210909-0005/</a><br><a href="https://sourceware.org/bugzilla/show_bug.cgi?id=28213">https://sourceware.org/bugzilla/show_bug.cgi?id=28213</a><br><a href="https://sourceware.org/git/?p=glibc.git;a=commit;h=4cc79c217744743077bf7a0ec5e0a4318f1e6641">https://sourceware.org/git/?p=glibc.git;a=commit;h=4cc79c217744743077bf7a0ec5e0a4318f1e6641</a><br><a href="https://sourceware.org/git/?p=glibc.git;a=commit;h=b805aebd42364fe696e417808a700fdb9800c9e8">https://sourceware.org/git/?p=glibc.git;a=commit;h=b805aebd42364fe696e417808a700fdb9800c9e8</a><br></details>  |
| locales         |    CVE-2009-5155   |   LOW  |  2.27-3ubuntu1.4 |  | <details><summary>Expand...</summary><a href="http://git.savannah.gnu.org/cgit/gnulib.git/commit/?id=5513b40999149090987a0341c018d05d3eea1272">http://git.savannah.gnu.org/cgit/gnulib.git/commit/?id=5513b40999149090987a0341c018d05d3eea1272</a><br><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2009-5155">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2009-5155</a><br><a href="https://debbugs.gnu.org/cgi/bugreport.cgi?bug=22793">https://debbugs.gnu.org/cgi/bugreport.cgi?bug=22793</a><br><a href="https://debbugs.gnu.org/cgi/bugreport.cgi?bug=32806">https://debbugs.gnu.org/cgi/bugreport.cgi?bug=32806</a><br><a href="https://debbugs.gnu.org/cgi/bugreport.cgi?bug=34238">https://debbugs.gnu.org/cgi/bugreport.cgi?bug=34238</a><br><a href="https://lists.apache.org/thread.html/r58af02e294bd07f487e2c64ffc0a29b837db5600e33b6e698b9d696b@%3Cissues.bookkeeper.apache.org%3E">https://lists.apache.org/thread.html/r58af02e294bd07f487e2c64ffc0a29b837db5600e33b6e698b9d696b@%3Cissues.bookkeeper.apache.org%3E</a><br><a href="https://lists.apache.org/thread.html/rf4c02775860db415b4955778a131c2795223f61cb8c6a450893651e4@%3Cissues.bookkeeper.apache.org%3E">https://lists.apache.org/thread.html/rf4c02775860db415b4955778a131c2795223f61cb8c6a450893651e4@%3Cissues.bookkeeper.apache.org%3E</a><br><a href="https://security.netapp.com/advisory/ntap-20190315-0002/">https://security.netapp.com/advisory/ntap-20190315-0002/</a><br><a href="https://sourceware.org/bugzilla/show_bug.cgi?id=11053">https://sourceware.org/bugzilla/show_bug.cgi?id=11053</a><br><a href="https://sourceware.org/bugzilla/show_bug.cgi?id=18986">https://sourceware.org/bugzilla/show_bug.cgi?id=18986</a><br><a href="https://sourceware.org/git/gitweb.cgi?p=glibc.git;h=eb04c21373e2a2885f3d52ff192b0499afe3c672">https://sourceware.org/git/gitweb.cgi?p=glibc.git;h=eb04c21373e2a2885f3d52ff192b0499afe3c672</a><br><a href="https://support.f5.com/csp/article/K64119434">https://support.f5.com/csp/article/K64119434</a><br><a href="https://support.f5.com/csp/article/K64119434?utm_source=f5support&amp;amp;utm_medium=RSS">https://support.f5.com/csp/article/K64119434?utm_source=f5support&amp;amp;utm_medium=RSS</a><br><a href="https://ubuntu.com/security/notices/USN-4954-1">https://ubuntu.com/security/notices/USN-4954-1</a><br></details>  |
| locales         |    CVE-2015-8985   |   LOW  |  2.27-3ubuntu1.4 |  | <details><summary>Expand...</summary><a href="http://www.openwall.com/lists/oss-security/2017/02/14/9">http://www.openwall.com/lists/oss-security/2017/02/14/9</a><br><a href="http://www.securityfocus.com/bid/76916">http://www.securityfocus.com/bid/76916</a><br><a href="https://bugs.debian.org/cgi-bin/bugreport.cgi?bug=779392">https://bugs.debian.org/cgi-bin/bugreport.cgi?bug=779392</a><br><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2015-8985">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2015-8985</a><br><a href="https://security.gentoo.org/glsa/201908-06">https://security.gentoo.org/glsa/201908-06</a><br></details>  |
| locales         |    CVE-2016-10228   |   LOW  |  2.27-3ubuntu1.4 |  | <details><summary>Expand...</summary><a href="http://openwall.com/lists/oss-security/2017/03/01/10">http://openwall.com/lists/oss-security/2017/03/01/10</a><br><a href="http://www.securityfocus.com/bid/96525">http://www.securityfocus.com/bid/96525</a><br><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2016-10228">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2016-10228</a><br><a href="https://linux.oracle.com/cve/CVE-2016-10228.html">https://linux.oracle.com/cve/CVE-2016-10228.html</a><br><a href="https://linux.oracle.com/errata/ELSA-2021-9344.html">https://linux.oracle.com/errata/ELSA-2021-9344.html</a><br><a href="https://lists.apache.org/thread.html/rf9fa47ab66495c78bb4120b0754dd9531ca2ff0430f6685ac9b07772@%3Cdev.mina.apache.org%3E">https://lists.apache.org/thread.html/rf9fa47ab66495c78bb4120b0754dd9531ca2ff0430f6685ac9b07772@%3Cdev.mina.apache.org%3E</a><br><a href="https://security.gentoo.org/glsa/202101-20">https://security.gentoo.org/glsa/202101-20</a><br><a href="https://sourceware.org/bugzilla/show_bug.cgi?id=19519">https://sourceware.org/bugzilla/show_bug.cgi?id=19519</a><br><a href="https://sourceware.org/bugzilla/show_bug.cgi?id=19519#c21">https://sourceware.org/bugzilla/show_bug.cgi?id=19519#c21</a><br><a href="https://sourceware.org/bugzilla/show_bug.cgi?id=26224">https://sourceware.org/bugzilla/show_bug.cgi?id=26224</a><br></details>  |
| locales         |    CVE-2016-10739   |   LOW  |  2.27-3ubuntu1.4 |  | <details><summary>Expand...</summary><a href="http://lists.opensuse.org/opensuse-security-announce/2019-04/msg00082.html">http://lists.opensuse.org/opensuse-security-announce/2019-04/msg00082.html</a><br><a href="http://www.securityfocus.com/bid/106672">http://www.securityfocus.com/bid/106672</a><br><a href="https://access.redhat.com/errata/RHSA-2019:2118">https://access.redhat.com/errata/RHSA-2019:2118</a><br><a href="https://access.redhat.com/errata/RHSA-2019:3513">https://access.redhat.com/errata/RHSA-2019:3513</a><br><a href="https://bugzilla.redhat.com/show_bug.cgi?id=1347549">https://bugzilla.redhat.com/show_bug.cgi?id=1347549</a><br><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2016-10739">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2016-10739</a><br><a href="https://linux.oracle.com/cve/CVE-2016-10739.html">https://linux.oracle.com/cve/CVE-2016-10739.html</a><br><a href="https://linux.oracle.com/errata/ELSA-2019-3513.html">https://linux.oracle.com/errata/ELSA-2019-3513.html</a><br><a href="https://sourceware.org/bugzilla/show_bug.cgi?id=20018">https://sourceware.org/bugzilla/show_bug.cgi?id=20018</a><br></details>  |
| locales         |    CVE-2019-25013   |   LOW  |  2.27-3ubuntu1.4 |  | <details><summary>Expand...</summary><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2019-25013">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2019-25013</a><br><a href="https://linux.oracle.com/cve/CVE-2019-25013.html">https://linux.oracle.com/cve/CVE-2019-25013.html</a><br><a href="https://linux.oracle.com/errata/ELSA-2021-9344.html">https://linux.oracle.com/errata/ELSA-2021-9344.html</a><br><a href="https://lists.apache.org/thread.html/r32d767ac804e9b8aad4355bb85960a6a1385eab7afff549a5e98660f@%3Cjira.kafka.apache.org%3E">https://lists.apache.org/thread.html/r32d767ac804e9b8aad4355bb85960a6a1385eab7afff549a5e98660f@%3Cjira.kafka.apache.org%3E</a><br><a href="https://lists.apache.org/thread.html/r448bb851cc8e6e3f93f3c28c70032b37062625d81214744474ac49e7@%3Cdev.kafka.apache.org%3E">https://lists.apache.org/thread.html/r448bb851cc8e6e3f93f3c28c70032b37062625d81214744474ac49e7@%3Cdev.kafka.apache.org%3E</a><br><a href="https://lists.apache.org/thread.html/r4806a391091e082bdea17266452ca656ebc176e51bb3932733b3a0a2@%3Cjira.kafka.apache.org%3E">https://lists.apache.org/thread.html/r4806a391091e082bdea17266452ca656ebc176e51bb3932733b3a0a2@%3Cjira.kafka.apache.org%3E</a><br><a href="https://lists.apache.org/thread.html/r499e4f96d0b5109ef083f2feccd33c51650c1b7d7068aa3bd47efca9@%3Cjira.kafka.apache.org%3E">https://lists.apache.org/thread.html/r499e4f96d0b5109ef083f2feccd33c51650c1b7d7068aa3bd47efca9@%3Cjira.kafka.apache.org%3E</a><br><a href="https://lists.apache.org/thread.html/r5af4430421bb6f9973294691a7904bbd260937e9eef96b20556f43ff@%3Cjira.kafka.apache.org%3E">https://lists.apache.org/thread.html/r5af4430421bb6f9973294691a7904bbd260937e9eef96b20556f43ff@%3Cjira.kafka.apache.org%3E</a><br><a href="https://lists.apache.org/thread.html/r750eee18542bc02bd8350861c424ee60a9b9b225568fa09436a37ece@%3Cissues.zookeeper.apache.org%3E">https://lists.apache.org/thread.html/r750eee18542bc02bd8350861c424ee60a9b9b225568fa09436a37ece@%3Cissues.zookeeper.apache.org%3E</a><br><a href="https://lists.apache.org/thread.html/r7a2e94adfe0a2f0a1d42e4927e8c32ecac97d37db9cb68095fe9ddbc@%3Cdev.zookeeper.apache.org%3E">https://lists.apache.org/thread.html/r7a2e94adfe0a2f0a1d42e4927e8c32ecac97d37db9cb68095fe9ddbc@%3Cdev.zookeeper.apache.org%3E</a><br><a href="https://lists.apache.org/thread.html/rd2354f9ccce41e494fbadcbc5ad87218de6ec0fff8a7b54c8462226c@%3Cissues.zookeeper.apache.org%3E">https://lists.apache.org/thread.html/rd2354f9ccce41e494fbadcbc5ad87218de6ec0fff8a7b54c8462226c@%3Cissues.zookeeper.apache.org%3E</a><br><a href="https://lists.apache.org/thread.html/rf9fa47ab66495c78bb4120b0754dd9531ca2ff0430f6685ac9b07772@%3Cdev.mina.apache.org%3E">https://lists.apache.org/thread.html/rf9fa47ab66495c78bb4120b0754dd9531ca2ff0430f6685ac9b07772@%3Cdev.mina.apache.org%3E</a><br><a href="https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/4Y6TX47P47KABSFOL26FLDNVCWXDKDEZ/">https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/4Y6TX47P47KABSFOL26FLDNVCWXDKDEZ/</a><br><a href="https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/TVCUNLQ3HXGS4VPUQKWTJGRAW2KTFGXS/">https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/TVCUNLQ3HXGS4VPUQKWTJGRAW2KTFGXS/</a><br><a href="https://security.netapp.com/advisory/ntap-20210205-0004/">https://security.netapp.com/advisory/ntap-20210205-0004/</a><br><a href="https://sourceware.org/bugzilla/show_bug.cgi?id=24973">https://sourceware.org/bugzilla/show_bug.cgi?id=24973</a><br><a href="https://sourceware.org/git/?p=glibc.git;a=commit;h=ee7a3144c9922808181009b7b3e50e852fb4999b">https://sourceware.org/git/?p=glibc.git;a=commit;h=ee7a3144c9922808181009b7b3e50e852fb4999b</a><br></details>  |
| locales         |    CVE-2020-27618   |   LOW  |  2.27-3ubuntu1.4 |  | <details><summary>Expand...</summary><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2020-27618">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2020-27618</a><br><a href="https://linux.oracle.com/cve/CVE-2020-27618.html">https://linux.oracle.com/cve/CVE-2020-27618.html</a><br><a href="https://linux.oracle.com/errata/ELSA-2021-9344.html">https://linux.oracle.com/errata/ELSA-2021-9344.html</a><br><a href="https://security.netapp.com/advisory/ntap-20210401-0006/">https://security.netapp.com/advisory/ntap-20210401-0006/</a><br><a href="https://sourceware.org/bugzilla/show_bug.cgi?id=19519#c21">https://sourceware.org/bugzilla/show_bug.cgi?id=19519#c21</a><br><a href="https://sourceware.org/bugzilla/show_bug.cgi?id=26224">https://sourceware.org/bugzilla/show_bug.cgi?id=26224</a><br></details>  |
| locales         |    CVE-2020-6096   |   LOW  |  2.27-3ubuntu1.4 |  | <details><summary>Expand...</summary><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2020-6096">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2020-6096</a><br><a href="https://lists.apache.org/thread.html/rf9fa47ab66495c78bb4120b0754dd9531ca2ff0430f6685ac9b07772@%3Cdev.mina.apache.org%3E">https://lists.apache.org/thread.html/rf9fa47ab66495c78bb4120b0754dd9531ca2ff0430f6685ac9b07772@%3Cdev.mina.apache.org%3E</a><br><a href="https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/SPYXTDOOB4PQGTYAMZAZNJIB3FF6YQXI/">https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/SPYXTDOOB4PQGTYAMZAZNJIB3FF6YQXI/</a><br><a href="https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/URXOIA2LDUKHQXK4BE55BQBRI6ZZG3Y6/">https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/URXOIA2LDUKHQXK4BE55BQBRI6ZZG3Y6/</a><br><a href="https://security.gentoo.org/glsa/202101-20">https://security.gentoo.org/glsa/202101-20</a><br><a href="https://sourceware.org/bugzilla/attachment.cgi?id=12334">https://sourceware.org/bugzilla/attachment.cgi?id=12334</a><br><a href="https://sourceware.org/bugzilla/show_bug.cgi?id=25620">https://sourceware.org/bugzilla/show_bug.cgi?id=25620</a><br><a href="https://talosintelligence.com/vulnerability_reports/TALOS-2020-1019">https://talosintelligence.com/vulnerability_reports/TALOS-2020-1019</a><br><a href="https://ubuntu.com/security/notices/USN-4954-1">https://ubuntu.com/security/notices/USN-4954-1</a><br><a href="https://www.talosintelligence.com/vulnerability_reports/TALOS-2020-1019">https://www.talosintelligence.com/vulnerability_reports/TALOS-2020-1019</a><br></details>  |
| locales         |    CVE-2021-3326   |   LOW  |  2.27-3ubuntu1.4 |  | <details><summary>Expand...</summary><a href="http://www.openwall.com/lists/oss-security/2021/01/28/2">http://www.openwall.com/lists/oss-security/2021/01/28/2</a><br><a href="https://bugs.chromium.org/p/project-zero/issues/detail?id=2146">https://bugs.chromium.org/p/project-zero/issues/detail?id=2146</a><br><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2021-3326">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2021-3326</a><br><a href="https://linux.oracle.com/cve/CVE-2021-3326.html">https://linux.oracle.com/cve/CVE-2021-3326.html</a><br><a href="https://linux.oracle.com/errata/ELSA-2021-9344.html">https://linux.oracle.com/errata/ELSA-2021-9344.html</a><br><a href="https://security.netapp.com/advisory/ntap-20210304-0007/">https://security.netapp.com/advisory/ntap-20210304-0007/</a><br><a href="https://sourceware.org/bugzilla/show_bug.cgi?id=27256">https://sourceware.org/bugzilla/show_bug.cgi?id=27256</a><br><a href="https://sourceware.org/git/?p=glibc.git;a=commit;h=7d88c6142c6efc160c0ee5e4f85cde382c072888">https://sourceware.org/git/?p=glibc.git;a=commit;h=7d88c6142c6efc160c0ee5e4f85cde382c072888</a><br><a href="https://sourceware.org/pipermail/libc-alpha/2021-January/122058.html">https://sourceware.org/pipermail/libc-alpha/2021-January/122058.html</a><br></details>  |
| locales         |    CVE-2021-33574   |   LOW  |  2.27-3ubuntu1.4 |  | <details><summary>Expand...</summary><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2021-33574">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2021-33574</a><br><a href="https://linux.oracle.com/cve/CVE-2021-33574.html">https://linux.oracle.com/cve/CVE-2021-33574.html</a><br><a href="https://linux.oracle.com/errata/ELSA-2021-9560.html">https://linux.oracle.com/errata/ELSA-2021-9560.html</a><br><a href="https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/RBUUWUGXVILQXVWEOU7N42ICHPJNAEUP/">https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/RBUUWUGXVILQXVWEOU7N42ICHPJNAEUP/</a><br><a href="https://security.gentoo.org/glsa/202107-07">https://security.gentoo.org/glsa/202107-07</a><br><a href="https://security.netapp.com/advisory/ntap-20210629-0005/">https://security.netapp.com/advisory/ntap-20210629-0005/</a><br><a href="https://sourceware.org/bugzilla/show_bug.cgi?id=27896">https://sourceware.org/bugzilla/show_bug.cgi?id=27896</a><br><a href="https://sourceware.org/bugzilla/show_bug.cgi?id=27896#c1">https://sourceware.org/bugzilla/show_bug.cgi?id=27896#c1</a><br></details>  |
| login         |    CVE-2013-4235   |   LOW  |  1:4.5-1ubuntu2 |  | <details><summary>Expand...</summary><a href="https://access.redhat.com/security/cve/cve-2013-4235">https://access.redhat.com/security/cve/cve-2013-4235</a><br><a href="https://bugzilla.redhat.com/show_bug.cgi?id=CVE-2013-4235">https://bugzilla.redhat.com/show_bug.cgi?id=CVE-2013-4235</a><br><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2013-4235">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2013-4235</a><br><a href="https://lists.apache.org/thread.html/rf9fa47ab66495c78bb4120b0754dd9531ca2ff0430f6685ac9b07772@%3Cdev.mina.apache.org%3E">https://lists.apache.org/thread.html/rf9fa47ab66495c78bb4120b0754dd9531ca2ff0430f6685ac9b07772@%3Cdev.mina.apache.org%3E</a><br><a href="https://security-tracker.debian.org/tracker/CVE-2013-4235">https://security-tracker.debian.org/tracker/CVE-2013-4235</a><br></details>  |
| login         |    CVE-2018-7169   |   LOW  |  1:4.5-1ubuntu2 |  | <details><summary>Expand...</summary><a href="https://bugs.launchpad.net/ubuntu/+source/shadow/+bug/1729357">https://bugs.launchpad.net/ubuntu/+source/shadow/+bug/1729357</a><br><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2018-7169">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2018-7169</a><br><a href="https://github.com/shadow-maint/shadow/pull/97">https://github.com/shadow-maint/shadow/pull/97</a><br><a href="https://security.gentoo.org/glsa/201805-09">https://security.gentoo.org/glsa/201805-09</a><br></details>  |
| mono-4.0-gac         |    CVE-2018-1002208   |   LOW  |  6.12.0.122-0xamarin1+ubuntu1804b1 |  | <details><summary>Expand...</summary><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2018-1002208">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2018-1002208</a><br><a href="https://github.com/icsharpcode/SharpZipLib/issues/232">https://github.com/icsharpcode/SharpZipLib/issues/232</a><br><a href="https://github.com/icsharpcode/SharpZipLib/wiki/Release-1.0">https://github.com/icsharpcode/SharpZipLib/wiki/Release-1.0</a><br><a href="https://github.com/snyk/zip-slip-vulnerability">https://github.com/snyk/zip-slip-vulnerability</a><br><a href="https://snyk.io/research/zip-slip-vulnerability">https://snyk.io/research/zip-slip-vulnerability</a><br><a href="https://snyk.io/vuln/SNYK-DOTNET-SHARPZIPLIB-60247">https://snyk.io/vuln/SNYK-DOTNET-SHARPZIPLIB-60247</a><br></details>  |
| mono-csharp-shell         |    CVE-2018-1002208   |   LOW  |  6.12.0.122-0xamarin1+ubuntu1804b1 |  | <details><summary>Expand...</summary><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2018-1002208">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2018-1002208</a><br><a href="https://github.com/icsharpcode/SharpZipLib/issues/232">https://github.com/icsharpcode/SharpZipLib/issues/232</a><br><a href="https://github.com/icsharpcode/SharpZipLib/wiki/Release-1.0">https://github.com/icsharpcode/SharpZipLib/wiki/Release-1.0</a><br><a href="https://github.com/snyk/zip-slip-vulnerability">https://github.com/snyk/zip-slip-vulnerability</a><br><a href="https://snyk.io/research/zip-slip-vulnerability">https://snyk.io/research/zip-slip-vulnerability</a><br><a href="https://snyk.io/vuln/SNYK-DOTNET-SHARPZIPLIB-60247">https://snyk.io/vuln/SNYK-DOTNET-SHARPZIPLIB-60247</a><br></details>  |
| mono-devel         |    CVE-2018-1002208   |   LOW  |  6.12.0.122-0xamarin1+ubuntu1804b1 |  | <details><summary>Expand...</summary><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2018-1002208">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2018-1002208</a><br><a href="https://github.com/icsharpcode/SharpZipLib/issues/232">https://github.com/icsharpcode/SharpZipLib/issues/232</a><br><a href="https://github.com/icsharpcode/SharpZipLib/wiki/Release-1.0">https://github.com/icsharpcode/SharpZipLib/wiki/Release-1.0</a><br><a href="https://github.com/snyk/zip-slip-vulnerability">https://github.com/snyk/zip-slip-vulnerability</a><br><a href="https://snyk.io/research/zip-slip-vulnerability">https://snyk.io/research/zip-slip-vulnerability</a><br><a href="https://snyk.io/vuln/SNYK-DOTNET-SHARPZIPLIB-60247">https://snyk.io/vuln/SNYK-DOTNET-SHARPZIPLIB-60247</a><br></details>  |
| mono-gac         |    CVE-2018-1002208   |   LOW  |  6.12.0.122-0xamarin1+ubuntu1804b1 |  | <details><summary>Expand...</summary><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2018-1002208">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2018-1002208</a><br><a href="https://github.com/icsharpcode/SharpZipLib/issues/232">https://github.com/icsharpcode/SharpZipLib/issues/232</a><br><a href="https://github.com/icsharpcode/SharpZipLib/wiki/Release-1.0">https://github.com/icsharpcode/SharpZipLib/wiki/Release-1.0</a><br><a href="https://github.com/snyk/zip-slip-vulnerability">https://github.com/snyk/zip-slip-vulnerability</a><br><a href="https://snyk.io/research/zip-slip-vulnerability">https://snyk.io/research/zip-slip-vulnerability</a><br><a href="https://snyk.io/vuln/SNYK-DOTNET-SHARPZIPLIB-60247">https://snyk.io/vuln/SNYK-DOTNET-SHARPZIPLIB-60247</a><br></details>  |
| mono-llvm-support         |    CVE-2018-1002208   |   LOW  |  6.12.0.122-0xamarin1+ubuntu1804b1 |  | <details><summary>Expand...</summary><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2018-1002208">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2018-1002208</a><br><a href="https://github.com/icsharpcode/SharpZipLib/issues/232">https://github.com/icsharpcode/SharpZipLib/issues/232</a><br><a href="https://github.com/icsharpcode/SharpZipLib/wiki/Release-1.0">https://github.com/icsharpcode/SharpZipLib/wiki/Release-1.0</a><br><a href="https://github.com/snyk/zip-slip-vulnerability">https://github.com/snyk/zip-slip-vulnerability</a><br><a href="https://snyk.io/research/zip-slip-vulnerability">https://snyk.io/research/zip-slip-vulnerability</a><br><a href="https://snyk.io/vuln/SNYK-DOTNET-SHARPZIPLIB-60247">https://snyk.io/vuln/SNYK-DOTNET-SHARPZIPLIB-60247</a><br></details>  |
| mono-mcs         |    CVE-2018-1002208   |   LOW  |  6.12.0.122-0xamarin1+ubuntu1804b1 |  | <details><summary>Expand...</summary><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2018-1002208">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2018-1002208</a><br><a href="https://github.com/icsharpcode/SharpZipLib/issues/232">https://github.com/icsharpcode/SharpZipLib/issues/232</a><br><a href="https://github.com/icsharpcode/SharpZipLib/wiki/Release-1.0">https://github.com/icsharpcode/SharpZipLib/wiki/Release-1.0</a><br><a href="https://github.com/snyk/zip-slip-vulnerability">https://github.com/snyk/zip-slip-vulnerability</a><br><a href="https://snyk.io/research/zip-slip-vulnerability">https://snyk.io/research/zip-slip-vulnerability</a><br><a href="https://snyk.io/vuln/SNYK-DOTNET-SHARPZIPLIB-60247">https://snyk.io/vuln/SNYK-DOTNET-SHARPZIPLIB-60247</a><br></details>  |
| mono-roslyn         |    CVE-2018-1002208   |   LOW  |  6.12.0.122-0xamarin1+ubuntu1804b1 |  | <details><summary>Expand...</summary><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2018-1002208">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2018-1002208</a><br><a href="https://github.com/icsharpcode/SharpZipLib/issues/232">https://github.com/icsharpcode/SharpZipLib/issues/232</a><br><a href="https://github.com/icsharpcode/SharpZipLib/wiki/Release-1.0">https://github.com/icsharpcode/SharpZipLib/wiki/Release-1.0</a><br><a href="https://github.com/snyk/zip-slip-vulnerability">https://github.com/snyk/zip-slip-vulnerability</a><br><a href="https://snyk.io/research/zip-slip-vulnerability">https://snyk.io/research/zip-slip-vulnerability</a><br><a href="https://snyk.io/vuln/SNYK-DOTNET-SHARPZIPLIB-60247">https://snyk.io/vuln/SNYK-DOTNET-SHARPZIPLIB-60247</a><br></details>  |
| mono-runtime         |    CVE-2018-1002208   |   LOW  |  6.12.0.122-0xamarin1+ubuntu1804b1 |  | <details><summary>Expand...</summary><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2018-1002208">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2018-1002208</a><br><a href="https://github.com/icsharpcode/SharpZipLib/issues/232">https://github.com/icsharpcode/SharpZipLib/issues/232</a><br><a href="https://github.com/icsharpcode/SharpZipLib/wiki/Release-1.0">https://github.com/icsharpcode/SharpZipLib/wiki/Release-1.0</a><br><a href="https://github.com/snyk/zip-slip-vulnerability">https://github.com/snyk/zip-slip-vulnerability</a><br><a href="https://snyk.io/research/zip-slip-vulnerability">https://snyk.io/research/zip-slip-vulnerability</a><br><a href="https://snyk.io/vuln/SNYK-DOTNET-SHARPZIPLIB-60247">https://snyk.io/vuln/SNYK-DOTNET-SHARPZIPLIB-60247</a><br></details>  |
| mono-runtime-common         |    CVE-2018-1002208   |   LOW  |  6.12.0.122-0xamarin1+ubuntu1804b1 |  | <details><summary>Expand...</summary><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2018-1002208">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2018-1002208</a><br><a href="https://github.com/icsharpcode/SharpZipLib/issues/232">https://github.com/icsharpcode/SharpZipLib/issues/232</a><br><a href="https://github.com/icsharpcode/SharpZipLib/wiki/Release-1.0">https://github.com/icsharpcode/SharpZipLib/wiki/Release-1.0</a><br><a href="https://github.com/snyk/zip-slip-vulnerability">https://github.com/snyk/zip-slip-vulnerability</a><br><a href="https://snyk.io/research/zip-slip-vulnerability">https://snyk.io/research/zip-slip-vulnerability</a><br><a href="https://snyk.io/vuln/SNYK-DOTNET-SHARPZIPLIB-60247">https://snyk.io/vuln/SNYK-DOTNET-SHARPZIPLIB-60247</a><br></details>  |
| mono-runtime-sgen         |    CVE-2018-1002208   |   LOW  |  6.12.0.122-0xamarin1+ubuntu1804b1 |  | <details><summary>Expand...</summary><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2018-1002208">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2018-1002208</a><br><a href="https://github.com/icsharpcode/SharpZipLib/issues/232">https://github.com/icsharpcode/SharpZipLib/issues/232</a><br><a href="https://github.com/icsharpcode/SharpZipLib/wiki/Release-1.0">https://github.com/icsharpcode/SharpZipLib/wiki/Release-1.0</a><br><a href="https://github.com/snyk/zip-slip-vulnerability">https://github.com/snyk/zip-slip-vulnerability</a><br><a href="https://snyk.io/research/zip-slip-vulnerability">https://snyk.io/research/zip-slip-vulnerability</a><br><a href="https://snyk.io/vuln/SNYK-DOTNET-SHARPZIPLIB-60247">https://snyk.io/vuln/SNYK-DOTNET-SHARPZIPLIB-60247</a><br></details>  |
| mono-xbuild         |    CVE-2018-1002208   |   LOW  |  6.12.0.122-0xamarin1+ubuntu1804b1 |  | <details><summary>Expand...</summary><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2018-1002208">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2018-1002208</a><br><a href="https://github.com/icsharpcode/SharpZipLib/issues/232">https://github.com/icsharpcode/SharpZipLib/issues/232</a><br><a href="https://github.com/icsharpcode/SharpZipLib/wiki/Release-1.0">https://github.com/icsharpcode/SharpZipLib/wiki/Release-1.0</a><br><a href="https://github.com/snyk/zip-slip-vulnerability">https://github.com/snyk/zip-slip-vulnerability</a><br><a href="https://snyk.io/research/zip-slip-vulnerability">https://snyk.io/research/zip-slip-vulnerability</a><br><a href="https://snyk.io/vuln/SNYK-DOTNET-SHARPZIPLIB-60247">https://snyk.io/vuln/SNYK-DOTNET-SHARPZIPLIB-60247</a><br></details>  |
| multiarch-support         |    CVE-2021-35942   |   MEDIUM  |  2.27-3ubuntu1.4 |  | <details><summary>Expand...</summary><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2021-35942">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2021-35942</a><br><a href="https://linux.oracle.com/cve/CVE-2021-35942.html">https://linux.oracle.com/cve/CVE-2021-35942.html</a><br><a href="https://linux.oracle.com/errata/ELSA-2021-9560.html">https://linux.oracle.com/errata/ELSA-2021-9560.html</a><br><a href="https://security.netapp.com/advisory/ntap-20210827-0005/">https://security.netapp.com/advisory/ntap-20210827-0005/</a><br><a href="https://sourceware.org/bugzilla/show_bug.cgi?id=28011">https://sourceware.org/bugzilla/show_bug.cgi?id=28011</a><br><a href="https://sourceware.org/git/?p=glibc.git;a=commit;h=5adda61f62b77384718b4c0d8336ade8f2b4b35c">https://sourceware.org/git/?p=glibc.git;a=commit;h=5adda61f62b77384718b4c0d8336ade8f2b4b35c</a><br><a href="https://sourceware.org/git/?p=glibc.git;a=commitdiff;h=5adda61f62b77384718b4c0d8336ade8f2b4b35c">https://sourceware.org/git/?p=glibc.git;a=commitdiff;h=5adda61f62b77384718b4c0d8336ade8f2b4b35c</a><br><a href="https://sourceware.org/glibc/wiki/Security%20Exceptions">https://sourceware.org/glibc/wiki/Security%20Exceptions</a><br></details>  |
| multiarch-support         |    CVE-2021-38604   |   MEDIUM  |  2.27-3ubuntu1.4 |  | <details><summary>Expand...</summary><a href="https://blog.tuxcare.com/cve/tuxcare-team-identifies-cve-2021-38604-a-new-vulnerability-in-glibc">https://blog.tuxcare.com/cve/tuxcare-team-identifies-cve-2021-38604-a-new-vulnerability-in-glibc</a><br><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2021-38604">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2021-38604</a><br><a href="https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/GYEXYM37RCJWJ6B5KQUYQI4NZBDDYSXP/">https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/GYEXYM37RCJWJ6B5KQUYQI4NZBDDYSXP/</a><br><a href="https://security.netapp.com/advisory/ntap-20210909-0005/">https://security.netapp.com/advisory/ntap-20210909-0005/</a><br><a href="https://sourceware.org/bugzilla/show_bug.cgi?id=28213">https://sourceware.org/bugzilla/show_bug.cgi?id=28213</a><br><a href="https://sourceware.org/git/?p=glibc.git;a=commit;h=4cc79c217744743077bf7a0ec5e0a4318f1e6641">https://sourceware.org/git/?p=glibc.git;a=commit;h=4cc79c217744743077bf7a0ec5e0a4318f1e6641</a><br><a href="https://sourceware.org/git/?p=glibc.git;a=commit;h=b805aebd42364fe696e417808a700fdb9800c9e8">https://sourceware.org/git/?p=glibc.git;a=commit;h=b805aebd42364fe696e417808a700fdb9800c9e8</a><br></details>  |
| multiarch-support         |    CVE-2009-5155   |   LOW  |  2.27-3ubuntu1.4 |  | <details><summary>Expand...</summary><a href="http://git.savannah.gnu.org/cgit/gnulib.git/commit/?id=5513b40999149090987a0341c018d05d3eea1272">http://git.savannah.gnu.org/cgit/gnulib.git/commit/?id=5513b40999149090987a0341c018d05d3eea1272</a><br><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2009-5155">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2009-5155</a><br><a href="https://debbugs.gnu.org/cgi/bugreport.cgi?bug=22793">https://debbugs.gnu.org/cgi/bugreport.cgi?bug=22793</a><br><a href="https://debbugs.gnu.org/cgi/bugreport.cgi?bug=32806">https://debbugs.gnu.org/cgi/bugreport.cgi?bug=32806</a><br><a href="https://debbugs.gnu.org/cgi/bugreport.cgi?bug=34238">https://debbugs.gnu.org/cgi/bugreport.cgi?bug=34238</a><br><a href="https://lists.apache.org/thread.html/r58af02e294bd07f487e2c64ffc0a29b837db5600e33b6e698b9d696b@%3Cissues.bookkeeper.apache.org%3E">https://lists.apache.org/thread.html/r58af02e294bd07f487e2c64ffc0a29b837db5600e33b6e698b9d696b@%3Cissues.bookkeeper.apache.org%3E</a><br><a href="https://lists.apache.org/thread.html/rf4c02775860db415b4955778a131c2795223f61cb8c6a450893651e4@%3Cissues.bookkeeper.apache.org%3E">https://lists.apache.org/thread.html/rf4c02775860db415b4955778a131c2795223f61cb8c6a450893651e4@%3Cissues.bookkeeper.apache.org%3E</a><br><a href="https://security.netapp.com/advisory/ntap-20190315-0002/">https://security.netapp.com/advisory/ntap-20190315-0002/</a><br><a href="https://sourceware.org/bugzilla/show_bug.cgi?id=11053">https://sourceware.org/bugzilla/show_bug.cgi?id=11053</a><br><a href="https://sourceware.org/bugzilla/show_bug.cgi?id=18986">https://sourceware.org/bugzilla/show_bug.cgi?id=18986</a><br><a href="https://sourceware.org/git/gitweb.cgi?p=glibc.git;h=eb04c21373e2a2885f3d52ff192b0499afe3c672">https://sourceware.org/git/gitweb.cgi?p=glibc.git;h=eb04c21373e2a2885f3d52ff192b0499afe3c672</a><br><a href="https://support.f5.com/csp/article/K64119434">https://support.f5.com/csp/article/K64119434</a><br><a href="https://support.f5.com/csp/article/K64119434?utm_source=f5support&amp;amp;utm_medium=RSS">https://support.f5.com/csp/article/K64119434?utm_source=f5support&amp;amp;utm_medium=RSS</a><br><a href="https://ubuntu.com/security/notices/USN-4954-1">https://ubuntu.com/security/notices/USN-4954-1</a><br></details>  |
| multiarch-support         |    CVE-2015-8985   |   LOW  |  2.27-3ubuntu1.4 |  | <details><summary>Expand...</summary><a href="http://www.openwall.com/lists/oss-security/2017/02/14/9">http://www.openwall.com/lists/oss-security/2017/02/14/9</a><br><a href="http://www.securityfocus.com/bid/76916">http://www.securityfocus.com/bid/76916</a><br><a href="https://bugs.debian.org/cgi-bin/bugreport.cgi?bug=779392">https://bugs.debian.org/cgi-bin/bugreport.cgi?bug=779392</a><br><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2015-8985">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2015-8985</a><br><a href="https://security.gentoo.org/glsa/201908-06">https://security.gentoo.org/glsa/201908-06</a><br></details>  |
| multiarch-support         |    CVE-2016-10228   |   LOW  |  2.27-3ubuntu1.4 |  | <details><summary>Expand...</summary><a href="http://openwall.com/lists/oss-security/2017/03/01/10">http://openwall.com/lists/oss-security/2017/03/01/10</a><br><a href="http://www.securityfocus.com/bid/96525">http://www.securityfocus.com/bid/96525</a><br><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2016-10228">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2016-10228</a><br><a href="https://linux.oracle.com/cve/CVE-2016-10228.html">https://linux.oracle.com/cve/CVE-2016-10228.html</a><br><a href="https://linux.oracle.com/errata/ELSA-2021-9344.html">https://linux.oracle.com/errata/ELSA-2021-9344.html</a><br><a href="https://lists.apache.org/thread.html/rf9fa47ab66495c78bb4120b0754dd9531ca2ff0430f6685ac9b07772@%3Cdev.mina.apache.org%3E">https://lists.apache.org/thread.html/rf9fa47ab66495c78bb4120b0754dd9531ca2ff0430f6685ac9b07772@%3Cdev.mina.apache.org%3E</a><br><a href="https://security.gentoo.org/glsa/202101-20">https://security.gentoo.org/glsa/202101-20</a><br><a href="https://sourceware.org/bugzilla/show_bug.cgi?id=19519">https://sourceware.org/bugzilla/show_bug.cgi?id=19519</a><br><a href="https://sourceware.org/bugzilla/show_bug.cgi?id=19519#c21">https://sourceware.org/bugzilla/show_bug.cgi?id=19519#c21</a><br><a href="https://sourceware.org/bugzilla/show_bug.cgi?id=26224">https://sourceware.org/bugzilla/show_bug.cgi?id=26224</a><br></details>  |
| multiarch-support         |    CVE-2016-10739   |   LOW  |  2.27-3ubuntu1.4 |  | <details><summary>Expand...</summary><a href="http://lists.opensuse.org/opensuse-security-announce/2019-04/msg00082.html">http://lists.opensuse.org/opensuse-security-announce/2019-04/msg00082.html</a><br><a href="http://www.securityfocus.com/bid/106672">http://www.securityfocus.com/bid/106672</a><br><a href="https://access.redhat.com/errata/RHSA-2019:2118">https://access.redhat.com/errata/RHSA-2019:2118</a><br><a href="https://access.redhat.com/errata/RHSA-2019:3513">https://access.redhat.com/errata/RHSA-2019:3513</a><br><a href="https://bugzilla.redhat.com/show_bug.cgi?id=1347549">https://bugzilla.redhat.com/show_bug.cgi?id=1347549</a><br><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2016-10739">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2016-10739</a><br><a href="https://linux.oracle.com/cve/CVE-2016-10739.html">https://linux.oracle.com/cve/CVE-2016-10739.html</a><br><a href="https://linux.oracle.com/errata/ELSA-2019-3513.html">https://linux.oracle.com/errata/ELSA-2019-3513.html</a><br><a href="https://sourceware.org/bugzilla/show_bug.cgi?id=20018">https://sourceware.org/bugzilla/show_bug.cgi?id=20018</a><br></details>  |
| multiarch-support         |    CVE-2019-25013   |   LOW  |  2.27-3ubuntu1.4 |  | <details><summary>Expand...</summary><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2019-25013">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2019-25013</a><br><a href="https://linux.oracle.com/cve/CVE-2019-25013.html">https://linux.oracle.com/cve/CVE-2019-25013.html</a><br><a href="https://linux.oracle.com/errata/ELSA-2021-9344.html">https://linux.oracle.com/errata/ELSA-2021-9344.html</a><br><a href="https://lists.apache.org/thread.html/r32d767ac804e9b8aad4355bb85960a6a1385eab7afff549a5e98660f@%3Cjira.kafka.apache.org%3E">https://lists.apache.org/thread.html/r32d767ac804e9b8aad4355bb85960a6a1385eab7afff549a5e98660f@%3Cjira.kafka.apache.org%3E</a><br><a href="https://lists.apache.org/thread.html/r448bb851cc8e6e3f93f3c28c70032b37062625d81214744474ac49e7@%3Cdev.kafka.apache.org%3E">https://lists.apache.org/thread.html/r448bb851cc8e6e3f93f3c28c70032b37062625d81214744474ac49e7@%3Cdev.kafka.apache.org%3E</a><br><a href="https://lists.apache.org/thread.html/r4806a391091e082bdea17266452ca656ebc176e51bb3932733b3a0a2@%3Cjira.kafka.apache.org%3E">https://lists.apache.org/thread.html/r4806a391091e082bdea17266452ca656ebc176e51bb3932733b3a0a2@%3Cjira.kafka.apache.org%3E</a><br><a href="https://lists.apache.org/thread.html/r499e4f96d0b5109ef083f2feccd33c51650c1b7d7068aa3bd47efca9@%3Cjira.kafka.apache.org%3E">https://lists.apache.org/thread.html/r499e4f96d0b5109ef083f2feccd33c51650c1b7d7068aa3bd47efca9@%3Cjira.kafka.apache.org%3E</a><br><a href="https://lists.apache.org/thread.html/r5af4430421bb6f9973294691a7904bbd260937e9eef96b20556f43ff@%3Cjira.kafka.apache.org%3E">https://lists.apache.org/thread.html/r5af4430421bb6f9973294691a7904bbd260937e9eef96b20556f43ff@%3Cjira.kafka.apache.org%3E</a><br><a href="https://lists.apache.org/thread.html/r750eee18542bc02bd8350861c424ee60a9b9b225568fa09436a37ece@%3Cissues.zookeeper.apache.org%3E">https://lists.apache.org/thread.html/r750eee18542bc02bd8350861c424ee60a9b9b225568fa09436a37ece@%3Cissues.zookeeper.apache.org%3E</a><br><a href="https://lists.apache.org/thread.html/r7a2e94adfe0a2f0a1d42e4927e8c32ecac97d37db9cb68095fe9ddbc@%3Cdev.zookeeper.apache.org%3E">https://lists.apache.org/thread.html/r7a2e94adfe0a2f0a1d42e4927e8c32ecac97d37db9cb68095fe9ddbc@%3Cdev.zookeeper.apache.org%3E</a><br><a href="https://lists.apache.org/thread.html/rd2354f9ccce41e494fbadcbc5ad87218de6ec0fff8a7b54c8462226c@%3Cissues.zookeeper.apache.org%3E">https://lists.apache.org/thread.html/rd2354f9ccce41e494fbadcbc5ad87218de6ec0fff8a7b54c8462226c@%3Cissues.zookeeper.apache.org%3E</a><br><a href="https://lists.apache.org/thread.html/rf9fa47ab66495c78bb4120b0754dd9531ca2ff0430f6685ac9b07772@%3Cdev.mina.apache.org%3E">https://lists.apache.org/thread.html/rf9fa47ab66495c78bb4120b0754dd9531ca2ff0430f6685ac9b07772@%3Cdev.mina.apache.org%3E</a><br><a href="https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/4Y6TX47P47KABSFOL26FLDNVCWXDKDEZ/">https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/4Y6TX47P47KABSFOL26FLDNVCWXDKDEZ/</a><br><a href="https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/TVCUNLQ3HXGS4VPUQKWTJGRAW2KTFGXS/">https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/TVCUNLQ3HXGS4VPUQKWTJGRAW2KTFGXS/</a><br><a href="https://security.netapp.com/advisory/ntap-20210205-0004/">https://security.netapp.com/advisory/ntap-20210205-0004/</a><br><a href="https://sourceware.org/bugzilla/show_bug.cgi?id=24973">https://sourceware.org/bugzilla/show_bug.cgi?id=24973</a><br><a href="https://sourceware.org/git/?p=glibc.git;a=commit;h=ee7a3144c9922808181009b7b3e50e852fb4999b">https://sourceware.org/git/?p=glibc.git;a=commit;h=ee7a3144c9922808181009b7b3e50e852fb4999b</a><br></details>  |
| multiarch-support         |    CVE-2020-27618   |   LOW  |  2.27-3ubuntu1.4 |  | <details><summary>Expand...</summary><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2020-27618">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2020-27618</a><br><a href="https://linux.oracle.com/cve/CVE-2020-27618.html">https://linux.oracle.com/cve/CVE-2020-27618.html</a><br><a href="https://linux.oracle.com/errata/ELSA-2021-9344.html">https://linux.oracle.com/errata/ELSA-2021-9344.html</a><br><a href="https://security.netapp.com/advisory/ntap-20210401-0006/">https://security.netapp.com/advisory/ntap-20210401-0006/</a><br><a href="https://sourceware.org/bugzilla/show_bug.cgi?id=19519#c21">https://sourceware.org/bugzilla/show_bug.cgi?id=19519#c21</a><br><a href="https://sourceware.org/bugzilla/show_bug.cgi?id=26224">https://sourceware.org/bugzilla/show_bug.cgi?id=26224</a><br></details>  |
| multiarch-support         |    CVE-2020-6096   |   LOW  |  2.27-3ubuntu1.4 |  | <details><summary>Expand...</summary><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2020-6096">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2020-6096</a><br><a href="https://lists.apache.org/thread.html/rf9fa47ab66495c78bb4120b0754dd9531ca2ff0430f6685ac9b07772@%3Cdev.mina.apache.org%3E">https://lists.apache.org/thread.html/rf9fa47ab66495c78bb4120b0754dd9531ca2ff0430f6685ac9b07772@%3Cdev.mina.apache.org%3E</a><br><a href="https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/SPYXTDOOB4PQGTYAMZAZNJIB3FF6YQXI/">https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/SPYXTDOOB4PQGTYAMZAZNJIB3FF6YQXI/</a><br><a href="https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/URXOIA2LDUKHQXK4BE55BQBRI6ZZG3Y6/">https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/URXOIA2LDUKHQXK4BE55BQBRI6ZZG3Y6/</a><br><a href="https://security.gentoo.org/glsa/202101-20">https://security.gentoo.org/glsa/202101-20</a><br><a href="https://sourceware.org/bugzilla/attachment.cgi?id=12334">https://sourceware.org/bugzilla/attachment.cgi?id=12334</a><br><a href="https://sourceware.org/bugzilla/show_bug.cgi?id=25620">https://sourceware.org/bugzilla/show_bug.cgi?id=25620</a><br><a href="https://talosintelligence.com/vulnerability_reports/TALOS-2020-1019">https://talosintelligence.com/vulnerability_reports/TALOS-2020-1019</a><br><a href="https://ubuntu.com/security/notices/USN-4954-1">https://ubuntu.com/security/notices/USN-4954-1</a><br><a href="https://www.talosintelligence.com/vulnerability_reports/TALOS-2020-1019">https://www.talosintelligence.com/vulnerability_reports/TALOS-2020-1019</a><br></details>  |
| multiarch-support         |    CVE-2021-3326   |   LOW  |  2.27-3ubuntu1.4 |  | <details><summary>Expand...</summary><a href="http://www.openwall.com/lists/oss-security/2021/01/28/2">http://www.openwall.com/lists/oss-security/2021/01/28/2</a><br><a href="https://bugs.chromium.org/p/project-zero/issues/detail?id=2146">https://bugs.chromium.org/p/project-zero/issues/detail?id=2146</a><br><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2021-3326">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2021-3326</a><br><a href="https://linux.oracle.com/cve/CVE-2021-3326.html">https://linux.oracle.com/cve/CVE-2021-3326.html</a><br><a href="https://linux.oracle.com/errata/ELSA-2021-9344.html">https://linux.oracle.com/errata/ELSA-2021-9344.html</a><br><a href="https://security.netapp.com/advisory/ntap-20210304-0007/">https://security.netapp.com/advisory/ntap-20210304-0007/</a><br><a href="https://sourceware.org/bugzilla/show_bug.cgi?id=27256">https://sourceware.org/bugzilla/show_bug.cgi?id=27256</a><br><a href="https://sourceware.org/git/?p=glibc.git;a=commit;h=7d88c6142c6efc160c0ee5e4f85cde382c072888">https://sourceware.org/git/?p=glibc.git;a=commit;h=7d88c6142c6efc160c0ee5e4f85cde382c072888</a><br><a href="https://sourceware.org/pipermail/libc-alpha/2021-January/122058.html">https://sourceware.org/pipermail/libc-alpha/2021-January/122058.html</a><br></details>  |
| multiarch-support         |    CVE-2021-33574   |   LOW  |  2.27-3ubuntu1.4 |  | <details><summary>Expand...</summary><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2021-33574">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2021-33574</a><br><a href="https://linux.oracle.com/cve/CVE-2021-33574.html">https://linux.oracle.com/cve/CVE-2021-33574.html</a><br><a href="https://linux.oracle.com/errata/ELSA-2021-9560.html">https://linux.oracle.com/errata/ELSA-2021-9560.html</a><br><a href="https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/RBUUWUGXVILQXVWEOU7N42ICHPJNAEUP/">https://lists.fedoraproject.org/archives/list/package-announce@lists.fedoraproject.org/message/RBUUWUGXVILQXVWEOU7N42ICHPJNAEUP/</a><br><a href="https://security.gentoo.org/glsa/202107-07">https://security.gentoo.org/glsa/202107-07</a><br><a href="https://security.netapp.com/advisory/ntap-20210629-0005/">https://security.netapp.com/advisory/ntap-20210629-0005/</a><br><a href="https://sourceware.org/bugzilla/show_bug.cgi?id=27896">https://sourceware.org/bugzilla/show_bug.cgi?id=27896</a><br><a href="https://sourceware.org/bugzilla/show_bug.cgi?id=27896#c1">https://sourceware.org/bugzilla/show_bug.cgi?id=27896#c1</a><br></details>  |
| ncurses-base         |    CVE-2019-17594   |   LOW  |  6.1-1ubuntu1.18.04 |  | <details><summary>Expand...</summary><a href="http://lists.opensuse.org/opensuse-security-announce/2019-11/msg00059.html">http://lists.opensuse.org/opensuse-security-announce/2019-11/msg00059.html</a><br><a href="http://lists.opensuse.org/opensuse-security-announce/2019-11/msg00061.html">http://lists.opensuse.org/opensuse-security-announce/2019-11/msg00061.html</a><br><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2019-17594">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2019-17594</a><br><a href="https://linux.oracle.com/cve/CVE-2019-17594.html">https://linux.oracle.com/cve/CVE-2019-17594.html</a><br><a href="https://linux.oracle.com/errata/ELSA-2021-4426.html">https://linux.oracle.com/errata/ELSA-2021-4426.html</a><br><a href="https://lists.gnu.org/archive/html/bug-ncurses/2019-10/msg00017.html">https://lists.gnu.org/archive/html/bug-ncurses/2019-10/msg00017.html</a><br><a href="https://lists.gnu.org/archive/html/bug-ncurses/2019-10/msg00045.html">https://lists.gnu.org/archive/html/bug-ncurses/2019-10/msg00045.html</a><br><a href="https://security.gentoo.org/glsa/202101-28">https://security.gentoo.org/glsa/202101-28</a><br></details>  |
| ncurses-base         |    CVE-2019-17595   |   LOW  |  6.1-1ubuntu1.18.04 |  | <details><summary>Expand...</summary><a href="http://lists.opensuse.org/opensuse-security-announce/2019-11/msg00059.html">http://lists.opensuse.org/opensuse-security-announce/2019-11/msg00059.html</a><br><a href="http://lists.opensuse.org/opensuse-security-announce/2019-11/msg00061.html">http://lists.opensuse.org/opensuse-security-announce/2019-11/msg00061.html</a><br><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2019-17595">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2019-17595</a><br><a href="https://linux.oracle.com/cve/CVE-2019-17595.html">https://linux.oracle.com/cve/CVE-2019-17595.html</a><br><a href="https://linux.oracle.com/errata/ELSA-2021-4426.html">https://linux.oracle.com/errata/ELSA-2021-4426.html</a><br><a href="https://lists.gnu.org/archive/html/bug-ncurses/2019-10/msg00013.html">https://lists.gnu.org/archive/html/bug-ncurses/2019-10/msg00013.html</a><br><a href="https://lists.gnu.org/archive/html/bug-ncurses/2019-10/msg00045.html">https://lists.gnu.org/archive/html/bug-ncurses/2019-10/msg00045.html</a><br><a href="https://security.gentoo.org/glsa/202101-28">https://security.gentoo.org/glsa/202101-28</a><br></details>  |
| ncurses-bin         |    CVE-2019-17594   |   LOW  |  6.1-1ubuntu1.18.04 |  | <details><summary>Expand...</summary><a href="http://lists.opensuse.org/opensuse-security-announce/2019-11/msg00059.html">http://lists.opensuse.org/opensuse-security-announce/2019-11/msg00059.html</a><br><a href="http://lists.opensuse.org/opensuse-security-announce/2019-11/msg00061.html">http://lists.opensuse.org/opensuse-security-announce/2019-11/msg00061.html</a><br><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2019-17594">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2019-17594</a><br><a href="https://linux.oracle.com/cve/CVE-2019-17594.html">https://linux.oracle.com/cve/CVE-2019-17594.html</a><br><a href="https://linux.oracle.com/errata/ELSA-2021-4426.html">https://linux.oracle.com/errata/ELSA-2021-4426.html</a><br><a href="https://lists.gnu.org/archive/html/bug-ncurses/2019-10/msg00017.html">https://lists.gnu.org/archive/html/bug-ncurses/2019-10/msg00017.html</a><br><a href="https://lists.gnu.org/archive/html/bug-ncurses/2019-10/msg00045.html">https://lists.gnu.org/archive/html/bug-ncurses/2019-10/msg00045.html</a><br><a href="https://security.gentoo.org/glsa/202101-28">https://security.gentoo.org/glsa/202101-28</a><br></details>  |
| ncurses-bin         |    CVE-2019-17595   |   LOW  |  6.1-1ubuntu1.18.04 |  | <details><summary>Expand...</summary><a href="http://lists.opensuse.org/opensuse-security-announce/2019-11/msg00059.html">http://lists.opensuse.org/opensuse-security-announce/2019-11/msg00059.html</a><br><a href="http://lists.opensuse.org/opensuse-security-announce/2019-11/msg00061.html">http://lists.opensuse.org/opensuse-security-announce/2019-11/msg00061.html</a><br><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2019-17595">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2019-17595</a><br><a href="https://linux.oracle.com/cve/CVE-2019-17595.html">https://linux.oracle.com/cve/CVE-2019-17595.html</a><br><a href="https://linux.oracle.com/errata/ELSA-2021-4426.html">https://linux.oracle.com/errata/ELSA-2021-4426.html</a><br><a href="https://lists.gnu.org/archive/html/bug-ncurses/2019-10/msg00013.html">https://lists.gnu.org/archive/html/bug-ncurses/2019-10/msg00013.html</a><br><a href="https://lists.gnu.org/archive/html/bug-ncurses/2019-10/msg00045.html">https://lists.gnu.org/archive/html/bug-ncurses/2019-10/msg00045.html</a><br><a href="https://security.gentoo.org/glsa/202101-28">https://security.gentoo.org/glsa/202101-28</a><br></details>  |
| passwd         |    CVE-2013-4235   |   LOW  |  1:4.5-1ubuntu2 |  | <details><summary>Expand...</summary><a href="https://access.redhat.com/security/cve/cve-2013-4235">https://access.redhat.com/security/cve/cve-2013-4235</a><br><a href="https://bugzilla.redhat.com/show_bug.cgi?id=CVE-2013-4235">https://bugzilla.redhat.com/show_bug.cgi?id=CVE-2013-4235</a><br><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2013-4235">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2013-4235</a><br><a href="https://lists.apache.org/thread.html/rf9fa47ab66495c78bb4120b0754dd9531ca2ff0430f6685ac9b07772@%3Cdev.mina.apache.org%3E">https://lists.apache.org/thread.html/rf9fa47ab66495c78bb4120b0754dd9531ca2ff0430f6685ac9b07772@%3Cdev.mina.apache.org%3E</a><br><a href="https://security-tracker.debian.org/tracker/CVE-2013-4235">https://security-tracker.debian.org/tracker/CVE-2013-4235</a><br></details>  |
| passwd         |    CVE-2018-7169   |   LOW  |  1:4.5-1ubuntu2 |  | <details><summary>Expand...</summary><a href="https://bugs.launchpad.net/ubuntu/+source/shadow/+bug/1729357">https://bugs.launchpad.net/ubuntu/+source/shadow/+bug/1729357</a><br><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2018-7169">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2018-7169</a><br><a href="https://github.com/shadow-maint/shadow/pull/97">https://github.com/shadow-maint/shadow/pull/97</a><br><a href="https://security.gentoo.org/glsa/201805-09">https://security.gentoo.org/glsa/201805-09</a><br></details>  |
| patch         |    CVE-2018-6952   |   LOW  |  2.7.6-2ubuntu1.1 |  | <details><summary>Expand...</summary><a href="http://www.securityfocus.com/bid/103047">http://www.securityfocus.com/bid/103047</a><br><a href="https://access.redhat.com/errata/RHSA-2019:2033">https://access.redhat.com/errata/RHSA-2019:2033</a><br><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2018-6952">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2018-6952</a><br><a href="https://linux.oracle.com/cve/CVE-2018-6952.html">https://linux.oracle.com/cve/CVE-2018-6952.html</a><br><a href="https://linux.oracle.com/errata/ELSA-2019-2033.html">https://linux.oracle.com/errata/ELSA-2019-2033.html</a><br><a href="https://savannah.gnu.org/bugs/index.php?53133">https://savannah.gnu.org/bugs/index.php?53133</a><br><a href="https://security.gentoo.org/glsa/201904-17">https://security.gentoo.org/glsa/201904-17</a><br></details>  |
| perl         |    CVE-2020-16156   |   MEDIUM  |  5.26.1-6ubuntu0.5 |  | <details><summary>Expand...</summary><a href="http://blogs.perl.org/users/neilb/2021/11/addressing-cpan-vulnerabilities-related-to-checksums.html">http://blogs.perl.org/users/neilb/2021/11/addressing-cpan-vulnerabilities-related-to-checksums.html</a><br><a href="https://blog.hackeriet.no/cpan-signature-verification-vulnerabilities/">https://blog.hackeriet.no/cpan-signature-verification-vulnerabilities/</a><br><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2020-16156">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2020-16156</a><br><a href="https://github.com/andk/cpanpm/commit/b27c51adf0fda25dee84cb72cb2b1bf7d832148c">https://github.com/andk/cpanpm/commit/b27c51adf0fda25dee84cb72cb2b1bf7d832148c</a><br><a href="https://metacpan.org/pod/distribution/CPAN/scripts/cpan">https://metacpan.org/pod/distribution/CPAN/scripts/cpan</a><br></details>  |
| perl-base         |    CVE-2020-16156   |   MEDIUM  |  5.26.1-6ubuntu0.5 |  | <details><summary>Expand...</summary><a href="http://blogs.perl.org/users/neilb/2021/11/addressing-cpan-vulnerabilities-related-to-checksums.html">http://blogs.perl.org/users/neilb/2021/11/addressing-cpan-vulnerabilities-related-to-checksums.html</a><br><a href="https://blog.hackeriet.no/cpan-signature-verification-vulnerabilities/">https://blog.hackeriet.no/cpan-signature-verification-vulnerabilities/</a><br><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2020-16156">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2020-16156</a><br><a href="https://github.com/andk/cpanpm/commit/b27c51adf0fda25dee84cb72cb2b1bf7d832148c">https://github.com/andk/cpanpm/commit/b27c51adf0fda25dee84cb72cb2b1bf7d832148c</a><br><a href="https://metacpan.org/pod/distribution/CPAN/scripts/cpan">https://metacpan.org/pod/distribution/CPAN/scripts/cpan</a><br></details>  |
| perl-modules-5.26         |    CVE-2020-16156   |   MEDIUM  |  5.26.1-6ubuntu0.5 |  | <details><summary>Expand...</summary><a href="http://blogs.perl.org/users/neilb/2021/11/addressing-cpan-vulnerabilities-related-to-checksums.html">http://blogs.perl.org/users/neilb/2021/11/addressing-cpan-vulnerabilities-related-to-checksums.html</a><br><a href="https://blog.hackeriet.no/cpan-signature-verification-vulnerabilities/">https://blog.hackeriet.no/cpan-signature-verification-vulnerabilities/</a><br><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2020-16156">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2020-16156</a><br><a href="https://github.com/andk/cpanpm/commit/b27c51adf0fda25dee84cb72cb2b1bf7d832148c">https://github.com/andk/cpanpm/commit/b27c51adf0fda25dee84cb72cb2b1bf7d832148c</a><br><a href="https://metacpan.org/pod/distribution/CPAN/scripts/cpan">https://metacpan.org/pod/distribution/CPAN/scripts/cpan</a><br></details>  |
| xdg-user-dirs         |    CVE-2017-15131   |   LOW  |  0.17-1ubuntu1 |  | <details><summary>Expand...</summary><a href="http://bugs.freedesktop.org/show_bug.cgi?id=102303">http://bugs.freedesktop.org/show_bug.cgi?id=102303</a><br><a href="https://access.redhat.com/errata/RHSA-2018:0842">https://access.redhat.com/errata/RHSA-2018:0842</a><br><a href="https://bugzilla.redhat.com/show_bug.cgi?id=1412762">https://bugzilla.redhat.com/show_bug.cgi?id=1412762</a><br><a href="https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2017-15131">https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2017-15131</a><br><a href="https://linux.oracle.com/cve/CVE-2017-15131.html">https://linux.oracle.com/cve/CVE-2017-15131.html</a><br><a href="https://linux.oracle.com/errata/ELSA-2018-0842.html">https://linux.oracle.com/errata/ELSA-2018-0842.html</a><br><a href="https://lists.apache.org/thread.html/rf9fa47ab66495c78bb4120b0754dd9531ca2ff0430f6685ac9b07772@%3Cdev.mina.apache.org%3E">https://lists.apache.org/thread.html/rf9fa47ab66495c78bb4120b0754dd9531ca2ff0430f6685ac9b07772@%3Cdev.mina.apache.org%3E</a><br></details>  |

